(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    664508,      14281]
NotebookOptionsPosition[    650012,      14062]
NotebookOutlinePosition[    650383,      14078]
CellTagsIndexPosition[    650340,      14075]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "Section",
 CellChangeTimes->{{3.7812739573149953`*^9, 
  3.7812739586334505`*^9}},ExpressionUUID->"76f44a64-3640-4015-853c-\
253782a1e72b"],

Cell["\<\
This document comprises the calculations done for the project that relate to \
gravity and pressure.
It is subdivided in 5 chapters: Non-uniformity of gravity; Calculation of \
gravity and pressure; Density; Calculating the balloon sizes; Actually \
calculating the balloon sizes

For those who are unfamiliar with how Wolfram Mathematica works, it should \
suffice to \[OpenCurlyQuote]select all\[CloseCurlyQuote] using ctrl+A and \
then execute using shift+enter. You will be able to see the most relevant \
calculations.
If you want to ask Mathematica to display a particular value, say, the value \
assigned to g, simply type in a new line:\
\>", "Text",
 CellChangeTimes->{{3.7812739497561917`*^9, 3.781274167301464*^9}, {
  3.781274724144327*^9, 
  3.7812748149684734`*^9}},ExpressionUUID->"8ace106f-1d12-470d-8a18-\
390a34dc8036"],

Cell[BoxData["g"], "Input",
 CellChangeTimes->{
  3.781274155869037*^9},ExpressionUUID->"55847610-67ca-4f38-aeb1-\
a844655f3306"],

Cell["\<\
And then execute.
Furthermore, output can be suppressed by ending a command line with a \
semicolon (;), like this:\
\>", "Text",
 CellChangeTimes->{{3.781274157861676*^9, 3.7812742068616753`*^9}, {
  3.7812748282260017`*^9, 
  3.781274832652175*^9}},ExpressionUUID->"d99e1840-adba-448c-843c-\
48952433b680"],

Cell[BoxData[
 RowBox[{"g", ";"}]], "Input",
 CellChangeTimes->{{3.781274208274867*^9, 
  3.7812742092921734`*^9}},ExpressionUUID->"d1d0f014-0b03-4cf0-b945-\
7788706b1f9f"],

Cell["\<\
You will see that there is no output. In principle, that\[CloseCurlyQuote]s \
all you\[CloseCurlyQuote]ll need to be able to look at the results of the \
calculations. If you want to do more manipulations, you can open the \
Mathematica Help Browser by pressing F1 or clicking the \[OpenCurlyQuote]Help\
\[CloseCurlyQuote] button in the toolbar above.\
\>", "Text",
 CellChangeTimes->{{3.781274210947714*^9, 
  3.781274290385316*^9}},ExpressionUUID->"10dcd794-0ded-4b17-98b6-\
28c3bd4c2b45"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non-uniformity of gravity", "Section",
 CellChangeTimes->{{3.781273375962823*^9, 
  3.781273381001365*^9}},ExpressionUUID->"2c949d39-4642-4878-b2d5-\
425a5476d010"],

Cell["\<\
Orbit and size data of  the earth and its moon, Jupiter and Europa, and the \
sun.
Capital R indicates an orbital radius, small r indicates a planetary radius.\
\>", "Text",
 CellChangeTimes->{{3.781271762426731*^9, 3.781271822165975*^9}, {
  3.7812718569250555`*^9, 
  3.781271885279233*^9}},ExpressionUUID->"7aa7650f-8547-41cc-b663-\
6c05ba659465"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G", "=", 
   RowBox[{"6.67408", "*", 
    RowBox[{"10", "^", 
     RowBox[{"-", "11"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", "9.81"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rEur", "=", "1560800"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rMoon", "=", "1737500"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"REur", "=", "671100000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RMoon", "=", "384400000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rMars", "=", "3389500"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MEur", "=", 
   RowBox[{"4.7988", "*", 
    RowBox[{"10", "^", "22"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MJup", "=", 
   RowBox[{"1.898", "*", 
    RowBox[{"10", "^", "27"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MMoon", "=", 
   RowBox[{"7.3477", "*", 
    RowBox[{"10", "^", "22"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MEarth", "=", 
   RowBox[{"5.9722", "*", 
    RowBox[{"10", "^", "24"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MMars", "=", 
   RowBox[{"6.4169", "*", 
    RowBox[{"10", "^", "23"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MSun", "=", 
   RowBox[{"1.989", "*", 
    RowBox[{"10", "^", "30"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r0", "=", "1400000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rc", "=", "1550000"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7765995798282022`*^9, 3.77659958692031*^9}, {
  3.7765999102435884`*^9, 3.7765999131009617`*^9}, {3.7766608641166277`*^9, 
  3.7766609773548155`*^9}, {3.7766610567501173`*^9, 3.776661088054671*^9}, {
  3.7774546235768995`*^9, 3.777454634313686*^9}, {3.778734810474069*^9, 
  3.778734846122781*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"9b62f570-9d32-43d0-bb28-041fb8721c0e"],

Cell["\<\
Gravitational accelerations.
XAtY indicates an acceleration on planetoid Y as a consequence of X\
\[CloseCurlyQuote]s gravity.\
\>", "Text",
 CellChangeTimes->{{3.781271902088249*^9, 
  3.781271956664302*^9}},ExpressionUUID->"52ffb717-368c-4b9d-a782-\
f77549e168ac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EurAtEur", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MEur", "/", 
    RowBox[{"rEur", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"JupAtEur", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MJup", "/", 
    RowBox[{"REur", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"MoonAtMoon", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MMoon", "/", 
    RowBox[{"rMoon", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EarthAtMoon", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MEarth", "/", 
    RowBox[{"RMoon", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"MarsAtMars", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MMars", "/", 
    RowBox[{"rMars", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"SunAtEarth", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MSun", "/", 
    RowBox[{"149597871000", "^", "2"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.776599393925168*^9, 3.77659942793458*^9}, {
   3.776599590166624*^9, 3.776599606429244*^9}, {3.776599811023444*^9, 
   3.7765998856841383`*^9}, {3.776601646517497*^9, 3.776601692654248*^9}, 
   3.776660682250584*^9, {3.7766610090713873`*^9, 3.7766610699699244`*^9}, {
   3.777454659287791*^9, 3.7774547266264544`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"eed5f51d-b24e-4bcb-adb5-f363a6ffff8f"],

Cell[BoxData["1.3147087261694181`"], "Output",
 CellChangeTimes->{
  3.776599429674944*^9, 3.776599607075573*^9, 3.7765998820957174`*^9, 
   3.7766016936036987`*^9, 3.7766606789701047`*^9, {3.776661076436965*^9, 
   3.776661092772132*^9}, 3.777450633918058*^9, {3.777454667844857*^9, 
   3.777454691161224*^9}, 3.777454727252983*^9, 3.7787347972843904`*^9, 
   3.778734827757903*^9, 3.778746549800974*^9, 3.779601561387209*^9, {
   3.780332720552759*^9, 3.7803327234555283`*^9}, 3.7803670421501064`*^9, 
   3.7803759818879375`*^9, 3.780389365618781*^9, 3.7805715510167575`*^9, 
   3.780573827680898*^9, 3.7812690524962*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"f0b793c1-aad1-4a59-aecf-b85321ad2e3c"],

Cell[BoxData["0.28126334573343853`"], "Output",
 CellChangeTimes->{
  3.776599429674944*^9, 3.776599607075573*^9, 3.7765998820957174`*^9, 
   3.7766016936036987`*^9, 3.7766606789701047`*^9, {3.776661076436965*^9, 
   3.776661092772132*^9}, 3.777450633918058*^9, {3.777454667844857*^9, 
   3.777454691161224*^9}, 3.777454727252983*^9, 3.7787347972843904`*^9, 
   3.778734827757903*^9, 3.778746549800974*^9, 3.779601561387209*^9, {
   3.780332720552759*^9, 3.7803327234555283`*^9}, 3.7803670421501064`*^9, 
   3.7803759818879375`*^9, 3.780389365618781*^9, 3.7805715510167575`*^9, 
   3.780573827680898*^9, 3.781269052502184*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"c9bfaff2-affa-4aff-87c9-60b852aa79a3"],

Cell[BoxData["1.6244008112540755`"], "Output",
 CellChangeTimes->{
  3.776599429674944*^9, 3.776599607075573*^9, 3.7765998820957174`*^9, 
   3.7766016936036987`*^9, 3.7766606789701047`*^9, {3.776661076436965*^9, 
   3.776661092772132*^9}, 3.777450633918058*^9, {3.777454667844857*^9, 
   3.777454691161224*^9}, 3.777454727252983*^9, 3.7787347972843904`*^9, 
   3.778734827757903*^9, 3.778746549800974*^9, 3.779601561387209*^9, {
   3.780332720552759*^9, 3.7803327234555283`*^9}, 3.7803670421501064`*^9, 
   3.7803759818879375`*^9, 3.780389365618781*^9, 3.7805715510167575`*^9, 
   3.780573827680898*^9, 3.7812690525052075`*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"b30ab26f-94d8-47d2-8ad0-ea5b223a7330"],

Cell[BoxData["0.0026974847198926715`"], "Output",
 CellChangeTimes->{
  3.776599429674944*^9, 3.776599607075573*^9, 3.7765998820957174`*^9, 
   3.7766016936036987`*^9, 3.7766606789701047`*^9, {3.776661076436965*^9, 
   3.776661092772132*^9}, 3.777450633918058*^9, {3.777454667844857*^9, 
   3.777454691161224*^9}, 3.777454727252983*^9, 3.7787347972843904`*^9, 
   3.778734827757903*^9, 3.778746549800974*^9, 3.779601561387209*^9, {
   3.780332720552759*^9, 3.7803327234555283`*^9}, 3.7803670421501064`*^9, 
   3.7803759818879375`*^9, 3.780389365618781*^9, 3.7805715510167575`*^9, 
   3.780573827680898*^9, 3.781269052509201*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"20a8bd31-123e-4d01-ab27-148237066307"],

Cell[BoxData["3.727738189933025`"], "Output",
 CellChangeTimes->{
  3.776599429674944*^9, 3.776599607075573*^9, 3.7765998820957174`*^9, 
   3.7766016936036987`*^9, 3.7766606789701047`*^9, {3.776661076436965*^9, 
   3.776661092772132*^9}, 3.777450633918058*^9, {3.777454667844857*^9, 
   3.777454691161224*^9}, 3.777454727252983*^9, 3.7787347972843904`*^9, 
   3.778734827757903*^9, 3.778746549800974*^9, 3.779601561387209*^9, {
   3.780332720552759*^9, 3.7803327234555283`*^9}, 3.7803670421501064`*^9, 
   3.7803759818879375`*^9, 3.780389365618781*^9, 3.7805715510167575`*^9, 
   3.780573827680898*^9, 3.7812690525141525`*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"1fb743bc-97af-4f3e-83cc-ffa4df6b4d77"],

Cell[BoxData["0.005931647924494758`"], "Output",
 CellChangeTimes->{
  3.776599429674944*^9, 3.776599607075573*^9, 3.7765998820957174`*^9, 
   3.7766016936036987`*^9, 3.7766606789701047`*^9, {3.776661076436965*^9, 
   3.776661092772132*^9}, 3.777450633918058*^9, {3.777454667844857*^9, 
   3.777454691161224*^9}, 3.777454727252983*^9, 3.7787347972843904`*^9, 
   3.778734827757903*^9, 3.778746549800974*^9, 3.779601561387209*^9, {
   3.780332720552759*^9, 3.7803327234555283`*^9}, 3.7803670421501064`*^9, 
   3.7803759818879375`*^9, 3.780389365618781*^9, 3.7805715510167575`*^9, 
   3.780573827680898*^9, 3.7812690525181413`*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"4e10d356-43cf-4924-9244-388a899b8bb2"]
}, Open  ]],

Cell["Accelerations as fractions of 1 G.", "Text",
 CellChangeTimes->{{3.7812719659026203`*^9, 
  3.781271976618965*^9}},ExpressionUUID->"1b02befe-9f27-4d7b-9b86-\
fd7d7ba37a76"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EurAtEur", "/", "g"}], "\[IndentingNewLine]", 
 RowBox[{"MoonAtMoon", "/", "g"}]}], "Input",
 CellChangeTimes->{{3.776599901599661*^9, 3.776599931536785*^9}, {
  3.776602034107414*^9, 3.776602034321846*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"9d88ee5c-dd9f-41fc-b63c-1319bff39f23"],

Cell[BoxData["0.13401719940564913`"], "Output",
 CellChangeTimes->{3.77659993263982*^9, 3.7766020356163893`*^9, 
  3.7766606858185806`*^9, 3.7796015614281*^9, 3.780332723523347*^9, 
  3.780367042195983*^9, 3.7803759819449434`*^9, 3.780389365665075*^9, 
  3.78057155109037*^9, 3.7805738277476196`*^9, 3.781269052554124*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"606b3597-d7c7-40b4-bf8c-c24951597b83"],

Cell[BoxData["0.1655862192919547`"], "Output",
 CellChangeTimes->{3.77659993263982*^9, 3.7766020356163893`*^9, 
  3.7766606858185806`*^9, 3.7796015614281*^9, 3.780332723523347*^9, 
  3.780367042195983*^9, 3.7803759819449434`*^9, 3.780389365665075*^9, 
  3.78057155109037*^9, 3.7805738277476196`*^9, 3.7812690525600815`*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"68b4fa3c-ddb8-4620-9874-bfdb481071fd"]
}, Open  ]],

Cell["Differences between planet and moon gravities.", "Text",
 CellChangeTimes->{{3.781272027413132*^9, 
  3.7812720735756693`*^9}},ExpressionUUID->"cad05219-547c-4eb4-a8a0-\
097140813e89"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"EurAtEur", "-", "JupAtEur"}], ")"}], "/", 
  "g"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"MoonAtMoon", "-", "EarthAtMoon"}], ")"}], "/", "g"}]}], "Input",
 CellChangeTimes->{{3.7765999556853027`*^9, 3.7765999629070272`*^9}, {
  3.7766020413910255`*^9, 3.7766020514282827`*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"b28fa99f-f261-4998-bd96-ae7ada529644"],

Cell[BoxData["0.10534611421365744`"], "Output",
 CellChangeTimes->{3.7765999632461224`*^9, 3.7766020519269323`*^9, 
  3.776660687818112*^9, 3.779601561448047*^9, 3.780332723567234*^9, 
  3.7803670422229595`*^9, 3.780375981985965*^9, 3.7803893656919484`*^9, 
  3.7805715511338053`*^9, 3.7805738277933054`*^9, 3.781269052593973*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"1dfb6d0b-55af-4d9f-824c-c5c2eb4baef4"],

Cell[BoxData["0.1653112463337597`"], "Output",
 CellChangeTimes->{3.7765999632461224`*^9, 3.7766020519269323`*^9, 
  3.776660687818112*^9, 3.779601561448047*^9, 3.780332723567234*^9, 
  3.7803670422229595`*^9, 3.780375981985965*^9, 3.7803893656919484`*^9, 
  3.7805715511338053`*^9, 3.7805738277933054`*^9, 3.7812690526029634`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"ed11f457-2745-446f-8b7e-85f6c8611822"]
}, Open  ]],

Cell["\<\
Vectorfield of the gravitational force inside Europa. Jupiter is to the right.\
\>", "Text",
 CellChangeTimes->{{3.7812720916333857`*^9, 3.781272095923896*^9}, {
  3.7812721267425137`*^9, 3.7812721385339456`*^9}, {3.7812723195867786`*^9, 
  3.781272322340412*^9}},ExpressionUUID->"3ea15f92-97af-40f3-be55-\
67f7aa441b32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"JupAtEur", "-", 
      RowBox[{"G", "*", 
       RowBox[{"MEur", "/", 
        RowBox[{"rEur", "^", "3"}]}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}], "*", "x"}]}], ",", 
     RowBox[{
      RowBox[{"-", "G"}], "*", 
      RowBox[{"MEur", "/", 
       RowBox[{"rEur", "^", "3"}]}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", 
        RowBox[{"y", "^", "2"}]}], "]"}], "*", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "rEur"}], ",", "rEur"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "rEur"}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}], "<", "rEur"}]}], "]"}]}], ",", 
   RowBox[{"VectorPoints", "\[Rule]", " ", "21"}], ",", 
   RowBox[{"VectorScale", "\[Rule]", " ", "0.1"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "rEur"}], ",", "rEur"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "rEur"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.776660690598892*^9, 3.7766606978077154`*^9}, {
   3.7766607735941157`*^9, 3.776660854306277*^9}, {3.776661104253971*^9, 
   3.7766611292654076`*^9}, 3.776661209398114*^9, {3.7766619433394184`*^9, 
   3.776662049316142*^9}, {3.77666212917439*^9, 3.7766621742736964`*^9}, 
   3.7766622336156626`*^9, {3.7766623789665265`*^9, 3.7766623866211395`*^9}, {
   3.7766624671940527`*^9, 3.776662548507372*^9}, {3.776662583176346*^9, 
   3.7766626509695716`*^9}, {3.7766626997670574`*^9, 
   3.7766627559252033`*^9}, {3.7766636806724243`*^9, 3.776663681547186*^9}, {
   3.776663921424923*^9, 3.776663973971198*^9}, {3.776664273915289*^9, 
   3.7766642772425966`*^9}, {3.7766643292779517`*^9, 
   3.7766643317773633`*^9}, {3.78127218840162*^9, 3.781272208739236*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"86e507a9-b397-4fb3-a36c-5ca6a54dbca0"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.05028020196201999, 1.}}], 
      ArrowBox[{{-1.6841920802794588`*^6, 
       1.684192068320081*^6}, {-1.437407919720541*^6, 
       1.437407931679919*^6}}]}, 
     {Arrowheads[{{0.02036348425369102, 1.}}], 
      ArrowBox[{{-1.4753936202449258`*^6, 0.}, {-1.3340463797550742`*^6, 
       0.}}]}, 
     {Arrowheads[{{0.0204263344977923, 1.}}], 
      ArrowBox[{{-1.4755026004303778`*^6, 
       81972.36602616668}, {-1.333937399569622*^6, 74107.63397383333}}]}, 
     {Arrowheads[{{0.02061488523024194, 1.}}], 
      ArrowBox[{{-1.475828538862433*^6, 
       163980.94743367282`}, {-1.333611461137567*^6, 148179.05256632718`}}]}, 
     {Arrowheads[{{0.020929136451466494`, 1.}}], 
      ArrowBox[{{-1.4763684746860955`*^6, 
       246061.41045445294`}, {-1.3330715253139047`*^6, 
       222178.58954554706`}}]}, 
     {Arrowheads[{{0.02136908816214184, 1.}}], 
      ArrowBox[{{-1.477117620131146*^6, 
       328248.35737150407`}, {-1.332322379868854*^6, 296071.642628496}}]}, 
     {Arrowheads[{{0.02193474036314588, 1.}}], 
      ArrowBox[{{-1.478069565277688*^6, 
       410574.8759217528}, {-1.331370434722312*^6, 369825.1240782472}}]}, 
     {Arrowheads[{{0.022626093055501416`, 1.}}], 
      ArrowBox[{{-1.4792165361743376`*^6, 
       493072.17473832}, {-1.3302234638256624`*^6, 443407.82526168006`}}]}, 
     {Arrowheads[{{0.023443146240316147`, 1.}}], 
      ArrowBox[{{-1.4805496836805206`*^6, 
       575769.3167804445}, {-1.3288903163194794`*^6, 516790.6832195555}}]}, 
     {Arrowheads[{{0.02438589991872558, 1.}}], 
      ArrowBox[{{-1.4820593806642892`*^6, 
       658693.0527577384}, {-1.327380619335711*^6, 589946.9472422616}}]}, 
     {Arrowheads[{{0.02545435409184362, 1.}}], 
      ArrowBox[{{-1.4837355081302167`*^6, 
       741867.7480854195}, {-1.3257044918697833`*^6, 662852.2519145805}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.045503582875673396`, 1.}}], 
      ArrowBox[{{-1.5103662515064797`*^6, 
       1.6781847106078912`*^6}, {-1.29907374849352*^6, 
       1.443415289392109*^6}}]}, 
     {Arrowheads[{{0.016089667294032287`, 1.}}], 
      ArrowBox[{{-1.3044808876417861`*^6, 0.}, {-1.1927991123582139`*^6, 
       0.}}]}, 
     {Arrowheads[{{0.0161525175367284, 1.}}], 
      ArrowBox[{{-1.3045898455516025`*^6, 
       81536.86459951404}, {-1.1926901544483977`*^6, 74543.13540048595}}]}, 
     {Arrowheads[{{0.01634106826504956, 1.}}], 
      ArrowBox[{{-1.3049154535396618`*^6, 
       163114.43019753552`}, {-1.1923645464603382`*^6, 
       149045.56980246448`}}]}, 
     {Arrowheads[{{0.016655319479672203`, 1.}}], 
      ArrowBox[{{-1.3054539867820672`*^6, 
       244772.6202792543}, {-1.1918260132179325`*^6, 223467.37972074572`}}]}, 
     {Arrowheads[{{0.017095271181654118`, 1.}}], 
      ArrowBox[{{-1.3061994691257663`*^6, 
       326549.86429159716`}, {-1.1910805308742337`*^6, 
       297770.13570840284`}}]}, 
     {Arrowheads[{{0.017660923372343297`, 1.}}], 
      ArrowBox[{{-1.3071439900075784`*^6, 
       408482.4931400627}, {-1.1901360099924216`*^6, 371917.50685993733`}}]}, 
     {Arrowheads[{{0.018352276053271572`, 1.}}], 
      ArrowBox[{{-1.3082780933309163`*^6, 
       490604.28051432694`}, {-1.1890019066690837`*^6, 
       445875.71948567306`}}]}, 
     {Arrowheads[{{0.019169329226049, 1.}}], 
      ArrowBox[{{-1.3095911974764047`*^6, 
       572946.1436636993}, {-1.1876888025235953`*^6, 519613.85633630067`}}]}, 
     {Arrowheads[{{0.020112082892270202`, 1.}}], 
      ArrowBox[{{-1.3110720089338678`*^6, 
       655535.9984872451}, {-1.1862079910661322`*^6, 593104.0015127549}}]}, 
     {Arrowheads[{{0.021180537053440265`, 1.}}], 
      ArrowBox[{{-1.3127089002012797`*^6, 
       738398.7496360699}, {-1.1845710997987203`*^6, 666321.2503639301}}]}, 
     {Arrowheads[{{0.02237469171092353, 1.}}], 
      ArrowBox[{{-1.3144902329075476`*^6, 
       821556.3880926062}, {-1.1827897670924524`*^6, 739243.6119073938}}]}, 
     {Arrowheads[{{0.023694546865913796`, 1.}}], 
      ArrowBox[{{-1.3164046171846068`*^6, 
       905028.1660923451}, {-1.180875382815393*^6, 811851.833907655}}]}, 
     {Arrowheads[{{0.025140102519422773`, 1.}}], 
      ArrowBox[{{-1.3184411065623881`*^6, 
       988525.9772022578}, {-1.1788388934376116`*^6, 883824.335297742}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.04122976576346556, 1.}}], 
      ArrowBox[{{-1.3380290280897538`*^6, 
       1.67253627016297*^6}, {-1.1592509719102462`*^6, 
       1.4490637298370302`*^6}}]}, 
     {Arrowheads[{{0.012318652329627502`, 1.}}], 
      ArrowBox[{{-1.1353131824037216`*^6, 0.}, {-1.0498068175962784`*^6, 
       0.}}]}, 
     {Arrowheads[{{0.012381502570277167`, 1.}}], 
      ArrowBox[{{-1.135422107855277*^6, 
       81101.57827827852}, {-1.049697892144723*^6, 74978.42172172148}}]}, 
     {Arrowheads[{{0.012570053292621425`, 1.}}], 
      ArrowBox[{{-1.135747235871406*^6, 
       162249.60341600404`}, {-1.0493727641285937`*^6, 
       149910.39658399596`}}]}, 
     {Arrowheads[{{0.012884304497797483`, 1.}}], 
      ArrowBox[{{-1.1362837436957972`*^6, 
       243489.37108637558`}, {-1.0488362563042028`*^6, 
       224750.62891362442`}}]}, 
     {Arrowheads[{{0.013324256187550676`, 1.}}], 
      ArrowBox[{{-1.1370239803808013`*^6, 
       324863.9909775496}, {-1.0480960196191989`*^6, 299456.0090224504}}]}, 
     {Arrowheads[{{0.01388990836404437, 1.}}], 
      ArrowBox[{{-1.1379579813159094`*^6, 
       406413.5604844756}, {-1.0471620186840907`*^6, 373986.4395155244}}]}, 
     {Arrowheads[{{0.014581261029651876`, 1.}}], 
      ArrowBox[{{-1.1390740756251563`*^6, 
       488174.59871390514`}, {-1.0460459243748436`*^6, 448305.4012860949}}]}, 
     {Arrowheads[{{0.015398314186764257`, 1.}}], 
      ArrowBox[{{-1.1403595096429717`*^6, 
       570179.748841797}, {-1.0447604903570283`*^6, 522380.251158203}}]}, 
     {Arrowheads[{{0.016341067837637707`, 1.}}], 
      ArrowBox[{{-1.1418010233421263`*^6, 
       652457.7207901421}, {-1.0433189766578736`*^6, 596182.2792098579}}]}, 
     {Arrowheads[{{0.01740952198429012, 1.}}], 
      ArrowBox[{{-1.1433853382080141`*^6, 
       735033.4240169806}, {-1.0417346617919859`*^6, 669686.5759830194}}]}, 
     {Arrowheads[{{0.01860367662844542, 1.}}], 
      ArrowBox[{{-1.1450995374393149`*^6, 
       817928.2324856694}, {-1.0400204625606852`*^6, 742871.7675143307}}]}, 
     {Arrowheads[{{0.01992353177151717, 1.}}], 
      ArrowBox[{{-1.1469313375835142`*^6, 
       901160.3272761072}, {-1.0381886624164858`*^6, 815719.6727238928}}]}, 
     {Arrowheads[{{0.02136908741462016, 1.}}], 
      ArrowBox[{{-1.148869262759642*^6, 
       984745.0721145122}, {-1.036250737240358*^6, 888214.9278854879}}]}, 
     {Arrowheads[{{0.02294034355859943, 1.}}], 
      ArrowBox[{{-1.1509027387069382`*^6, 
       1.0686953891227348`*^6}, {-1.0342172612930618`*^6, 
       960344.6108772652}}]}, 
     {Arrowheads[{{0.024637300204067604`, 1.}}], 
      ArrowBox[{{-1.1530221254362175`*^6, 
       1.1530221134768398`*^6}, {-1.0320978745637826`*^6, 
       1.0320978865231603`*^6}}]}, 
     {Arrowheads[{{0.026459957351444328`, 1.}}], 
      ArrowBox[{{-1.1552187059365448`*^6, 
       1.237734314975536*^6}, {-1.0299012940634553`*^6, 
       1.1034656850244638`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.03745875062251774, 1.}}], 
      ArrowBox[{{-1.1671127194990672`*^6, 
       1.6673038679138422`*^6}, {-1.0180072805009328`*^6, 
       1.4542961320861578`*^6}}]}, 
     {Arrowheads[{{0.009050439360476717, 1.}}], 
      ArrowBox[{{-967890.5045307324, 0.}, {-905069.4954692675, 0.}}]}, 
     {Arrowheads[{{0.00911328959798048, 1.}}], 
      ArrowBox[{{-967999.3800480794, 80666.6140073918}, {-904960.6199519205, 
       75413.38599260818}}]}, 
     {Arrowheads[{{0.00930184031121846, 1.}}], 
      ArrowBox[{{-968323.7731712522, 
       161387.29353531243`}, {-904636.2268287478, 150772.7064646876}}]}, 
     {Arrowheads[{{0.009616091502251352, 1.}}], 
      ArrowBox[{{-968857.2066154713, 242214.2986640234}, {-904102.7933845286, 
       226025.7013359766}}]}, 
     {Arrowheads[{{0.010056043174152225`, 1.}}], 
      ArrowBox[{{-969589.5782771377, 323196.52210592}, {-903370.4217228623, 
       301123.47789408005`}}]}, 
     {Arrowheads[{{0.01062169533057582, 1.}}], 
      ArrowBox[{{-970508.0455783453, 404378.3473412365}, {-902451.9544216546, 
       376021.65265876346`}}]}, 
     {Arrowheads[{{0.011313047975325785`, 1.}}], 
      ArrowBox[{{-971598.0102575284, 
       485798.99914907536`}, {-901361.9897424716, 450681.0008509247}}]}, 
     {Arrowheads[{{0.01213010111200241, 1.}}], 
      ArrowBox[{{-972844.0543534256, 567492.3580631947}, {-900115.9456465744, 
       525067.6419368053}}]}, 
     {Arrowheads[{{0.013072854743769837`, 1.}}], 
      ArrowBox[{{-974230.7258105777, 649487.1425674667}, {-898729.2741894221, 
       599152.8574325333}}]}, 
     {Arrowheads[{{0.014141308873242248`, 1.}}], 
      ArrowBox[{{-975743.1276735711, 731807.3367856451}, {-897216.8723264289, 
       672912.663214355}}]}, 
     {Arrowheads[{{0.01533546350246397, 1.}}], 
      ArrowBox[{{-977367.3101969596, 814472.7485313183}, {-895592.6898030404, 
       746327.2514686817}}]}, 
     {Arrowheads[{{0.016655318632951235`, 1.}}], 
      ArrowBox[{{-979090.4930763949, 897499.607690599}, {-893869.5069236051, 
       819380.3923094008}}]}, 
     {Arrowheads[{{0.018100874265766037`, 1.}}], 
      ArrowBox[{{-980901.156554607, 980901.1445952292}, {-892058.8434453931, 
       892058.8554047708}}]}, 
     {Arrowheads[{{0.01967213040160069, 1.}}], 
      ArrowBox[{{-982789.0404046897, 
       1.064688114149088*^6}, {-890170.9595953103, 964351.8858509118}}]}, 
     {Arrowheads[{{0.021369087040859297`, 1.}}], 
      ArrowBox[{{-984745.0840738899, 
       1.1488692508002643`*^6}, {-888214.9159261101, 
       1.0362507491997358`*^6}}]}, 
     {Arrowheads[{{0.023191744183729466`, 1.}}], 
      ArrowBox[{{-986761.3335327142, 
       1.2334516519666705`*^6}, {-886198.6664672857, 
       1.1077483480333292`*^6}}]}, 
     {Arrowheads[{{0.025140101830241776`, 1.}}], 
      ArrowBox[{{-988830.8329116356, 
       1.3181362508530105`*^6}, {-884129.1670883644, 
       1.1785340616469895`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.034190537450173704`, 1.}}], 
      ArrowBox[{{-997531.0356850327, 
       1.662551706209425*^6}, {-875428.9643149672, 1.459048293790575*^6}}]}, 
     {Arrowheads[{{0.006285028386579879, 1.}}], 
      ArrowBox[{{-802212.8540228185, 0.}, {-758587.1459771815, 0.}}]}, 
     {Arrowheads[{{0.006347878618885272, 1.}}], 
      ArrowBox[{{-802321.6469274511, 80232.16349680733}, {-758478.3530725489, 
       75847.83650319265}}]}, 
     {Arrowheads[{{0.0065364293172897586`, 1.}}], 
      ArrowBox[{{-802644.8334250582, 160528.9642931361}, {-758155.1665749418, 
       151631.0357068639}}]}, 
     {Arrowheads[{{0.006850680485914045, 1.}}], 
      ArrowBox[{{-803173.2876566555, 
       240951.98270918336`}, {-757626.7123433443, 227288.01729081664`}}]}, 
     {Arrowheads[{{0.007290632130625383, 1.}}], 
      ArrowBox[{{-803893.1618441027, 
       321557.25995388994`}, {-756906.8381558975, 302762.74004611}}]}, 
     {Arrowheads[{{0.007856284257954798, 1.}}], 
      ArrowBox[{{-804787.510777538, 402393.7494090801}, {-756012.489222462, 
       378006.25059091987`}}]}, 
     {Arrowheads[{{0.008547636874157053, 1.}}], 
      ArrowBox[{{-805837.938511734, 483502.75593141373`}, {-754962.061488266, 
       452977.24406858627`}}]}, 
     {Arrowheads[{{0.00936468998460098, 1.}}], 
      ArrowBox[{{-807025.9789378382, 564918.1768849224}, {-753774.0210621617, 
       527641.8231150777}}]}, 
     {Arrowheads[{{0.010307443593506545`, 1.}}], 
      ArrowBox[{{-808334.0795001202, 646667.254032594}, {-752465.9204998798, 
       601972.7459674061}}]}, 
     {Arrowheads[{{0.011375897703942508`, 1.}}], 
      ArrowBox[{{-809746.1896113505, 728771.5598867756}, {-751053.8103886495, 
       675948.4401132246}}]}, 
     {Arrowheads[{{0.01257005231797245, 1.}}], 
      ArrowBox[{{-811248.0290393981, 811248.0170800203}, {-749551.970960602, 
       749551.9829199797}}]}, 
     {Arrowheads[{{0.013889907436857866`, 1.}}], 
      ArrowBox[{{-812827.1329283289, 894109.8330658462}, {-747972.8670716712, 
       822770.1669341536}}]}, 
     {Arrowheads[{{0.015335463061261094`, 1.}}], 
      ArrowBox[{{-814472.7604906961, 977367.298237582}, {-746327.239509304, 
       895592.701762418}}]}, 
     {Arrowheads[{{0.01690671919142045, 1.}}], 
      ArrowBox[{{-816175.7329472153, 
       1.0610284372841888`*^6}, {-744624.2670527847, 968011.5627158111}}]}, 
     {Arrowheads[{{0.018603675827288852`, 1.}}], 
      ArrowBox[{{-817928.2444450471, 
       1.1450995254799372`*^6}, {-742871.7555549529, 
       1.0400204745200628`*^6}}]}, 
     {Arrowheads[{{0.02042633296863702, 1.}}], 
      ArrowBox[{{-819723.6722210444, 1.2295854903925*^6}, {-741076.3277789556,
        1.1116145096075*^6}}]}, 
     {Arrowheads[{{0.022374690615127975`, 1.}}], 
      ArrowBox[{{-821556.4000519839, 1.31449022094817*^6}, {-739243.599948016,
        1.18278977905183*^6}}]}, 
     {Arrowheads[{{0.024448748766367785`, 1.}}], 
      ArrowBox[{{-823421.6612404216, 
       1.3998168037777746`*^6}, {-737378.3387595784, 
       1.2535431962222254`*^6}}]}, 
     {Arrowheads[{{0.0266485074219401, 1.}}], 
      ArrowBox[{{-825315.4028011677, 
       1.485567703515222*^6}, {-735484.5971988322, 1.323872296484778*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.03142512624442892, 1.}}], 
      ArrowBox[{{-829175.0095956981, 
       1.6583499952726408`*^6}, {-731624.9904043019, 
       1.4632500047273594`*^6}}]}, 
     {Arrowheads[{{0.0040224194079370255`, 1.}}], 
      ArrowBox[{{-638280.2308799798, 0.}, {-610359.7691200201, 0.}}]}, 
     {Arrowheads[{{0.0040852696307340855`, 1.}}], 
      ArrowBox[{{-638388.8723544488, 79798.60754938389}, {-610251.1276455512, 
       76281.39245061613}}]}, 
     {Arrowheads[{{0.004273820302677972, 1.}}], 
      ArrowBox[{{-638709.8762509748, 159677.4660728993}, {-609930.123749025, 
       152482.5339271007}}]}, 
     {Arrowheads[{{0.004588071433194279, 1.}}], 
      ArrowBox[{{-639229.5323022624, 
       239711.07012858175`}, {-609410.4676977376, 228528.92987141828`}}]}, 
     {Arrowheads[{{0.005028023034651301, 1.}}], 
      ArrowBox[{{-639928.0112030002, 
       319963.99962181126`}, {-608711.9887969997, 304356.00037818874`}}]}, 
     {Arrowheads[{{0.005593675119322531, 1.}}], 
      ArrowBox[{{-640782.5671964202, 400489.0970231515}, {-607857.4328035797, 
       379910.9029768484}}]}, 
     {Arrowheads[{{0.0062850276973991665`, 1.}}], 
      ArrowBox[{{-641770.2856101304, 
       481327.70523806446`}, {-606869.7143898697, 455152.29476193554`}}]}, 
     {Arrowheads[{{0.007102080776270674, 1.}}], 
      ArrowBox[{{-642869.9072973399, 562511.1584207169}, {-605770.09270266, 
       530048.8415792831}}]}, 
     {Arrowheads[{{0.008044834360686861, 1.}}], 
      ArrowBox[{{-644062.7428905907, 644062.730931213}, {-604577.2571094093, 
       604577.269068787}}]}, 
     {Arrowheads[{{0.009113288453313407, 1.}}], 
      ArrowBox[{{-645332.9240185122, 725999.5260665263}, {-603307.0759814879, 
       678720.4739334737}}]}, 
     {Arrowheads[{{0.010307443055346683`, 1.}}], 
      ArrowBox[{{-646667.2659919717, 808334.0675407425}, {-601972.7340080283, 
       752465.9324592574}}]}, 
     {Arrowheads[{{0.01162729816703233, 1.}}], 
      ArrowBox[{{-648054.9502023852, 891075.5400841354}, {-600585.0497976147, 
       825804.4599158647}}]}, 
     {Arrowheads[{{0.013072853788047848`, 1.}}], 
      ArrowBox[{{-649487.1545268444, 974230.7138512001}, {-599152.8454731555, 
       898729.2861487999}}]}, 
     {Arrowheads[{{0.014644109917762223`, 1.}}], 
      ArrowBox[{{-650956.6986458396, 
       1.0578046158655004`*^6}, {-597683.3013541604, 971235.3841344996}}]}, 
     {Arrowheads[{{0.016341066555402066`, 1.}}], 
      ArrowBox[{{-652457.7327495198, 
       1.1418010113827486`*^6}, {-596182.2672504801, 
       1.0433189886172513`*^6}}]}, 
     {Arrowheads[{{0.018163723700152387`, 1.}}], 
      ArrowBox[{{-653985.4771656572, 
       1.226222747261774*^6}, {-594654.5228343428, 1.114977252738226*^6}}]}, 
     {Arrowheads[{{0.020112081351214714`, 1.}}], 
      ArrowBox[{{-655536.0104466227, 
       1.3110719969744901`*^6}, {-593103.9895533771, 
       1.1862080030255099`*^6}}]}, 
     {Arrowheads[{{0.02218613950783786, 1.}}], 
      ArrowBox[{{-657106.099530421, 
       1.3963504360884668`*^6}, {-591533.900469579, 
       1.2570095639115332`*^6}}]}, 
     {Arrowheads[{{0.0243858981693324, 1.}}], 
      ArrowBox[{{-658693.0647171161, 
       1.4820593687049113`*^6}, {-589946.9352828839, 
       1.3273806312950884`*^6}}]}, 
     {Arrowheads[{{0.02671135733507497, 1.}}], 
      ArrowBox[{{-660294.6726883706, 
       1.5681998192313581`*^6}, {-588345.3273116294, 
       1.3973201807686419`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.029162517004507463`, 1.}}], 
      ArrowBox[{{-661909.0517749375, 
       1.6547725995388995`*^6}, {-586730.9482250625, 
       1.4668274004611005`*^6}}]}, 
     {Arrowheads[{{0.0022626124245481286`, 1.}}], 
      ArrowBox[{{-476092.6351022164, 0.}, {-460387.36489778355`, 0.}}]}, 
     {Arrowheads[{{0.002325462627069688, 1.}}], 
      ArrowBox[{{-476200.95226234634`, 
       79366.8233838281}, {-460279.04773765366`, 76713.17661617188}}]}, 
     {Arrowheads[{{0.0025140132453428535`, 1.}}], 
      ArrowBox[{{-476517.4035388177, 158839.13052648}, {-459962.5964611823, 
       153320.86947352}}]}, 
     {Arrowheads[{{0.0028282643054153623`, 1.}}], 
      ArrowBox[{{-477019.5115339154, 
       238509.74978726884`}, {-459460.48846608464`, 229730.25021273116`}}]}, 
     {Arrowheads[{{0.0032682158363178514`, 1.}}], 
      ArrowBox[{{-477677.6904221777, 318451.7856418667}, {-458802.3095778222, 
       305868.2143581333}}]}, 
     {Arrowheads[{{0.003833867861029899, 1.}}], 
      ArrowBox[{{-478461.8365187732, 
       398718.18713282957`}, {-458018.16348122683`, 381681.81286717043`}}]}, 
     {Arrowheads[{{0.00452522039390936, 1.}}], 
      ArrowBox[{{-479345.298108185, 479345.2861488073}, {-457134.70189181494`,
        457134.71385119273`}}]}, 
     {Arrowheads[{{0.0053422734421394785`, 1.}}], 
      ArrowBox[{{-480306.27998800576`, 
       560357.312700066}, {-456173.72001199424`, 532202.687299934}}]}, 
     {Arrowheads[{{0.006285027008218378, 1.}}], 
      ArrowBox[{{-481327.7171974422, 641770.2736507526}, {-455152.2828025578, 
       606869.7263492474}}]}, 
     {Arrowheads[{{0.007353481092034192, 1.}}], 
      ArrowBox[{{-482396.5296535778, 723594.7765413}, {-454083.4703464223, 
       681125.2234586999}}]}, 
     {Arrowheads[{{0.00854763569222163, 1.}}], 
      ArrowBox[{{-483502.76789079147`, 
       805837.9265523562}, {-452977.2321092085, 754962.0734476437}}]}, 
     {Arrowheads[{{0.00986749080693869, 1.}}], 
      ArrowBox[{{-484638.85961967334`, 
       888504.5540438753}, {-451841.14038032666`, 828375.4459561248}}]}, 
     {Arrowheads[{{0.011313046434270415`, 1.}}], 
      ArrowBox[{{-485799.01110845304`, 
       971597.9982981507}, {-450680.9888915469, 901362.0017018494}}]}, 
     {Arrowheads[{{0.012884302572418137`, 1.}}], 
      ArrowBox[{{-486978.7541321289, 
       1.055120608040961*^6}, {-449501.2458678711, 973919.3919590391}}]}, 
     {Arrowheads[{{0.014581259219774044`, 1.}}], 
      ArrowBox[{{-488174.6106732828, 
       1.1390740636657786`*^6}, {-448305.3893267171, 
       1.0460459363342214`*^6}}]}, 
     {Arrowheads[{{0.016403916374938148`, 1.}}], 
      ArrowBox[{{-489383.84685563017`, 
       1.223459587240631*^6}, {-447096.15314436983`, 1.117740412759369*^6}}]}, 
     {Arrowheads[{{0.0183522740367083, 1.}}], 
      ArrowBox[{{-490604.29247370467`, 
       1.3082780813715386`*^6}, {-445875.70752629533`, 
       1.1890019186284614`*^6}}]}, 
     {Arrowheads[{{0.020426332204059375`, 1.}}], 
      ArrowBox[{{-491834.20811637776`, 
       1.3935302224448335`*^6}, {-444645.79188362224`, 
       1.2598297775551665`*^6}}]}, 
     {Arrowheads[{{0.022626090876119793`, 1.}}], 
      ArrowBox[{{-493072.18669769773`, 
       1.47921652421496*^6}, {-443407.81330230227`, 1.33022347578504*^6}}]}, 
     {Arrowheads[{{0.02495155005214864, 1.}}], 
      ArrowBox[{{-494317.0799069421, 
       1.5653373818339538`*^6}, {-442162.9200930579, 
       1.4001826181660462`*^6}}]}, 
     {Arrowheads[{{0.027402709731515117`, 1.}}], 
      ArrowBox[{{-495567.94279611117`, 
       1.6518931027891114`*^6}, {-440912.05720388883`, 
       1.4697068972108886`*^6}}]}, 
     {Arrowheads[{{0.0010056074364132059`, 1.}}], 
      ArrowBox[{{-315650.06668952823`, 0.}, {-308669.9333104717, 0.}}]}, 
     {Arrowheads[{{0.0010684575829341622`, 1.}}], 
      ArrowBox[{{-315757.478032277, 78939.36651822482}, {-308562.521967723, 
       77140.63348177518}}]}, 
     {Arrowheads[{{0.0012570080702472368`, 1.}}], 
      ArrowBox[{{-316062.01177028334`, 
       158030.9999054528}, {-308257.9882297166, 154129.00009454717`}}]}, 
     {Arrowheads[{{0.0015712589918942265`, 1.}}], 
      ArrowBox[{{-316522.5803720659, 
       237391.92630951613`}, {-307797.4196279341, 230848.0736904839}}]}, 
     {Arrowheads[{{0.0020112104176403314`, 1.}}], 
      ArrowBox[{{-317095.69469218096`, 
       317095.6827328032}, {-307224.30530781904`, 307224.3172671967}}]}, 
     {Arrowheads[{{0.002576862378317948, 1.}}], 
      ArrowBox[{{-317746.8254675262, 397183.5168851856}, {-306573.1745324738, 
       383216.4831148144}}]}, 
     {Arrowheads[{{0.0032682148805963864`, 1.}}], 
      ArrowBox[{{-318451.7976012444, 
       477677.67846280005`}, {-305868.2023987556, 458802.3215372}}]}, 
     {Arrowheads[{{0.004085267921087376, 1.}}], 
      ArrowBox[{{-319194.4421569132, 558590.2528456872}, {-305125.5578430867, 
       533969.7471543129}}]}, 
     {Arrowheads[{{0.005028021493596326, 1.}}], 
      ArrowBox[{{-319964.011581189, 639927.9992436225}, {-304355.988418811, 
       608712.0007563775}}]}, 
     {Arrowheads[{{0.006096475591969866, 1.}}], 
      ArrowBox[{{-320753.27514881233`, 
       721694.8421762278}, {-303566.72485118767`, 683025.1578237722}}]}, 
     {Arrowheads[{{0.007290630210960338, 1.}}], 
      ArrowBox[{{-321557.2719132677, 803893.1498847249}, {-302762.7280867323, 
       756906.8501152751}}]}, 
     {Arrowheads[{{0.008610485346339057, 1.}}], 
      ArrowBox[{{-322372.5227814776, 886524.4047607746}, {-301947.4772185224, 
       830355.5952392253}}]}, 
     {Arrowheads[{{0.010056040994770848`, 1.}}], 
      ArrowBox[{{-323196.5340652977, 
       969589.5663177599}, {-301123.46593470225`, 903370.43368224}}]}, 
     {Arrowheads[{{0.011627297153640501`, 1.}}], 
      ArrowBox[{{-324027.4810808815, 
       1.0530892746448873`*^6}, {-300292.5189191185, 975950.7253551128}}]}, 
     {Arrowheads[{{0.013324253820893564`, 1.}}], 
      ArrowBox[{{-324864.00293692725`, 
       1.1370239684214233`*^6}, {-299455.9970630727, 
       1.0480960315785767`*^6}}]}, 
     {Arrowheads[{{0.015146910994907297`, 1.}}], 
      ArrowBox[{{-325705.06679196906`, 
       1.2213939556222176`*^6}, {-298614.93320803094`, 
       1.1198060443777824`*^6}}]}, 
     {Arrowheads[{{0.017095268674390075`, 1.}}], 
      ArrowBox[{{-326549.8762509749, 
       1.3061994571663886`*^6}, {-297770.1237490251, 
       1.1910805428336114`*^6}}]}, 
     {Arrowheads[{{0.019169326858305743`, 1.}}], 
      ArrowBox[{{-327397.8083386345, 
       1.3914406346118413`*^6}, {-296922.1916613655, 
       1.2619193653881587`*^6}}]}, 
     {Arrowheads[{{0.02136908554581578, 1.}}], 
      ArrowBox[{{-328248.3693308818, 
       1.4771176081717683`*^6}, {-296071.63066911825`, 
       1.3323223918282317`*^6}}]}, 
     {Arrowheads[{{0.023694544736236157`, 1.}}], 
      ArrowBox[{{-329101.163265685, 
       1.5632304687049596`*^6}, {-295218.836734315, 
       1.4022895312950402`*^6}}]}, 
     {Arrowheads[{{0.026145704429004275`, 1.}}], 
      ArrowBox[{{-329955.8691319221, 
       1.6497792858627217`*^6}, {-294364.130868078, 
       1.4718207141372783`*^6}}]}, 
     {Arrowheads[{{0.000251404443532249, 1.}}], 
      ArrowBox[{{-156952.52564191536`, 0.}, {-155207.47435808464`, 0.}}]}, 
     {Arrowheads[{{0.000314254329148875, 1.}}], 
      ArrowBox[{{-157055.51191210412`, 
       78527.74997636321}, {-155104.48808789585`, 77552.2500236368}}]}, 
     {Arrowheads[{{0.0005028044318828522, 1.}}], 
      ArrowBox[{{-157313.93264257853`, 
       157313.92068320082`}, {-154846.06735742145`, 154846.0793167992}}]}, 
     {Arrowheads[{{0.0008170551537370544, 1.}}], 
      ArrowBox[{{-157652.9583698444, 236479.4196157}, {-154507.0416301556, 
       231760.5803843}}]}, 
     {Arrowheads[{{0.0012570065291943851`, 1.}}], 
      ArrowBox[{{-158031.01186483054`, 
       316061.9998109056}, {-154128.98813516946`, 308258.00018909434`}}]}, 
     {Arrowheads[{{0.0018226585125755328`, 1.}}], 
      ArrowBox[{{-158429.3269478502, 
       396073.28747118125`}, {-153730.67305214977`, 384326.7125288188}}]}, 
     {Arrowheads[{{0.002514011065962893, 1.}}], 
      ArrowBox[{{-158839.1424858577, 476517.39157944}, {-153320.85751414226`, 
       459962.60842056}}]}, 
     {Arrowheads[{{0.0033310641652221718`, 1.}}], 
      ArrowBox[{{-159256.0097037651, 
       557395.9921053558}, {-152903.99029623487`, 535164.0078946442}}]}, 
     {Arrowheads[{{0.004273817795414835, 1.}}], 
      ArrowBox[{{-159677.47803227702`, 638709.8642915972}, {-152482.521967723,
        609930.1357084028}}]}, 
     {Arrowheads[{{0.005342271947096293, 1.}}], 
      ArrowBox[{{-160102.10130225375`, 
       720459.402042942}, {-152057.89869774628`, 684260.5979570579}}]}, 
     {Arrowheads[{{0.006536426614100105, 1.}}], 
      ArrowBox[{{-160528.97625251382`, 
       802644.8214656804}, {-151631.0237474862, 758155.1785343195}}]}, 
     {Arrowheads[{{0.007856281792266273, 1.}}], 
      ArrowBox[{{-160957.51172300975`, 
       885266.2486999762}, {-151202.48827699022`, 831613.7513000239}}]}, 
     {Arrowheads[{{0.009301837478702397, 1.}}], 
      ArrowBox[{{-161387.30549469014`, 
       968323.7612118745}, {-150772.69450530986`, 904636.2387881255}}]}, 
     {Arrowheads[{{0.010873093671342296`, 1.}}], 
      ArrowBox[{{-161818.07482578265`, 
       1.051817408631632*^6}, {-150341.92517421735`, 977222.5913683679}}]}, 
     {Arrowheads[{{0.012570050368674285`, 1.}}], 
      ArrowBox[{{-162249.61537538178`, 
       1.1357472239120284`*^6}, {-149910.38462461822`, 
       1.0493727760879716`*^6}}]}, 
     {Arrowheads[{{0.014392707569568924`, 1.}}], 
      ArrowBox[{{-162681.7759074321, 
       1.2201132296104077`*^6}, {-149478.22409256792`, 
       1.1210867703895923`*^6}}]}, 
     {Arrowheads[{{0.016341065273166307`, 1.}}], 
      ArrowBox[{{-163114.44215691325`, 
       1.3049154415802842`*^6}, {-149045.55784308678`, 
       1.1923645584197158`*^6}}]}, 
     {Arrowheads[{{0.01841512347880081, 1.}}], 
      ArrowBox[{{-163547.526220849, 
       1.3901538712225056`*^6}, {-148612.47377915104`, 
       1.2632061287774944`*^6}}]}, 
     {Arrowheads[{{0.020614882185949618`, 1.}}], 
      ArrowBox[{{-163980.95939305055`, 
       1.4758285269030554`*^6}, {-148179.04060694948`, 
       1.3336114730969446`*^6}}]}, 
     {Arrowheads[{{0.02294034139419647, 1.}}], 
      ArrowBox[{{-164414.68720902922`, 
       1.5619394148716892`*^6}, {-147745.31279097075`, 
       1.4035805851283106`*^6}}]}, 
     {Arrowheads[{{0.025391501103206097`, 1.}}], 
      ArrowBox[{{-164848.66594660707`, 
       1.6484865398722936`*^6}, {-147311.3340533929, 
       1.4731134601277064`*^6}}]}, 
     {Arrowheads[{{3.4459052632904258`*^-9, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 0.}, {0.011959377724548118`, 0.}}]}, 
     {Arrowheads[{{0.00006285024950121043, 1.}}], 
      ArrowBox[{{-0.01195937772454812, 78258.12842063441}, {
       0.01195937772454812, 77821.8715793656}}]}, 
     {Arrowheads[{{0.000251400997650599, 1.}}], 
      ArrowBox[{{-0.01195937772454812, 156952.51368253762`}, {
       0.01195937772454812, 155207.48631746238`}}]}, 
     {Arrowheads[{{0.0005656522446712138, 1.}}], 
      ArrowBox[{{-0.011959377724548116`, 236083.15578570968`}, {
       0.011959377724548116`, 232156.84421429032`}}]}, 
     {Arrowheads[{{0.001005603990513844, 1.}}], 
      ArrowBox[{{-0.01195937772454812, 315650.0547301505}, {
       0.01195937772454812, 308669.94526984944`}}]}, 
     {Arrowheads[{{0.001571256235172436, 1.}}], 
      ArrowBox[{{-0.01195937772454812, 395653.2105158602}, {
       0.01195937772454812, 384746.78948413976`}}]}, 
     {Arrowheads[{{0.0022626089786454864`, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 476092.6231428387}, {
       0.011959377724548118`, 460387.37685716135`}}]}, 
     {Arrowheads[{{0.0030796622209325075`, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 556968.292611086}, {
       0.011959377724548118`, 535591.707388914}}]}, 
     {Arrowheads[{{0.004022415962033235, 1.}}], 
      ArrowBox[{{-0.011959377724548116`, 638280.2189206021}, {
       0.011959377724548116`, 610359.7810793979}}]}, 
     {Arrowheads[{{0.00509087020194761, 1.}}], 
      ArrowBox[{{-0.01195937772454812, 720028.402071387}, {
       0.01195937772454812, 684691.597928613}}]}, 
     {Arrowheads[{{0.006285024940675558, 1.}}], 
      ArrowBox[{{-0.011959377724548116`, 802212.8420634408}, {
       0.011959377724548116`, 758587.1579365593}}]}, 
     {Arrowheads[{{0.007604880178217069, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 884833.5388967633}, {
       0.011959377724548118`, 832046.4611032367}}]}, 
     {Arrowheads[{{0.009050435914572106, 1.}}], 
      ArrowBox[{{-0.01195937772454812, 967890.4925713547}, {
       0.01195937772454812, 905069.5074286453}}]}, 
     {Arrowheads[{{0.010621692149740642`, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 1.0513837030872148`*^6}, {
       0.011959377724548118`, 977656.2969127852}}]}, 
     {Arrowheads[{{0.012318648883722734`, 1.}}], 
      ArrowBox[{{-0.011959377724548116`, 1.135313170444344*^6}, {
       0.011959377724548116`, 1.049806829555656*^6}}]}, 
     {Arrowheads[{{0.014141306116518346`, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 1.219678894642742*^6}, {
       0.011959377724548118`, 1.121521105357258*^6}}]}, 
     {Arrowheads[{{0.016089663848127406`, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 1.3044808756824085`*^6}, {
       0.011959377724548118`, 1.1927991243175915`*^6}}]}, 
     {Arrowheads[{{0.01816372207854998, 1.}}], 
      ArrowBox[{{-0.011959377724548116`, 1.3897191135633439`*^6}, {
       0.011959377724548116`, 1.2636408864366561`*^6}}]}, 
     {Arrowheads[{{0.02036348080778606, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 1.4753936082855482`*^6}, {
       0.011959377724548118`, 1.3340463917144518`*^6}}]}, 
     {Arrowheads[{{0.02268894003583566, 1.}}], 
      ArrowBox[{{-0.011959377724548118`, 1.5615043598490213`*^6}, {
       0.011959377724548118`, 1.4040156401509787`*^6}}]}, 
     {Arrowheads[{{0.025140099762698688`, 1.}}], 
      ArrowBox[{{-0.011959377724548116`, 1.647898946378763*^6}, {
       0.011959377724548116`, 1.473396209871237*^6}}]}, 
     {Arrowheads[{{0.0002513975517217209, 1.}}], 
      ArrowBox[{{156952.50172315992`, 0.}, {155207.4982768401, 0.}}]}, 
     {Arrowheads[{{0.00031424816492614353`, 1.}}], 
      ArrowBox[{{157055.48799334868`, 78527.74997636321}, {
       155104.51200665132`, 77552.2500236368}}]}, 
     {Arrowheads[{{0.0005027995586368932, 1.}}], 
      ArrowBox[{{157313.9087238231, 157313.92068320082`}, {154846.0912761769, 
       154846.0793167992}}]}, 
     {Arrowheads[{{0.0008170513308484043, 1.}}], 
      ArrowBox[{{157652.93445108895`, 236479.4196157}, {154507.06554891105`, 
       231760.5803843}}]}, 
     {Arrowheads[{{0.001257003447083021, 1.}}], 
      ArrowBox[{{158030.9879460751, 316061.9998109056}, {154129.0120539249, 
       308258.00018909434`}}]}, 
     {Arrowheads[{{0.0018226559530213594`, 1.}}], 
      ArrowBox[{{158429.30302909476`, 396073.28747118125`}, {
       153730.69697090524`, 384326.7125288188}}]}, 
     {Arrowheads[{{0.002514008886581046, 1.}}], 
      ArrowBox[{{158839.11856710227`, 476517.39157944}, {153320.88143289773`, 
       459962.60842056}}]}, 
     {Arrowheads[{{0.0033310622718962105`, 1.}}], 
      ArrowBox[{{159255.98578500966`, 557395.9921053558}, {
       152904.01421499034`, 535164.0078946442}}]}, 
     {Arrowheads[{{0.004273816123905262, 1.}}], 
      ArrowBox[{{159677.45411352155`, 638709.8642915972}, {
       152482.54588647842`, 609930.1357084028}}]}, 
     {Arrowheads[{{0.00534227045205268, 1.}}], 
      ArrowBox[{{160102.07738349828`, 720459.402042942}, {152057.92261650172`,
        684260.5979570579}}]}, 
     {Arrowheads[{{0.00653642526250486, 1.}}], 
      ArrowBox[{{160528.95233375835`, 802644.8214656804}, {
       151631.04766624165`, 758155.1785343195}}]}, 
     {Arrowheads[{{0.007856280559421726, 1.}}], 
      ArrowBox[{{160957.4878042543, 885266.2486999762}, {151202.5121957457, 
       831613.7513000239}}]}, 
     {Arrowheads[{{0.009301836345695728, 1.}}], 
      ArrowBox[{{161387.2815759347, 968323.7612118745}, {150772.7184240653, 
       904636.2387881255}}]}, 
     {Arrowheads[{{0.010873092623392994`, 1.}}], 
      ArrowBox[{{161818.0509070272, 1.051817408631632*^6}, {150341.9490929728,
        977222.5913683679}}]}, 
     {Arrowheads[{{0.012570049394025094`, 1.}}], 
      ArrowBox[{{162249.59145662634`, 1.1357472239120284`*^6}, {
       149910.40854337366`, 1.0493727760879716`*^6}}]}, 
     {Arrowheads[{{0.014392706658721607`, 1.}}], 
      ArrowBox[{{162681.75198867664`, 1.2201132296104077`*^6}, {
       149478.24801132336`, 1.1210867703895923`*^6}}]}, 
     {Arrowheads[{{0.01634106441834242, 1.}}], 
      ArrowBox[{{163114.41823815778`, 1.3049154415802842`*^6}, {
       149045.5817618422, 1.1923645584197158`*^6}}]}, 
     {Arrowheads[{{0.01841512267355307, 1.}}], 
      ArrowBox[{{163547.50230209352`, 1.3901538712225056`*^6}, {
       148612.49769790648`, 1.2632061287774944`*^6}}]}, 
     {Arrowheads[{{0.020614881424876465`, 1.}}], 
      ArrowBox[{{163980.93547429508`, 1.4758285269030554`*^6}, {
       148179.0645257049, 1.3336114730969446`*^6}}]}, 
     {Arrowheads[{{0.022940340672728803`, 1.}}], 
      ArrowBox[{{164414.66329027378`, 1.5619394148716894`*^6}, {
       147745.33670972622`, 1.4035805851283106`*^6}}]}, 
     {Arrowheads[{{0.025391500417445315`, 1.}}], 
      ArrowBox[{{164848.64202785163`, 1.6484865398722936`*^6}, {
       147311.35797214837`, 1.4731134601277064`*^6}}]}, 
     {Arrowheads[{{0.0010056005446026737`, 1.}}], 
      ArrowBox[{{315650.0427707728, 0.}, {308669.95722922724`, 0.}}]}, 
     {Arrowheads[{{0.0010684508968958617`, 1.}}], 
      ArrowBox[{{315757.45411352155`, 78939.36651822482}, {
       308562.54588647845`, 77140.63348177518}}]}, 
     {Arrowheads[{{0.0012570019060245013`, 1.}}], 
      ArrowBox[{{316061.9878515279, 158030.9999054528}, {308258.01214847213`, 
       154129.00009454717`}}]}, 
     {Arrowheads[{{0.0015712534784458007`, 1.}}], 
      ArrowBox[{{316522.5564533104, 237391.92630951613`}, {307797.4435466896, 
       230848.0736904839}}]}, 
     {Arrowheads[{{0.002011205544394376, 1.}}], 
      ArrowBox[{{317095.67077342555`, 317095.6827328032}, {307224.3292265745, 
       307224.3172671967}}]}, 
     {Arrowheads[{{0.0025768580730380444`, 1.}}], 
      ArrowBox[{{317746.80154877075`, 397183.5168851856}, {306573.1984512292, 
       383216.4831148144}}]}, 
     {Arrowheads[{{0.003268211057707732, 1.}}], 
      ArrowBox[{{318451.77368248894`, 477677.67846280005`}, {
       305868.22631751106`, 458802.3215372}}]}, 
     {Arrowheads[{{0.0040852645017918155`, 1.}}], 
      ArrowBox[{{319194.4182381578, 558590.2528456872}, {305125.58176184224`, 
       533969.7471543129}}]}, 
     {Arrowheads[{{0.0050280184114849585`, 1.}}], 
      ArrowBox[{{319963.98766243353`, 639927.9992436225}, {
       304356.01233756647`, 608712.0007563775}}]}, 
     {Arrowheads[{{0.006096472792940508, 1.}}], 
      ArrowBox[{{320753.25123005686`, 721694.8421762278}, {
       303566.74876994314`, 683025.1578237722}}]}, 
     {Arrowheads[{{0.007290627651406166, 1.}}], 
      ArrowBox[{{321557.24799451226`, 803893.1498847249}, {302762.7520054878, 
       756906.8501152751}}]}, 
     {Arrowheads[{{0.008610482991110616, 1.}}], 
      ArrowBox[{{322372.49886272213`, 886524.4047607746}, {
       301947.50113727787`, 830355.5952392253}}]}, 
     {Arrowheads[{{0.010056038815389003`, 1.}}], 
      ArrowBox[{{323196.5101465423, 969589.5663177599}, {301123.4898534577, 
       903370.43368224}}]}, 
     {Arrowheads[{{0.01162729512685655, 1.}}], 
      ArrowBox[{{324027.457162126, 1.0530892746448873`*^6}, {300292.542837874,
        975950.7253551128}}]}, 
     {Arrowheads[{{0.013324251927567603`, 1.}}], 
      ArrowBox[{{324863.97901817184`, 1.1370239684214233`*^6}, {
       299456.0209818282, 1.0480960315785767`*^6}}]}, 
     {Arrowheads[{{0.015146909219145131`, 1.}}], 
      ArrowBox[{{325705.04287321365`, 1.2213939556222176`*^6}, {
       298614.9571267864, 1.1198060443777824`*^6}}]}, 
     {Arrowheads[{{0.0170952670028805, 1.}}], 
      ArrowBox[{{326549.8523322194, 1.3061994571663886`*^6}, {
       297770.1476677806, 1.1910805428336114`*^6}}]}, 
     {Arrowheads[{{0.01916932527981005, 1.}}], 
      ArrowBox[{{327397.784419879, 1.3914406346118413`*^6}, {
       296922.2155801209, 1.2619193653881587`*^6}}]}, 
     {Arrowheads[{{0.021369084050772168`, 1.}}], 
      ArrowBox[{{328248.34541212633`, 1.4771176081717683`*^6}, {
       296071.65458787367`, 1.3323223918282317`*^6}}]}, 
     {Arrowheads[{{0.023694543316450958`, 1.}}], 
      ArrowBox[{{329101.13934692956`, 1.5632304687049596`*^6}, {
       295218.8606530704, 1.4022895312950402`*^6}}]}, 
     {Arrowheads[{{0.026145703077409002`, 1.}}], 
      ArrowBox[{{329955.8452131666, 1.6497792858627217`*^6}, {
       294364.1547868334, 1.4718207141372785`*^6}}]}, 
     {Arrowheads[{{0.0022626055327375962`, 1.}}], 
      ArrowBox[{{476092.611183461, 0.}, {460387.3888165391, 0.}}]}, 
     {Arrowheads[{{0.002325455829029663, 1.}}], 
      ArrowBox[{{476200.92834359093`, 79366.8233838281}, {460279.0716564091, 
       76713.17661617188}}]}, 
     {Arrowheads[{{0.002514006707197316, 1.}}], 
      ArrowBox[{{476517.37962006225`, 158839.13052648}, {459962.6203799377, 
       153320.86947352}}]}, 
     {Arrowheads[{{0.0028282581411926346`, 1.}}], 
      ArrowBox[{{477019.48761515995`, 238509.74978726884`}, {
       459460.51238484005`, 229730.25021273116`}}]}, 
     {Arrowheads[{{0.0032682101019848695`, 1.}}], 
      ArrowBox[{{477677.6665034223, 318451.7856418667}, {458802.33349657775`, 
       305868.2143581333}}]}, 
     {Arrowheads[{{0.0038338625665944, 1.}}], 
      ArrowBox[{{478461.81260001776`, 398718.18713282957`}, {
       458018.18739998224`, 381681.81286717043`}}]}, 
     {Arrowheads[{{0.004525215520663403, 1.}}], 
      ArrowBox[{{479345.2741894296, 479345.2861488073}, {457134.7258105704, 
       457134.71385119273`}}]}, 
     {Arrowheads[{{0.005342268957008637, 1.}}], 
      ArrowBox[{{480306.2560692503, 560357.312700066}, {456173.7439307497, 
       532202.687299934}}]}, 
     {Arrowheads[{{0.006285022873132063, 1.}}], 
      ArrowBox[{{481327.6932786867, 641770.2736507526}, {455152.3067213132, 
       606869.7263492474}}]}, 
     {Arrowheads[{{0.007353477269145542, 1.}}], 
      ArrowBox[{{482396.5057348223, 723594.7765413}, {454083.4942651777, 
       681125.2234586999}}]}, 
     {Arrowheads[{{0.008547632146414363, 1.}}], 
      ArrowBox[{{483502.74397203606`, 805837.9265523562}, {452977.256027964, 
       754962.0734476437}}]}, 
     {Arrowheads[{{0.009867487506780532, 1.}}], 
      ArrowBox[{{484638.8357009179, 888504.5540438753}, {451841.1642990821, 
       828375.4459561248}}]}, 
     {Arrowheads[{{0.01131304335215905, 1.}}], 
      ArrowBox[{{485798.9871896976, 971597.9982981507}, {450681.0128103024, 
       901362.0017018494}}]}, 
     {Arrowheads[{{0.01288429968434858, 1.}}], 
      ArrowBox[{{486978.73021337343`, 1.055120608040961*^6}, {
       449501.2697866265, 973919.3919590391}}]}, 
     {Arrowheads[{{0.014581256504956876`, 1.}}], 
      ArrowBox[{{488174.5867545274, 1.1390740636657786`*^6}, {
       448305.4132454726, 1.0460459363342214`*^6}}]}, 
     {Arrowheads[{{0.016403913815383975`, 1.}}], 
      ArrowBox[{{489383.8229368747, 1.223459587240631*^6}, {447096.1770631253,
        1.117740412759369*^6}}]}, 
     {Arrowheads[{{0.01835227161683207, 1.}}], 
      ArrowBox[{{490604.2685549492, 1.3082780813715386`*^6}, {
       445875.73144505074`, 1.1890019186284614`*^6}}]}, 
     {Arrowheads[{{0.020426329910326183`, 1.}}], 
      ArrowBox[{{491834.18419762235`, 1.3935302224448335`*^6}, {
       444645.8158023777, 1.2598297775551665`*^6}}]}, 
     {Arrowheads[{{0.022626088696737944`, 1.}}], 
      ArrowBox[{{493072.16277894226`, 1.47921652421496*^6}, {
       443407.83722105774`, 1.33022347578504*^6}}]}, 
     {Arrowheads[{{0.024951547976808305`, 1.}}], 
      ArrowBox[{{494317.0559881866, 1.5653373818339538`*^6}, {
       442162.9440118134, 1.4001826181660462`*^6}}]}, 
     {Arrowheads[{{0.027402707751167935`, 1.}}], 
      ArrowBox[{{495567.9188773557, 1.6518931027891114`*^6}, {
       440912.08112264425`, 1.4697068972108886`*^6}}]}, 
     {Arrowheads[{{0.004022412516126476, 1.}}], 
      ArrowBox[{{638280.2069612243, 0.}, {610359.7930387757, 0.}}]}, 
     {Arrowheads[{{0.004085262792142963, 1.}}], 
      ArrowBox[{{638388.8484356933, 79798.60754938389}, {610251.1515643067, 
       76281.39245061613}}]}, 
     {Arrowheads[{{0.004273813616639672, 1.}}], 
      ArrowBox[{{638709.8523322195, 159677.4660728993}, {609930.1476677806, 
       152482.5339271007}}]}, 
     {Arrowheads[{{0.004588064980190991, 1.}}], 
      ArrowBox[{{639229.5083835069, 239711.07012858175`}, {609410.4916164931, 
       228528.92987141828`}}]}, 
     {Arrowheads[{{0.005028016870428566, 1.}}], 
      ArrowBox[{{639927.9872842449, 319963.99962181126`}, {608712.0127157553, 
       304356.00037818874`}}]}, 
     {Arrowheads[{{0.005593669275078893, 1.}}], 
      ArrowBox[{{640782.5432776648, 400489.0970231516}, {607857.4567223353, 
       379910.9029768484}}]}, 
     {Arrowheads[{{0.006285022183950753, 1.}}], 
      ArrowBox[{{641770.2616913749, 481327.70523806446`}, {606869.7383086251, 
       455152.29476193554`}}]}, 
     {Arrowheads[{{0.007102075589654683, 1.}}], 
      ArrowBox[{{642869.8833785844, 562511.1584207169}, {605770.1166214155, 
       530048.8415792831}}]}, 
     {Arrowheads[{{0.00804482948744091, 1.}}], 
      ArrowBox[{{644062.7189718352, 644062.730931213}, {604577.2810281647, 
       604577.269068787}}]}, 
     {Arrowheads[{{0.009113283874643717, 1.}}], 
      ArrowBox[{{645332.9000997568, 725999.5260665263}, {603307.0999002432, 
       678720.4739334737}}]}, 
     {Arrowheads[{{0.010307438750066776`, 1.}}], 
      ArrowBox[{{646667.2420732162, 808334.0675407425}, {601972.7579267838, 
       752465.9324592574}}]}, 
     {Arrowheads[{{0.011627294113464437`, 1.}}], 
      ArrowBox[{{648054.9262836298, 891075.5400841354}, {600585.0737163702, 
       825804.4599158647}}]}, 
     {Arrowheads[{{0.013072849965159195`, 1.}}], 
      ArrowBox[{{649487.130608089, 974230.7138512001}, {599152.8693919111, 
       898729.2861487999}}]}, 
     {Arrowheads[{{0.014644106305782063`, 1.}}], 
      ArrowBox[{{650956.6747270841, 1.0578046158655004`*^6}, {
       597683.3252729159, 971235.3841344996}}]}, 
     {Arrowheads[{{0.016341063136106494`, 1.}}], 
      ArrowBox[{{652457.7088307644, 1.1418010113827486`*^6}, {
       596182.2911692357, 1.0433189886172514`*^6}}]}, 
     {Arrowheads[{{0.018163720456947433`, 1.}}], 
      ArrowBox[{{653985.4532469017, 1.226222747261774*^6}, {594654.5467530983,
        1.114977252738226*^6}}]}, 
     {Arrowheads[{{0.020112078269103342`, 1.}}], 
      ArrowBox[{{655535.9865278673, 1.3110719969744901`*^6}, {
       593104.0134721326, 1.1862080030255099`*^6}}]}, 
     {Arrowheads[{{0.02218613657332536, 1.}}], 
      ArrowBox[{{657106.0756116655, 1.3963504360884668`*^6}, {
       591533.9243883345, 1.2570095639115332`*^6}}]}, 
     {Arrowheads[{{0.024385895370303057`, 1.}}], 
      ArrowBox[{{658693.0407983607, 1.4820593687049113`*^6}, {
       589946.9592016393, 1.3273806312950884`*^6}}]}, 
     {Arrowheads[{{0.026711354660659655`, 1.}}], 
      ArrowBox[{{660294.6487696152, 1.5681998192313581`*^6}, {
       588345.3512303849, 1.3973201807686419`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.029162514444953293`, 1.}}], 
      ArrowBox[{{661909.0278561821, 1.6547725995388995`*^6}, {
       586730.9721438178, 1.4668274004611005`*^6}}]}, 
     {Arrowheads[{{0.006285021494769347, 1.}}], 
      ArrowBox[{{802212.830104063, 0.}, {758587.169895937, 0.}}]}, 
     {Arrowheads[{{0.006347871761277484, 1.}}], 
      ArrowBox[{{802321.6230086957, 80232.16349680733}, {758478.3769913043, 
       75847.83650319265}}]}, 
     {Arrowheads[{{0.00653642255931353, 1.}}], 
      ArrowBox[{{802644.8095063027, 160528.9642931361}, {758155.1904936973, 
       151631.0357068639}}]}, 
     {Arrowheads[{{0.006850673884756763, 1.}}], 
      ArrowBox[{{803173.2637379002, 240951.98270918336`}, {757626.7362620999, 
       227288.01729081664`}}]}, 
     {Arrowheads[{{0.007290625731739961, 1.}}], 
      ArrowBox[{{803893.1379253472, 321557.25995388994`}, {756906.8620746528, 
       302762.74004611}}]}, 
     {Arrowheads[{{0.007856278093732063, 1.}}], 
      ArrowBox[{{804787.4868587825, 402393.7494090801}, {756012.5131412175, 
       378006.25059091987`}}]}, 
     {Arrowheads[{{0.008547630964478277, 1.}}], 
      ArrowBox[{{805837.9145929785, 483502.75593141373`}, {754962.0854070215, 
       452977.24406858627`}}]}, 
     {Arrowheads[{{0.009364684338609802, 1.}}], 
      ArrowBox[{{807025.9550190829, 564918.1768849224}, {753774.0449809172, 
       527641.8231150777}}]}, 
     {Arrowheads[{{0.01030743821190666, 1.}}], 
      ArrowBox[{{808334.0555813648, 646667.254032594}, {752465.9444186352, 
       601972.7459674061}}]}, 
     {Arrowheads[{{0.011375892581300081`, 1.}}], 
      ArrowBox[{{809746.1656925951, 728771.5598867756}, {751053.8343074049, 
       675948.4401132246}}]}, 
     {Arrowheads[{{0.012570047444726487`, 1.}}], 
      ArrowBox[{{811248.0051206426, 811248.0170800203}, {749551.9948793575, 
       749551.9829199797}}]}, 
     {Arrowheads[{{0.013889902800924421`, 1.}}], 
      ArrowBox[{{812827.1090095735, 894109.8330658462}, {747972.8909904266, 
       822770.1669341536}}]}, 
     {Arrowheads[{{0.015335458649231517`, 1.}}], 
      ArrowBox[{{814472.7365719406, 977367.298237582}, {746327.2634280594, 
       895592.701762418}}]}, 
     {Arrowheads[{{0.01690671498940942, 1.}}], 
      ArrowBox[{{816175.7090284599, 1.0610284372841888`*^6}, {744624.29097154,
        968011.5627158111}}]}, 
     {Arrowheads[{{0.018603671821505335`, 1.}}], 
      ArrowBox[{{817928.2205262916, 1.1450995254799372`*^6}, {
       742871.7794737084, 1.0400204745200629`*^6}}]}, 
     {Arrowheads[{{0.020426329145748365`, 1.}}], 
      ArrowBox[{{819723.648302289, 1.2295854903925*^6}, {741076.351697711, 
       1.1116145096075*^6}}]}, 
     {Arrowheads[{{0.0223746869624757, 1.}}], 
      ArrowBox[{{821556.3761332285, 1.31449022094817*^6}, {739243.6238667716, 
       1.18278977905183*^6}}]}, 
     {Arrowheads[{{0.02444874527208114, 1.}}], 
      ArrowBox[{{823421.6373216661, 1.3998168037777746`*^6}, {
       737378.3626783339, 1.2535431962222254`*^6}}]}, 
     {Arrowheads[{{0.026648504074981035`, 1.}}], 
      ArrowBox[{{825315.3788824123, 1.485567703515222*^6}, {735484.6211175878,
        1.323872296484778*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.03142512316231756, 1.}}], 
      ArrowBox[{{829174.9856769426, 1.6583499952726408`*^6}, {
       731625.0143230573, 1.4632500047273594`*^6}}]}, 
     {Arrowheads[{{0.009050432468666183, 1.}}], 
      ArrowBox[{{967890.480611977, 0.}, {905069.5193880231, 0.}}]}, 
     {Arrowheads[{{0.009113282729975927, 1.}}], 
      ArrowBox[{{967999.3561293241, 80666.6140073918}, {904960.643870676, 
       75413.38599260818}}]}, 
     {Arrowheads[{{0.009301833513178443, 1.}}], 
      ArrowBox[{{968323.7492524968, 161387.29353531243`}, {904636.2507475031, 
       150772.7064646876}}]}, 
     {Arrowheads[{{0.009616084816213052, 1.}}], 
      ArrowBox[{{968857.1826967159, 242214.2986640234}, {904102.8173032842, 
       226025.7013359766}}]}, 
     {Arrowheads[{{0.010056036636006679`, 1.}}], 
      ArrowBox[{{969589.5543583822, 323196.52210592}, {903370.4456416178, 
       301123.47789408005`}}]}, 
     {Arrowheads[{{0.01062168896890456, 1.}}], 
      ArrowBox[{{970508.02165959, 404378.3473412365}, {902451.9783404102, 
       376021.65265876346`}}]}, 
     {Arrowheads[{{0.011313041811103049`, 1.}}], 
      ArrowBox[{{971597.9863387729, 485798.99914907536`}, {901362.0136612271, 
       450681.0008509247}}]}, 
     {Arrowheads[{{0.012130095159001875`, 1.}}], 
      ArrowBox[{{972844.0304346702, 567492.3580631946}, {900115.9695653298, 
       525067.6419368053}}]}, 
     {Arrowheads[{{0.013072849009436855`, 1.}}], 
      ArrowBox[{{974230.7018918224, 649487.1425674667}, {898729.2981081777, 
       599152.8574325333}}]}, 
     {Arrowheads[{{0.014141303359793835`, 1.}}], 
      ArrowBox[{{975743.1037548156, 731807.3367856451}, {897216.8962451842, 
       672912.663214355}}]}, 
     {Arrowheads[{{0.015335458208028478`, 1.}}], 
      ArrowBox[{{977367.2862782042, 814472.7485313183}, {895592.7137217957, 
       746327.2514686817}}]}, 
     {Arrowheads[{{0.01665531355262458, 1.}}], 
      ArrowBox[{{979090.4691576394, 897499.607690599}, {893869.5308423605, 
       819380.3923094008}}]}, 
     {Arrowheads[{{0.0181008693925201, 1.}}], 
      ArrowBox[{{980901.1326358515, 980901.1445952292}, {892058.8673641485, 
       892058.8554047707}}]}, 
     {Arrowheads[{{0.019672125727022757`, 1.}}], 
      ArrowBox[{{982789.0164859344, 1.064688114149088*^6}, {890170.9835140656,
        964351.8858509118}}]}, 
     {Arrowheads[{{0.021369082555728457`, 1.}}], 
      ArrowBox[{{984745.0601551344, 1.1488692508002643`*^6}, {
       888214.9398448656, 1.0362507491997358`*^6}}]}, 
     {Arrowheads[{{0.023191739878449535`, 1.}}], 
      ArrowBox[{{986761.3096139588, 1.2334516519666705`*^6}, {
       886198.6903860413, 1.1077483480333295`*^6}}]}, 
     {Arrowheads[{{0.025140097695155454`, 1.}}], 
      ArrowBox[{{988830.8089928802, 1.3181362508530105`*^6}, {
       884129.1910071198, 1.1785340616469895`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.03419053390436643, 1.}}], 
      ArrowBox[{{997531.0117662774, 1.662551706209425*^6}, {875428.9882337227,
        1.459048293790575*^6}}]}, 
     {Arrowheads[{{0.012318645437817003`, 1.}}], 
      ArrowBox[{{1.1353131584849663`*^6, 0.}, {1.0498068415150337`*^6, 0.}}]}, 
     {Arrowheads[{{0.012381495695980828`, 1.}}], 
      ArrowBox[{{1.1354220839365216`*^6, 81101.57827827852}, {
       1.0496979160634784`*^6, 74978.42172172149}}]}, 
     {Arrowheads[{{0.012570046470077078`, 1.}}], 
      ArrowBox[{{1.1357472119526507`*^6, 162249.60341600404`}, {
       1.0493727880473493`*^6, 149910.39658399593`}}]}, 
     {Arrowheads[{{0.012884297758968507`, 1.}}], 
      ArrowBox[{{1.1362837197770416`*^6, 243489.37108637558`}, {
       1.0488362802229582`*^6, 224750.62891362442`}}]}, 
     {Arrowheads[{{0.013324249560909787`, 1.}}], 
      ArrowBox[{{1.1370239564620457`*^6, 324863.9909775495}, {
       1.0480960435379543`*^6, 299456.0090224504}}]}, 
     {Arrowheads[{{0.013889901873737528`, 1.}}], 
      ArrowBox[{{1.1379579573971538`*^6, 406413.5604844756}, {
       1.0471620426028462`*^6, 373986.4395155244}}]}, 
     {Arrowheads[{{0.014581254695078493`, 1.}}], 
      ArrowBox[{{1.139074051706401*^6, 488174.59871390514`}, {
       1.0460459482935991`*^6, 448305.4012860949}}]}, 
     {Arrowheads[{{0.015398308022541548`, 1.}}], 
      ArrowBox[{{1.1403594857242163`*^6, 570179.748841797}, {
       1.0447605142757837`*^6, 522380.25115820306`}}]}, 
     {Arrowheads[{{0.01634106185387049, 1.}}], 
      ArrowBox[{{1.141800999423371*^6, 652457.7207901421}, {
       1.0433190005766291`*^6, 596182.2792098579}}]}, 
     {Arrowheads[{{0.01740951618704747, 1.}}], 
      ArrowBox[{{1.1433853142892588`*^6, 735033.4240169806}, {
       1.0417346857107412`*^6, 669686.5759830194}}]}, 
     {Arrowheads[{{0.018603671020348524`, 1.}}], 
      ArrowBox[{{1.1450995135205593`*^6, 817928.2324856694}, {
       1.0400204864794406`*^6, 742871.7675143306}}]}, 
     {Arrowheads[{{0.01992352635236015, 1.}}], 
      ArrowBox[{{1.1469313136647586`*^6, 901160.3272761072}, {
       1.0381886863352413`*^6, 815719.6727238928}}]}, 
     {Arrowheads[{{0.021369082181967487`, 1.}}], 
      ArrowBox[{{1.1488692388408864`*^6, 984745.0721145122}, {
       1.0362507611591136`*^6, 888214.9278854879}}]}, 
     {Arrowheads[{{0.022940338508325553`, 1.}}], 
      ArrowBox[{{1.1509027147881829`*^6, 1.0686953891227348`*^6}, {
       1.0342172852118171`*^6, 960344.6108772652}}]}, 
     {Arrowheads[{{0.02463729533082168, 1.}}], 
      ArrowBox[{{1.1530221015174622`*^6, 1.1530221134768398`*^6}, {
       1.032097898482538*^6, 1.0320978865231602`*^6}}]}, 
     {Arrowheads[{{0.02645995264903623, 1.}}], 
      ArrowBox[{{1.1552186820177892`*^6, 1.237734314975536*^6}, {
       1.0299013179822107`*^6, 1.1034656850244638`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.03745874667032393, 1.}}], 
      ArrowBox[{{1.1671126955803118`*^6, 1.6673038679138422`*^6}, {
       1.0180073044196882`*^6, 1.4542961320861578`*^6}}]}, 
     {Arrowheads[{{0.016089660402221755`, 1.}}], 
      ArrowBox[{{1.3044808637230308`*^6, 0.}, {1.1927991362769695`*^6, 0.}}]}, 
     {Arrowheads[{{0.016152510658339128`, 1.}}], 
      ArrowBox[{{1.304589821632847*^6, 81536.86459951404}, {
       1.192690178367153*^6, 74543.13540048595}}]}, 
     {Arrowheads[{{0.01634106142645847, 1.}}], 
      ArrowBox[{{1.3049154296209065`*^6, 163114.43019753552`}, {
       1.1923645703790935`*^6, 149045.56980246448`}}]}, 
     {Arrowheads[{{0.016655312705903313`, 1.}}], 
      ArrowBox[{{1.3054539628633119`*^6, 244772.6202792543}, {
       1.1918260371366881`*^6, 223467.3797207457}}]}, 
     {Arrowheads[{{0.01709526449561585, 1.}}], 
      ArrowBox[{{1.306199445207011*^6, 326549.86429159716`}, {
       1.191080554792989*^6, 297770.13570840284`}}]}, 
     {Arrowheads[{{0.017660916794248162`, 1.}}], 
      ArrowBox[{{1.307143966088823*^6, 408482.4931400627}, {
       1.190136033911177*^6, 371917.50685993733`}}]}, 
     {Arrowheads[{{0.018352269600268284`, 1.}}], 
      ArrowBox[{{1.308278069412161*^6, 490604.28051432694`}, {
       1.1890019305878393`*^6, 445875.71948567306`}}]}, 
     {Arrowheads[{{0.019169322912066262`, 1.}}], 
      ArrowBox[{{1.3095911735576494`*^6, 572946.1436636993}, {
       1.1876888264423506`*^6, 519613.85633630067`}}]}, 
     {Arrowheads[{{0.02011207672804747, 1.}}], 
      ArrowBox[{{1.3110719850151124`*^6, 655535.9984872451}, {
       1.1862080149848878`*^6, 593104.0015127549}}]}, 
     {Arrowheads[{{0.021180531046706797`, 1.}}], 
      ArrowBox[{{1.3127088762825243`*^6, 738398.7496360699}, {
       1.184571123717476*^6, 666321.2503639301}}]}, 
     {Arrowheads[{{0.022374685866679917`, 1.}}], 
      ArrowBox[{{1.3144902089887923`*^6, 821556.3880926062}, {
       1.1827897910112077`*^6, 739243.6119073938}}]}, 
     {Arrowheads[{{0.023694541186772975`, 1.}}], 
      ArrowBox[{{1.3164045932658515`*^6, 905028.166092345}, {
       1.1808754067341485`*^6, 811851.833907655}}]}, 
     {Arrowheads[{{0.02514009700597435, 1.}}], 
      ArrowBox[{{1.3184410826436328`*^6, 988525.9772022578}, {
       1.1788389173563672`*^6, 883824.335297742}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.041229761458185625`, 1.}}], 
      ArrowBox[{{1.3380290041709982`*^6, 1.67253627016297*^6}, {
       1.1592509958290018`*^6, 1.4490637298370302`*^6}}]}, 
     {Arrowheads[{{0.02036347736188052, 1.}}], 
      ArrowBox[{{1.4753935963261705`*^6, 0.}, {1.3340464036738295`*^6, 0.}}]}, 
     {Arrowheads[{{0.020426327616592726`, 1.}}], 
      ArrowBox[{{1.4755025765116224`*^6, 81972.36602616668}, {
       1.3339374234883776`*^6, 74107.63397383333}}]}, 
     {Arrowheads[{{0.02061487838058355, 1.}}], 
      ArrowBox[{{1.4758285149436777`*^6, 163980.94743367282`}, {
       1.3336114850563225`*^6, 148179.05256632718`}}]}, 
     {Arrowheads[{{0.020929129653426463`, 1.}}], 
      ArrowBox[{{1.47636845076734*^6, 246061.41045445294`}, {
       1.33307154923266*^6, 222178.58954554706`}}]}, 
     {Arrowheads[{{0.021369081434445606`, 1.}}], 
      ArrowBox[{{1.4771175962123906`*^6, 328248.35737150407`}, {
       1.3323224037876094`*^6, 296071.642628496}}]}, 
     {Arrowheads[{{0.02193473372276297, 1.}}], 
      ArrowBox[{{1.4780695413589324`*^6, 410574.8759217528}, {
       1.3313704586410676`*^6, 369825.1240782472}}]}, 
     {Arrowheads[{{0.022626086517355898`, 1.}}], 
      ArrowBox[{{1.4792165122555823`*^6, 493072.17473832}, {
       1.3302234877444177`*^6, 443407.82526168006`}}]}, 
     {Arrowheads[{{0.023443139817116564`, 1.}}], 
      ArrowBox[{{1.4805496597617653`*^6, 575769.3167804445}, {
       1.3288903402382347`*^6, 516790.6832195555}}]}, 
     {Arrowheads[{{0.024385893620909524`, 1.}}], 
      ArrowBox[{{1.4820593567455336`*^6, 658693.0527577384}, {
       1.3273806432544664`*^6, 589946.9472422616}}]}, 
     {Arrowheads[{{0.025454347927620885`, 1.}}], 
      ArrowBox[{{1.4837354842114614`*^6, 741867.7480854195}, {
       1.3257045157885388`*^6, 662852.2519145805}}]}}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-1560800, 1560800}, {0, 1560800}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.776662659436328*^9, {3.7766627092833023`*^9, 3.776662756387731*^9}, 
   3.7766636821251745`*^9, {3.7766639223776736`*^9, 3.7766639747208595`*^9}, {
   3.776664274649322*^9, 3.776664279351313*^9}, 3.7766643322460394`*^9, 
   3.779601561917877*^9, 3.780332723851252*^9, 3.7803670428671165`*^9, 
   3.7803759825637703`*^9, 3.780389366151904*^9, 3.780571551536414*^9, 
   3.7805738279941454`*^9, 3.781269052827986*^9, {3.781272189637287*^9, 
   3.7812722099968414`*^9}},
 CellLabel->
  "Out[128]=",ExpressionUUID->"eccae03c-40c2-4347-a14d-62a070c6418a"]
}, Open  ]],

Cell["\<\
Vectorfield of the gravity outside Europa. Jupiter is to the right.\
\>", "Text",
 CellChangeTimes->{{3.781272238359993*^9, 3.7812722476002994`*^9}, {
  3.7812723247878923`*^9, 
  3.781272327523551*^9}},ExpressionUUID->"fcbfd747-7689-4e2e-9b44-\
0c0cbfa1814c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"JupAtEur", "+", 
      RowBox[{
       RowBox[{"-", "G"}], "*", 
       RowBox[{"MEur", "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "x"}]}], ",", 
     RowBox[{
      RowBox[{"-", "G"}], "*", 
      RowBox[{"MEur", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "rEur"}], ",", 
     RowBox[{"2", "rEur"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", "rEur"}]}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}], ">", "rEur"}]}], "]"}]}], ",", 
   RowBox[{"VectorPoints", "\[Rule]", " ", "51"}], ",", 
   RowBox[{"VectorScale", "\[Rule]", "10"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.5"}], "rEur"}], ",", 
        RowBox[{"1.5", "rEur"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"1.5", "rEur"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"VectorStyle", "\[Rule]", 
    RowBox[{"Arrowheads", "[", "0.015", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7766622670839095`*^9, 3.776662296516169*^9}, {
  3.7766623730930786`*^9, 3.776662373530299*^9}, {3.776662438905507*^9, 
  3.7766624616953235`*^9}, {3.7766625028946724`*^9, 3.776662551569302*^9}, {
  3.7766625866275167`*^9, 3.7766626023330173`*^9}, {3.7766626416906805`*^9, 
  3.776662644049515*^9}, {3.776662713188773*^9, 3.7766627161811595`*^9}, {
  3.776662772706748*^9, 3.776662878032446*^9}, {3.7766629172733526`*^9, 
  3.776662935908816*^9}, {3.7766636011865363`*^9, 3.776663821186053*^9}, {
  3.7766638512015123`*^9, 3.7766639015320625`*^9}, {3.7766643363546004`*^9, 
  3.7766643378228145`*^9}, {3.776670111727291*^9, 3.7766701821689177`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"22d74ead-4ab9-42ce-a378-44a9035d88e7"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.147506584579937*^6, 0.}, {-3.095693415420063*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.147498212634782*^6, 
       62711.03693668258}, {-3.0957017873652186`*^6, 62152.96306331741}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1474731469390583`*^6, 
       125421.07124553624`}, {-3.0957268530609417`*^6, 
       124306.92875446378`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1474315372128133`*^6, 
       188129.11028472963`}, {-3.095768462787187*^6, 186462.88971527034`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.147373630676346*^6, 
       250834.18119005547`}, {-3.095826369323654*^6, 248621.8188099445}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.147299768641104*^6, 
       313535.34028404515`}, {-3.0959002313588955`*^6, 310784.6597159548}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.147210381855623*^6, 
       376231.68192659644`}, {-3.095989618144377*^6, 372952.31807340356`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1471059847196722`*^6, 
       438922.34664866276`}, {-3.0960940152803278`*^6, 435125.6533513372}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.146987168504545*^6, 
       501606.52843262284`}, {-3.0962128314954545`*^6, 
       497305.47156737716`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1468545937371077`*^6, 
       564283.481028562}, {-3.0963454062628923`*^6, 559492.518971438}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.146708981919291*^6, 
       626952.5232237277}, {-3.096491018080709*^6, 621687.4767762723}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1465511067628623`*^6, 
       689613.0430116862}, {-3.0966488932371377`*^6, 683890.9569883138}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.146381785121612*^6, 
       752264.5006370302}, {-3.0968182148783887`*^6, 746103.4993629698}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1462018677997906`*^6, 
       814906.430519776}, {-3.096998132200209*^6, 808325.569480224}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1460122304072822`*^6, 
       877538.4420898564}, {-3.097187769592718*^6, 870557.5579101437}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1458137644192185`*^6, 
       940160.2195855698}, {-3.097386235580782*^6, 932799.7804144302}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.145607368581473*^6, 
       1.0027715208898624`*^6}, {-3.0975926314185276`*^6, 
       995052.4791101374}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.14539394078447*^6, 
       1.065372175494498*^6}, {-3.09780605921553*^6, 1.057315824505502*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.145174370507064*^6, 
       1.1279620816943082`*^6}, {-3.0980256294929357`*^6, 
       1.119589918305692*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1449495319106635`*^6, 
       1.1905412031218042`*^6}, {-3.0982504680893365`*^6, 
       1.1818747968781958`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1447202776422254`*^6, 
       1.2531095647366291`*^6}, {-3.0984797223577746`*^6, 
       1.2441704352633709`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.144487433383842*^6, 
       1.3156672483849397`*^6}, {-3.0987125666161575`*^6, 
       1.3064767516150603`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1442517931670984`*^6, 
       1.3782143880412362`*^6}, {-3.0989482068329016`*^6, 
       1.3687936119587638`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.144014115452587*^6, 
       1.44075116483989*^6}, {-3.0991858845474124`*^6, 
       1.43112083516011*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.143775119959322*^6, 
       1.5032778019961612`*^6}, {-3.099424880040678*^6, 
       1.4934581980038385`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1435354852154525`*^6, 
       1.5657945597074*^6}, {-3.0996645147845475`*^6, 1.5558054402926*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.143295846790807*^6, 
       1.6283017301148803`*^6}, {-3.099904153209193*^6, 
       1.6181622698851197`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1430567961632786`*^6, 
       1.6907996323958181`*^6}, {-3.1001432038367214`*^6, 
       1.6805283676041819`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.142818880164919*^6, 
       1.7532886080439892`*^6}, {-3.1003811198350815`*^6, 
       1.7429033919560108`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.14258260094956*^6, 
       1.8157690163863662`*^6}, {-3.1006173990504406`*^6, 
       1.8052869836136338`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.142348416421708*^6, 
       1.8782412303726336`*^6}, {-3.1008515835782913`*^6, 
       1.8676787696273664`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1421167410660437`*^6, 
       1.9407056326645426`*^6}, {-3.1010832589339563`*^6, 
       1.9300783673354574`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1418879471178837`*^6, 
       2.003162612043028*^6}, {-3.1013120528821163`*^6, 
       1.9924853879569718`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.141662366017183*^6, 
       2.0656125601429099`*^6}, {-3.1015376339828176`*^6, 
       2.0548994398570901`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1414402900917353`*^6, 
       2.128055868517936*^6}, {-3.101759709908265*^6, 
       2.117320131482064*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1412219744190546`*^6, 
       2.1904929260328817`*^6}, {-3.101978025580945*^6, 
       2.1797470739671183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.141007638820651*^6, 
       2.2529241165743987`*^6}, {-3.102192361179349*^6, 
       2.242179883425601*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1407974699469637`*^6, 
       2.3153498170682704`*^6}, {-3.1024025300530368`*^6, 
       2.30461818293173*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1405916234158617`*^6, 
       2.377770395787559*^6}, {-3.1026083765841387`*^6, 
       2.367061604212441*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1403902259722385`*^6, 
       2.440186210933837*^6}, {-3.1028097740277615`*^6, 
       2.429509789066163*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1401933776407405`*^6, 
       2.5025976094720704`*^6}, {-3.1030066223592595`*^6, 
       2.4919623905279296`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.140001153847952*^6, 
       2.5650049261987857`*^6}, {-3.1031988461520476`*^6, 
       2.5544190738012143`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.139813607494382*^6, 
       2.627408483022733*^6}, {-3.103386392505618*^6, 
       2.616879516977267*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1396307709603016`*^6, 
       2.6898085884372983`*^6}, {-3.103569229039698*^6, 
       2.679343411562701*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.139452658032848*^6, 
       2.7522055371643323`*^6}, {-3.103747341967152*^6, 
       2.741810462835668*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.139279265744836*^6, 
       2.8145996099497653`*^6}, {-3.1039207342551644`*^6, 
       2.8042803900502347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1391105761183817`*^6, 
       2.876991073492311*^6}, {-3.1040894238816183`*^6, 
       2.866752926507689*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1389465578087815`*^6, 
       2.9393801804876416`*^6}, {-3.104253442191218*^6, 
       2.9292278195123584`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1387871676460905`*^6, 
       3.0017671697716205`*^6}, {-3.104412832353909*^6, 
       2.991704830228379*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1386323520735577`*^6, 
       3.064152266547447*^6}, {-3.1045676479264423`*^6, 
       3.054183733452553*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.1384820484834923`*^6, 
       3.12653568268284*^6}, {-3.1047179515165077`*^6, 
       3.1166643173171603`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0238301726358137`*^6, 0.}, {-2.969641827364186*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0238203161300956`*^6, 
       62747.37396519673}, {-2.969651683869905*^6, 62116.626034803274`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0237908106554924`*^6, 
       125493.51853561834`}, {-2.969681189344507*^6, 124234.48146438166`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.023741847370962*^6, 
       188237.21759814434`}, {-2.9697301526290383`*^6, 
       186354.78240185566`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0236737416720605`*^6, 
       250977.28132261735`}, {-2.9697982583279395`*^6, 
       248478.71867738265`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.023586928477788*^6, 
       313712.5586122016}, {-2.969885071522212*^6, 310607.4413877984}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.023481955810019*^6, 
       376441.9487511708}, {-2.969990044189981*^6, 372742.05124882923`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0233594768343978`*^6, 
       439164.4120257546}, {-2.970112523165602*^6, 434883.5879742455}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0232202405676013`*^6, 
       501878.9791278248}, {-2.9702517594323987`*^6, 497033.02087217517`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.023065081483752*^6, 
       564584.7591905812}, {-2.9704069185162475`*^6, 559191.2408094187}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.022894908271714*^6, 
       627280.9463481379}, {-2.970577091728286*^6, 621359.0536518622}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.022710692004667*^6, 
       689966.8247550867}, {-2.970761307995333*^6, 683537.1752449133}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0225134539839765`*^6, 
       752641.7720458311}, {-2.970958546016023*^6, 745726.2279541689}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.022304253511467*^6, 
       815305.2612550122}, {-2.971167746488533*^6, 807926.7387449878}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0220841758287656`*^6, 
       877956.8612581998}, {-2.971387824171234*^6, 870139.1387418003}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0218543204406444`*^6, 
       940596.2358249975}, {-2.9716176795593556`*^6, 932363.7641750025}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.021615790012604*^6, 
       1.0032231414039839`*^6}, {-2.971856209987396*^6, 994600.8585960161}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0213696800028896`*^6, 
       1.065837423779959*^6}, {-2.97210231999711*^6, 1.056850576220041*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.021117069157094*^6, 
       1.1284390137586656`*^6}, {-2.972354930842906*^6, 
       1.1191129862413344`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.020859010960972*^6, 
       1.1910279220426264`*^6}, {-2.9726129890390276`*^6, 
       1.1813880779573733`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0205965261152447`*^6, 
       1.2536042334644133`*^6}, {-2.9728754738847557`*^6, 
       1.2436757665355864`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0203305960661178`*^6, 
       1.316168100741141*^6}, {-2.9731414039338822`*^6, 
       1.3059758992588588`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0200621575977793`*^6, 
       1.3787197379070164`*^6}, {-2.9734098424022207`*^6, 
       1.3682882620929834`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.019792098468903*^6, 
       1.4412594135702034`*^6}, {-2.973679901531097*^6, 
       1.4306125864297964`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0195212540545585`*^6, 
       1.5037874441269531`*^6}, {-2.973950745945441*^6, 
       1.4929485558730469`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0192504049380715`*^6, 
       1.566304187050739*^6}, {-2.974221595061929*^6, 
       1.555295812949261*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.018980275384311*^6, 
       1.628810034357815*^6}, {-2.9744917246156894`*^6, 
       1.617653965642185*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0187115326164546`*^6, 
       1.6913054063338889`*^6}, {-2.9747604673835454`*^6, 
       1.6800225936661114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.018444786812207*^6, 
       1.7537907455900735`*^6}, {-2.9750272131877933`*^6, 
       1.7424012544099265`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0181805917324116`*^6, 
       1.816266511500438*^6}, {-2.975291408267588*^6, 
       1.804789488499562*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0179194458945766`*^6, 
       1.8787331750587027`*^6}, {-2.975552554105423*^6, 
       1.8671868249412973`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0176617942056037`*^6, 
       1.9411912141781976`*^6}, {-2.9758102057943963`*^6, 
       1.9295927858218022`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0174080299715693`*^6, 
       2.0036411094472778`*^6}, {-2.9760639700284307`*^6, 
       1.992006890552722*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0171584972073175`*^6, 
       2.0660833403420823`*^6}, {-2.9763135027926825`*^6, 
       2.0544286596579177`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.016913493174519*^6, 
       2.1285183818898224`*^6}, {-2.9765585068254806`*^6, 
       2.116857618110178*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0166732710834024`*^6, 
       2.190946701768672*^6}, {-2.976798728916597*^6, 
       2.179293298231328*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.016438042900255*^6, 
       2.253368757824702*^6}, {-2.9770339570997446`*^6, 
       2.2417352421752983`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.016207982209782*^6, 
       2.315784995982038*^6}, {-2.9772640177902174`*^6, 
       2.3041830040179626`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0159832270883196`*^6, 
       2.3781958485194035`*^6}, {-2.97748877291168*^6, 
       2.366636151480597*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0157638829505146`*^6, 
       2.440601732684263*^6}, {-2.9777081170494854`*^6, 
       2.4290942673157374`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0155500253383582`*^6, 
       2.503003049614755*^6}, {-2.9779219746616418`*^6, 
       2.491556950385245*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0153417026272453`*^6, 
       2.5654001835393813`*^6}, {-2.9781302973727547`*^6, 
       2.5540238164606183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0151389386290074`*^6, 
       2.6277935012248107`*^6}, {-2.978333061370993*^6, 
       2.6164944987751897`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0149417350766193`*^6, 
       2.6901833516430533`*^6}, {-2.978530264923381*^6, 
       2.678968648356946*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.01475007397946*^6, 
       2.752570065830574*^6}, {-2.97872192602054*^6, 
       2.7414459341694266`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0145639198416686`*^6, 
       2.8149539569134526`*^6}, {-2.978908080158332*^6, 
       2.8039260430865474`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0143832217392693`*^6, 
       2.8773353202745076`*^6}, {-2.979088778260731*^6, 
       2.8664086797254924`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.014207915254413*^6, 
       2.9397144338401407`*^6}, {-2.9792640847455864`*^6, 
       2.928893566159859*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.0140379242672757`*^6, 
       3.002091558466623*^6}, {-2.9794340757327243`*^6, 
       2.9913804415333765`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.013873162607969*^6, 
       3.0644669384074686`*^6}, {-2.979598837392031*^6, 
       3.053869061592531*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-3.013713535572273*^6, 
       3.1268408018454383`*^6}, {-2.979758464427727*^6, 
       3.1163591981545617`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.9003120080257053`*^6, 0.}, {-2.8434319919742947`*^6, 
       0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.9003003228384284`*^6, 
       62790.30341386469}, {-2.8434436771615716`*^6, 62073.69658613531}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.900265349932054*^6, 
       125579.08626658267`}, {-2.8434786500679464`*^6, 
       124148.91373341733`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.900207335912157*^6, 
       188364.84587683724`}, {-2.843536664087843*^6, 186227.15412316276`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.9001266872922275`*^6, 
       251146.11491231085`}, {-2.843617312707773*^6, 248309.88508768912`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.9000239638887704`*^6, 
       313921.4780530563}, {-2.8437200361112296`*^6, 310398.5219469437}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.899899869845481*^6, 
       376689.58748410805`}, {-2.8438441301545193`*^6, 372494.4125158919}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8997552425426655`*^6, 
       439449.1768955237}, {-2.843988757457335*^6, 434598.82310447627`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8995910397011177`*^6, 
       502199.07372182}, {-2.8441529602988823`*^6, 496712.9262781799}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.899408325029406*^6, 
       564938.2094143215}, {-2.8443356749705933`*^6, 558837.7905856787}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.899208252788816*^6, 
       627665.6276061225}, {-2.844535747211184*^6, 620974.3723938775}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.898992051660744*^6, 
       690380.4900969784}, {-2.844751948339256*^6, 683123.5099030215}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8987610082976376`*^6, 
       753082.0806513875}, {-2.844982991702362*^6, 745285.9193486125}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8985164509218116`*^6, 
       815769.8066646754}, {-2.8452275490781884`*^6, 807462.1933353245}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.898259733308453*^6, 
       878443.198806722}, {-2.845484266691547*^6, 869652.8011932779}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.897992219452036*^6, 
       941101.9087993642}, {-2.845751780547964*^6, 931858.0912006357}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8977152691715965`*^6, 
       1.0037457055203284`*^6}, {-2.8460287308284035`*^6, 
       994078.2944796717}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8974302248624195`*^6, 
       1.0663744696532618`*^6}, {-2.8463137751375805`*^6, 
       1.0563135303467382`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8971383995520067`*^6, 
       1.1289881871200951`*^6}, {-2.8466056004479937`*^6, 
       1.1185638128799049`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.896841066368935*^6, 
       1.1915869415390734`*^6}, {-2.846902933631065*^6, 
       1.1808290584609266`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8965394494862906`*^6, 
       1.2541709059502773`*^6}, {-2.8472045505137094`*^6, 
       1.2431090940497224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8962347165581994`*^6, 
       1.3167403340414888`*^6}, {-2.847509283441801*^6, 
       1.3054036659585114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8959279726298*^6, 
       1.379295551092201*^6}, {-2.8478160273702*^6, 
       1.3677124489077989`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8956202554684216`*^6, 
       1.4418369448338847`*^6}, {-2.848123744531578*^6, 
       1.4300350551661153`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8953125322371945`*^6, 
       1.504364956401674*^6}, {-2.848431467762806*^6, 
       1.4923710435983262`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8950056974118114`*^6, 
       1.5668800715278038`*^6}, {-2.848738302588189*^6, 
       1.5547199284721965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8947005718264836`*^6, 
       1.6293828121015567`*^6}, {-2.8490434281735164`*^6, 
       1.617081187898443*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.894397902725822*^6, 
       1.6918737281952081`*^6}, {-2.8493460972741777`*^6, 
       1.6794542718047916`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8940983646948994`*^6, 
       1.7543533906312808`*^6}, {-2.8496456353051006`*^6, 
       1.7418386093687192`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8938025613394026`*^6, 
       1.8168223841439947`*^6}, {-2.8499414386605974`*^6, 
       1.8042336158560053`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8935110275908667`*^6, 
       1.879281301167531*^6}, {-2.8502329724091333`*^6, 
       1.866638698832469*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.893224232517819*^6, 
       1.9417307362659166`*^6}, {-2.850519767482181*^6, 
       1.9290532637340836`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8929425825315267`*^6, 
       2.0041712812040865`*^6}, {-2.850801417468473*^6, 
       1.9914767187959133`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8926664248843715`*^6, 
       2.066603520647016*^6}, {-2.8510775751156285`*^6, 
       2.0539084793529843`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8923960513690747`*^6, 
       2.1290280284636165`*^6}, {-2.8513479486309253`*^6, 
       2.1163479715363835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.892131702137647*^6, 
       2.191445364604235*^6}, {-2.851612297862353*^6, 
       2.178794635395765*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8918735695695905`*^6, 
       2.2538560725148213`*^6}, {-2.8518704304304095`*^6, 
       2.241247927485179*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8916218021292915`*^6, 
       2.3162606770469486`*^6}, {-2.852122197870709*^6, 
       2.3037073229530514`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8913765081624324`*^6, 
       2.378659682820601*^6}, {-2.8523674918375676`*^6, 
       2.366172317179399*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.891137759590468*^6, 
       2.4410535729957134`*^6}, {-2.8526062404095316`*^6, 
       2.428642427004287*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.890905595470633*^6, 
       2.5034428084086785`*^6}, {-2.852838404529367*^6, 
       2.491117191591321*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.890680025396539*^6, 
       2.5658278270311165`*^6}, {-2.853063974603461*^6, 
       2.5535961729688835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8904610327211195`*^6, 
       2.6282090437099915`*^6}, {-2.8532829672788805`*^6, 
       2.616078956290008*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8902485775895156`*^6, 
       2.6905868501504594`*^6}, {-2.853495422410484*^6, 
       2.6785651498495406`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8900425997745236`*^6, 
       2.7529616151054422`*^6}, {-2.8537014002254764`*^6, 
       2.741054384894558*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.889843021311426*^6, 
       2.8153336847388004`*^6}, {-2.853900978688574*^6, 
       2.8035463152611996`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.889649748932552*^6, 
       2.8777033831319*^6}, {-2.8540942510674475`*^6, 2.8660406168681*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8894626763047427`*^6, 
       2.940071012906353*^6}, {-2.8542813236952573`*^6, 
       2.9285369870936465`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8892816860751603`*^6, 
       3.0024368559386167`*^6}, {-2.8544623139248397`*^6, 
       2.9910351440613833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8891066517326264`*^6, 
       3.064801174144929*^6}, {-2.8546373482673736`*^6, 
       3.053534825855071*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.8889374392929636`*^6, 
       3.1271642103177295`*^6}, {-2.854806560707037*^6, 
       3.116035789682271*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.776981507819357*^6, 0.}, {-2.717034492180643*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.776967549521627*^6, 
       62841.39053911306}, {-2.7170484504783726`*^6, 62022.60946088694}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7769257825209596`*^6, 
       125680.88257819579`}, {-2.71709021747904*^6, 124047.11742180421`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7768565285543273`*^6, 
       188516.60200593236`}, {-2.7171594714456727`*^6, 186075.3979940676}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7767603174439576`*^6, 
       251346.7228766641}, {-2.7172556825560424`*^6, 248109.27712333592`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7766378777041603`*^6, 
       314169.48998903495`}, {-2.71737812229584*^6, 310150.510010965}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.776490123811573*^6, 
       376983.23972876184`}, {-2.717525876188427*^6, 372200.7602712381}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.776318140534344*^6, 
       439786.4187076328}, {-2.717697859465656*^6, 434261.5812923672}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.77612316479484*^6, 
       502577.599817125}, {-2.71789283520516*^6, 496334.40018287505`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7759065655973763`*^6, 
       565355.4954129662}, {-2.7181094344026237`*^6, 558420.5045870338}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.775669822585669*^6, 
       628118.9674511402}, {-2.7183461774143307`*^6, 620521.03254886}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7754145038039475`*^6, 
       690867.0345008237}, {-2.7186014961960525`*^6, 682636.9654991762}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.775142243222308*^6, 
       753598.8756604516}, {-2.7188737567776917`*^6, 744769.1243395485}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7748547185532777`*^6, 
       816313.8314950939}, {-2.7191612814467223`*^6, 806918.1685049062}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7745536298360717`*^6, 
       879011.402193088}, {-2.719462370163928*^6, 869084.5978069119}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.774240679201618*^6, 
       941691.2432048746}, {-2.719775320798382*^6, 931268.7567951255}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.773917552159265*^6, 
       1.0043531586758591`*^6}, {-2.720098447840735*^6, 993470.8413241408}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7735859006694285`*^6, 
       1.0669970930174817`*^6}, {-2.7204300993305715`*^6, 
       1.0556909069825183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.773247328189073*^6, 
       1.1296231209770811`*^6}, {-2.720768671810927*^6, 
       1.1179288790229186`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7729033768023835`*^6, 
       1.192231436568929*^6}, {-2.721112623197617*^6, 
       1.1801845634310707`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.772555516479917*^6, 
       1.2548223412178475`*^6}, {-2.721460483520083*^6, 
       1.2424576587821525`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.772205136448124*^6, 
       1.3173962314453842`*^6}, {-2.7218108635518756`*^6, 
       1.3047477685546158`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7718535385986897`*^6, 
       1.3799535863990185`*^6}, {-2.7221624614013107`*^6, 
       1.3670544136009815`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7715019328244617`*^6, 
       1.4424949554897186`*^6}, {-2.7225140671755383`*^6, 
       1.4293770445102816`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.771151434135894*^6, 
       1.505020946364677*^6}, {-2.7228645658641066`*^6, 
       1.491715053635323*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7708030613885936`*^6, 
       1.5675322134022391`*^6}, {-2.723212938611407*^6, 
       1.5540677865977606`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7704577374380585`*^6, 
       1.630029446876649*^6}, {-2.7235582625619415`*^6, 
       1.616434553123351*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7701162905309456`*^6, 
       1.6925133629026797`*^6}, {-2.723899709469055*^6, 
       1.67881463709732*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.769779456742194*^6, 
       1.7549846942355265`*^6}, {-2.7242365432578065`*^6, 
       1.7412073057644735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7694478832727536`*^6, 
       1.8174441819702485`*^6}, {-2.7245681167272464`*^6, 
       1.8036118180297515`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.76912213243237*^6, 
       1.8798925681579893`*^6}, {-2.72489386756763*^6, 
       1.8660274318420107`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7688026861447417`*^6, 
       1.9423305893333354`*^6}, {-2.7252133138552587`*^6, 
       1.9284534106666644`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.76848995082732*^6, 
       2.0047589709284857`*^6}, {-2.72552604917268*^6, 
       1.9908890290715145`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.768184262514229*^6, 
       2.0671784225351824`*^6}, {-2.7258317374857706`*^6, 
       2.0533335774648173`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7678858921074127`*^6, 
       2.129589633964315*^6}, {-2.726130107892587*^6, 
       2.1157863660356854`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7675950506576523`*^6, 
       2.191993272045341*^6}, {-2.726420949342347*^6, 
       2.1782467279546587`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.767311894592966*^6, 
       2.254389978102802*^6}, {-2.7267041054070345`*^6, 
       2.240714021897198*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7670365308268326`*^6, 
       2.3167803660447425`*^6}, {-2.7269794691731674`*^6, 
       2.3031876339552575`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7667690216924082`*^6, 
       2.3791650209974255`*^6}, {-2.7272469783075918`*^6, 
       2.3656669790025745`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7665093896612492`*^6, 
       2.4415444984218925`*^6}, {-2.727506610338751*^6, 
       2.4281515015781075`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7662576218160423`*^6, 
       2.5039193236503545`*^6}, {-2.7277583781839577`*^6, 
       2.4906406763496455`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7660136740563572`*^6, 
       2.566289991783725*^6}, {-2.7280023259436428`*^6, 
       2.5531340082162754`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.765777475024607*^6, 
       2.628656967895593*^6}, {-2.728238524975393*^6, 
       2.615631032104407*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.765548929746269*^6, 
       2.691020687492307*^6}, {-2.7284670702537317`*^6, 
       2.678131312507693*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.765327922984072*^6, 
       2.7533815571834194`*^6}, {-2.7286880770159285`*^6, 
       2.7406344428165806`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7651143223104435`*^6, 
       2.8157399555213773`*^6}, {-2.7289016776895565`*^6, 
       2.803140044478623*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7649079809060944`*^6, 
       2.8780962339738715`*^6}, {-2.7291080190939056`*^6, 
       2.865647766026129*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.764708740095399*^6, 
       2.940450717996661*^6}, {-2.729307259904601*^6, 
       2.9281572820033394`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.764516431631226*^6, 
       3.0028037081788075`*^6}, {-2.729499568368774*^6, 
       2.990668291821192*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7643308797432953`*^6, 
       3.065155481436125*^6}, {-2.7296851202567047`*^6, 
       3.053180518563875*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.7641519029649845`*^6, 
       3.127506292232196*^6}, {-2.7298640970350155`*^6, 
       3.1156937077678046`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6538752563608633`*^6, 0.}, {-2.5904127436391367`*^6, 
       0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.653858444388141*^6, 
       62902.66853779735}, {-2.5904295556118586`*^6, 61961.33146220265}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6538081510584154`*^6, 
       125802.94215513156`}, {-2.590479848941585*^6, 123925.05784486842`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6537248013236895`*^6, 
       188698.45968021694`}, {-2.59056319867631*^6, 185893.54031978306`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.653609094159078*^6, 
       251586.92651032624`}, {-2.5906789058409217`*^6, 
       247869.07348967376`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6534619889882235`*^6, 
       314466.145617568}, {-2.5908260110117765`*^6, 309853.854382432}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6532846873450303`*^6, 
       377334.0459349111}, {-2.5910033126549697`*^6, 371849.9540650889}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.653078610394218*^6, 
       440188.70743226097`}, {-2.5912093896057815`*^6, 
       433859.29256773903`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.652845373052549*^6, 
       503028.38233369455`}, {-2.5914426269474514`*^6, 495883.6176663054}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.652586755534302*^6, 
       565851.512085782}, {-2.591701244465698*^6, 557924.4879142179}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.652304673186457*^6, 
       628656.7398537629}, {-2.5919833268135437`*^6, 619983.2601462371}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6520011454815427`*^6, 
       691442.9184878522}, {-2.592286854518457*^6, 682061.0815121477}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6516782650021557`*^6, 
       754209.1140575724}, {-2.592609734997844*^6, 744158.8859424276}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.651338167185566*^6, 
       816954.6051905685}, {-2.592949832814434*^6, 806277.3948094316}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.650983001506059*^6, 
       879678.8785684688}, {-2.5933049984939415`*^6, 868417.1214315312}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.650614904663757*^6, 
       942381.6210225372}, {-2.5936730953362435`*^6, 930578.3789774628}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6502359762290767`*^6, 
       1.0050627087346377`*^6}, {-2.5940520237709237`*^6, 
       992761.2912653622}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.649848257068743*^6, 
       1.0677221940847035`*^6}, {-2.5944397429312565`*^6, 
       1.0549658059152968`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6494537107586795`*^6, 
       1.1303602906962973`*^6}, {-2.59483428924132*^6, 
       1.1171917093037025`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6490542080763737`*^6, 
       1.1929773572199692`*^6}, {-2.5952337919236263`*^6, 
       1.1794386427800308`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.64865151456447*^6, 
       1.2555738803637228`*^6}, {-2.5956364854355296`*^6, 
       1.2417061196362774`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6482472810710603`*^6, 
       1.318150457635204*^6}, {-2.596040718928939*^6, 
       1.303993542364796*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.647843037101921*^6, 
       1.3807077802054263`*^6}, {-2.5964449628980793`*^6, 
       1.3663002197945735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.647440186766158*^6, 
       1.4432466162430148`*^6}, {-2.596847813233842*^6, 
       1.4286253837569852`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.647040007058848*^6, 
       1.5057677950046833`*^6}, {-2.5972479929411523`*^6, 
       1.490968204995317*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.646643648201073*^6, 
       1.5682721919050124`*^6}, {-2.5976443517989265`*^6, 
       1.5533278080949876`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6462521357475407`*^6, 
       1.6307607147290262`*^6}, {-2.598035864252459*^6, 
       1.6157032852709738`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6458663741727765`*^6, 
       1.6932342910963653`*^6}, {-2.598421625827224*^6, 
       1.6780937089036347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.645487151656544*^6, 
       1.755693857237261*^6}, {-2.598800848343456*^6, 
       1.740498142762739*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.645115145805648*^6, 
       1.8181403480986876`*^6}, {-2.599172854194352*^6, 
       1.8029156519013126`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.644750930070616*^6, 
       1.8805746887642595`*^6}, {-2.5995370699293846`*^6, 
       1.8653453112357405`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.644394980640248*^6, 
       1.942997787143511*^6}, {-2.599893019359752*^6, 
       1.9277862128564892`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6440476836231383`*^6, 
       2.0054105278647514`*^6}, {-2.600240316376861*^6, 
       1.9902374721352488`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6437093423517607`*^6, 
       2.0678137672901566`*^6}, {-2.6005786576482393`*^6, 
       2.0526982327098434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6433801846706467`*^6, 
       2.130208329561424*^6}, {-2.6009078153293533`*^6, 
       2.115167670438576*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.643060370094799*^6, 
       2.192595003578455*^6}, {-2.6012276299052015`*^6, 
       2.1776449964215443`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.64274999674725*^6, 
       2.2549745408113697`*^6}, {-2.6015380032527493`*^6, 
       2.2401294591886303`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.64244910800533*^6, 
       2.3173476538469777`*^6}, {-2.60183889199467*^6, 
       2.3026203461530223`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6421576988034854`*^6, 
       2.379715015573992*^6}, {-2.6021303011965146`*^6, 
       2.3651169844260085`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.641875721556466*^6, 
       2.4420772589161126`*^6}, {-2.602412278443534*^6, 
       2.4276187410838874`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.641603091680275*^6, 
       2.504434977028212*^6}, {-2.602684908319725*^6, 
       2.4901250229717884`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6413396926997155`*^6, 
       2.5667887238776567`*^6}, {-2.602948307300285*^6, 
       2.5526352761223433`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6410853809407316`*^6, 
       2.6291390151400794`*^6}, {-2.603202619059268*^6, 
       2.6151489848599206`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6408399898132673`*^6, 
       2.6914863293462484`*^6}, {-2.603448010186733*^6, 
       2.677665670653752*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6406033336962457`*^6, 
       2.753831109223955*^6}, {-2.603684666303755*^6, 
       2.7401848907760456`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6403752114407453`*^6, 
       2.8161737631858136`*^6}, {-2.6039127885592547`*^6, 
       2.8027062368141864`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.640155409510644*^6, 
       2.878514666920467*^6}, {-2.604132590489356*^6, 
       2.8652293330795327`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6399437047822145`*^6, 
       2.9408541650507953`*^6}, {-2.604344295217786*^6, 
       2.927753834949204*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.639739867025463*^6, 
       3.003192572828355*^6}, {-2.604548132974537*^6, 
       2.990279427171645*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6395436610906385`*^6, 
       3.065530177838317*^6}, {-2.604744338909362*^6, 
       3.0528058221616833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.6393548488233853`*^6, 
       3.12786724169373*^6}, {-2.604933151176614*^6, 
       3.1153327583062705`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.531039207643285*^6, 0.}, {-2.463520792356715*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5310187740686187`*^6, 
       62976.810206699156`}, {-2.463541225931381*^6, 61887.18979330084}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5309576643621502`*^6, 
       125950.56492807489`}, {-2.4636023356378498`*^6, 123777.4350719251}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.530856447423702*^6, 
       188918.25612172871`}, {-2.4637035525762984`*^6, 
       185673.74387827129`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5307160577388583`*^6, 
       251876.96919382058`}, {-2.4638439422611417`*^6, 
       247579.03080617942`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.53053777541414*^6, 
       314823.926201686}, {-2.46402222458586*^6, 309496.0737983141}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5303231993043646`*^6, 
       377756.52502555685`}, {-2.464236800695635*^6, 371427.47497444315`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5300742142326636`*^6, 
       440672.373475602}, {-2.464485785767336*^6, 433375.62652439805`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5297929534860253`*^6, 
       503569.31753707456`}, {-2.464767046513975*^6, 495342.68246292544`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5294817578862067`*^6, 
       566445.4632192497}, {-2.4650782421137937`*^6, 557330.5367807504}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5291431327846395`*^6, 
       629299.1917459967}, {-2.4654168672153605`*^6, 619340.8082540032}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.52877970431272*^6, 
       692129.1680908184}, {-2.4657802956872806`*^6, 681374.8319091814}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5283941761421617`*^6, 
       754934.3431024528}, {-2.4661658238578383`*^6, 743433.6568975472}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5279892878838032`*^6, 
       817713.9496770239}, {-2.466570712116197*^6, 805518.050322976}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5275677760895244`*^6, 
       880467.4936011053}, {-2.466992223910475*^6, 867628.5063988948}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5271323386339284`*^6, 
       943194.7398124785}, {-2.467427661366071*^6, 929765.2601875213}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.52668560305311*^6, 
       1.005895694900983*^6}, {-2.46787439694689*^6, 991928.3050990169}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5262300992191546`*^6, 
       1.0685705867028635`*^6}, {-2.4683299007808454`*^6, 
       1.0541174132971365`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.52576823654101*^6, 
       1.131219841833161*^6}, {-2.46879176345899*^6, 
       1.1163321581668393`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5253022857129322`*^6, 
       1.1938440619583328`*^6}, {-2.4692577142870678`*^6, 
       1.178571938041667*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5248343648862774`*^6, 
       1.2564439995428126`*^6}, {-2.4697256351137226`*^6, 
       1.2408360004571876`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.524366430022036*^6, 
       1.3190205337162265`*^6}, {-2.470193569977964*^6, 
       1.3031234662837735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5239002690912182`*^6, 
       1.3815746468098112`*^6}, {-2.4706597309087813`*^6, 
       1.3654333531901888`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.523437499727172*^6, 
       1.4441074020077488`*^6}, {-2.4711225002728277`*^6, 
       1.4277645979922512`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.522979569896052*^6, 
       1.50661992245724*^6}, {-2.4715804301039474`*^6, 
       1.4901160775427602`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5225277611359037`*^6, 
       1.569113372084532*^6}, {-2.472032238864097*^6, 
       1.552486627915468*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.522083193917581*^6, 
       1.6315889382760033`*^6}, {-2.472476806082419*^6, 
       1.6148750617239964`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5216468346982654`*^6, 
       1.6940478165058887`*^6}, {-2.472913165301735*^6, 
       1.6772801834941113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.521219504266906*^6, 
       1.7564911969263775`*^6}, {-2.473340495733094*^6, 
       1.7397008030736225`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.520801887017141*^6, 
       1.8189202528819542`*^6}, {-2.4737581129828594`*^6, 
       1.8021357471180458`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5203945408240804`*^6, 
       1.881336131267571*^6}, {-2.4741654591759196`*^6, 
       1.864583868732429*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5199979072442353`*^6, 
       1.9437399446187767`*^6}, {-2.4745620927557647`*^6, 
       1.9270440553812233`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.51961232180079*^6, 
       2.00613276480011*^6}, {-2.4749476781992097`*^6, 
       1.9895152351998899`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.519238024157768*^6, 
       2.0685156181446204`*^6}, {-2.475321975842232*^6, 
       2.0519963818553796`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5188751680253088`*^6, 
       2.130889481890958*^6}, {-2.4756848319746912`*^6, 
       2.114486518109042*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.518523830673483*^6, 
       2.1932552817637273`*^6}, {-2.4760361693265163`*^6, 
       2.176984718236273*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.518184021963439*^6, 
       2.255613890546508*^6}, {-2.4763759780365606`*^6, 
       2.239490109453492*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5178556928319563`*^6, 
       2.317966127503956*^6}, {-2.4767043071680437`*^6, 
       2.302001872496044*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.517538743188822*^6, 
       2.3803127585187615`*^6}, {-2.477021256811178*^6, 
       2.364519241481239*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5172330292058866`*^6, 
       2.4426544968201034`*^6}, {-2.477326970794114*^6, 
       2.427041503179897*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.51693836999259*^6, 
       2.5049920041919374`*^6}, {-2.47762163000741*^6, 
       2.489567995808062*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.516654553665453*^6, 
       2.567325892561421*^6}, {-2.477905446334547*^6, 
       2.552098107438579*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.516381342828864*^6, 
       2.6296567258796226`*^6}, {-2.478178657171136*^6, 
       2.614631274120378*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.516118479491879*^6, 
       2.6919850222180686`*^6}, {-2.4784415205081212`*^6, 
       2.6771669777819314`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5158656894510067`*^6, 
       2.7543112560153897`*^6}, {-2.478694310548993*^6, 
       2.73970474398461*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.515622686172453*^6, 
       2.816635860418276*^6}, {-2.478937313827547*^6, 
       2.802244139581724*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.515389174209331*^6, 
       2.8789592296699802`*^6}, {-2.479170825790669*^6, 
       2.8647847703300193`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5151648521902207`*^6, 
       2.9412817215077425`*^6}, {-2.4793951478097793`*^6, 
       2.9273262784922575`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.514949415415407*^6, 
       3.003603659537706*^6}, {-2.4796105845845924`*^6, 
       2.9898683404622944`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.5147425580963604`*^6, 
       3.0659253355622427`*^6}, {-2.479817441903639*^6, 
       3.052410664437758*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.514543975272723*^6, 
       3.128247011840088*^6}, {-2.4800160247272775`*^6, 
       3.1149529881599117`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4085317196429046`*^6, 0.}, {-2.336300280357096*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4085066346894675`*^6, 
       63067.375497074085`}, {-2.336325365310532*^6, 61796.62450292591}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4084316395823793`*^6, 
       126130.8038832488}, {-2.3364003604176203`*^6, 123597.19611675122`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.408307507328296*^6, 
       189186.40591007713`}, {-2.3365244926717044`*^6, 185405.5940899229}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.408135505697869*^6, 
       252230.43577865438`}, {-2.3366964943021312`*^6, 
       247225.56422134562`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.407917367290502*^6, 
       315259.342301296}, {-2.336914632709498*^6, 309060.65769870405`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4076552494122554`*^6, 
       378269.82372814784`}, {-2.3371767505877446`*^6, 370914.1762718522}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4073516854119864`*^6, 
       441258.87466524576`}, {-2.3374803145880136`*^6, 432789.1253347543}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4070095294028358`*^6, 
       504223.82391624915`}, {-2.337822470597164*^6, 494688.17608375085`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4066318964615865`*^6, 
       567162.3625249581}, {-2.338200103538413*^6, 556613.6374750419}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4062221004445353`*^6, 
       630072.5617483902}, {-2.3386098995554643`*^6, 618567.4382516097}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4057835914920103`*^6, 
       692952.8811211826}, {-2.3390484085079897`*^6, 680551.1188788175}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4053198951290622`*^6, 
       755802.16715634}, {-2.3395121048709378`*^6, 742565.8328436599}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4048345546274176`*^6, 
       818619.6435459985}, {-2.339997445372583*^6, 804612.3564540014}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.404331077996998*^6, 
       881404.8939670748}, {-2.340500922003002*^6, 866691.1060329253}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4038128906485843`*^6, 
       944157.8387557626}, {-2.3410191093514157`*^6, 928802.1612442374}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.40328329443544*^6, 
       1.0068787067935948`*^6}, {-2.34154870556456*^6, 990945.2932064051}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.402745433461035*^6, 
       1.069568003953329*^6}, {-2.342086566538965*^6, 
       1.0531199960466707`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.402202266748152*^6, 
       1.132226479396184*^6}, {-2.342629733251848*^6, 
       1.1153255206038158`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.401656547612979*^6, 
       1.1948550909061634`*^6}, {-2.3431754523870205`*^6, 
       1.1775609090938366`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.401110809382849*^6, 
       1.2574549703064193`*^6}, {-2.3437211906171506`*^6, 
       1.2398250296935807`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.4005673569405056`*^6, 
       1.3200273898404452`*^6}, {-2.3442646430594944`*^6, 
       1.3021166101595548`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.400028263470077*^6, 
       1.382573730229667*^6}, {-2.344803736529923*^6, 
       1.364434269770333*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.399495371716504*^6, 
       1.445095450949068*^6}, {-2.3453366282834965`*^6, 
       1.426776549050932*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.398970299045417*^6, 
       1.5075940631019566`*^6}, {-2.345861700954583*^6, 
       1.4891419368980434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.398454445597749*^6, 
       1.5700711051296687`*^6}, {-2.3463775544022513`*^6, 
       1.551528894870331*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.397949004865723*^6, 
       1.6325281214655747`*^6}, {-2.346882995134277*^6, 
       1.6139358785344253`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.397454976067546*^6, 
       1.6949666441370032`*^6}, {-2.3473770239324537`*^6, 
       1.6763613558629965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3969731777609233`*^6, 
       1.7573881772338836`*^6}, {-2.3478588222390767`*^6, 
       1.7388038227661161`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.396504262205088*^6, 
       1.819794184098122*^6}, {-2.3483277377949115`*^6, 
       1.8012618159018778`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3960487300529312`*^6, 
       1.8821860770412728`*^6}, {-2.3487832699470688`*^6, 
       1.8637339229587272`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3956069450255907`*^6, 
       1.9445652093677127`*^6}, {-2.3492250549744098`*^6, 
       1.9262187906322875`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3951791482889415`*^6, 
       2.0069328694638223`*^6}, {-2.3496528517110585`*^6, 
       1.9887151305361777`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.394765472313056*^6, 
       2.0692902767081396`*^6}, {-2.3500665276869447`*^6, 
       2.0512217232918604`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3943659540508175`*^6, 
       2.1316385789606743`*^6}, {-2.350466045949182*^6, 
       2.1137374210393257`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3939805473199976`*^6, 
       2.193978851399397*^6}, {-2.3508514526800024`*^6, 
       2.1762611486006035`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.393609134314096*^6, 
       2.2563120964864204`*^6}, {-2.351222865685904*^6, 
       2.2387919035135796`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3932515362014673`*^6, 
       2.3186392448639516`*^6}, {-2.3515804637985327`*^6, 
       2.301328755136049*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3929075228000293`*^6, 
       2.3809611569993766`*^6}, {-2.3519244771999707`*^6, 
       2.363870843000623*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.392576821336922*^6, 
       2.4432786254188027`*^6}, {-2.352255178663078*^6, 
       2.4264173745811973`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3922591243194137`*^6, 
       2.50559237738817*^6}, {-2.3525728756805863`*^6, 
       2.4889676226118305`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3919540965559003`*^6, 
       2.567903077920136*^6}, {-2.3528779034440997`*^6, 
       2.551520922079864*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.391661381374644*^6, 
       2.6302113330028327`*^6}, {-2.353170618625356*^6, 
       2.614076666997167*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3913806060936265`*^6, 
       2.6925176929631024`*^6}, {-2.3534513939063735`*^6, 
       2.676634307036898*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3911113867980777`*^6, 
       2.7548226558917556`*^6}, {-2.353720613201922*^6, 
       2.739193344108244*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.390853332483452*^6, 
       2.817126671071736*^6}, {-2.3539786675165477`*^6, 
       2.8017533289282634`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.390606048621253*^6, 
       2.87943014236178*^6}, {-2.3542259513787464`*^6, 
       2.8643138576382203`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.390369140203604*^6, 
       2.941733431498388*^6}, {-2.354462859796396*^6, 
       2.9268745685016126`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3901422143200557`*^6, 
       3.0040368612876674`*^6}, {-2.3546897856799443`*^6, 
       2.9894351387123326`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.3899248823171896`*^6, 
       3.066340718666061*^6}, {-2.354907117682811*^6, 
       3.051995281333939*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.389716761588211*^6, 
       3.128645257615209*^6}, {-2.3551152384117884`*^6, 
       3.114554742384791*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2864278001742726`*^6, 0.}, {-2.2086761998257274`*^6, 
       0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2863966618824564`*^6, 
       63179.17489116122}, {-2.2087073381175436`*^6, 61684.82510883878}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.286303606133709*^6, 
       126353.18001850315`}, {-2.208800393866291*^6, 123374.81998149684`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2861497006831556`*^6, 
       189516.94457354196`}, {-2.208954299316844*^6, 185075.05542645807`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.285936693501141*^6, 
       252665.59196672094`}, {-2.209167306498859*^6, 246790.40803327906`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.28566696692244*^6, 
       315794.5279335816}, {-2.2094370330775604`*^6, 308525.47206641844`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2853434764974504`*^6, 
       378899.5184494663}, {-2.20976052350255*^6, 370284.48155053373`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2849696773190284`*^6, 
       441976.755017462}, {-2.2101343226809716`*^6, 432071.24498253805`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2845494410390253`*^6, 
       505022.9056085273}, {-2.2105545589609747`*^6, 493889.0943914727}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2840869670154513`*^6, 
       568035.1503036997}, {-2.211017032984549*^6, 555740.8496963003}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2835866910445513`*^6, 
       631011.2014566385}, {-2.2115173089554487`*^6, 617628.7985433614}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.283053194949893*^6, 
       693949.3089067123}, {-2.212050805050107*^6, 679554.6910932877}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2824911199552333`*^6, 
       756848.2513848603}, {-2.2126128800447667`*^6, 741519.7486151396}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2819050863013444`*^6, 
       819707.315736361}, {-2.2131989136986556`*^6, 803524.6842636389}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.281299621025237*^6, 
       882526.2659206716}, {-2.213804378974763*^6, 865569.7340793282}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.280679095248816*^6, 
       945305.3039367349}, {-2.2144249047511835`*^6, 927654.6960632651}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2800476717635645`*^6, 
       1.0080450248724053`*^6}, {-2.2150563282364355`*^6, 
       989778.9751275947}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2794092631814824`*^6, 
       1.0707463682076142`*^6}, {-2.2156947368185176`*^6, 
       1.0519416317923858`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2787675004742634`*^6, 
       1.1334105673368056`*^6}, {-2.2163364995257366`*^6, 
       1.1141414326631946`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2781257113570906`*^6, 
       1.196039099043676*^6}, {-2.216978288642909*^6, 
       1.1763769009563243`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2774869076965256`*^6, 
       1.2586336343865963`*^6}, {-2.2176170923034744`*^6, 
       1.238646365613404*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.276853780932305*^6, 
       1.3211959921601308`*^6}, {-2.2182502190676946`*^6, 
       1.3009480078398692`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2762287043935885`*^6, 
       1.3837280958067945`*^6}, {-2.218875295606411*^6, 
       1.3632799041932058`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.275613741350601*^6, 
       1.4462319343791339`*^6}, {-2.219490258649399*^6, 
       1.4256400656208661`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.27501065766006*^6, 
       1.5087095279062719`*^6}, {-2.2200933423399394`*^6, 
       1.4880264720937281`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.274420937923938*^6, 
       1.5711628973078374`*^6}, {-2.2206830620760615`*^6, 
       1.5504371026921626`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2738458041732237`*^6, 
       1.6335940388246346`*^6}, {-2.221258195826777*^6, 
       1.6128699611753651`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.273286236199946*^6, 
       1.6960049027994701`*^6}, {-2.2218177638000543`*^6, 
       1.6753230972005296`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.272742992782007*^6, 
       1.7583973765410536`*^6}, {-2.222361007217993*^6, 
       1.7377946234589464`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.272216633168488*^6, 
       1.8207732709352009`*^6}, {-2.2228873668315117`*^6, 
       1.8002827290647991`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2717075383121297`*^6, 
       1.883134310426231*^6}, {-2.223396461687871*^6, 
       1.8627856895737692`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.271215931446388*^6, 
       1.9454821259727168`*^6}, {-2.2238880685536116`*^6, 
       1.9253018740272832`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2707418977042087`*^6, 
       2.0078182505809388`*^6}, {-2.2243621022957917`*^6, 
       1.9878297494190612`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2702854025629773`*^6, 
       2.0701441170321312`*^6}, {-2.2248185974370227`*^6, 
       2.050367882967869*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2698463089746055`*^6, 
       2.1324610574420667`*^6}, {-2.225257691025395*^6, 
       2.1129149425579337`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2694243931016093`*^6, 
       2.194770304320375*^6}, {-2.2256796068983907`*^6, 
       2.1754696956796255`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.269019358630205*^6, 
       2.2570729928295524`*^6}, {-2.226084641369795*^6, 
       2.238031007170447*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.268630849670892*^6, 
       2.3193701639777464`*^6}, {-2.226473150329108*^6, 
       2.3005978360222536`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2682584622870726`*^6, 
       2.381662768513444*^6}, {-2.226845537712927*^6, 
       2.3631692314865566`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2679017547142035`*^6, 
       2.4439516713230135`*^6}, {-2.2272022452857965`*^6, 
       2.425744328676986*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2675602563471603`*^6, 
       2.5062376561627868`*^6}, {-2.227543743652839*^6, 
       2.4883223438372132`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2672334755830774`*^6, 
       2.5685214305855394`*^6}, {-2.227870524416923*^6, 
       2.5509025694144606`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2669209066120223`*^6, 
       2.630803630946598*^6}, {-2.228183093387978*^6, 
       2.613484369053402*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.266622035249472*^6, 
       2.693084827397201*^6}, {-2.2284819647505283`*^6, 
       2.676067172602799*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2663363439034545`*^6, 
       2.7553655287923133`*^6}, {-2.228767656096546*^6, 
       2.7386504712076867`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2660633157661716`*^6, 
       2.817646187456899*^6}, {-2.2290406842338284`*^6, 
       2.801233812543101*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2658024383154735`*^6, 
       2.8799272037689383`*^6}, {-2.2293015616845265`*^6, 
       2.863816796231062*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2655532062061816`*^6, 
       2.9422089305294408`*^6}, {-2.2295507937938184`*^6, 
       2.9263990694705592`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2653151236253544`*^6, 
       3.0044916770996028`*^6}, {-2.2297888763746456`*^6, 
       2.9889803229003972`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.265087706179439*^6, 
       3.066775713293349*^6}, {-2.2300162938205604`*^6, 
       3.0515602867066516`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.2648704823750514`*^6, 
       3.1290612730199983`*^6}, {-2.2302335176249486`*^6, 
       3.114138726980001*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.164825150357929*^6, 0.}, {-2.080550849642071*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1647860177821578`*^6, 
       63318.813293573694`}, {-2.080589982217842*^6, 61545.186706426306`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.164669125824955*^6, 
       126630.75058966485`}, {-2.0807068741750452`*^6, 
       123097.24941033516`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.164475976613808*^6, 
       189929.08330704313`}, {-2.0809000233861923`*^6, 
       184662.91669295687`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1642090239003245`*^6, 
       253207.3715411379}, {-2.0811669760996758`*^6, 246248.62845886213`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1638716011541183`*^6, 
       316459.5934343332}, {-2.0815043988458817`*^6, 307860.4065656667}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.163467826227123*^6, 
       379680.2577223183}, {-2.081908173772877*^6, 369503.7422776817}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1630024873956195`*^6, 
       442864.49562249327`}, {-2.0823735126043803`*^6, 
       431183.50437750673`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1624809162790305`*^6, 
       506008.1295243243}, {-2.0828950837209693`*^6, 492903.87047567574`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.161908853423985*^6, 
       569107.7173120587}, {-2.0834671465760148`*^6, 554668.2826879413}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.161292312240209*^6, 
       632160.5724822225}, {-2.084083687759791*^6, 616479.4275177774}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.16063744652769*^6, 
       695164.7614116886}, {-2.0847385534723098`*^6, 678339.2385883114}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.159950426115206*^6, 
       758119.080111019}, {-2.085425573884794*^6, 740248.9198889812}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.159237324226527*^6, 
       821023.0135157756}, {-2.086138675773473*^6, 802208.9864842244}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1585040191939957`*^6, 
       883876.6808090237}, {-2.0868719808060043`*^6, 864219.3191909762}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1577561121348673`*^6, 
       946680.7704415654}, {-2.0876198878651324`*^6, 926279.2295584346}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1569988612650903`*^6, 
       1.009436468453853*^6}, {-2.08837713873491*^6, 988387.531546147}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1562371327011716`*^6, 
       1.0721453834502595`*^6}, {-2.0891388672988287`*^6, 
       1.0505426165497405`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1554753669268233`*^6, 
       1.1348094711844434`*^6}, {-2.0899006330731765`*^6, 
       1.1127425288155566`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1547175595919956`*^6, 
       1.1974309612363386`*^6}, {-2.0906584404080047`*^6, 
       1.1749850387636612`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.153967254966709*^6, 
       1.260012287744739*^6}, {-2.091408745033291*^6, 
       1.237267712255261*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.153227550177786*^6, 
       1.3225560256447003`*^6}, {-2.0921484498222137`*^6, 
       1.2995879743552997`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1525011082921196`*^6, 
       1.3850648333768318`*^6}, {-2.0928748917078802`*^6, 
       1.3619431666231684`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.151790178350384*^6, 
       1.4475414026071713`*^6}, {-2.093585821649616*^6, 
       1.4243305973928287`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1510966205737772`*^6, 
       1.5099884151339706`*^6}, {-2.0942793794262228`*^6, 
       1.4867475848660297`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.150421935138578*^6, 
       1.572408506866122*^6}, {-2.0949540648614217`*^6, 
       1.549191493133878*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1497672931169737`*^6, 
       1.6348042385360103`*^6}, {-2.0956087068830263`*^6, 
       1.6116597614639895`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1491335683994684`*^6, 
       1.697178072652001*^6}, {-2.0962424316005316`*^6, 
       1.674149927347999*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.148521369629981*^6, 
       1.759532356094741*^6}, {-2.096854630370019*^6, 
       1.736659643905259*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.147931071389106*^6, 
       1.8218693077077987`*^6}, {-2.097444928610894*^6, 
       1.7991866922922016`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1473628440471096`*^6, 
       1.8841910102174622`*^6}, {-2.0980131559528904`*^6, 
       1.8617289897825378`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.146816681872052*^6, 
       1.9464994058298054`*^6}, {-2.0985593181279483`*^6, 
       1.9242845941701946`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1462924291183874`*^6, 
       2.00879629488728*^6}, {-2.099083570881612*^6, 
       1.9868517051127197`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.145789803937536*^6, 
       2.071083337015211*^6}, {-2.099586196062464*^6, 
       2.049428662984789*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1453084200455486`*^6, 
       2.1333620542448964`*^6}, {-2.1000675799544514`*^6, 
       2.112013945755104*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.144847806156163*^6, 
       2.1956338356600846`*^6}, {-2.100528193843837*^6, 
       2.174606164339915*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.144407423242719*^6, 
       2.257899943173953*^6}, {-2.100968576757281*^6, 
       2.237204056826047*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1439866797321597`*^6, 
       2.3201615181019343`*^6}, {-2.1013893202678403`*^6, 
       2.2998064818980657`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1435849447613265`*^6, 
       2.3824195882501653`*^6}, {-2.1017910552386735`*^6, 
       2.3624124117498347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1432015596422716`*^6, 
       2.444675075288916*^6}, {-2.1021744403577284`*^6, 
       2.4250209247110835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1428358476916105`*^6, 
       2.506928802224656*^6}, {-2.1025401523083895`*^6, 
       2.4876311977753434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.142487122580882*^6, 
       2.569181500823218*^6}, {-2.102888877419118*^6, 
       2.5502424991767816`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1421546953620766`*^6, 
       2.6314338188699945`*^6}, {-2.103221304637924*^6, 
       2.612854181130006*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.141837880316289*^6, 
       2.6936863271815404`*^6}, {-2.103538119683711*^6, 
       2.6754656728184596`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1415359997649672`*^6, 
       2.7559395263067605`*^6}, {-2.1038400002350328`*^6, 
       2.7380764736932395`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1412483879732587`*^6, 
       2.8181938528755084`*^6}, {-2.1041276120267413`*^6, 
       2.8006861471244916`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1409743942642687`*^6, 
       2.880449685568422*^6}, {-2.1044016057357313`*^6, 
       2.863294314431578*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1407133854520703`*^6, 
       2.9427073506946075`*^6}, {-2.1046626145479297`*^6, 
       2.925900649305393*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1404647476904746`*^6, 
       3.0049671273738667`*^6}, {-2.1049112523095254`*^6, 
       2.9885048726261333`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.1402278878241223`*^6, 
       3.0672292523279423`*^6}, {-2.105148112175877*^6, 
       3.0511067476720577`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.140002234318589*^6, 
       3.1294939242910827`*^6}, {-2.1053737656814116`*^6, 
       3.1137060757089173`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0438529311797656`*^6, 0.}, {-1.9517950688202344`*^6, 
       0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.043803066421903*^6, 
       63495.52189441408}, {-1.951844933578097*^6, 61368.47810558592}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.043654199333849*^6, 
       126981.73959582478`}, {-1.951993800666151*^6, 122746.26040417522`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0434084868556657`*^6, 
       190449.57384890752`}, {-1.952239513144334*^6, 184142.4261510925}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0430694433217268`*^6, 
       253890.3846901343}, {-1.952578556678273*^6, 245565.61530986568`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0426418246846646`*^6, 
       317296.16545062687`}, {-1.9530061753153356`*^6, 307023.8345493731}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.042131476087627*^6, 
       380659.70817880775`}, {-1.953516523912373*^6, 368524.2918211923}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0415451513746015`*^6, 
       443974.73434430134`}, {-1.9541028486253987`*^6, 
       430073.26565569866`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.040890314213132*^6, 
       507235.9871031199}, {-1.954757685786868*^6, 491676.0128968801}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0401749308066086`*^6, 
       570439.2839079251}, {-1.9554730691933916`*^6, 553336.7160920749}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0394072637406345`*^6, 
       633581.5306062443}, {-1.9562407362593657`*^6, 615058.4693937555}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.038595675457713*^6, 
       696660.7001946146}, {-1.957052324542287*^6, 676843.2998053854}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0377484483526465`*^6, 
       759675.7809569978}, {-1.9578995516473535`*^6, 738692.2190430022}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0368736267149914`*^6, 
       822626.6997464502}, {-1.9587743732850086`*^6, 800605.3002535498}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0359788838979497`*^6, 
       885514.2266675675}, {-1.9596691161020505`*^6, 862581.7733324325}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0350714163243598`*^6, 
       948339.8674329878}, {-1.9605765836756402`*^6, 924620.1325670121}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0341578643719414`*^6, 
       1.0111057492856445`*^6}, {-1.9614901356280586`*^6, 
       986718.2507143555}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0332442588910006`*^6, 
       1.0738145057042476`*^6}, {-1.9624037411089991`*^6, 
       1.0488734942957526`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0323359911362075`*^6, 
       1.1364691642512497`*^6}, {-1.9633120088637923`*^6, 
       1.1110828357487503`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0314378032418482`*^6, 
       1.19907304098071*^6}, {-1.9642101967581518`*^6, 
       1.1733429590192898`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0305537960119823`*^6, 
       1.2616296438820811`*^6}, {-1.9650942039880177`*^6, 
       1.2356503561179189`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0296874506901565`*^6, 
       1.324142586958737*^6}, {-1.9659605493098437`*^6, 
       1.2980014130412631`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.028841661465649*^6, 
       1.3866155157696852`*^6}, {-1.966806338534351*^6, 
       1.3603924842303148`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0280187757106435`*^6, 
       1.4490520446228061`*^6}, {-1.9676292242893565`*^6, 
       1.422819955377194*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0272206392747583`*^6, 
       1.5114557051055795`*^6}, {-1.9684273607252415`*^6, 
       1.4852802948944205`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0264486445462615`*^6, 
       1.5738299052700072`*^6}, {-1.9691993554537385`*^6, 
       1.547770094729993*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.025703779387842*^6, 
       1.6361778985395916`*^6}, {-1.9699442206121578`*^6, 
       1.6102861014604084`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0249866754425725`*^6, 
       1.69850276126037*^6}, {-1.9706613245574278`*^6, 
       1.6728252387396302`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0242976546644508`*^6, 
       1.7608073777558235`*^6}, {-1.9713503453355492`*^6, 
       1.7353846222441762`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0236367732465526`*^6, 
       1.823094431747847*^6}, {-1.9720112267534472`*^6, 
       1.7979615682521528`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0230038623929385`*^6, 
       1.885366403055268*^6}, {-1.9726441376070615`*^6, 
       1.860553596944732*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0223985656069736`*^6, 
       1.9476255685623738`*^6}, {-1.9732494343930262`*^6, 
       1.9231584314376262`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.021820372350555*^6, 
       2.0098740065499025`*^6}, {-1.9738276276494453`*^6, 
       1.9857739934500977`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0212686480697931`*^6, 
       2.0721136035900512`*^6}, {-1.974379351930207*^6, 
       2.0483983964099486`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0207426606879325`*^6, 
       2.134346063317735*^6}, {-1.9749053393120673`*^6, 
       2.111029936682265*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0202416037410372`*^6, 
       2.1965729164972957`*^6}, {-1.9754063962589628`*^6, 
       2.173667083502704*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0197646163815912`*^6, 
       2.258795531903556*^6}, {-1.9758833836184088`*^6, 
       2.236308468096444*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0193108005045983`*^6, 
       2.321015127626437*^6}, {-1.9763371994954017`*^6, 
       2.2989528723735623`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0188792352644748`*^6, 
       2.383232782488289*^6}, {-1.9767687647355252`*^6, 
       2.3615992175117107`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0184689892528723`*^6, 
       2.445449447332393*^6}, {-1.9771790107471277`*^6, 
       2.424246552667607*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0180791306007623`*^6, 
       2.5076659560001376`*^6}, {-1.9775688693992374`*^6, 
       2.4868940439998624`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0177087352553136`*^6, 
       2.5698830358637846`*^6}, {-1.9779392647446864`*^6, 
       2.5495409641362154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0173568936654038`*^6, 
       2.632101317822486*^6}, {-1.9782911063345964`*^6, 
       2.612186682177514*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0170227160906796`*^6, 
       2.694321345702224*^6}, {-1.9786252839093206`*^6, 
       2.674830654297776*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0167053367291382`*^6, 
       2.756543585026668*^6}, {-1.978942663270862*^6, 
       2.7374724149733325`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0164039168381935`*^6, 
       2.818768431146542*^6}, {-1.9792440831618065`*^6, 
       2.800111568853458*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.016117647004739*^6, 
       2.8809962167308745`*^6}, {-1.9795303529952609`*^6, 
       2.8627477832691255`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0158457487012653`*^6, 
       2.943227218635275*^6}, {-1.979802251298735*^6, 
       2.925380781364725*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0155874752479303`*^6, 
       3.005461664170917*^6}, {-1.9800605247520695`*^6, 
       2.9880103358290833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0153421122847323`*^6, 
       3.0676997368037472`*^6}, {-1.980305887715268*^6, 
       3.0506362631962528`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-2.0151089778436804`*^6, 
       3.1299415813172315`*^6}, {-1.9805390221563193`*^6, 
       3.113258418682769*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9236847512986658`*^6, 0.}, {-1.8222352487013345`*^6, 
       0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9236202103047338`*^6, 
       63722.46148346938}, {-1.8222997896952664`*^6, 61141.53851653062}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9234276575550812`*^6, 
       127432.08611696192`}, {-1.8224923424449188`*^6, 
       122295.91388303808`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.923110262579685*^6, 
       191116.38967790327`}, {-1.8228097374203152`*^6, 
       183475.61032209676`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9226731735344427`*^6, 
       254763.57436450536`}, {-1.8232468264655573`*^6, 
       244692.42563549464`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9221233252040413`*^6, 
       318362.8265672315}, {-1.8237966747959587`*^6, 305957.17343276856`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9214691883524263`*^6, 
       381904.5645103548}, {-1.8244508116475737`*^6, 367279.4354896452}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.920720476296645*^6, 
       445380.6257823983}, {-1.8251995237033549`*^6, 428667.3742176017}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.919887826249362*^6, 
       508784.3894529892}, {-1.826032173750638*^6, 490127.6105470108}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9189824730744467`*^6, 
       572110.8321821383}, {-1.8269375269255533`*^6, 551665.1678178618}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.918015931783249*^6, 
       635356.5219941988}, {-1.827904068216751*^6, 613283.4780058011}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9169997026676112`*^6, 
       698519.5568512182}, {-1.8289202973323888`*^6, 674984.4431487819}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9159450098050216`*^6, 
       761599.4576017477}, {-1.8299749901949784`*^6, 736768.5423982523}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9148625801867375`*^6, 
       824597.0262339702}, {-1.8310574198132625`*^6, 798634.9737660298}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9137624672797427`*^6, 
       887514.1806902421}, {-1.8321575327202575`*^6, 860581.8193097579}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9126539197306524`*^6, 
       950353.776965}, {-1.8332660802693476`*^6, 922606.223035}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9115452933511906`*^6, 
       1.0131194280269537`*^6}, {-1.8343747066488091`*^6, 
       984704.5719730462}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9104440025905562`*^6, 
       1.0758153275142787`*^6}, {-1.835475997409444*^6, 
       1.0468726724857212`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9093565064146968`*^6, 
       1.1384460843684266`*^6}, {-1.8365634935853034`*^6, 
       1.1091059156315734`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9082883228261285`*^6, 
       1.2010165727828015`*^6}, {-1.8376316771738715`*^6, 
       1.1713994272171985`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9072440660781998`*^6, 
       1.2635318001850315`*^6}, {-1.8386759339218005`*^6, 
       1.2337481998149685`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.90622750085177*^6, 
       1.3259967945357822`*^6}, {-1.83969249914823*^6, 
       1.2961472054642176`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9052416081540734`*^6, 
       1.3884165110591755`*^6}, {-1.8406783918459264`*^6, 
       1.3585914889408248`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9042886583623516`*^6, 
       1.450795757630636*^6}, {-1.8416313416376484`*^6, 
       1.4210762423693638`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9033702875786747`*^6, 
       1.5131391374224178`*^6}, {-1.8425497124213255`*^6, 
       1.4835968625775822`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9024875742171793`*^6, 
       1.5754510070137724`*^6}, {-1.8434324257828204`*^6, 
       1.5461489929862274`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9016411134606507`*^6, 
       1.6377354479719985`*^6}, {-1.8442788865393493`*^6, 
       1.6087285520280015`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.9008310878678288`*^6, 
       1.6999962498604588`*^6}, {-1.8450889121321712`*^6, 
       1.6713317501395412`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.900057332968733*^6, 
       1.7622369026902087`*^6}, {-1.8458626670312667`*^6, 
       1.7339550973097915`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8993193971467298`*^6, 
       1.8244605969678748`*^6}, {-1.8466006028532702`*^6, 
       1.7965954030321252`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.898616595475208*^6, 
       1.8866702296745556`*^6}, {-1.847303404524792*^6, 
       1.8592497703254444`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8979480574609516`*^6, 
       1.9488684147156423`*^6}, {-1.8479719425390486`*^6, 
       1.9219155852843574`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8973127688559205`*^6, 
       2.011057496592286*^6}, {-1.8486072311440795`*^6, 
       1.984590503407714*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.896709607845727*^6, 
       2.073239566249582*^6}, {-1.849210392154273*^6, 
       2.047272433750418*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8961373760181146`*^6, 
       2.135416478246457*^6}, {-1.8497826239818854`*^6, 
       2.1099595217535426`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8955948245690248`*^6, 
       2.197589868563101*^6}, {-1.8503251754309752`*^6, 
       2.172650131436899*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8950806762268834`*^6, 
       2.259761172511477*^6}, {-1.8508393237731168`*^6, 
       2.235342827488523*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.894593643375776*^6, 
       2.3219316423426527`*^6}, {-1.8513263566242238`*^6, 
       2.298036357657348*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8941324428419252`*^6, 
       2.384102364252279*^6}, {-1.8517875571580748`*^6, 
       2.3607296357477214`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8936958077807701`*^6, 
       2.4462742745741527`*^6}, {-1.85222419221923*^6, 
       2.423421725425847*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8932824970682233`*^6, 
       2.5084481750234277`*^6}, {-1.8526375029317767`*^6, 
       2.4861118249765723`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8928913025625257`*^6, 
       2.5706247469078936`*^6}, {-1.8530286974374745`*^6, 
       2.548799253092107*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8925210545649119`*^6, 
       2.632804564269963*^6}, {-1.8533989454350881`*^6, 
       2.611483435730037*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8921706257697106`*^6, 
       2.69498810595565*^6}, {-1.8537493742302891`*^6, 
       2.6741638940443494`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8918389339586417`*^6, 
       2.757175766631718*^6}, {-1.8540810660413583`*^6, 
       2.7368402333682827`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8915249436606665`*^6, 
       2.819367866790021*^6}, {-1.8543950563393335`*^6, 
       2.7995121332099787`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8912276669681834`*^6, 
       2.881564661790214*^6}, {-1.8546923330318166`*^6, 
       2.8621793382097855`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8909461636727985`*^6, 
       2.9437663499996956`*^6}, {-1.8549738363272017`*^6, 
       2.9248416500003044`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8906795408593551`*^6, 
       3.0059730800939244`*^6}, {-1.8552404591406449`*^6, 
       2.9874989199060756`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8904269520752677`*^6, 
       3.068184957581871*^6}, {-1.8554930479247323`*^6, 
       3.0501510424181283`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.890187596173286*^6, 
       3.130402050621056*^6}, {-1.855732403826714*^6, 
       3.112797949378944*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.804558369561127*^6, 0.}, {-1.6916336304388733`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8044733342292584`*^6, 
       64018.820301021646`}, {-1.6917186657707414`*^6, 60845.17969897836}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.804219845727486*^6, 
       128019.53428048812`}, {-1.6919721542725137`*^6, 
       121708.46571951188`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8038026852299275`*^6, 
       191984.60565313662`}, {-1.6923893147700725`*^6, 
       182607.39434686338`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8032295892755026`*^6, 
       255897.60335355002`}, {-1.6929624107244974`*^6, 
       243558.39664644995`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8025109205795748`*^6, 
       319743.6704962361}, {-1.6936810794204252`*^6, 304576.3295037639}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8016592427013642`*^6, 
       383509.9021930096}, {-1.6945327572986358`*^6, 365674.0978069903}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.8006888290332789`*^6, 
       447185.6158081566}, {-1.6955031709667211`*^6, 426862.3841918434}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7996151390040352`*^6, 
       510762.50662953797`}, {-1.6965768609959646`*^6, 488149.4933704621}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7984542935453635`*^6, 
       574234.6910608}, {-1.6977377064546365`*^6, 549541.3089392}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7972225782426372`*^6, 
       637598.6473007088}, {-1.698969421757363*^6, 611041.3526992912}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7959359969541698`*^6, 
       700853.069381739}, {-1.7002560030458302`*^6, 672650.930618261}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7946098919562136`*^6, 
       763998.6540666692}, {-1.7015821080437861`*^6, 734369.345933331}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.793258639737015*^6, 
       827037.841470454}, {-1.702933360262985*^6, 796194.1585295461}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7918954251590706`*^6, 
       889974.5296792091}, {-1.7042965748409294`*^6, 858121.4703207909}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7905320913486187`*^6, 
       952813.7815435533}, {-1.7056599086513813`*^6, 920146.2184564467}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7891790586315924`*^6, 
       1.0155615387605372`*^6}, {-1.7070129413684073`*^6, 
       982262.4612394627}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7878453031778578`*^6, 
       1.0782243548361603`*^6}, {-1.7083466968221422`*^6, 
       1.0444636451638396`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7865383846379311`*^6, 
       1.140809154966822*^6}, {-1.7096536153620689`*^6, 
       1.1067428450331779`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7852645117505805`*^6, 
       1.2033230276088798`*^6}, {-1.7109274882494197`*^6, 
       1.1690929723911202`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7840286354080697`*^6, 
       1.2657730497195837`*^6}, {-1.7121633645919303`*^6, 
       1.231506950280416*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7828345597260152`*^6, 
       1.3281661454440223`*^6}, {-1.7133574402739846`*^6, 
       1.293977854555978*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.781685063040646*^6, 
       1.3905089764028522`*^6}, {-1.714506936959354*^6, 
       1.3564990235971478`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7805820222547073`*^6, 
       1.4528078606586878`*^6}, {-1.715609977745293*^6, 
       1.419064139341312*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.779526535430498*^6, 
       1.5150687168255819`*^6}, {-1.716665464569502*^6, 
       1.4816672831744181`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7785190388879587`*^6, 
       1.5772970295422378`*^6}, {-1.7176729611120413`*^6, 
       1.544302970457762*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.777559416251233*^6, 
       1.6394978325612536`*^6}, {-1.718632583748767*^6, 
       1.6069661674387467`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7766470978745006`*^6, 
       1.7016757059283536`*^6}, {-1.7195449021254994`*^6, 
       1.6696522940716466`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.775781149865831*^6, 
       1.7638347840651786`*^6}, {-1.720410850134169*^6, 
       1.7323572159348214`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7749603525300939`*^6, 
       1.8259787719697785`*^6}, {-1.7212316474699064`*^6, 
       1.7950772280302213`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7741832684908612`*^6, 
       1.8881109671680806`*^6}, {-1.722008731509139*^6, 
       1.8578090328319191`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7734483010527901`*^6, 
       1.950234285457724*^6}, {-1.7227436989472099`*^6, 
       1.9205497145422762`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.772753743556476*^6, 
       2.0123512888637984`*^6}, {-1.7234382564435238`*^6, 
       1.9832967111362016`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7720978205818415`*^6, 
       2.0744642145635444`*^6}, {-1.7240941794181583`*^6, 
       2.0460477854364556`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7714787218953934`*^6, 
       2.1365750038293283`*^6}, {-1.7247132781046066`*^6, 
       2.1088009961706717`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7708946300293675`*^6, 
       2.1986853302858938`*^6}, {-1.7252973699706325`*^6, 
       2.171554669714106*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.770343742341706*^6, 
       2.260796626981355*^6}, {-1.725848257658294*^6, 
       2.2343073730186457`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7698242883465718`*^6, 
       2.3229101119356793`*^6}, {-1.726367711653428*^6, 
       2.2970578880643207`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.769334543034536*^6, 
       2.3850268119602706`*^6}, {-1.7268574569654637`*^6, 
       2.359805188039729*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7688728368261608`*^6, 
       2.4471475846426724`*^6}, {-1.727319163173839*^6, 
       2.4225484153573276`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.76843756272703*^6, 
       2.5092731384662534`*^6}, {-1.72775443727297*^6, 
       2.485286861533746*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.76802718117944*^6, 
       2.5714040510903676`*^6}, {-1.7281648188205597`*^6, 
       2.548019948909632*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7676402230379134`*^6, 
       2.6335407858558916`*^6}, {-1.7285517769620866`*^6, 
       2.610747214144109*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7672752910335169`*^6, 
       2.6956837066076132`*^6}, {-1.7289167089664834`*^6, 
       2.673468293392387*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.766931060036179*^6, 
       2.7578330909415414`*^6}, {-1.7292609399638213`*^6, 
       2.7361829090584586`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7666062763748171`*^6, 
       2.8199891419941937`*^6}, {-1.7295857236251826`*^6, 
       2.798890858005807*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7662997564319333`*^6, 
       2.882151998894247*^6}, {-1.7298922435680667`*^6, 
       2.8615920011057532`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7660103846919741`*^6, 
       2.9443217459961474`*^6}, {-1.7301816153080256`*^6, 
       2.9242862540038526`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.765737111390726*^6, 
       3.0064984210115545`*^6}, {-1.730454888609274*^6, 
       2.9869735789884455`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7654789498857257`*^6, 
       3.0686820221488783`*^6}, {-1.7307130501142743`*^6, 
       3.0496539778511217`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.7652349738446416`*^6, 
       3.1308725143642663`*^6}, {-1.7309570261553584`*^6, 
       3.1123274856357337`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6868063938305518`*^6, 0.}, {-1.5596576061694482`*^6, 
       0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6866920460646783`*^6, 
       64413.295394770226`}, {-1.5597719539353217`*^6, 60450.70460522977}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6863515229788483`*^6, 
       128800.39670601508`}, {-1.5601124770211517`*^6, 
       120927.60329398494`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.685792256611081*^6, 
       193136.06432428025`}, {-1.560671743388919*^6, 181455.93567571975`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.685026216719929*^6, 
       257396.90014142715`}, {-1.561437783280071*^6, 242059.09985857285`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6840693245828133`*^6, 
       321562.1074581079}, {-1.5623946754171867`*^6, 302757.8925418921}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6829407052265855`*^6, 
       385614.0783290615}, {-1.5635232947734143`*^6, 363569.9216709385}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6816618390615957`*^6, 
       449538.7812625617}, {-1.5648021609384043`*^6, 424509.2187374384}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.680255676835809*^6, 
       513325.94185697124`}, {-1.566208323164191*^6, 485586.05814302876`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6787457777181005`*^6, 
       576969.0272021935}, {-1.5677182222818995`*^6, 546806.9727978064}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6771555206308034`*^6, 
       640465.0595500581}, {-1.5693084793691966`*^6, 608174.9404499419}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6755074257550864`*^6, 
       703814.2945961067}, {-1.5709565742449134`*^6, 669689.7054038934}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6738226086370277`*^6, 
       767019.8043860192}, {-1.5726413913629726`*^6, 731348.1956139806}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6721203754707705`*^6, 
       830087.004835059}, {-1.5743436245292292`*^6, 793144.9951649408}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6704179563503976`*^6, 
       893023.1641421705}, {-1.5760460436496027`*^6, 855072.8358578297}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6687303643708562`*^6, 
       955836.9222520407}, {-1.5777336356291438`*^6, 917123.0777479594}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6670703626525644`*^6, 
       1.0185378442165613`*^6}, {-1.5793936373474353`*^6, 
       979286.1557834387}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6654485184500935`*^6, 
       1.0811360228861729`*^6}, {-1.5810154815499068`*^6, 
       1.0415519771138271`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6638733229855695`*^6, 
       1.143641739589558*^6}, {-1.5825906770144308`*^6, 
       1.1039102604104422`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6623513568979825`*^6, 
       1.206065185801895*^6}, {-1.5841126431020175`*^6, 
       1.166350814198105*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6608874835924965`*^6, 
       1.2684162444552646`*^6}, {-1.5855765164075037`*^6, 
       1.2288637555447354`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6594850557582597`*^6, 
       1.3307043265042212`*^6}, {-1.5869789442417403`*^6, 
       1.2914396734957786`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6581461234662954`*^6, 
       1.3929382564863134`*^6}, {-1.5883178765337046`*^6, 
       1.3540697435136868`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6568716352556273`*^6, 
       1.455126199902478*^6}, {-1.5895923647443724`*^6, 
       1.416745800097522*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6556616262774332`*^6, 
       1.5172756250554898`*^6}, {-1.590802373722567*^6, 
       1.47946037494451*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.654515389800215*^6, 
       1.5793932923072716`*^6}, {-1.591948610199785*^6, 
       1.5422067076927286`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.653431630160268*^6, 
       1.6414852643596155`*^6}, {-1.593032369839732*^6, 
       1.6049787356403845`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6524085965940184`*^6, 
       1.7035569319777263`*^6}, {-1.5940554034059814`*^6, 
       1.6677710680222737`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.651444198361906*^6, 
       1.7656130504505807`*^6}, {-1.5950198016380942`*^6, 
       1.7305789495494193`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6505361022293265`*^6, 
       1.8276577829396748`*^6}, {-1.5959278977706737`*^6, 
       1.7933982170603252`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.649681813772651*^6, 
       1.8896947476599982`*^6}, {-1.596782186227349*^6, 
       1.8562252523400018`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.648878744187095*^6, 
       1.9517270665376815`*^6}, {-1.597585255812905*^6, 
       1.9190569334623185`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.648124264340244*^6, 
       2.0137574135871895`*^6}, {-1.598339735659756*^6, 
       1.9818905864128103`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6474157477833836`*^6, 
       2.0757880617473125`*^6}, {-1.5990482522166166`*^6, 
       2.0447239382526875`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6467506043366627`*^6, 
       2.137820927316321*^6}, {-1.599713395663337*^6, 
       2.1075550726836785`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.646126305729652*^6, 
       2.199857611442884*^6}, {-1.600337694270348*^6, 
       2.1703823885571156`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.645540404625287*^6, 
       2.261899438372571*^6}, {-1.6009235953747127`*^6, 
       2.233204561627429*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.644990548196106*^6, 
       2.3239474903319916`*^6}, {-1.601473451803894*^6, 
       2.2960205096680084`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6444744872662271`*^6, 
       2.3860026390650705`*^6}, {-1.6019895127337729`*^6, 
       2.358829360934929*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6439900818864699`*^6, 
       2.448065574128726*^6}, {-1.6024739181135301`*^6, 
       2.4216304258712735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6435353040766558`*^6, 
       2.510136828116928*^6}, {-1.602928695923344*^6, 
       2.4844231718830713`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6431082383499774`*^6, 
       2.572216799020089*^6}, {-1.6033557616500226`*^6, 
       2.5472072009799103`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6427070805296786`*^6, 
       2.6343057699468886`*^6}, {-1.6037569194703214`*^6, 
       2.6099822300531114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6423301352776873`*^6, 
       2.6964039264427884`*^6}, {-1.6041338647223127`*^6, 
       2.6727480735572116`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6419758126773015`*^6, 
       2.7585113716374063`*^6}, {-1.6044881873226985`*^6, 
       2.735504628362594*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6416426241463623`*^6, 
       2.820628139444498*^6}, {-1.604821375853638*^6, 
       2.7982518605555026`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.641329177902209*^6, 
       2.8827542060258314`*^6}, {-1.6051348220977907`*^6, 
       2.860989793974169*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6410341741538055`*^6, 
       2.944889499715315*^6}, {-1.6054298258461945`*^6, 
       2.923718500284685*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6407564001584675`*^6, 
       3.0070339095836584`*^6}, {-1.6057075998415325`*^6, 
       2.9864380904163416`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6404947252494856`*^6, 
       3.0691872928074165`*^6}, {-1.6059692747505142`*^6, 
       3.0491487071925835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.6402480959155327`*^6, 
       3.131349480990154*^6}, {-1.6062159040844673`*^6, 
       3.1118505190098453`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.563921605913106*^6, 
       453147.1950327989}, {-1.432814394086894*^6, 421876.304967201}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5620480626484593`*^6, 
       516700.56561593566`}, {-1.4346879373515404`*^6, 
       482211.43438406434`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5600531792264197`*^6, 
       580540.0550346627}, {-1.4366828207735803`*^6, 543235.9449653373}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.557971007059021*^6, 
       644176.9338576535}, {-1.4387649929409788`*^6, 604463.0661423464}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5558335329891602`*^6, 
       707614.951628066}, {-1.4409024670108398`*^6, 665889.0483719339}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5536699188162773`*^6, 
       770861.7765078124}, {-1.4430660811837227`*^6, 727506.2234921876}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5515060041352864`*^6, 
       833928.1374312601}, {-1.4452299958647138`*^6, 789303.86256874}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5493640498468708`*^6, 
       896826.9823602941}, {-1.447371950153129*^6, 851269.0176397059}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5472626861763499`*^6, 
       959572.7002348109}, {-1.4494733138236501`*^6, 913387.2997651892}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.54521702248432*^6, 
       1.0221804377891117`*^6}, {-1.4515189775156798`*^6, 
       975643.5622108883}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.543238875296119*^6, 
       1.0846655275592888`*^6}, {-1.4534971247038809`*^6, 
       1.0380224724407111`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.541337074199063*^6, 
       1.147043031298808*^6}, {-1.455398925800937*^6, 
       1.1005089687011922`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5395178109513219`*^6, 
       1.2093273940776133`*^6}, {-1.4572181890486781`*^6, 
       1.1630886059223867`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.537785003951476*^6, 
       1.2715321984590194`*^6}, {-1.458950996048524*^6, 
       1.2257478015409803`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5361406571140718`*^6, 
       1.333670004899242*^6}, {-1.4605953428859282`*^6, 
       1.288473995100758*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5345851985158834`*^6, 
       1.395752263322295*^6}, {-1.4621508014841168`*^6, 
       1.3512557366777048`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5331177895551196`*^6, 
       1.457789281098031*^6}, {-1.4636182104448806`*^6, 
       1.414082718901969*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5317365996671456`*^6, 
       1.5197902338664932`*^6}, {-1.4649994003328544`*^6, 
       1.476945766133507*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5304390448871355`*^6, 
       1.5817632073817533`*^6}, {-1.4662969551128645`*^6, 
       1.539836792618247*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5292219908561422`*^6, 
       1.6437152604767808`*^6}, {-1.4675140091438575`*^6, 
       1.6027487395232194`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.528081922388988*^6, 
       1.7056525011618775`*^6}, {-1.4686540776110122`*^6, 
       1.6656754988381225`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5270150826262343`*^6, 
       1.7675801696298455`*^6}, {-1.4697209173737657`*^6, 
       1.7286118303701545`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5260175852334793`*^6, 
       1.8295027234813324`*^6}, {-1.4707184147665207`*^6, 
       1.7915532765186676`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5250855032230702`*^6, 
       1.8914239217780223`*^6}, {-1.4716504967769298`*^6, 
       1.854496078221978*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5242149378646952`*^6, 
       1.9533469055827218`*^6}, {-1.4725210621353048`*^6, 
       1.917437094417278*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5234020709062319`*^6, 
       2.0152742734741059`*^6}, {-1.4733339290937681`*^6, 
       1.980373726525894*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5226432030068492`*^6, 
       2.0772081511585205`*^6}, {-1.474092796993151*^6, 
       2.0433038488414797`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.521934780934623*^6, 
       2.139150254773125*^6}, {-1.4748012190653773`*^6, 
       2.1062257452268754`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5212734157303977`*^6, 
       2.2011019478142117`*^6}, {-1.4754625842696023`*^6, 
       2.1691380521857883`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5206558937069243`*^6, 
       2.263064291859408*^6}, {-1.4760801062930757`*^6, 
       2.232039708140592*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5200791818481113`*^6, 
       2.3250380914064995`*^6}, {-1.4766568181518884`*^6, 
       2.294929908593501*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.519540428902609*^6, 
       2.387023933244765*^6}, {-1.477195571097391*^6, 
       2.3578080667552357`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5190369632302353`*^6, 
       2.449022220823072*^6}, {-1.4776990367697647`*^6, 
       2.4206737791769276`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5185662882578925`*^6, 
       2.5110332040954*^6}, {-1.4781697117421078`*^6, 2.4835267959046*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.518126076231143*^6, 
       2.5730570053187544`*^6}, {-1.4786099237688573`*^6, 
       2.546366994681245*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5177141608053357`*^6, 
       2.6350936412581955`*^6}, {-1.4790218391946645`*^6, 
       2.6091943587418045`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5173285289026597`*^6, 
       2.6971430422244295`*^6}, {-1.47940747109734*^6, 
       2.6720089577755705`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5169673121653295`*^6, 
       2.759205068335241*^6}, {-1.4797686878346705`*^6, 
       2.734810931664759*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5166287782570764`*^6, 
       2.8212795233557946`*^6}, {-1.4801072217429238`*^6, 
       2.797600476644205*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5163113222023265`*^6, 
       2.883366166436542*^6}, {-1.4804246777976735`*^6, 
       2.860377833563458*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5160134579023046`*^6, 
       2.945464722032402*^6}, {-1.4807225420976956`*^6, 
       2.9231432779675983`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5157338099276056`*^6, 
       3.0075748882539063`*^6}, {-1.4810021900723944`*^6, 
       2.9858971117460937`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5154711056556024`*^6, 
       3.069696343870523*^6}, {-1.4812648943443978`*^6, 
       3.0486396561294775`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.5152241677968137`*^6, 
       3.1318287541586696`*^6}, {-1.4815118322031861`*^6, 
       3.111371245841331*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.437047056992801*^6, 
       712550.3455960742}, {-1.3099609430071989`*^6, 660953.6544039258}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.434238639141617*^6, 
       775795.7854587081}, {-1.3127693608583827`*^6, 722572.2145412919}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.431463852350277*^6, 
       838805.7875065963}, {-1.315544147649723*^6, 784426.2124934037}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.428750729566818*^6, 
       901602.7769421055}, {-1.3182572704331817`*^6, 846493.2230578945}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.426121432327523*^6, 
       964210.2726319572}, {-1.320886567672477*^6, 908749.7273680428}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4235927059073234`*^6, 
       1.0266518837139425`*^6}, {-1.3234152940926766`*^6, 
       971172.1162860575}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4211764710276942`*^6, 
       1.0889505358572595`*^6}, {-1.3258315289723058`*^6, 
       1.0337374641427405`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4188804809699059`*^6, 
       1.1511279124112073`*^6}, {-1.3281275190300941`*^6, 
       1.0964240875887927`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4167089893676755`*^6, 
       1.2132040839897017`*^6}, {-1.3302990106323245`*^6, 
       1.1592119160102983`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.414663389862212*^6, 
       1.2751972946014176`*^6}, {-1.3323446101377883`*^6, 
       1.2220827053985824`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4127428026964709`*^6, 
       1.337123871582372*^6}, {-1.3342651973035291`*^6, 
       1.2850201284176277`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4109445945343303`*^6, 
       1.3989982287336779`*^6}, {-1.33606340546567*^6, 
       1.3480097712663224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4092648262224207`*^6, 
       1.460832935895485*^6}, {-1.3377431737775793`*^6, 
       1.4110390641045151`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4076986291229473`*^6, 
       1.522638832715231*^6}, {-1.3393093708770524`*^6, 
       1.4740971672847692`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.406240514457981*^6, 
       1.5844251689287827`*^6}, {-1.340767485542019*^6, 
       1.5371748310712175`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4048846222869658`*^6, 
       1.646199757665643*^6}, {-1.3421233777130344`*^6, 
       1.600264242334357*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4036249177280664`*^6, 
       1.707969131910917*^6}, {-1.3433830822719336`*^6, 
       1.6633588680890827`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.4024553422035046`*^6, 
       1.7697386972399936`*^6}, {-1.3445526577964954`*^6, 
       1.7264533027600064`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.401369927135042*^6, 
       1.8315128763044225`*^6}, {-1.3456380728649583`*^6, 
       1.7895431236955777`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.400362876859828*^6, 
       1.893295242353421*^6}, {-1.3466451231401723`*^6, 
       1.8526247576465788`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3994286267362824`*^6, 
       1.9550886404092966`*^6}, {-1.3475793732637176`*^6, 
       1.9156953595907032`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3985618815703376`*^6, 
       2.0168952956649966`*^6}, {-1.3484461184296624`*^6, 
       1.9787527043350034`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3977576386808439`*^6, 
       2.078716909320287*^6}, {-1.3492503613191564`*^6, 
       2.0417950906797128`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3970111991774843`*^6, 
       2.1405547424914674`*^6}, {-1.349996800822516*^6, 
       2.1048212575085326`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.396318170363786*^6, 
       2.2024096890777126`*^6}, {-1.3506898296362138`*^6, 
       2.1678303109222874`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.395674461607447*^6, 
       2.2642823385929363`*^6}, {-1.3513335383925533`*^6, 
       2.2308216614070637`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.395076275537935*^6, 
       2.3261730300127026`*^6}, {-1.351931724462065*^6, 
       2.293794969987297*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3945200960303193`*^6, 
       2.388081897669425*^6}, {-1.3524879039696807`*^6, 
       2.3567501023305757`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3940026741054745`*^6, 
       2.4500089101767302`*^6}, {-1.3530053258945255`*^6, 
       2.41968708982327*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3935210126104637`*^6, 
       2.511953903290566*^6}, {-1.3534869873895363`*^6, 
       2.482606096709434*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3930723503294413`*^6, 
       2.5739166075309245`*^6}, {-1.353935649670559*^6, 
       2.5455073924690755`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.392654146006079*^6, 
       2.6358966713012685`*^6}, {-1.354353853993921*^6, 
       2.6083913286987315`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3922640626254424`*^6, 
       2.697893680157544*^6}, {-1.3547439373745576`*^6, 
       2.6712583198424564`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.391899952199671*^6, 
       2.759907172798037*^6}, {-1.355108047800329*^6, 
       2.734108827201963*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.391559841222003*^6, 
       2.8219366542709447`*^6}, {-1.355448158777997*^6, 
       2.7969433457290553`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3912419168928533`*^6, 
       2.8839816068291473`*^6}, {-1.3557660831071464`*^6, 
       2.859762393170852*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.39094451417584*^6, 
       2.9460414988015373`*^6}, {-1.3560634858241598`*^6, 
       2.922566501198463*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3906661037076688`*^6, 
       3.008115791797127*^6}, {-1.356341896292331*^6, 
       2.9853562082028734`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3904052805610127`*^6, 
       3.0702039465117115`*^6}, {-1.3566027194389873`*^6, 
       3.048132053488288*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3901607538418886`*^6, 
       3.132305427366446*^6}, {-1.3568472461581114`*^6, 
       3.1108945726335538`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3052590658943637`*^6, 
       970472.2750702834}, {-1.1920209341056363`*^6, 903463.2249297166}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.3021301898012024`*^6, 
       1.0321470592004401`*^6}, {-1.1951498101987974`*^6, 
       965676.9407995599}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2991815746992773`*^6, 
       1.0941499275638312`*^6}, {-1.1980984253007225`*^6, 
       1.0285380724361688`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2964169904517992`*^6, 
       1.156023562186032*^6}, {-1.2008630095482008`*^6, 
       1.0915284378139677`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2938358753533317`*^6, 
       1.2177950340750453`*^6}, {-1.2034441246466683`*^6, 
       1.1546209659249547`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2914343825684027`*^6, 
       1.2794880167677503`*^6}, {-1.2058456174315973`*^6, 
       1.21779198323225*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2892062739135*^6, 
       1.3411229035184898`*^6}, {-1.2080737260865*^6, 1.28102109648151*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.28714366040207*^6, 
       1.4027170240615595`*^6}, {-1.21013633959793*^6, 
       1.3442909759384408`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2852375994353672`*^6, 
       1.464284918679922*^6}, {-1.2120424005646328`*^6, 
       1.4075870813200783`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2834785642596718`*^6, 
       1.5258386381508233`*^6}, {-1.213801435740328*^6, 
       1.4708973618491765`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.281856803688934*^6, 
       1.587388047360352*^6}, {-1.215423196311066*^6, 
       1.534211952639648*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.280362610255917*^6, 
       1.648941117791844*^6}, {-1.216917389744083*^6, 
       1.5975228822081562`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2789865137860226`*^6, 
       1.7105041997802495`*^6}, {-1.2182934862139774`*^6, 
       1.6608238002197505`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2777194155202361`*^6, 
       1.7720822696074173`*^6}, {-1.2195605844797636`*^6, 
       1.7241097303925827`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2765526757749254`*^6, 
       1.8336791494626957`*^6}, {-1.2207273242250746`*^6, 
       1.787376850537304*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.275478165985684*^6, 
       1.8952977002775474`*^6}, {-1.221801834014316*^6, 
       1.8506222997224529`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2744882939947105`*^6, 
       1.95693998870079*^6}, {-1.2227917060052895`*^6, 
       1.91384401129921*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2735760096827336`*^6, 
       2.0186074302113298`*^6}, {-1.2237039903172664`*^6, 
       1.9770405697886702`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.272734796543335*^6, 
       2.0803009107254264`*^6}, {-1.2245452034566647`*^6, 
       2.0402110892745734`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2719586535453915`*^6, 
       2.1420208891660566`*^6}, {-1.2253213464546085`*^6, 
       2.1033551108339434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2712420706073963`*^6, 
       2.2037674834118015`*^6}, {-1.226037929392604*^6, 
       2.166472516588198*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2705800001872487`*^6, 
       2.265540541895873*^6}, {-1.2266999998127515`*^6, 
       2.2295634581041266`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2699678268422277`*^6, 
       2.327339702926914*^6}, {-1.2273121731577723`*^6, 
       2.2926282970730853`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2694013361070717`*^6, 
       2.3891644435821967`*^6}, {-1.2278786638929283`*^6, 
       2.3556675564178033`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2688766836469222`*^6, 
       2.4510141198002263`*^6}, {-1.2284033163530775`*^6, 
       2.4186818801997737`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.268390365343465*^6, 
       2.512887999085625*^6}, {-1.2288896346565352`*^6, 
       2.4816720009143753`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.267939188747586*^6, 
       2.574785287041214*^6}, {-1.2293408112524138`*^6, 
       2.5446387129587857`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2675202461643752`*^6, 
       2.6367051487638177`*^6}, {-1.229759753835625*^6, 
       2.6075828512361823`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.267130889513393*^6, 
       2.698646725982392*^6}, {-1.230149110486607*^6, 
       2.6705052740176083`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2667687070185*^6, 
       2.7606091506792647`*^6}, {-1.2305112929815*^6, 
       2.733406849320736*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.266431501718992*^6, 
       2.822591555816264*^6}, {-1.230848498281008*^6, 
       2.7962884441837366`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2661172717509298`*^6, 
       2.884593083685638*^6}, {-1.23116272824907*^6, 
       2.8591509163143616`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.265824192319392*^6, 
       2.946612892319038*^6}, {-1.231455807680608*^6, 
       2.921995107680962*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2655505992650657`*^6, 
       3.008650160314592*^6}, {-1.231729400734934*^6, 
       2.984821839685408*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2652949741192085`*^6, 
       3.0707040903804624`*^6}, {-1.2319850258807915`*^6, 
       3.047631909619537*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.2650559305372816`*^6, 
       3.1327739118415727`*^6}, {-1.2322240694627184`*^6, 
       3.110426088158427*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.177114138496464*^6, 
       1.1004362297682664`*^6}, {-1.070437861503536*^6, 
       1.0222517702317336`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1738063371188624`*^6, 
       1.16185997131821*^6}, {-1.0737456628811376`*^6, 
       1.08569202868179*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.170762751746334*^6, 
       1.2231950740537748`*^6}, {-1.076789248253666*^6, 
       1.1492209259462252`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1679699279866845`*^6, 
       1.2844706246511468`*^6}, {-1.0795820720133153`*^6, 
       1.2128093753488532`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1654125290461313`*^6, 
       1.345710523786392*^6}, {-1.0821394709538687`*^6, 
       1.276433476213608*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1630742782118598`*^6, 
       1.4069341151692534`*^6}, {-1.0844777217881402`*^6, 
       1.3400738848307466`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.160938655859937*^6, 
       1.4681568150757526`*^6}, {-1.086613344140063*^6, 
       1.4037151849242474`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1589893970994605`*^6, 
       1.5293907083984106`*^6}, {-1.0885626029005398`*^6, 
       1.4673452916015894`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.157210832098248*^6, 
       1.5906450920799938`*^6}, {-1.090341167901752*^6, 
       1.5309549079200062`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1555881053902104`*^6, 
       1.6519269571849168`*^6}, {-1.0919638946097898`*^6, 
       1.594537042815083*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1541073043006912`*^6, 
       1.7132414077500585`*^6}, {-1.0934446956993085`*^6, 
       1.6580865922499418`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1527555207674743`*^6, 
       1.7745920188372787`*^6}, {-1.0947964792325255`*^6, 
       1.7215999811627215`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1515208656429113`*^6, 
       1.8359811386347502`*^6}, {-1.096031134357089*^6, 
       1.7850748613652496`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.150392450169079*^6, 
       1.8974101406140444`*^6}, {-1.097159549830921*^6, 
       1.8485098593859558`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.149360345721985*^6, 
       1.9588796320867394`*^6}, {-1.098191654278015*^6, 
       1.9119043679132606`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1484155300519022`*^6, 
       2.020389625335555*^6}, {-1.0991364699480978`*^6, 
       1.9752583746644447`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1475498260045226`*^6, 
       2.0819396770404289`*^6}, {-1.1000021739954774`*^6, 
       2.0385723229595714`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1467558369850959`*^6, 
       2.143529001126171*^6}, {-1.1007961630149041`*^6, 
       2.101846998873829*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1460268821248244`*^6, 
       2.205156559519223*^6}, {-1.1015251178751758`*^6, 
       2.165083440480777*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.145356933137458*^6, 
       2.2668211346736113`*^6}, {-1.1021950668625422`*^6, 
       2.228282865326389*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.144740554140247*^6, 
       2.3285213871425*^6}, {-1.102811445859753*^6, 2.2914466128575*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1441728451968366`*^6, 
       2.3902559009474996`*^6}, {-1.1033791548031634`*^6, 
       2.3545760990525*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1436493899722164`*^6, 
       2.452023219038389*^6}, {-1.1039026100277833`*^6, 
       2.4176727809616113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1431662076338134`*^6, 
       2.5138218707403573`*^6}, {-1.1043857923661869`*^6, 
       2.480738129259642*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1427197089591431`*^6, 
       2.575650392749896*^6}, {-1.1048322910408566`*^6, 
       2.543773607250104*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1423066564969497`*^6, 
       2.6375073449580274`*^6}, {-1.10524534350305*^6, 
       2.606780655041973*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1419241285586546`*^6, 
       2.6993913221441163`*^6}, {-1.1056278714413454`*^6, 
       2.6697606778558837`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1415694867777335`*^6, 
       2.761300962388421*^6}, {-1.1059825132222662`*^6, 
       2.7327150376115795`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1412403469569848`*^6, 
       2.8232349528908306`*^6}, {-1.1063116530430154`*^6, 
       2.795645047109169*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1409345529207475`*^6, 
       2.885192033751354*^6}, {-1.1066174470792525`*^6, 
       2.858551966248646*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1406501530960014`*^6, 
       2.9471710001600776`*^6}, {-1.1069018469039986`*^6, 
       2.9214369998399224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.140385379559318*^6, 
       3.009170703356442*^6}, {-1.107166620440682*^6, 
       2.9843012966435584`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1401386293033361`*^6, 
       3.0711900506461947`*^6}, {-1.1074133706966639`*^6, 
       3.0471459493538053`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.1399084474949606`*^6, 
       3.1332280047064116`*^6}, {-1.1076435525050394`*^6, 
       3.1099719952935884`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0472938436559415`*^6, 
       1.2294751299531558`*^6}, {-950530.1563440585, 1.142940870046844*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0440934250010925`*^6, 
       1.29018382400055*^6}, {-953730.5749989075, 1.2070961759994498`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0412044772596576`*^6, 
       1.3509012712899444`*^6}, {-956619.5227403424, 
       1.2712427287100558`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0385982495145949`*^6, 
       1.411646340106671*^6}, {-959225.7504854051, 1.335361659893329*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0362474906169988`*^6, 
       1.4724328669234978`*^6}, {-961576.5093830012, 
       1.3994391330765022`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0341268035897642`*^6, 
       1.5332706566836676`*^6}, {-963697.1964102358, 
       1.4634653433163322`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0322128139727646`*^6, 
       1.5941663252689254`*^6}, {-965611.1860272352, 
       1.5274336747310746`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0304842100172137`*^6, 
       1.655123996851912*^6}, {-967339.7899827863, 1.5913400031480878`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0289216980412984`*^6, 
       1.71614587315609*^6}, {-968902.3019587016, 1.65518212684391*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0275079045611896`*^6, 
       1.77723269283094*^6}, {-970316.0954388103, 1.7189593071690598`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.026227247738569*^6, 
       1.8383840985124737`*^6}, {-971596.752261431, 1.782671901487526*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0250657938276061`*^6, 
       1.8995989275505382`*^6}, {-972758.2061723938, 
       1.8463210724494616`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.024011109230321*^6, 
       1.960875440394983*^6}, {-973812.890769679, 1.909908559605017*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0230521150862969`*^6, 
       2.022211498571289*^6}, {-974771.8849137031, 1.973436501428711*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0221789486977084`*^6, 
       2.083604702225178*^6}, {-975645.0513022916, 2.036907297774822*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0213828342545055`*^6, 
       2.1450524954644376`*^6}, {-976441.1657454945, 
       2.1003235045355624`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0206559640669613`*^6, 
       2.2065522462075506`*^6}, {-977168.0359330387, 
       2.1636877537924494`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0199913906730578`*^6, 
       2.2681013059629123`*^6}, {-977832.6093269422, 2.227002694037088*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0193829296460475`*^6, 
       2.329697053892476*^6}, {-978441.0703539526, 2.290270946107524*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0188250725942472`*^6, 
       2.3913369286347874`*^6}, {-978998.9274057527, 2.353495071365212*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0183129096560354`*^6, 
       2.4530184506474957`*^6}, {-979511.0903439646, 2.416677549352504*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0178420607016354`*^6, 
       2.5147392372524575`*^6}, {-979981.9392983645, 2.479820762747542*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0174086144264614`*^6, 
       2.5764970121036354`*^6}, {-980415.3855735386, 
       2.5429269878963646`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0170090745352901`*^6, 
       2.638289610428424*^6}, {-980814.9254647098, 2.605998389571576*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0166403122561525`*^6, 
       2.7001149810991567`*^6}, {-981183.6877438475, 2.669037018900844*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0162995244765116`*^6, 
       2.7619711863586125`*^6}, {-981524.4755234885, 2.732044813641387*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0159841968546162`*^6, 
       2.823856399839273*^6}, {-981839.8031453837, 2.795023600160727*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0156920713209808`*^6, 
       2.885768903370944*^6}, {-982131.9286790192, 2.857975096629056*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.015421117445674*^6, 
       2.947707082957251*^6}, {-982402.882554326, 2.920900917042749*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0151695072046363`*^6, 
       3.009669424211952*^6}, {-982654.4927953637, 2.9838025757880486`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.0149355927315614`*^6, 
       3.071654507475909*^6}, {-982888.4072684385, 3.046681492524091*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-1.014717886690515*^6, 
       3.1336610027808202`*^6}, {-983106.1133094851, 
       3.1095389972191798`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-919575.1535061625, 
       1.2966125538650143`*^6}, {-828520.8464938374, 
       1.2006674461349857`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-916385.7947496964, 
       1.356659143423566*^6}, {-831710.2052503037, 1.265484856576434*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-913549.1427427579, 
       1.4168043637661657`*^6}, {-834546.8572572421, 1.330203636233834*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-911023.9283257758, 
       1.4770559955769882`*^6}, {-837072.0716742243, 
       1.3948160044230116`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-908773.3481609465, 
       1.5374176840462184`*^6}, {-839322.6518390535, 
       1.4593183159537814`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-906764.797976609, 
       1.5978900574570652`*^6}, {-841331.202023391, 
       1.5237099425429348`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-904969.5299428229, 
       1.6584715905497451`*^6}, {-843126.4700571772, 1.587992409450255*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-903362.2801889005, 
       1.71915926346305*^6}, {-844733.7198110995, 1.6521687365369499`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-901920.8954798615, 
       1.7799490593584182`*^6}, {-846175.1045201385, 
       1.7162429406415818`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-900625.9763915224, 
       1.840836336223945*^6}, {-847470.0236084776, 1.780219663776055*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-899460.5464908945, 
       1.9018161014790903`*^6}, {-848635.4535091055, 1.84410389852091*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-898409.7519106842, 
       1.9628832121007845`*^6}, {-849686.248089316, 
       1.9079007878992155`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-897460.5924682199, 
       2.0240325180972973`*^6}, {-850635.4075317801, 1.971615481902703*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-896601.6835172444, 
       2.0852589631891097`*^6}, {-851494.3164827556, 
       2.0352530368108903`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-895823.0466096761, 
       2.146557653393343*^6}, {-852272.9533903238, 2.0988183466066564`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-895115.9264876507, 
       2.2079239017174956`*^6}, {-852980.0735123493, 
       2.1623160982825044`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-894472.631721324, 
       2.269353255224584*^6}, {-853623.3682786758, 2.2257507447754154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-893886.3963185211, 
       2.330841509225796*^6}, {-854209.6036814789, 2.2891264907742045`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-893351.2597677272, 
       2.392384712196346*^6}, {-854744.7402322729, 2.3524472878036546`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-892861.9631771224, 
       2.4539791641201666`*^6}, {-855234.0368228775, 
       2.4157168358798334`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-892413.8594017577, 
       2.515621410288872*^6}, {-855682.1405982424, 2.478938589711128*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-892002.8352853762, 
       2.5773082320624054`*^6}, {-856093.1647146238, 2.542115767937595*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-891625.2443691213, 
       2.6390366357054063`*^6}, {-856470.7556308788, 
       2.6052513642945937`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-891277.8486289736, 
       2.700803840115558*^6}, {-856818.1513710264, 2.668348159884442*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-890957.7679937404, 
       2.7626072640354196`*^6}, {-857138.2320062595, 
       2.7314087359645804`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-890662.4365647337, 
       2.8244445131702614`*^6}, {-857433.5634352661, 
       2.7944354868297386`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-890389.5646073744, 
       2.886313367507801*^6}, {-857706.4353926255, 2.8574306324921995`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-890137.1055151033, 
       2.9482117690413706`*^6}, {-857958.8944848967, 2.920396230958629*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-889903.2270588522, 
       3.0101378100281134`*^6}, {-858192.7729411479, 
       2.9833341899718866`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-889686.2863327465, 
       3.072089721862329*^6}, {-858409.7136672536, 3.046246278137671*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-889484.8078905088, 
       3.1340658646066296`*^6}, {-858611.1921094913, 
       3.1091341353933704`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-790729.5458193852, 
       1.3628705650327825`*^6}, {-707638.4541806147, 
       1.2592734349672177`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-787742.1512593605, 
       1.4222922733409647`*^6}, {-710625.8487406395, 1.324715726659035*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-785118.1914073485, 
       1.4819126657461675`*^6}, {-713249.8085926515, 
       1.3899593342538327`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-782808.1423084649, 
       1.5417235530156249`*^6}, {-715559.8576915351, 
       1.4550124469843751`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-780769.5737852977, 
       1.6017150166346775`*^6}, {-717598.4262147024, 
       1.5198849833653225`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-778966.1701866717, 
       1.661876242836375*^6}, {-719401.8298133282, 1.5845877571636247`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-777366.8544627064, 
       1.7221960994896214`*^6}, {-721001.1455372935, 
       1.6491319005103784`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-775945.0198673216, 
       1.7826635261555612`*^6}, {-722422.9801326785, 
       1.7135284738444386`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-774677.8649811369, 
       1.8432677896861709`*^6}, {-723690.135018863, 
       1.7777882103138291`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-773545.8234024001, 
       1.9039986440043692`*^6}, {-724822.1765975999, 
       1.8419213559956308`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-772532.077677886, 1.96484642234952*^6}, {-725835.9223221141,
        1.90593757765048*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-771622.1467576502, 
       2.0258020825519941`*^6}, {-726745.8532423498, 
       1.9698459174480059`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-770803.5367799576, 
       2.0868572201930892`*^6}, {-727564.4632200424, 
       2.0336547798069108`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-770065.4459116714, 
       2.148004060314554*^6}, {-728302.5540883287, 2.0973719396854467`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-769398.5150391683, 
       2.2092354352790047`*^6}, {-728969.4849608318, 
       2.1610045647209957`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-768794.6171855127, 
       2.270544754154581*^6}, {-729573.3828144872, 2.2245592458454194`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-768246.6795465873, 
       2.3319259673832995`*^6}, {-730121.3204534126, 2.288042032616701*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-767748.5329569924, 
       2.39337352932841*^6}, {-730619.4670430075, 2.35145847067159*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-767294.7844037508, 
       2.4548823604600695`*^6}, {-731073.2155962492, 
       2.4148136395399305`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-766880.7089031052, 
       2.5164478103415095`*^6}, {-731487.2910968948, 2.478112189658491*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-766502.1576506353, 
       2.5780656221541082`*^6}, {-731865.8423493648, 2.541358377845892*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-766155.4798582249, 
       2.6397318992015035`*^6}, {-732212.5201417751, 
       2.6045561007984965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-765837.4561146622, 
       2.701443073625202*^6}, {-732530.5438853378, 2.667708926374798*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-765545.241461104, 
       2.7631958774216557`*^6}, {-732822.7585388961, 
       2.7308201225783443`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-765276.3166686476, 
       2.824987315754982*^6}, {-733091.6833313523, 2.7938926842450183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-765028.4464520399, 
       2.8868146424969854`*^6}, {-733339.5535479601, 
       2.8569293575030146`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-764799.6435590888, 
       2.948675337887209*^6}, {-733568.3564409112, 2.9199326621127906`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-764588.1378464835, 
       3.0105670881833243`*^6}, {-733779.8621535165, 
       2.9829049118166757`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-764392.3495952348, 
       3.0724877671612115`*^6}, {-733975.6504047652, 3.045848232838788*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-764210.8664376826, 
       3.134435419320959*^6}, {-734157.1335623174, 3.108764580679041*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-660995.7306720425, 
       1.427908602717058*^6}, {-587644.2693279575, 1.3190993972829417`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-658389.9896017622, 
       1.4868203347425521`*^6}, {-590250.010398238, 
       1.3850516652574479`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-656123.299658306, 
       1.5460246412583685`*^6}, {-592516.700341694, 
       1.4507113587416313`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-654144.6247471691, 
       1.6054956473662916`*^6}, {-594495.3752528309, 
       1.5161043526337084`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-652411.4253507105, 
       1.665209154830151*^6}, {-596228.5746492895, 1.581254845169849*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-650888.1522677324, 
       1.725142823461116*^6}, {-597751.8477322676, 1.6461851765388842`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-649545.0131013612, 
       1.7852762124419848`*^6}, {-599094.9868986388, 
       1.7109157875580154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-648356.9642574734, 
       1.8455907355247808`*^6}, {-600283.0357425265, 
       1.7754652644752192`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-647302.8877948512, 
       1.9060695659825965`*^6}, {-601337.1122051487, 
       1.8398504340174035`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-646364.9189900265, 
       1.9666975148870593`*^6}, {-602275.0810099737, 
       1.9040864851129407`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-645527.8964068968, 
       2.0274608979399821`*^6}, {-603112.1035931031, 1.968187102060018*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-644778.9113972869, 
       2.088347400468894*^6}, {-603861.088602713, 2.032164599531106*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-644106.9382828749, 
       2.1493459464395563`*^6}, {-604533.061717125, 
       2.0960300535604435`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-643502.5300435567, 
       2.210446574850165*^6}, {-605137.4699564433, 2.1597934251498347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-642957.5672572909, 
       2.2716403252438987`*^6}, {-605682.432742709, 2.223463674756101*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-642465.0504032444, 
       2.3329191330295904`*^6}, {-606174.9495967557, 
       2.2870488669704096`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-642018.9275490427, 
       2.394275734643883*^6}, {-606621.0724509573, 2.350556265356117*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-641613.9509781951, 
       2.4557035821924163`*^6}, {-607026.0490218049, 
       2.4139924178075837`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-641245.5575466491, 
       2.517196766983987*^6}, {-607394.4424533508, 2.4773632330160127`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-640909.7685471012, 
       2.57874995126044*^6}, {-607730.2314528988, 2.5406740487395604`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-640603.1056544153, 
       2.640358307385804*^6}, {-608036.8943455847, 2.603929692614196*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-640322.5201643233, 
       2.702017463763785*^6}, {-608317.4798356767, 2.6671345362362154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-640065.3332517926, 
       2.7637234567850167`*^6}, {-608574.6667482074, 
       2.7302925432149833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-639829.1853901099, 
       2.8254726881525586`*^6}, {-608810.8146098901, 
       2.7934073118474414`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-639611.993406775, 
       2.8872618869881635`*^6}, {-609028.006593225, 2.856482113011836*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-639411.913923618, 
       2.9490880761779384`*^6}, {-609228.086076382, 
       2.9195199238220616`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-639227.3121487903, 
       3.010948542471062*^6}, {-609412.6878512098, 2.9825234575289385`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-639056.7351674783, 
       3.0728408098974465`*^6}, {-609583.2648325218, 3.045495190102553*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-638898.8890243801, 
       3.134762616118639*^6}, {-609741.1109756199, 
       3.1084373838813617`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-530737.1878819658, 
       1.4915236134837759`*^6}, {-468174.8121180342, 
       1.3803483865162241`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-528646.9314165881, 
       1.550101696847807*^6}, {-470265.0685834119, 1.4466343031521928`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-526840.4493601024, 
       1.6090440111232812`*^6}, {-472071.55063989764`, 
       1.5125559888767188`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-525272.3076576237, 
       1.6683093110351565`*^6}, {-473639.69234237634`, 
       1.5781546889648433`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-523905.31420901674`, 
       1.7278614508782295`*^6}, {-475006.68579098326`, 
       1.6434665491217705`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-522708.8724301904, 
       1.7876687732033827`*^6}, {-476203.1275698096, 
       1.7085232267966173`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-521657.6889873717, 
       1.8477035465518571`*^6}, {-477254.3110126284, 
       1.7733524534481426`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-520730.75525364163`, 
       1.9079414604487095`*^6}, {-478181.24474635837`, 
       1.8379785395512905`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-519910.54095596506`, 
       1.9683611787268366`*^6}, {-479001.45904403494`, 
       1.9024228212731637`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-519182.3529037723, 
       2.0289439484124796`*^6}, {-479729.6470962277, 
       1.9667040515875204`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-518533.82265685644`, 
       2.0896732595318416`*^6}, {-480378.17734314356`, 
       2.0308387404681584`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-517954.49532497674`, 
       2.1505345504783783`*^6}, {-480957.5046750233, 
       2.0948414495216217`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-517435.4980318793, 
       2.2115149535116176`*^6}, {-481476.5019681207, 
       2.1587250464883824`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-516969.2714091797, 
       2.2726030752383727`*^6}, {-481942.7285908203, 2.222500924761627*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-516549.35117909213`, 
       2.3337888073752834`*^6}, {-482362.64882090787`, 
       2.286179192624716*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-516170.1897169016, 
       2.3950631636021836`*^6}, {-482741.8102830984, 
       2.3497688363978164`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-515827.0096630591, 
       2.4564181388292327`*^6}, {-483084.9903369409, 2.413277861170768*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-515515.683337727, 
       2.5178465876853727`*^6}, {-483396.316662273, 
       2.4767134123146273`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-515232.6330155489, 
       2.5793421194763444`*^6}, {-483679.3669844511, 
       2.5400818805236556`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-514974.74813434697`, 
       2.6408990072518964`*^6}, {-483937.251865653, 
       2.6033889927481036`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-514739.3163055892, 
       2.7025121089640353`*^6}, {-484172.6836944107, 
       2.6666398910359642`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-514523.96561777743`, 
       2.7641767989941873`*^6}, {-484388.0343822226, 
       2.7298392010058123`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-514326.6162151139, 
       2.825888908581346*^6}, {-484585.3837848861, 2.792991091418654*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-514145.4395224725, 
       2.8876446739004655`*^6}, {-484766.56047752756`, 
       2.856099326099535*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-513978.8237964471, 
       2.9494406907252935`*^6}, {-484933.1762035529, 
       2.9191673092747065`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-513825.3449284772, 
       3.0112738747669486`*^6}, {-485086.6550715228, 2.982198125233051*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-513683.7416231632, 
       3.0731414269128786`*^6}, {-485228.2583768368, 
       3.0451945730871214`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-513552.89423327526`, 
       3.135040802703893*^6}, {-485359.10576672474`, 
       3.108159197296107*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-400369.4539839767, 
       1.553692352733297*^6}, {-348814.54601602326`, 
       1.4430436472667027`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-398860.3683487733, 
       1.612141677283837*^6}, {-350323.6316512267, 1.509458322716163*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-397560.4441297139, 
       1.670994339425933*^6}, {-351623.5558702861, 1.5754696605740667`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-396435.08688247873`, 
       1.7301992448682184`*^6}, {-352748.91311752127`, 
       1.6411287551317818`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-395456.2679936621, 
       1.7897128769007118`*^6}, {-353727.73200633796`, 
       1.7064791230992884`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-394601.1325003418, 
       1.8494980390484987`*^6}, {-354582.8674996582, 
       1.7715579609515013`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-393850.9303110072, 
       1.9095228225517739`*^6}, {-355333.0696889928, 
       1.8363971774482261`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-393190.1897437724, 
       1.969759757039453*^6}, {-355993.8102562276, 1.9010242429605469`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-392606.07397946017`, 
       2.0301851102869746`*^6}, {-356577.92602053983`, 
       1.9654628897130254`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-392087.8765866524, 
       2.0907783093229998`*^6}, {-357096.1234133476, 2.029733690677*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-391626.6235229707, 
       2.1515214604264703`*^6}, {-357557.3764770293, 
       2.0938545395735297`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-391214.75720574765`, 
       2.2123989498630553`*^6}, {-357969.24279425235`, 
       2.1578410501369443`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-390845.88425011875`, 
       2.2733971106967977`*^6}, {-358338.11574988125`, 
       2.2217068893032023`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-390514.5729068138, 
       2.3345039438213287`*^6}, {-358669.4270931862, 
       2.2854640561786713`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-390216.18952880026`, 
       2.3957088836116027`*^6}, {-358967.8104711998, 2.349123116388397*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-389946.7658635089, 
       2.457002600408567*^6}, {-359237.2341364911, 2.4126933995914324`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-389702.8908262093, 
       2.5183768335037124`*^6}, {-359481.1091737907, 
       2.4761831664962876`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-389481.6218191396, 
       2.579824249459662*^6}, {-359702.3781808604, 2.5395997505403375`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-389280.41173556354`, 
       2.641338321544378*^6}, {-359903.58826443646`, 
       2.6029496784556224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-389097.0486122082, 
       2.70291322681615*^6}, {-360086.95138779184`, 
       2.6662387731838506`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388929.60552941426`, 
       2.76454375801092*^6}, {-360254.3944705857, 2.7294722419890794`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388776.3988515437, 
       2.8262252478816845`*^6}, {-360407.60114845634`, 
       2.7926547521183155`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388635.9532847605, 
       2.8879535040448285`*^6}, {-360548.04671523947`, 
       2.8557904959551715`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388506.9725306908, 
       2.9497247527186335`*^6}, {-360677.0274693092, 2.918883247281366*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388388.31455182325`, 
       3.0115355900093666`*^6}, {-360795.6854481768, 2.981936409990634*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388278.9706523262, 
       3.0733829396220027`*^6}, {-360905.02934767376`, 
       3.0449530603779973`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-388178.04772724886`, 
       3.13526401605497*^6}, {-361005.9522727511, 3.1079359839450293`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-271366.2823119516, 
       1.556519499067795*^6}, {-228089.71768804837`, 1.440216500932205*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-270276.4795311438, 
       1.614563210815571*^6}, {-229179.5204688562, 1.507036789184429*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-269343.26594207954`, 
       1.6730798509192765`*^6}, {-230112.73405792043`, 
       1.5733841490807235`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-268539.6388564247, 
       1.7320045931264632`*^6}, {-230916.36114357525`, 
       1.639323406873537*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-267843.96915420244`, 
       1.7912832234748502`*^6}, {-231612.03084579756`, 
       1.7049087765251498`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-267238.79974891664`, 
       1.8508701461249155`*^6}, {-232217.20025108336`, 
       1.7701858538750845`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-266709.9401651578, 
       1.9107268077337903`*^6}, {-232746.0598348422, 
       1.8351931922662097`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-266245.77795724216`, 
       1.9708204442135703`*^6}, {-233210.22204275784`, 
       1.8999635557864297`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-265836.75049078674`, 
       2.0311230775210743`*^6}, {-233619.24950921326`, 
       1.9645249224789254`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-265474.93642639695`, 
       2.0916107076623922`*^6}, {-233981.06357360305`, 
       2.0289012923376076`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-265153.7373417903, 
       2.152262658099672*^6}, {-234302.26265820971`, 
       2.0931133419003282`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-264867.627795507, 
       2.2130610424549775`*^6}, {-234588.37220449297`, 
       2.157178957545022*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-264611.95776737336`, 
       2.2739903277004883`*^6}, {-234844.04223262664`, 
       2.2211136722995113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-264382.7954808019, 
       2.335036974541383*^6}, {-235073.20451919807`, 
       2.2849310254586176`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-264176.80157930683`, 
       2.3961891398972166`*^6}, {-235279.1984206932, 
       2.3486428601027834`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263991.12781132624`, 
       2.4574364296040693`*^6}, {-235464.87218867376`, 
       2.41225957039593*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263823.334994473, 
       2.5187696919382056`*^6}, {-235632.665005527, 2.475790308061794*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263671.32623802027`, 
       2.5801808444830202`*^6}, {-235784.67376197976`, 
       2.5392431555169798`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263533.2923109787, 
       2.6416627283584257`*^6}, {-235922.7076890213, 
       2.6026252716415743`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263407.66673138994`, 
       2.7032089850054285`*^6}, {-236048.33326861006`, 
       2.6659430149945715`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263293.0886773165, 
       2.764813951643305*^6}, {-236162.9113226835, 2.7292020483566946`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263188.3722227908, 
       2.826472572249057*^6}, {-236267.6277772092, 2.7924074277509437`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263092.48071296327`, 
       2.888180321491575*^6}, {-236363.51928703673`, 2.855563678508425*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-263004.5053341775, 
       2.94993313951892*^6}, {-236451.49466582245`, 
       2.9186748604810797`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-262923.6471232698, 
       3.0117273758714083`*^6}, {-236532.35287673023`, 
       2.981744624128592*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-262849.20180842315`, 
       3.0735597410951913`*^6}, {-236606.79819157685`, 
       3.0447762589048087`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-262780.5469907079, 
       3.1354272648756937`*^6}, {-236675.45300929208`, 
       3.1077727351243068`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-141807.4910911218, 
       1.5583335034856326`*^6}, {-107920.5089088782, 
       1.4384024965143676`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-141235.09056087435`, 
       1.6161090595027742`*^6}, {-108492.90943912564`, 
       1.5054909404972258`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-140746.7625066675, 
       1.674405157178196*^6}, {-108981.2374933325, 1.572058842821804*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-140327.64032789756`, 
       1.7331472061178093`*^6}, {-109400.35967210244`, 
       1.6381807938821907`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-139965.90008114054`, 
       1.7922734799268337`*^6}, {-109762.09991885944`, 
       1.7039185200731661`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-139652.0588522, 
       1.8517325492474395`*^6}, {-110075.94114780001`, 
       1.7693234507525605`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-139378.45191761435`, 
       1.9114812917544288`*^6}, {-110349.54808238565`, 
       1.8344387082455712`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-139138.83908137865`, 
       1.9714833358512565`*^6}, {-110589.16091862135`, 
       1.8993006641487435`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138928.1053964772, 
       2.0317078335331965`*^6}, {-110799.89460352279`, 
       1.9639401664668035`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138742.03157896083`, 
       2.0921284853420889`*^6}, {-110985.96842103916`, 
       2.0283835146579114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138577.11639031727`, 
       2.152722760024302*^6}, {-111150.88360968273`, 
       2.0926532399756976`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138430.43813024968`, 
       2.213471265767952*^6}, {-111297.56186975032`, 2.156768734232048*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138299.54581915558`, 
       2.2743572403330565`*^6}, {-111428.45418084442`, 
       2.220746759666943*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138182.3731031975, 
       2.3353661350970836`*^6}, {-111545.62689680251`, 
       2.2846018649029164`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-138077.16968390121`, 
       2.396485273781727*^6}, {-111650.83031609879`, 2.348346726218273*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137982.44636175424`, 
       2.457703570941485*^6}, {-111745.55363824578`, 2.411992429058515*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137896.9307287273, 
       2.519011298561498*^6}, {-111831.06927127267`, 
       2.4755487014385024`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137819.53124475427`, 
       2.5803998916040882`*^6}, {-111908.46875524572`, 
       2.539024108395912*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137749.307955784, 
       2.6418617852577628`*^6}, {-111978.692044216, 
       2.6024262147422372`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137685.44850404176`, 
       2.7033902781228707`*^6}, {-112042.55149595824`, 
       2.6657617218771293`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137627.24837884822`, 
       2.7649794167203074`*^6}, {-112100.7516211518, 
       2.7290365832796926`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137574.09458340224`, 
       2.826623897611871*^6}, {-112153.90541659777`, 2.792256102388129*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137525.4520672351, 
       2.8883189841314014`*^6}, {-112202.54793276491`, 
       2.8554250158685986`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137480.85240867513`, 
       2.9500604352885336`*^6}, {-112247.14759132487`, 
       2.918547564711467*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137439.88433627077`, 
       3.01184444485484*^6}, {-112288.11566372923`, 2.98162755514516*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137402.18575985968`, 
       3.073667589000578*^6}, {-112325.81424014032`, 3.044668410999422*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-137367.43704618866`, 
       3.1355267811384057`*^6}, {-112360.56295381134`, 
       3.107673218861594*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 1.617128625117139*^6}, {
       11946.365800652426`, 1.5054468748828608`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 1.6748600280298993`*^6}, {
       11946.365800652426`, 1.5716039719701007`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 1.7335385499975472`*^6}, {
       11946.365800652426`, 1.6377894500024528`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 1.7926120037604743`*^6}, {
       11946.365800652426`, 1.7035799962395257`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652424`, 1.852026866763629*^6}, {
       11946.365800652424`, 1.7690291332363712`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 1.9117383854980133`*^6}, {
       11946.365800652426`, 1.834181614501987*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 1.9717089062936648`*^6}, {
       11946.365800652426`, 1.8990750937063352`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.0319065653791132`*^6}, {
       11946.365800652426`, 1.9637414346208868`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.0923042524776969`*^6}, {
       11946.365800652426`, 2.0282077475223031`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652424`, 2.152878784557277*^6}, {
       11946.365800652424`, 2.0924972154427231`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652424`, 2.2136102424067035`*^6}, {
       11946.365800652424`, 2.1566297575932965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.2744814343736204`*^6}, {
       11946.365800652426`, 2.22062256562638*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.3354774601520905`*^6}, {
       11946.365800652426`, 2.2844905398479095`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.396585353842252*^6}, {
       11946.365800652426`, 2.348246646157748*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.457793790235511*^6}, {
       11946.365800652426`, 2.4119022097644894`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.5190928418426323`*^6}, {
       11946.365800652426`, 2.4754671581573673`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.580473776887693*^6}, {
       11946.365800652426`, 2.538950223112307*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.6419288905602107`*^6}, {
       11946.365800652426`, 2.602359109439789*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.7034513634116882`*^6}, {
       11946.365800652426`, 2.6657006365883113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.7650351420187047`*^6}, {
       11946.365800652426`, 2.728980857981296*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652427`, 2.826674837999117*^6}, {
       11946.365800652427`, 2.792205162000883*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652424`, 2.8883656422250527`*^6}, {
       11946.365800652424`, 2.855378357774947*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 2.9501032516741566`*^6}, {
       11946.365800652426`, 2.9185047483258434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652427`, 3.0118838068351615`*^6}, {
       11946.365800652427`, 2.9815881931648385`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652424`, 3.0737038379626037`*^6}, {
       11946.365800652424`, 3.044632162037396*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{-11946.365800652426`, 3.135560218779285*^6}, {
       11946.365800652426`, 3.1076397812207155`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{117914.75948981695`, 1.5583335034856326`*^6}, {
       131813.24051018307`, 1.4384024965143676`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{117342.35895956951`, 1.6161090595027742`*^6}, {
       132385.6410404305, 1.5054909404972258`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{116854.03090536264`, 1.674405157178196*^6}, {
       132873.96909463737`, 1.572058842821804*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{116434.90872659271`, 1.7331472061178093`*^6}, {
       133293.0912734073, 1.6381807938821907`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{116073.1684798357, 1.7922734799268337`*^6}, {
       133654.8315201643, 1.7039185200731661`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{115759.32725089513`, 1.8517325492474395`*^6}, {
       133968.67274910485`, 1.7693234507525605`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{115485.7203163095, 1.9114812917544288`*^6}, {
       134242.2796836905, 1.8344387082455712`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{115246.1074800738, 1.9714833358512565`*^6}, {
       134481.89251992622`, 1.8993006641487435`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{115035.37379517236`, 2.0317078335331965`*^6}, {
       134692.62620482763`, 1.9639401664668035`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114849.29997765599`, 2.0921284853420889`*^6}, {
       134878.700022344, 2.0283835146579114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114684.38478901242`, 2.152722760024302*^6}, {
       135043.6152109876, 2.0926532399756976`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114537.70652894484`, 2.213471265767952*^6}, {
       135190.29347105516`, 2.156768734232048*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114406.81421785073`, 2.2743572403330565`*^6}, {
       135321.1857821493, 2.220746759666943*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114289.64150189263`, 2.3353661350970836`*^6}, {
       135438.35849810738`, 2.2846018649029164`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114184.43808259636`, 2.396485273781727*^6}, {
       135543.56191740365`, 2.348346726218273*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114089.71476044938`, 2.457703570941485*^6}, {
       135638.2852395506, 2.411992429058515*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{114004.19912742247`, 2.519011298561498*^6}, {
       135723.80087257753`, 2.4755487014385024`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113926.79964344943`, 2.5803998916040882`*^6}, {
       135801.20035655057`, 2.539024108395912*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113856.57635447914`, 2.6418617852577628`*^6}, {
       135871.42364552084`, 2.6024262147422372`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113792.71690273691`, 2.7033902781228707`*^6}, {
       135935.2830972631, 2.6657617218771293`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113734.51677754337`, 2.7649794167203074`*^6}, {
       135993.48322245662`, 2.7290365832796926`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113681.36298209739`, 2.826623897611871*^6}, {
       136046.63701790263`, 2.792256102388129*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113632.72046593025`, 2.8883189841314014`*^6}, {
       136095.27953406973`, 2.8554250158685986`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113588.12080737027`, 2.9500604352885336`*^6}, {
       136139.87919262974`, 2.918547564711467*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113547.15273496592`, 3.01184444485484*^6}, {
       136180.84726503407`, 2.98162755514516*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113509.45415855484`, 3.073667589000578*^6}, {
       136218.54584144516`, 3.044668410999422*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{113474.7054448838, 3.1355267811384057`*^6}, {
       136253.2945551162, 3.107673218861594*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{247473.55071064676`, 1.556519499067795*^6}, {
       251982.44928935324`, 1.440216500932205*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{246383.74792983895`, 1.614563210815571*^6}, {
       253072.25207016108`, 1.507036789184429*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{245450.53434077473`, 1.6730798509192765`*^6}, {
       254005.4656592253, 1.5733841490807235`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{244646.9072551199, 1.7320045931264632`*^6}, {
       254809.09274488012`, 1.639323406873537*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{243951.2375528976, 1.7912832234748502`*^6}, {
       255504.7624471024, 1.7049087765251498`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{243346.06814761178`, 1.8508701461249155`*^6}, {
       256109.93185238822`, 1.7701858538750845`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{242817.20856385294`, 1.9107268077337903`*^6}, {
       256638.79143614706`, 1.8351931922662097`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{242353.0463559373, 1.9708204442135703`*^6}, {
       257102.9536440627, 1.8999635557864297`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{241944.01888948187`, 2.0311230775210743`*^6}, {
       257511.98111051813`, 1.9645249224789254`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{241582.20482509208`, 2.0916107076623922`*^6}, {
       257873.79517490792`, 2.0289012923376078`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{241261.00574048545`, 2.152262658099672*^6}, {
       258194.99425951455`, 2.093113341900328*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{240974.89619420216`, 2.2130610424549775`*^6}, {
       258481.10380579784`, 2.157178957545022*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{240719.22616606852`, 2.2739903277004883`*^6}, {
       258736.77383393148`, 2.2211136722995113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{240490.06387949706`, 2.335036974541383*^6}, {
       258965.93612050294`, 2.2849310254586176`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{240284.06997800196`, 2.3961891398972166`*^6}, {
       259171.93002199804`, 2.3486428601027834`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{240098.39621002137`, 2.4574364296040693`*^6}, {
       259357.60378997863`, 2.41225957039593*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239930.60339316816`, 2.5187696919382056`*^6}, {
       259525.39660683184`, 2.475790308061794*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239778.5946367154, 2.5801808444830202`*^6}, {
       259677.4053632846, 2.5392431555169798`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239640.56070967382`, 2.6416627283584257`*^6}, {
       259815.43929032618`, 2.6026252716415743`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239514.9351300851, 2.7032089850054285`*^6}, {
       259941.0648699149, 2.6659430149945715`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239400.35707601166`, 2.764813951643305*^6}, {
       260055.64292398834`, 2.7292020483566946`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239295.64062148595`, 2.826472572249057*^6}, {
       260160.35937851405`, 2.7924074277509437`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239199.74911165843`, 2.888180321491575*^6}, {
       260256.25088834157`, 2.855563678508425*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239111.77373287268`, 2.94993313951892*^6}, {
       260344.22626712732`, 2.9186748604810797`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{239030.91552196493`, 3.0117273758714083`*^6}, {
       260425.08447803507`, 2.981744624128592*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{238956.47020711828`, 3.0735597410951913`*^6}, {
       260499.52979288172`, 3.0447762589048087`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{238887.81538940305`, 3.1354272648756937`*^6}, {
       260568.18461059695`, 3.1077727351243068`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{376476.72238267184`, 1.553692352733297*^6}, {
       372707.2776173281, 1.4430436472667027`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{374967.63674746844`, 1.6121416772838368`*^6}, {
       374216.36325253156`, 1.509458322716163*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{373667.7125284091, 1.670994339425933*^6}, {375516.2874715909,
        1.5754696605740667`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{372542.3552811739, 1.7301992448682184`*^6}, {
       376641.64471882617`, 1.6411287551317818`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{371563.5363923572, 1.7897128769007116`*^6}, {
       377620.46360764274`, 1.7064791230992882`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{370708.40089903696`, 1.8494980390484987`*^6}, {
       378475.59910096304`, 1.7715579609515013`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{369958.19870970235`, 1.9095228225517739`*^6}, {
       379225.80129029765`, 1.8363971774482261`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{369297.4581424675, 1.969759757039453*^6}, {
       379886.54185753246`, 1.901024242960547*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{368713.3423781553, 2.0301851102869746`*^6}, {
       380470.65762184473`, 1.9654628897130254`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{368195.1449853476, 2.0907783093229998`*^6}, {
       380988.8550146525, 2.029733690677*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{367733.89192166587`, 2.1515214604264703`*^6}, {
       381450.10807833413`, 2.0938545395735297`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{367322.0256044428, 2.2123989498630553`*^6}, {
       381861.97439555725`, 2.1578410501369443`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{366953.1526488139, 2.2733971106967977`*^6}, {
       382230.84735118615`, 2.2217068893032023`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{366621.841305509, 2.3345039438213287`*^6}, {382562.158694491,
        2.2854640561786713`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{366323.4579274954, 2.3957088836116027`*^6}, {
       382860.54207250464`, 2.349123116388397*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{366054.0342622041, 2.457002600408567*^6}, {383129.9657377959,
        2.4126933995914324`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{365810.15922490443`, 2.5183768335037124`*^6}, {
       383373.84077509557`, 2.4761831664962876`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{365588.89021783473`, 2.579824249459662*^6}, {
       383595.10978216527`, 2.5395997505403375`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{365387.6801342587, 2.641338321544378*^6}, {383796.3198657413,
        2.6029496784556224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{365204.3170109033, 2.70291322681615*^6}, {383979.6829890966, 
       2.6662387731838506`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{365036.8739281094, 2.76454375801092*^6}, {384147.1260718906, 
       2.7294722419890794`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{364883.6672502388, 2.8262252478816845`*^6}, {
       384300.3327497611, 2.7926547521183155`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{364743.22168345563`, 2.8879535040448285`*^6}, {
       384440.77831654437`, 2.8557904959551715`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{364614.24092938594`, 2.9497247527186335`*^6}, {
       384569.7590706141, 2.918883247281366*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{364495.58295051835`, 3.0115355900093666`*^6}, {
       384688.4170494816, 2.981936409990634*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{364386.23905102134`, 3.0733829396220027`*^6}, {
       384797.76094897866`, 3.044953060377998*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{364285.316125944, 3.1352640160549707`*^6}, {384898.683874056,
        3.10793598394503*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{506844.45628066093`, 1.4915236134837759`*^6}, {
       492067.5437193391, 1.3803483865162241`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{504754.19981528324`, 1.550101696847807*^6}, {
       494157.80018471676`, 1.4466343031521928`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{502947.7177587976, 1.6090440111232812`*^6}, {
       495964.2822412024, 1.5125559888767188`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{501379.5760563188, 1.6683093110351565`*^6}, {
       497532.4239436812, 1.5781546889648433`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{500012.5826077119, 1.7278614508782295`*^6}, {
       498899.4173922881, 1.6434665491217703`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{498816.14082888555`, 1.7876687732033827`*^6}, {
       500095.8591711145, 1.708523226796617*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{497764.9573860668, 1.8477035465518571`*^6}, {
       501147.04261393315`, 1.7733524534481426`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{496838.0236523368, 1.9079414604487095`*^6}, {
       502073.9763476632, 1.8379785395512905`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{496017.8093546602, 1.9683611787268366`*^6}, {
       502894.1906453398, 1.9024228212731637`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{495289.6213024675, 2.0289439484124796`*^6}, {
       503622.3786975325, 1.9667040515875204`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{494641.0910555516, 2.0896732595318416`*^6}, {
       504270.9089444484, 2.0308387404681584`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{494061.76372367184`, 2.1505345504783783`*^6}, {
       504850.2362763281, 2.0948414495216217`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{493542.76643057447`, 2.2115149535116176`*^6}, {
       505369.23356942553`, 2.1587250464883824`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{493076.5398078749, 2.2726030752383727`*^6}, {
       505835.4601921252, 2.222500924761627*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{492656.6195777873, 2.3337888073752834`*^6}, {
       506255.3804222127, 2.286179192624716*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{492277.45811559673`, 2.3950631636021836`*^6}, {
       506634.54188440327`, 2.3497688363978164`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{491934.27806175424`, 2.4564181388292327`*^6}, {
       506977.72193824576`, 2.413277861170768*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{491622.95173642214`, 2.5178465876853727`*^6}, {
       507289.04826357786`, 2.4767134123146273`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{491339.9014142441, 2.5793421194763444`*^6}, {
       507572.098585756, 2.5400818805236556`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{491082.01653304213`, 2.6408990072518964`*^6}, {
       507829.98346695787`, 2.6033889927481036`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{490846.5847042844, 2.7025121089640353`*^6}, {
       508065.4152957156, 2.6666398910359642`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{490631.2340164726, 2.7641767989941873`*^6}, {
       508280.76598352747`, 2.7298392010058123`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{490433.88461380906`, 2.825888908581346*^6}, {
       508478.115386191, 2.792991091418654*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{490252.7079211676, 2.8876446739004655`*^6}, {
       508659.29207883234`, 2.856099326099535*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{490086.09219514224`, 2.9494406907252935`*^6}, {
       508825.9078048578, 2.9191673092747065`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{489932.61332717235`, 3.0112738747669486`*^6}, {
       508979.3866728276, 2.982198125233051*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{489791.0100218584, 3.0731414269128786`*^6}, {
       509120.9899781417, 3.0451945730871214`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{489660.1626319704, 3.135040802703893*^6}, {509251.8373680296,
        3.108159197296107*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{637102.9990707376, 1.427908602717058*^6}, {611537.0009292624,
        1.3190993972829417`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{634497.2580004572, 1.4868203347425524`*^6}, {
       614142.7419995427, 1.3850516652574479`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{632230.5680570011, 1.5460246412583685`*^6}, {
       616409.4319429988, 1.4507113587416313`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{630251.8931458642, 1.6054956473662916`*^6}, {
       618388.1068541358, 1.5161043526337084`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{628518.6937494057, 1.665209154830151*^6}, {620121.3062505943,
        1.581254845169849*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{626995.4206664276, 1.725142823461116*^6}, {621644.5793335724,
        1.646185176538884*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{625652.2815000564, 1.7852762124419848`*^6}, {
       622987.7184999436, 1.7109157875580154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{624464.2326561685, 1.8455907355247808`*^6}, {
       624175.7673438314, 1.7754652644752192`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{623410.1561935464, 1.9060695659825965`*^6}, {
       625229.8438064535, 1.8398504340174035`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{622472.1873887216, 1.9666975148870593`*^6}, {
       626167.8126112785, 1.9040864851129407`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{621635.1648055919, 2.0274608979399821`*^6}, {
       627004.835194408, 1.968187102060018*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{620886.1797959821, 2.088347400468894*^6}, {627753.8202040178,
        2.032164599531106*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{620214.20668157, 2.1493459464395563`*^6}, {628425.7933184298,
        2.0960300535604435`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{619609.7984422519, 2.210446574850165*^6}, {629030.2015577481,
        2.1597934251498347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{619064.8356559861, 2.2716403252438987`*^6}, {
       629575.1643440138, 2.223463674756101*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{618572.3188019396, 2.3329191330295904`*^6}, {
       630067.6811980605, 2.2870488669704096`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{618126.1959477378, 2.394275734643883*^6}, {630513.8040522621,
        2.350556265356117*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{617721.2193768902, 2.4557035821924163`*^6}, {
       630918.7806231099, 2.4139924178075837`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{617352.8259453443, 2.517196766983987*^6}, {631287.1740546556,
        2.4773632330160127`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{617017.0369457963, 2.57874995126044*^6}, {631622.9630542037, 
       2.5406740487395604`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{616710.3740531105, 2.640358307385804*^6}, {631929.6259468895,
        2.603929692614196*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{616429.7885630184, 2.702017463763785*^6}, {632210.2114369815,
        2.6671345362362154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{616172.6016504877, 2.7637234567850167`*^6}, {
       632467.3983495124, 2.7302925432149833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{615936.453788805, 2.8254726881525586`*^6}, {632703.546211195,
        2.7934073118474414`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{615719.2618054701, 2.8872618869881635`*^6}, {
       632920.7381945299, 2.856482113011836*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{615519.1823223132, 2.9490880761779384`*^6}, {
       633120.8176776868, 2.9195199238220616`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{615334.5805474855, 3.010948542471062*^6}, {633305.4194525145,
        2.9825234575289385`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{615164.0035661734, 3.0728408098974465`*^6}, {
       633475.9964338266, 3.045495190102553*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{615006.1574230753, 3.134762616118639*^6}, {633633.8425769247,
        3.1084373838813617`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{766836.8142180804, 1.3628705650327825`*^6}, {
       731531.1857819196, 1.2592734349672177`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{763849.4196580556, 1.4222922733409647`*^6}, {
       734518.5803419444, 1.324715726659035*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{761225.4598060437, 1.4819126657461675`*^6}, {
       737142.5401939563, 1.3899593342538327`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{758915.41070716, 1.5417235530156249`*^6}, {739452.58929284, 
       1.4550124469843751`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{756876.8421839928, 1.6017150166346775`*^6}, {
       741491.1578160073, 1.5198849833653225`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{755073.4385853668, 1.6618762428363753`*^6}, {
       743294.5614146331, 1.5845877571636247`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{753474.1228614015, 1.7221960994896214`*^6}, {
       744893.8771385985, 1.6491319005103784`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{752052.2882660168, 1.7826635261555612`*^6}, {
       746315.7117339834, 1.7135284738444386`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{750785.133379832, 1.8432677896861709`*^6}, {
       747582.8666201679, 1.7777882103138291`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{749653.0918010953, 1.9039986440043692`*^6}, {
       748714.9081989048, 1.8419213559956308`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{748639.3460765812, 1.96484642234952*^6}, {749728.653923419, 
       1.90593757765048*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{747729.4151563453, 2.0258020825519941`*^6}, {
       750638.5848436547, 1.9698459174480059`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{746910.8051786528, 2.0868572201930892`*^6}, {
       751457.1948213472, 2.0336547798069108`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{746172.7143103665, 2.148004060314554*^6}, {752195.2856896336,
        2.0973719396854467`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{745505.7834378635, 2.2092354352790047`*^6}, {
       752862.2165621367, 2.1610045647209957`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{744901.8855842078, 2.270544754154581*^6}, {753466.114415792, 
       2.2245592458454194`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{744353.9479452824, 2.3319259673832995`*^6}, {
       754014.0520547176, 2.288042032616701*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{743855.8013556876, 2.39337352932841*^6}, {754512.1986443123, 
       2.35145847067159*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{743402.052802446, 2.4548823604600695`*^6}, {
       754965.9471975542, 2.4148136395399305`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{742987.9773018004, 2.5164478103415095`*^6}, {
       755380.0226981996, 2.478112189658491*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{742609.4260493304, 2.5780656221541082`*^6}, {
       755758.5739506695, 2.541358377845892*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{742262.74825692, 2.6397318992015035`*^6}, {756105.25174308, 
       2.6045561007984965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{741944.7245133574, 2.701443073625202*^6}, {756423.2754866426,
        2.667708926374798*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{741652.5098597992, 2.7631958774216557`*^6}, {
       756715.490140201, 2.7308201225783443`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{741383.5850673427, 2.824987315754982*^6}, {756984.4149326571,
        2.7938926842450183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{741135.714850735, 2.8868146424969854`*^6}, {757232.285149265,
        2.8569293575030146`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{740906.911957784, 2.948675337887209*^6}, {757461.088042216, 
       2.9199326621127906`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{740695.4062451787, 3.0105670881833243`*^6}, {
       757672.5937548213, 2.9829049118166757`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{740499.61799393, 3.0724877671612115`*^6}, {757868.38200607, 
       3.045848232838788*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{740318.1348363778, 3.134435419320959*^6}, {758049.8651636222,
        3.108764580679041*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{895682.4219048576, 1.2966125538650143`*^6}, {
       852413.5780951423, 1.2006674461349854`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{892493.0631483914, 1.356659143423566*^6}, {855602.9368516086,
        1.265484856576434*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{889656.4111414531, 1.4168043637661657`*^6}, {
       858439.5888585469, 1.330203636233834*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{887131.1967244709, 1.4770559955769882`*^6}, {
       860964.8032755292, 1.3948160044230116`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{884880.6165596417, 1.5374176840462184`*^6}, {
       863215.3834403583, 1.4593183159537814`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{882872.0663753041, 1.5978900574570652`*^6}, {
       865223.933624696, 1.5237099425429348`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{881076.798341518, 1.6584715905497451`*^6}, {
       867019.2016584821, 1.587992409450255*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{879469.5485875957, 1.71915926346305*^6}, {868626.4514124043, 
       1.6521687365369499`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{878028.1638785567, 1.7799490593584182`*^6}, {
       870067.8361214433, 1.7162429406415818`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{876733.2447902176, 1.840836336223945*^6}, {871362.7552097824,
        1.780219663776055*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{875567.8148895897, 1.9018161014790903`*^6}, {
       872528.1851104103, 1.84410389852091*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{874517.0203093793, 1.9628832121007845`*^6}, {
       873578.9796906208, 1.9079007878992155`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{873567.8608669151, 2.0240325180972973`*^6}, {
       874528.1391330849, 1.971615481902703*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{872708.9519159396, 2.0852589631891097`*^6}, {
       875387.0480840604, 2.0352530368108903`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{871930.3150083713, 2.146557653393343*^6}, {876165.6849916286,
        2.0988183466066564`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{871223.1948863459, 2.2079239017174956`*^6}, {
       876872.8051136541, 2.1623160982825044`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{870579.9001200192, 2.269353255224584*^6}, {877516.0998799807,
        2.2257507447754154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{869993.6647172163, 2.330841509225796*^6}, {878102.3352827837,
        2.2891264907742045`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{869458.5281664224, 2.392384712196346*^6}, {878637.4718335777,
        2.3524472878036546`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{868969.2315758176, 2.4539791641201666`*^6}, {
       879126.7684241824, 2.4157168358798334`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{868521.1278004529, 2.515621410288872*^6}, {879574.8721995472,
        2.478938589711128*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{868110.1036840713, 2.5773082320624054`*^6}, {
       879985.8963159287, 2.542115767937595*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{867732.5127678163, 2.6390366357054063`*^6}, {
       880363.4872321836, 2.6052513642945937`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{867385.1170276687, 2.700803840115558*^6}, {880710.8829723313,
        2.668348159884442*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{867065.0363924355, 2.7626072640354196`*^6}, {
       881030.9636075643, 2.7314087359645804`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{866769.7049634289, 2.8244445131702614`*^6}, {
       881326.295036571, 2.7944354868297386`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{866496.8330060695, 2.886313367507801*^6}, {881599.1669939305,
        2.8574306324921995`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{866244.3739137985, 2.9482117690413706`*^6}, {
       881851.6260862016, 2.920396230958629*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{866010.4954575474, 3.0101378100281134`*^6}, {
       882085.5045424527, 2.9833341899718866`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{865793.5547314415, 3.072089721862329*^6}, {882302.4452685583,
        3.046246278137671*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{865592.0762892038, 3.1340658646066296`*^6}, {
       882503.923710796, 3.1091341353933704`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0234011120546367`*^6, 1.2294751299531558`*^6}, {
       974422.8879453633, 1.142940870046844*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0202006933997876`*^6, 1.29018382400055*^6}, {
       977623.3066002125, 1.2070961759994498`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0173117456583527`*^6, 1.3509012712899444`*^6}, {
       980512.2543416473, 1.2712427287100558`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0147055179132901`*^6, 1.411646340106671*^6}, {
       983118.4820867099, 1.335361659893329*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0123547590156939`*^6, 1.4724328669234978`*^6}, {
       985469.2409843062, 1.3994391330765022`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0102340719884593`*^6, 1.5332706566836676`*^6}, {
       987589.9280115407, 1.4634653433163322`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0083200823714598`*^6, 1.5941663252689254`*^6}, {
       989503.9176285401, 1.5274336747310746`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0065914784159089`*^6, 1.655123996851912*^6}, {
       991232.5215840911, 1.5913400031480878`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0050289664399936`*^6, 1.71614587315609*^6}, {
       992795.0335600065, 1.65518212684391*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0036151729598847`*^6, 1.77723269283094*^6}, {
       994208.8270401151, 1.7189593071690598`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0023345161372642`*^6, 1.8383840985124737`*^6}, {
       995489.4838627359, 1.782671901487526*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0011730622263013`*^6, 1.8995989275505382`*^6}, {
       996650.9377736986, 1.8463210724494616`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.0001183776290162`*^6, 1.960875440394983*^6}, {
       997705.6223709838, 1.909908559605017*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{999159.3834849921, 2.022211498571289*^6}, {998664.6165150079,
        1.973436501428711*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{998286.2170964036, 2.083604702225178*^6}, {999537.7829035965,
        2.036907297774822*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{997490.1026532006, 2.1450524954644376`*^6}, {
       1.0003338973467995`*^6, 2.1003235045355624`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{996763.2324656565, 2.2065522462075506`*^6}, {
       1.0010607675343435`*^6, 2.1636877537924494`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{996098.6590717529, 2.2681013059629123`*^6}, {
       1.0017253409282471`*^6, 2.227002694037088*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{995490.1980447426, 2.329697053892476*^6}, {
       1.0023338019552573`*^6, 2.290270946107524*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{994932.3409929423, 2.3913369286347874`*^6}, {
       1.0028916590070577`*^6, 2.353495071365212*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{994420.1780547305, 2.4530184506474957`*^6}, {
       1.0034038219452695`*^6, 2.416677549352504*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{993949.3291003306, 2.5147392372524575`*^6}, {
       1.0038746708996693`*^6, 2.479820762747542*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{993515.8828251566, 2.5764970121036354`*^6}, {
       1.0043081171748436`*^6, 2.5429269878963646`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{993116.3429339853, 2.638289610428424*^6}, {
       1.0047076570660146`*^6, 2.605998389571576*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{992747.5806548477, 2.7001149810991567`*^6}, {
       1.0050764193451523`*^6, 2.669037018900844*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{992406.7928752067, 2.7619711863586125`*^6}, {
       1.0054172071247932`*^6, 2.732044813641387*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{992091.4652533113, 2.823856399839273*^6}, {
       1.0057325347466886`*^6, 2.795023600160727*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{991799.339719676, 2.885768903370944*^6}, {
       1.0060246602803242`*^6, 2.857975096629056*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{991528.3858443692, 2.947707082957251*^6}, {
       1.0062956141556309`*^6, 2.920900917042749*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{991276.7756033315, 3.009669424211952*^6}, {
       1.0065472243966685`*^6, 2.9838025757880486`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{991042.8611302566, 3.071654507475909*^6}, {
       1.0067811388697433`*^6, 3.046681492524091*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{990825.15508921, 3.1336610027808202`*^6}, {
       1.0069988449107899`*^6, 3.1095389972191798`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{1.153221406895159*^6, 1.1004362297682664`*^6}, {
       1.094330593104841*^6, 1.0222517702317336`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1499136055175576`*^6, 1.16185997131821*^6}, {
       1.0976383944824424`*^6, 1.08569202868179*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.146870020145029*^6, 1.2231950740537748`*^6}, {
       1.1006819798549712`*^6, 1.1492209259462252`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1440771963853796`*^6, 1.2844706246511468`*^6}, {
       1.1034748036146201`*^6, 1.2128093753488532`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1415197974448265`*^6, 1.345710523786392*^6}, {
       1.1060322025551735`*^6, 1.276433476213608*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.139181546610555*^6, 1.4069341151692534`*^6}, {
       1.108370453389445*^6, 1.3400738848307466`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1370459242586321`*^6, 1.4681568150757526`*^6}, {
       1.1105060757413679`*^6, 1.4037151849242474`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1350966654981556`*^6, 1.5293907083984106`*^6}, {
       1.1124553345018446`*^6, 1.4673452916015894`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.133318100496943*^6, 1.5906450920799938`*^6}, {
       1.114233899503057*^6, 1.5309549079200062`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1316953737889056`*^6, 1.6519269571849168`*^6}, {
       1.1158566262110947`*^6, 1.594537042815083*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1302145726993864`*^6, 1.7132414077500585`*^6}, {
       1.1173374273006134`*^6, 1.6580865922499418`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1288627891661695`*^6, 1.7745920188372787`*^6}, {
       1.1186892108338303`*^6, 1.7215999811627215`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1276281340416064`*^6, 1.8359811386347502`*^6}, {
       1.1199238659583938`*^6, 1.7850748613652496`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1264997185677742`*^6, 1.8974101406140444`*^6}, {
       1.1210522814322258`*^6, 1.8485098593859558`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1254676141206801`*^6, 1.9588796320867394`*^6}, {
       1.1220843858793199`*^6, 1.9119043679132606`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1245227984505973`*^6, 2.020389625335555*^6}, {
       1.1230292015494027`*^6, 1.9752583746644447`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1236570944032178`*^6, 2.0819396770404289`*^6}, {
       1.1238949055967822`*^6, 2.0385723229595714`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.122863105383791*^6, 2.143529001126171*^6}, {
       1.124688894616209*^6, 2.101846998873829*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1221341505235194`*^6, 2.205156559519223*^6}, {
       1.1254178494764804`*^6, 2.165083440480777*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.121464201536153*^6, 2.2668211346736113`*^6}, {
       1.1260877984638468`*^6, 2.228282865326389*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.120847822538942*^6, 2.3285213871425*^6}, {
       1.126704177461058*^6, 2.2914466128575*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1202801135955316`*^6, 2.3902559009474996`*^6}, {
       1.1272718864044682`*^6, 2.3545760990525*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1197566583709116`*^6, 2.452023219038389*^6}, {
       1.1277953416290882`*^6, 2.4176727809616113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1192734760325085`*^6, 2.5138218707403573`*^6}, {
       1.1282785239674917`*^6, 2.480738129259642*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1188269773578383`*^6, 2.575650392749896*^6}, {
       1.1287250226421615`*^6, 2.543773607250104*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.118413924895645*^6, 2.6375073449580274`*^6}, {
       1.1291380751043549`*^6, 2.606780655041973*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1180313969573497`*^6, 2.6993913221441163`*^6}, {
       1.1295206030426503`*^6, 2.6697606778558837`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1176767551764287`*^6, 2.761300962388421*^6}, {
       1.129875244823571*^6, 2.7327150376115795`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1173476153556798`*^6, 2.8232349528908306`*^6}, {
       1.13020438464432*^6, 2.795645047109169*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1170418213194427`*^6, 2.885192033751354*^6}, {
       1.1305101786805573`*^6, 2.858551966248646*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1167574214946965`*^6, 2.9471710001600776`*^6}, {
       1.1307945785053037`*^6, 2.9214369998399224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1164926479580132`*^6, 3.009170703356442*^6}, {
       1.1310593520419868`*^6, 2.9843012966435584`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1162458977020313`*^6, 3.0711900506461947`*^6}, {
       1.1313061022979687`*^6, 3.0471459493538053`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.1160157158936558`*^6, 3.1332280047064116`*^6}, {
       1.1315362841063445`*^6, 3.1099719952935884`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2813663342930588`*^6, 970472.2750702834}, {
       1.2159136657069412`*^6, 903463.2249297166}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2782374581998975`*^6, 1.0321470592004401`*^6}, {
       1.2190425418001022`*^6, 965676.94079956}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2752888430979725`*^6, 1.0941499275638312`*^6}, {
       1.2219911569020275`*^6, 1.0285380724361688`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2725242588504944`*^6, 1.156023562186032*^6}, {
       1.2247557411495056`*^6, 1.0915284378139677`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2699431437520268`*^6, 1.2177950340750453`*^6}, {
       1.2273368562479732`*^6, 1.1546209659249547`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2675416509670978`*^6, 1.2794880167677503`*^6}, {
       1.2297383490329022`*^6, 1.21779198323225*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.265313542312195*^6, 1.34112290351849*^6}, {
       1.231966457687805*^6, 1.2810210964815102`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2632509288007652`*^6, 1.4027170240615595`*^6}, {
       1.2340290711992348`*^6, 1.3442909759384408`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.261344867834062*^6, 1.464284918679922*^6}, {
       1.2359351321659377`*^6, 1.4075870813200783`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.259585832658367*^6, 1.5258386381508233`*^6}, {
       1.2376941673416328`*^6, 1.4708973618491765`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2579640720876292`*^6, 1.587388047360352*^6}, {
       1.2393159279123708`*^6, 1.534211952639648*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2564698786546122`*^6, 1.648941117791844*^6}, {
       1.240810121345388*^6, 1.5975228822081562`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2550937821847175`*^6, 1.7105041997802495`*^6}, {
       1.2421862178152823`*^6, 1.6608238002197505`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2538266839189313`*^6, 1.7720822696074173`*^6}, {
       1.2434533160810685`*^6, 1.7241097303925827`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2526599441736205`*^6, 1.8336791494626957`*^6}, {
       1.2446200558263795`*^6, 1.787376850537304*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.251585434384379*^6, 1.8952977002775474`*^6}, {
       1.245694565615621*^6, 1.8506222997224529`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2505955623934057`*^6, 1.95693998870079*^6}, {
       1.2466844376065943`*^6, 1.91384401129921*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2496832780814287`*^6, 2.0186074302113298`*^6}, {
       1.2475967219185713`*^6, 1.9770405697886702`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2488420649420302`*^6, 2.0803009107254264`*^6}, {
       1.2484379350579698`*^6, 2.0402110892745734`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2480659219440867`*^6, 2.1420208891660566`*^6}, {
       1.2492140780559133`*^6, 2.1033551108339434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2473493390060915`*^6, 2.2037674834118015`*^6}, {
       1.2499306609939088`*^6, 2.166472516588198*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2466872685859438`*^6, 2.265540541895873*^6}, {
       1.2505927314140564`*^6, 2.2295634581041266`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2460750952409229`*^6, 2.327339702926914*^6}, {
       1.2512049047590771`*^6, 2.2926282970730853`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2455086045057669`*^6, 2.3891644435821967`*^6}, {
       1.2517713954942331`*^6, 2.3556675564178033`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2449839520456174`*^6, 2.4510141198002263`*^6}, {
       1.2522960479543824`*^6, 2.4186818801997737`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.24449763374216*^6, 2.512887999085625*^6}, {
       1.2527823662578398`*^6, 2.4816720009143753`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2440464571462811`*^6, 2.574785287041214*^6}, {
       1.2532335428537186`*^6, 2.5446387129587857`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2436275145630704`*^6, 2.6367051487638177`*^6}, {
       1.2536524854369299`*^6, 2.6075828512361823`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.243238157912088*^6, 2.698646725982392*^6}, {
       1.254041842087912*^6, 2.6705052740176083`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2428759754171951`*^6, 2.7606091506792647`*^6}, {
       1.2544040245828049`*^6, 2.733406849320736*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.242538770117687*^6, 2.822591555816264*^6}, {
       1.254741229882313*^6, 2.7962884441837366`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.242224540149625*^6, 2.884593083685638*^6}, {
       1.2550554598503748`*^6, 2.8591509163143616`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2419314607180872`*^6, 2.946612892319038*^6}, {
       1.2553485392819128`*^6, 2.921995107680962*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.241657867663761*^6, 3.008650160314592*^6}, {
       1.2556221323362389`*^6, 2.984821839685408*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2414022425179037`*^6, 3.0707040903804624`*^6}, {
       1.2558777574820963`*^6, 3.047631909619537*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.2411631989359767`*^6, 3.1327739118415727`*^6}, {
       1.2561168010640233`*^6, 3.110426088158427*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{1.413154325391496*^6, 712550.3455960742}, {
       1.333853674608504*^6, 660953.6544039258}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4103459075403123`*^6, 775795.7854587081}, {
       1.3366620924596875`*^6, 722572.2145412919}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.407571120748972*^6, 838805.7875065963}, {
       1.339436879251028*^6, 784426.2124934037}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4048579979655133`*^6, 901602.7769421055}, {
       1.3421500020344865`*^6, 846493.2230578945}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.402228700726218*^6, 964210.2726319572}, {
       1.344779299273782*^6, 908749.7273680428}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3996999743060186`*^6, 1.0266518837139425`*^6}, {
       1.3473080256939814`*^6, 971172.1162860575}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3972837394263893`*^6, 1.0889505358572595`*^6}, {
       1.3497242605736107`*^6, 1.0337374641427405`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.394987749368601*^6, 1.1511279124112073`*^6}, {
       1.352020250631399*^6, 1.0964240875887927`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3928162577663707`*^6, 1.2132040839897017`*^6}, {
       1.3541917422336293`*^6, 1.1592119160102983`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.390770658260907*^6, 1.2751972946014176`*^6}, {
       1.3562373417390932`*^6, 1.2220827053985824`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.388850071095166*^6, 1.337123871582372*^6}, {
       1.358157928904834*^6, 1.2850201284176277`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3870518629330255`*^6, 1.3989982287336779`*^6}, {
       1.3599561370669748`*^6, 1.3480097712663224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3853720946211158`*^6, 1.460832935895485*^6}, {
       1.3616359053788842`*^6, 1.4110390641045151`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3838058975216425`*^6, 1.522638832715231*^6}, {
       1.3632021024783573`*^6, 1.4740971672847692`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3823477828566763`*^6, 1.5844251689287827`*^6}, {
       1.3646602171433237`*^6, 1.5371748310712175`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.380991890685661*^6, 1.646199757665643*^6}, {
       1.3660161093143392`*^6, 1.600264242334357*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3797321861267616`*^6, 1.707969131910917*^6}, {
       1.3672758138732384`*^6, 1.6633588680890827`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3785626106021998`*^6, 1.7697386972399936`*^6}, {
       1.3684453893978002`*^6, 1.7264533027600064`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.377477195533737*^6, 1.8315128763044225`*^6}, {
       1.3695308044662632`*^6, 1.7895431236955777`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.376470145258523*^6, 1.893295242353421*^6}, {
       1.3705378547414772`*^6, 1.8526247576465788`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3755358951349775`*^6, 1.9550886404092966`*^6}, {
       1.3714721048650225`*^6, 1.9156953595907032`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3746691499690327`*^6, 2.0168952956649966`*^6}, {
       1.3723388500309673`*^6, 1.9787527043350034`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.373864907079539*^6, 2.078716909320287*^6}, {
       1.3731430929204612`*^6, 2.0417950906797128`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3731184675761794`*^6, 2.1405547424914674`*^6}, {
       1.3738895324238208`*^6, 2.1048212575085326`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.372425438762481*^6, 2.2024096890777126`*^6}, {
       1.3745825612375187`*^6, 2.1678303109222874`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.371781730006142*^6, 2.2642823385929363`*^6}, {
       1.3752262699938582`*^6, 2.2308216614070637`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3711835439366302`*^6, 2.3261730300127026`*^6}, {
       1.3758244560633698`*^6, 2.293794969987297*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3706273644290145`*^6, 2.388081897669425*^6}, {
       1.3763806355709855`*^6, 2.3567501023305757`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3701099425041697`*^6, 2.4500089101767302`*^6}, {
       1.3768980574958303`*^6, 2.41968708982327*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3696282810091588`*^6, 2.511953903290566*^6}, {
       1.3773797189908412`*^6, 2.482606096709434*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3691796187281364`*^6, 2.5739166075309245`*^6}, {
       1.3778283812718638`*^6, 2.5455073924690755`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3687614144047739`*^6, 2.6358966713012685`*^6}, {
       1.378246585595226*^6, 2.6083913286987315`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3683713310241376`*^6, 2.697893680157544*^6}, {
       1.3786366689758624`*^6, 2.6712583198424564`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.368007220598366*^6, 2.759907172798037*^6}, {
       1.379000779401634*^6, 2.734108827201963*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3676671096206983`*^6, 2.8219366542709447`*^6}, {
       1.3793408903793017`*^6, 2.7969433457290553`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3673491852915485`*^6, 2.8839816068291473`*^6}, {
       1.3796588147084513`*^6, 2.859762393170852*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.367051782574535*^6, 2.9460414988015373`*^6}, {
       1.379956217425465*^6, 2.922566501198463*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.366773372106364*^6, 3.008115791797127*^6}, {
       1.3802346278936358`*^6, 2.9853562082028734`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3665125489597078`*^6, 3.0702039465117115`*^6}, {
       1.3804954510402922`*^6, 3.048132053488288*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.3662680222405838`*^6, 3.132305427366446*^6}, {
       1.3807399777594162`*^6, 3.1108945726335538`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.015], 
      ArrowBox[{{1.540028874311801*^6, 453147.1950327989}, {
       1.456707125688199*^6, 421876.304967201}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5381553310471545`*^6, 516700.56561593566`}, {
       1.4585806689528453`*^6, 482211.43438406434`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5361604476251148`*^6, 580540.0550346627}, {
       1.4605755523748852`*^6, 543235.9449653373}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.534078275457716*^6, 644176.9338576535}, {
       1.4626577245422837`*^6, 604463.0661423464}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5319408013878553`*^6, 707614.951628066}, {
       1.4647951986121447`*^6, 665889.0483719339}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5297771872149725`*^6, 770861.7765078124}, {
       1.4669588127850275`*^6, 727506.2234921876}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5276132725339816`*^6, 833928.1374312601}, {
       1.4691227274660186`*^6, 789303.86256874}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.525471318245566*^6, 896826.9823602941}, {
       1.4712646817544338`*^6, 851269.0176397059}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.523369954575045*^6, 959572.7002348109}, {
       1.473366045424955*^6, 913387.2997651892}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5213242908830151`*^6, 1.0221804377891117`*^6}, {
       1.4754117091169849`*^6, 975643.5622108883}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.519346143694814*^6, 1.0846655275592888`*^6}, {
       1.4773898563051857`*^6, 1.0380224724407111`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5174443425977582`*^6, 1.147043031298808*^6}, {
       1.4792916574022418`*^6, 1.1005089687011922`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.515625079350017*^6, 1.2093273940776133`*^6}, {
       1.481110920649983*^6, 1.1630886059223867`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5138922723501709`*^6, 1.2715321984590194`*^6}, {
       1.482843727649829*^6, 1.2257478015409803`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.512247925512767*^6, 1.333670004899242*^6}, {
       1.484488074487233*^6, 1.288473995100758*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5106924669145786`*^6, 1.395752263322295*^6}, {
       1.4860435330854217`*^6, 1.3512557366777048`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5092250579538147`*^6, 1.457789281098031*^6}, {
       1.4875109420461855`*^6, 1.414082718901969*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5078438680658408`*^6, 1.5197902338664932`*^6}, {
       1.4888921319341594`*^6, 1.476945766133507*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5065463132858307`*^6, 1.5817632073817533`*^6}, {
       1.4901896867141693`*^6, 1.539836792618247*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5053292592548374`*^6, 1.6437152604767808`*^6}, {
       1.4914067407451624`*^6, 1.6027487395232194`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5041891907876832`*^6, 1.7056525011618775`*^6}, {
       1.492546809212317*^6, 1.6656754988381225`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5031223510249294`*^6, 1.7675801696298455`*^6}, {
       1.4936136489750706`*^6, 1.7286118303701545`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5021248536321744`*^6, 1.8295027234813324`*^6}, {
       1.4946111463678256`*^6, 1.7915532765186676`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5011927716217653`*^6, 1.8914239217780223`*^6}, {
       1.4955432283782347`*^6, 1.854496078221978*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.5003222062633904`*^6, 1.9533469055827218`*^6}, {
       1.4964137937366096`*^6, 1.917437094417278*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.499509339304927*^6, 2.0152742734741059`*^6}, {
       1.497226660695073*^6, 1.980373726525894*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4987504714055443`*^6, 2.0772081511585205`*^6}, {
       1.497985528594456*^6, 2.0433038488414797`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4980420493333181`*^6, 2.139150254773125*^6}, {
       1.498693950666682*^6, 2.1062257452268754`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4973806841290928`*^6, 2.2011019478142117`*^6}, {
       1.4993553158709072`*^6, 2.1691380521857883`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4967631621056194`*^6, 2.263064291859408*^6}, {
       1.4999728378943806`*^6, 2.232039708140592*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4961864502468065`*^6, 2.3250380914064995`*^6}, {
       1.5005495497531933`*^6, 2.294929908593501*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4956476973013042`*^6, 2.387023933244765*^6}, {
       1.5010883026986958`*^6, 2.3578080667552357`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4951442316289304`*^6, 2.449022220823072*^6}, {
       1.5015917683710698`*^6, 2.4206737791769276`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4946735566565876`*^6, 2.5110332040954*^6}, {
       1.5020624433434126`*^6, 2.4835267959046*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.494233344629838*^6, 2.5730570053187544`*^6}, {
       1.5025026553701619`*^6, 2.546366994681245*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.493821429204031*^6, 2.6350936412581955`*^6}, {
       1.5029145707959693`*^6, 2.6091943587418045`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4934357973013548`*^6, 2.6971430422244295`*^6}, {
       1.503300202698645*^6, 2.6720089577755705`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4930745805640246`*^6, 2.759205068335241*^6}, {
       1.5036614194359754`*^6, 2.734810931664759*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4927360466557716`*^6, 2.8212795233557946`*^6}, {
       1.5039999533442287`*^6, 2.797600476644205*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4924185906010217`*^6, 2.883366166436542*^6}, {
       1.5043174093989786`*^6, 2.860377833563458*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4921207263009998`*^6, 2.945464722032402*^6}, {
       1.5046152736990005`*^6, 2.9231432779675983`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4918410783263007`*^6, 3.0075748882539063`*^6}, {
       1.5048949216736993`*^6, 2.9858971117460937`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4915783740542976`*^6, 3.069696343870523*^6}, {
       1.5051576259457027`*^6, 3.0486396561294775`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.4913314361955088`*^6, 3.1318287541586696`*^6}, {
       1.505404563804491*^6, 3.111371245841331*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.662913662229247*^6, 0.}, {1.5835503377707533`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6627993144633735`*^6, 64413.295394770226`}, {
       1.5836646855366265`*^6, 60450.70460522977}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6624587913775435`*^6, 128800.39670601508`}, {
       1.5840052086224565`*^6, 120927.60329398492`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6618995250097762`*^6, 193136.06432428025`}, {
       1.5845644749902238`*^6, 181455.93567571978`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.661133485118624*^6, 257396.90014142715`}, {
       1.585330514881376*^6, 242059.09985857285`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6601765929815085`*^6, 321562.1074581079}, {
       1.5862874070184913`*^6, 302757.8925418921}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6590479736252807`*^6, 385614.0783290615}, {
       1.587416026374719*^6, 363569.9216709385}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.657769107460291*^6, 449538.7812625617}, {
       1.588694892539709*^6, 424509.2187374384}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.656362945234504*^6, 513325.94185697124`}, {
       1.5901010547654957`*^6, 485586.05814302876`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6548530461167956`*^6, 576969.0272021935}, {
       1.5916109538832044`*^6, 546806.9727978064}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6532627890294986`*^6, 640465.0595500581}, {
       1.5932012109705014`*^6, 608174.9404499419}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6516146941537815`*^6, 703814.2945961067}, {
       1.5948493058462183`*^6, 669689.7054038934}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6499298770357226`*^6, 767019.8043860192}, {
       1.5965341229642772`*^6, 731348.1956139806}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6482276438694657`*^6, 830087.004835059}, {
       1.598236356130534*^6, 793144.9951649408}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6465252247490927`*^6, 893023.1641421705}, {
       1.5999387752509075`*^6, 855072.8358578297}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6448376327695514`*^6, 955836.9222520407}, {
       1.6016263672304486`*^6, 917123.0777479594}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6431776310512596`*^6, 1.0185378442165613`*^6}, {
       1.6032863689487402`*^6, 979286.1557834387}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6415557868487886`*^6, 1.0811360228861729`*^6}, {
       1.6049082131512116`*^6, 1.0415519771138271`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6399805913842644`*^6, 1.143641739589558*^6}, {
       1.6064834086157354`*^6, 1.1039102604104422`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6384586252966777`*^6, 1.206065185801895*^6}, {
       1.6080053747033223`*^6, 1.166350814198105*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6369947519911916`*^6, 1.2684162444552646`*^6}, {
       1.6094692480088086`*^6, 1.2288637555447354`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.635592324156955*^6, 1.3307043265042212`*^6}, {
       1.610871675843045*^6, 1.2914396734957786`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6342533918649906`*^6, 1.3929382564863134`*^6}, {
       1.6122106081350094`*^6, 1.3540697435136868`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6329789036543225`*^6, 1.455126199902478*^6}, {
       1.6134850963456773`*^6, 1.416745800097522*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6317688946761284`*^6, 1.5172756250554898`*^6}, {
       1.6146951053238718`*^6, 1.47946037494451*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.63062265819891*^6, 1.5793932923072716`*^6}, {
       1.6158413418010902`*^6, 1.5422067076927286`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.629538898558963*^6, 1.6414852643596155`*^6}, {
       1.616925101441037*^6, 1.6049787356403845`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6285158649927136`*^6, 1.7035569319777263`*^6}, {
       1.6179481350072862`*^6, 1.6677710680222737`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6275514667606011`*^6, 1.7656130504505807`*^6}, {
       1.618912533239399*^6, 1.7305789495494193`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6266433706280217`*^6, 1.8276577829396748`*^6}, {
       1.6198206293719786`*^6, 1.7933982170603252`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.625789082171346*^6, 1.8896947476599982`*^6}, {
       1.620674917828654*^6, 1.8562252523400018`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6249860125857901`*^6, 1.9517270665376815`*^6}, {
       1.6214779874142099`*^6, 1.9190569334623185`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6242315327389392`*^6, 2.0137574135871895`*^6}, {
       1.6222324672610608`*^6, 1.9818905864128103`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6235230161820787`*^6, 2.0757880617473125`*^6}, {
       1.6229409838179215`*^6, 2.0447239382526875`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6228578727353578`*^6, 2.137820927316321*^6}, {
       1.623606127264642*^6, 2.1075550726836785`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6222335741283472`*^6, 2.199857611442884*^6}, {
       1.6242304258716528`*^6, 2.1703823885571156`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6216476730239822`*^6, 2.261899438372571*^6}, {
       1.6248163269760176`*^6, 2.233204561627429*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6210978165948011`*^6, 2.3239474903319916`*^6}, {
       1.6253661834051989`*^6, 2.2960205096680084`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6205817556649223`*^6, 2.3860026390650705`*^6}, {
       1.6258822443350777`*^6, 2.358829360934929*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.620097350285165*^6, 2.448065574128726*^6}, {
       1.626366649714835*^6, 2.4216304258712735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.619642572475351*^6, 2.510136828116928*^6}, {
       1.6268214275246488`*^6, 2.4844231718830713`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6192155067486726`*^6, 2.572216799020089*^6}, {
       1.6272484932513274`*^6, 2.5472072009799103`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6188143489283738`*^6, 2.6343057699468886`*^6}, {
       1.6276496510716262`*^6, 2.6099822300531114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6184374036763825`*^6, 2.6964039264427884`*^6}, {
       1.6280265963236175`*^6, 2.6727480735572116`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6180830810759966`*^6, 2.7585113716374063`*^6}, {
       1.6283809189240034`*^6, 2.735504628362594*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6177498925450575`*^6, 2.820628139444498*^6}, {
       1.6287141074549428`*^6, 2.7982518605555026`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6174364463009043`*^6, 2.8827542060258314`*^6}, {
       1.6290275536990955`*^6, 2.860989793974169*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6171414425525006`*^6, 2.944889499715315*^6}, {
       1.6293225574474994`*^6, 2.923718500284685*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6168636685571626`*^6, 3.0070339095836584`*^6}, {
       1.6296003314428374`*^6, 2.9864380904163416`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6166019936481807`*^6, 3.0691872928074165`*^6}, {
       1.6298620063518193`*^6, 3.0491487071925835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.6163553643142278`*^6, 3.131349480990154*^6}, {
       1.6301086356857722`*^6, 3.1118505190098453`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.780665637959822*^6, 0.}, {1.715526362040178*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7805806026279535`*^6, 64018.820301021646`}, {
       1.7156113973720463`*^6, 60845.17969897836}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7803271141261812`*^6, 128019.53428048812`}, {
       1.7158648858738185`*^6, 121708.46571951188`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7799099536286227`*^6, 191984.60565313662`}, {
       1.7162820463713773`*^6, 182607.39434686338`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7793368576741978`*^6, 255897.60335355002`}, {
       1.7168551423258022`*^6, 243558.39664644995`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.77861818897827*^6, 319743.6704962361}, {
       1.71757381102173*^6, 304576.3295037638}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7777665111000594`*^6, 383509.9021930096}, {
       1.7184254888999409`*^6, 365674.0978069903}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.776796097431974*^6, 447185.6158081566}, {
       1.719395902568026*^6, 426862.3841918434}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7757224074027303`*^6, 510762.50662953797`}, {
       1.7204695925972697`*^6, 488149.4933704621}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7745615619440586`*^6, 574234.6910608}, {
       1.7216304380559414`*^6, 549541.3089392}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7733298466413324`*^6, 637598.6473007088}, {
       1.7228621533586676`*^6, 611041.3526992912}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.772043265352865*^6, 700853.0693817389}, {
       1.7241487346471353`*^6, 672650.930618261}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7707171603549088`*^6, 763998.6540666692}, {
       1.725474839645091*^6, 734369.345933331}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.76936590813571*^6, 827037.841470454}, {
       1.7268260918642902`*^6, 796194.158529546}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7680026935577658`*^6, 889974.5296792091}, {
       1.7281893064422342`*^6, 858121.4703207909}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.766639359747314*^6, 952813.7815435533}, {
       1.7295526402526863`*^6, 920146.2184564467}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7652863270302876`*^6, 1.0155615387605372`*^6}, {
       1.7309056729697122`*^6, 982262.4612394627}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.763952571576553*^6, 1.0782243548361603`*^6}, {
       1.732239428423447*^6, 1.0444636451638396`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7626456530366263`*^6, 1.140809154966822*^6}, {
       1.733546346963374*^6, 1.1067428450331779`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7613717801492757`*^6, 1.2033230276088798`*^6}, {
       1.7348202198507246`*^6, 1.1690929723911204`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7601359038067649`*^6, 1.2657730497195837`*^6}, {
       1.7360560961932351`*^6, 1.231506950280416*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7589418281247104`*^6, 1.3281661454440223`*^6}, {
       1.7372501718752894`*^6, 1.293977854555978*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7577923314393412`*^6, 1.3905089764028522`*^6}, {
       1.7383996685606588`*^6, 1.3564990235971478`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7566892906534022`*^6, 1.4528078606586878`*^6}, {
       1.7395027093465975`*^6, 1.419064139341312*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.755633803829193*^6, 1.5150687168255819`*^6}, {
       1.740558196170807*^6, 1.4816672831744181`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.754626307286654*^6, 1.5772970295422378`*^6}, {
       1.741565692713346*^6, 1.544302970457762*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7536666846499282`*^6, 1.6394978325612536`*^6}, {
       1.7425253153500718`*^6, 1.6069661674387467`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7527543662731957`*^6, 1.7016757059283536`*^6}, {
       1.7434376337268043`*^6, 1.6696522940716466`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7518884182645262`*^6, 1.7638347840651786`*^6}, {
       1.7443035817354738`*^6, 1.7323572159348214`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.751067620928789*^6, 1.8259787719697785`*^6}, {
       1.7451243790712112`*^6, 1.7950772280302213`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7502905368895563`*^6, 1.8881109671680806`*^6}, {
       1.745901463110444*^6, 1.8578090328319191`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7495555694514853`*^6, 1.950234285457724*^6}, {
       1.7466364305485147`*^6, 1.9205497145422762`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7488610119551711`*^6, 2.0123512888637984`*^6}, {
       1.7473309880448286`*^6, 1.9832967111362016`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7482050889805367`*^6, 2.0744642145635444`*^6}, {
       1.7479869110194633`*^6, 2.0460477854364556`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7475859902940886`*^6, 2.1365750038293283`*^6}, {
       1.7486060097059114`*^6, 2.1088009961706717`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7470018984280627`*^6, 2.1986853302858938`*^6}, {
       1.7491901015719373`*^6, 2.171554669714106*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7464510107404012`*^6, 2.260796626981355*^6}, {
       1.7497409892595988`*^6, 2.2343073730186457`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.745931556745267*^6, 2.3229101119356793`*^6}, {
       1.7502604432547328`*^6, 2.2970578880643207`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7454418114332312`*^6, 2.3850268119602706`*^6}, {
       1.7507501885667685`*^6, 2.359805188039729*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.744980105224856*^6, 2.4471475846426724`*^6}, {
       1.7512118947751438`*^6, 2.4225484153573276`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.744544831125725*^6, 2.5092731384662534`*^6}, {
       1.751647168874275*^6, 2.485286861533746*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7441344495781353`*^6, 2.5714040510903676`*^6}, {
       1.7520575504218645`*^6, 2.548019948909632*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7437474914366086`*^6, 2.6335407858558916`*^6}, {
       1.7524445085633914`*^6, 2.610747214144109*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7433825594322118`*^6, 2.6956837066076132`*^6}, {
       1.752809440567788*^6, 2.673468293392387*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7430383284348738`*^6, 2.7578330909415414`*^6}, {
       1.753153671565126*^6, 2.7361829090584586`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7427135447735123`*^6, 2.8199891419941937`*^6}, {
       1.7534784552264875`*^6, 2.798890858005807*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7424070248306284`*^6, 2.882151998894247*^6}, {
       1.7537849751693716`*^6, 2.8615920011057532`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7421176530906693`*^6, 2.9443217459961474`*^6}, {
       1.7540743469093305`*^6, 2.9242862540038526`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.741844379789421*^6, 3.0064984210115545`*^6}, {
       1.754347620210579*^6, 2.9869735789884455`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.741586218284421*^6, 3.0686820221488783`*^6}, {
       1.754605781715579*^6, 3.0496539778511217`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.7413422422433367`*^6, 3.1308725143642663`*^6}, {
       1.7548497577566633`*^6, 3.1123274856357337`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.899792019697361*^6, 0.}, {1.8461279803026393`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.899727478703429*^6, 63722.46148346938}, {
       1.8461925212965712`*^6, 61141.53851653062}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8995349259537763`*^6, 127432.08611696192`}, {
       1.8463850740462237`*^6, 122295.91388303808`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8992175309783802`*^6, 191116.38967790327`}, {
       1.84670246902162*^6, 183475.61032209676`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8987804419331378`*^6, 254763.57436450536`}, {
       1.8471395580668622`*^6, 244692.42563549464`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8982305936027365`*^6, 318362.8265672315}, {
       1.8476894063972635`*^6, 305957.17343276856`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8975764567511214`*^6, 381904.5645103548}, {
       1.8483435432488786`*^6, 367279.4354896452}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.89682774469534*^6, 445380.6257823983}, {
       1.8490922553046597`*^6, 428667.3742176017}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8959950946480571`*^6, 508784.3894529892}, {
       1.8499249053519429`*^6, 490127.6105470108}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8950897414731418`*^6, 572110.8321821383}, {
       1.8508302585268582`*^6, 551665.1678178618}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.894123200181944*^6, 635356.5219941988}, {
       1.851796799818056*^6, 613283.4780058011}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8931069710663063`*^6, 698519.5568512182}, {
       1.852813028933694*^6, 674984.4431487818}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8920522782037167`*^6, 761599.4576017477}, {
       1.8538677217962833`*^6, 736768.5423982524}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8909698485854326`*^6, 824597.0262339702}, {
       1.8549501514145674`*^6, 798634.9737660298}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8898697356784379`*^6, 887514.1806902421}, {
       1.8560502643215624`*^6, 860581.8193097579}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8887611881293475`*^6, 950353.776965}, {
       1.8571588118706525`*^6, 922606.223035}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8876525617498858`*^6, 1.0131194280269537`*^6}, {
       1.858267438250114*^6, 984704.5719730462}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8865512709892513`*^6, 1.0758153275142787`*^6}, {
       1.859368729010749*^6, 1.0468726724857212`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.885463774813392*^6, 1.1384460843684266`*^6}, {
       1.8604562251866083`*^6, 1.1091059156315734`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8843955912248236`*^6, 1.2010165727828015`*^6}, {
       1.8615244087751764`*^6, 1.1713994272171985`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.883351334476895*^6, 1.2635318001850315`*^6}, {
       1.8625686655231053`*^6, 1.2337481998149685`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.882334769250465*^6, 1.3259967945357822`*^6}, {
       1.863585230749535*^6, 1.2961472054642176`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8813488765527685`*^6, 1.3884165110591755`*^6}, {
       1.8645711234472312`*^6, 1.3585914889408248`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8803959267610468`*^6, 1.450795757630636*^6}, {
       1.8655240732389532`*^6, 1.4210762423693638`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.87947755597737*^6, 1.5131391374224178`*^6}, {
       1.8664424440226303`*^6, 1.4835968625775822`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8785948426158745`*^6, 1.5754510070137724`*^6}, {
       1.8673251573841253`*^6, 1.5461489929862274`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8777483818593458`*^6, 1.6377354479719985`*^6}, {
       1.8681716181406542`*^6, 1.6087285520280015`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.876938356266524*^6, 1.6999962498604588`*^6}, {
       1.868981643733476*^6, 1.6713317501395412`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8761646013674282`*^6, 1.7622369026902087`*^6}, {
       1.8697553986325716`*^6, 1.7339550973097915`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.875426665545425*^6, 1.8244605969678748`*^6}, {
       1.870493334454575*^6, 1.7965954030321252`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8747238638739032`*^6, 1.8866702296745556`*^6}, {
       1.8711961361260968`*^6, 1.8592497703254444`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8740553258596468`*^6, 1.9488684147156423`*^6}, {
       1.8718646741403535`*^6, 1.9219155852843574`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8734200372546157`*^6, 2.011057496592286*^6}, {
       1.8724999627453843`*^6, 1.984590503407714*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.872816876244422*^6, 2.073239566249582*^6}, {
       1.873103123755578*^6, 2.047272433750418*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8722446444168098`*^6, 2.135416478246457*^6}, {
       1.8736753555831902`*^6, 2.1099595217535426`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.87170209296772*^6, 2.197589868563101*^6}, {
       1.87421790703228*^6, 2.172650131436899*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8711879446255784`*^6, 2.259761172511477*^6}, {
       1.8747320553744214`*^6, 2.235342827488523*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8707009117744712`*^6, 2.3219316423426527`*^6}, {
       1.8752190882255286`*^6, 2.298036357657348*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8702397112406204`*^6, 2.384102364252279*^6}, {
       1.8756802887593796`*^6, 2.3607296357477214`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8698030761794653`*^6, 2.4462742745741527`*^6}, {
       1.876116923820535*^6, 2.423421725425847*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8693897654669185`*^6, 2.5084481750234277`*^6}, {
       1.8765302345330815`*^6, 2.4861118249765723`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.868998570961221*^6, 2.5706247469078936`*^6}, {
       1.8769214290387793`*^6, 2.548799253092107*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.868628322963607*^6, 2.632804564269963*^6}, {
       1.877291677036393*^6, 2.611483435730037*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8682778941684058`*^6, 2.69498810595565*^6}, {
       1.877642105831594*^6, 2.6741638940443494`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8679462023573369`*^6, 2.757175766631718*^6}, {
       1.8779737976426631`*^6, 2.7368402333682827`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8676322120593616`*^6, 2.819367866790021*^6}, {
       1.8782877879406384`*^6, 2.7995121332099787`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8673349353668785`*^6, 2.881564661790214*^6}, {
       1.8785850646331215`*^6, 2.8621793382097855`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8670534320714937`*^6, 2.9437663499996956`*^6}, {
       1.8788665679285065`*^6, 2.9248416500003044`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8667868092580503`*^6, 3.0059730800939244`*^6}, {
       1.8791331907419497`*^6, 2.9874989199060756`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8665342204739626`*^6, 3.068184957581871*^6}, {
       1.8793857795260372`*^6, 3.0501510424181283`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.8662948645719811`*^6, 3.130402050621056*^6}, {
       1.8796251354280189`*^6, 3.112797949378944*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0199601995784608`*^6, 0.}, {1.9756878004215392`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0199103348205981`*^6, 63495.52189441408}, {
       1.9757376651794019`*^6, 61368.47810558592}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.019761467732544*^6, 126981.73959582478`}, {
       1.975886532267456*^6, 122746.26040417522`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0195157552543608`*^6, 190449.57384890752`}, {
       1.976132244745639*^6, 184142.4261510925}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.019176711720422*^6, 253890.3846901343}, {
       1.9764712882795779`*^6, 245565.61530986568`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0187490930833595`*^6, 317296.16545062687`}, {
       1.9768989069166402`*^6, 307023.8345493731}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0182387444863222`*^6, 380659.70817880775`}, {
       1.9774092555136778`*^6, 368524.2918211923}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0176524197732965`*^6, 443974.73434430134`}, {
       1.9779955802267035`*^6, 430073.26565569866`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0169975826118272`*^6, 507235.9871031199}, {
       1.9786504173881728`*^6, 491676.0128968801}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0162821992053038`*^6, 570439.2839079251}, {
       1.9793658007946964`*^6, 553336.7160920749}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0155145321393297`*^6, 633581.5306062443}, {
       1.9801334678606705`*^6, 615058.4693937555}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0147029438564081`*^6, 696660.7001946146}, {
       1.9809450561435919`*^6, 676843.2998053854}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0138557167513417`*^6, 759675.7809569978}, {
       1.9817922832486583`*^6, 738692.2190430022}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0129808951136866`*^6, 822626.6997464502}, {
       1.9826671048863137`*^6, 800605.3002535498}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0120861522966449`*^6, 885514.2266675675}, {
       1.9835618477033554`*^6, 862581.7733324325}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.011178684723055*^6, 948339.8674329878}, {
       1.984469315276945*^6, 924620.1325670121}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0102651327706366`*^6, 1.0111057492856445`*^6}, {
       1.9853828672293634`*^6, 986718.2507143555}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0093515272896958`*^6, 1.0738145057042476`*^6}, {
       1.986296472710304*^6, 1.0488734942957526`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0084432595349026`*^6, 1.1364691642512497`*^6}, {
       1.9872047404650971`*^6, 1.1110828357487503`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0075450716405434`*^6, 1.19907304098071*^6}, {
       1.9881029283594566`*^6, 1.1733429590192898`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0066610644106774`*^6, 1.2616296438820811`*^6}, {
       1.9889869355893226`*^6, 1.2356503561179189`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0057947190888517`*^6, 1.324142586958737*^6}, {
       1.9898532809111485`*^6, 1.2980014130412631`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0049489298643442`*^6, 1.3866155157696852`*^6}, {
       1.9906990701356558`*^6, 1.3603924842303148`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0041260441093387`*^6, 1.4490520446228061`*^6}, {
       1.9915219558906613`*^6, 1.422819955377194*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0033279076734534`*^6, 1.5114557051055795`*^6}, {
       1.9923200923265463`*^6, 1.4852802948944205`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0025559129449567`*^6, 1.5738299052700072`*^6}, {
       1.9930920870550433`*^6, 1.547770094729993*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.001811047786537*^6, 1.6361778985395916`*^6}, {
       1.993836952213463*^6, 1.6102861014604084`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.0010939438412676`*^6, 1.69850276126037*^6}, {
       1.9945540561587326`*^6, 1.6728252387396302`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.000404923063146*^6, 1.7608073777558235`*^6}, {
       1.995243076936854*^6, 1.7353846222441762`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9997440416452477`*^6, 1.823094431747847*^6}, {
       1.995903958354752*^6, 1.7979615682521528`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9991111307916336`*^6, 1.885366403055268*^6}, {
       1.9965368692083664`*^6, 1.860553596944732*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9985058340056688`*^6, 1.9476255685623738`*^6}, {
       1.997142165994331*^6, 1.9231584314376262`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.99792764074925*^6, 2.0098740065499025`*^6}, {
       1.9977203592507502`*^6, 1.9857739934500977`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9973759164684883`*^6, 2.0721136035900512`*^6}, {
       1.998272083531512*^6, 2.0483983964099486`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9968499290866277`*^6, 2.134346063317735*^6}, {
       1.998798070913372*^6, 2.111029936682265*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9963488721397324`*^6, 2.1965729164972957`*^6}, {
       1.9992991278602676`*^6, 2.173667083502704*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9958718847802863`*^6, 2.258795531903556*^6}, {
       1.9997761152197137`*^6, 2.236308468096444*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9954180689032935`*^6, 2.321015127626437*^6}, {
       2.0002299310967068`*^6, 2.2989528723735623`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.99498650366317*^6, 2.383232782488289*^6}, {
       2.00066149633683*^6, 2.3615992175117107`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9945762576515675`*^6, 2.445449447332393*^6}, {
       2.0010717423484325`*^6, 2.424246552667607*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9941863989994575`*^6, 2.5076659560001376`*^6}, {
       2.0014616010005423`*^6, 2.4868940439998624`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9938160036540087`*^6, 2.5698830358637846`*^6}, {
       2.0018319963459913`*^6, 2.5495409641362154`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.993464162064099*^6, 2.632101317822486*^6}, {
       2.0021838379359012`*^6, 2.612186682177514*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9931299844893748`*^6, 2.694321345702224*^6}, {
       2.0025180155106254`*^6, 2.674830654297776*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9928126051278333`*^6, 2.756543585026668*^6}, {
       2.002835394872167*^6, 2.7374724149733325`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9925111852368887`*^6, 2.818768431146542*^6}, {
       2.0031368147631113`*^6, 2.800111568853458*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.992224915403434*^6, 2.8809962167308745`*^6}, {
       2.0034230845965657`*^6, 2.8627477832691255`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9919530170999605`*^6, 2.943227218635275*^6}, {
       2.0036949829000398`*^6, 2.925380781364725*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9916947436466254`*^6, 3.005461664170917*^6}, {
       2.0039532563533743`*^6, 2.9880103358290833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9914493806834274`*^6, 3.0676997368037472`*^6}, {
       2.0041986193165728`*^6, 3.0506362631962528`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{1.9912162462423756`*^6, 3.1299415813172315`*^6}, {
       2.0044317537576242`*^6, 3.113258418682769*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.140932418756624*^6, 0.}, {2.104443581243376*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.140893286180853*^6, 63318.813293573694`}, {
       2.1044827138191466`*^6, 61545.186706426306`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.14077639422365*^6, 126630.75058966485`}, {
       2.10459960577635*^6, 123097.24941033516`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.140583245012503*^6, 189929.08330704313`}, {
       2.104792754987497*^6, 184662.91669295687`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1403162922990196`*^6, 253207.3715411379}, {
       2.1050597077009804`*^6, 246248.62845886213`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1399788695528135`*^6, 316459.5934343332}, {
       2.1053971304471865`*^6, 307860.4065656667}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.139575094625818*^6, 379680.2577223183}, {
       2.1058009053741824`*^6, 369503.7422776817}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1391097557943147`*^6, 442864.49562249327`}, {
       2.106266244205685*^6, 431183.50437750673`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1385881846777257`*^6, 506008.1295243243}, {
       2.106787815322274*^6, 492903.87047567574`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1380161218226803`*^6, 569107.7173120587}, {
       2.1073598781773197`*^6, 554668.2826879413}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.137399580638904*^6, 632160.5724822225}, {
       2.107976419361096*^6, 616479.4275177774}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1367447149263853`*^6, 695164.7614116886}, {
       2.1086312850736147`*^6, 678339.2385883114}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.136057694513901*^6, 758119.080111019}, {
       2.109318305486099*^6, 740248.9198889812}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.135344592625222*^6, 821023.0135157756}, {
       2.110031407374778*^6, 802208.9864842244}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.134611287592691*^6, 883876.6808090237}, {
       2.110764712407309*^6, 864219.3191909762}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1338633805335625`*^6, 946680.7704415654}, {
       2.1115126194664375`*^6, 926279.2295584346}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1331061296637855`*^6, 1.009436468453853*^6}, {
       2.112269870336215*^6, 988387.531546147}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1323444010998667`*^6, 1.0721453834502595`*^6}, {
       2.1130315989001337`*^6, 1.0505426165497405`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1315826353255184`*^6, 1.1348094711844434`*^6}, {
       2.1137933646744816`*^6, 1.1127425288155566`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1308248279906907`*^6, 1.1974309612363386`*^6}, {
       2.1145511720093098`*^6, 1.1749850387636612`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.130074523365404*^6, 1.260012287744739*^6}, {
       2.115301476634596*^6, 1.237267712255261*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.129334818576481*^6, 1.3225560256447003`*^6}, {
       2.1160411814235183`*^6, 1.2995879743552997`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1286083766908147`*^6, 1.3850648333768318`*^6}, {
       2.1167676233091853`*^6, 1.3619431666231684`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.127897446749079*^6, 1.4475414026071713`*^6}, {
       2.117478553250921*^6, 1.4243305973928287`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1272038889724724`*^6, 1.5099884151339706`*^6}, {
       2.1181721110275276`*^6, 1.4867475848660297`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.126529203537273*^6, 1.572408506866122*^6}, {
       2.118846796462727*^6, 1.549191493133878*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.125874561515669*^6, 1.6348042385360103`*^6}, {
       2.119501438484331*^6, 1.6116597614639895`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1252408367981636`*^6, 1.697178072652001*^6}, {
       2.1201351632018364`*^6, 1.674149927347999*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.124628638028676*^6, 1.759532356094741*^6}, {
       2.1207473619713243`*^6, 1.736659643905259*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1240383397878013`*^6, 1.8218693077077987`*^6}, {
       2.121337660212199*^6, 1.7991866922922016`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1234701124458048`*^6, 1.8841910102174622`*^6}, {
       2.1219058875541952`*^6, 1.8617289897825378`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.122923950270747*^6, 1.9464994058298054`*^6}, {
       2.1224520497292527`*^6, 1.9242845941701946`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1223996975170826`*^6, 2.00879629488728*^6}, {
       2.122976302482917*^6, 1.9868517051127197`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1218970723362314`*^6, 2.071083337015211*^6}, {
       2.123478927663768*^6, 2.049428662984789*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1214156884442437`*^6, 2.1333620542448964`*^6}, {
       2.1239603115557563`*^6, 2.112013945755104*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1209550745548583`*^6, 2.1956338356600846`*^6}, {
       2.1244209254451413`*^6, 2.174606164339915*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.120514691641414*^6, 2.257899943173953*^6}, {
       2.124861308358586*^6, 2.237204056826047*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.120093948130855*^6, 2.3201615181019343`*^6}, {
       2.1252820518691456`*^6, 2.2998064818980657`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1196922131600217`*^6, 2.3824195882501653`*^6}, {
       2.125683786839978*^6, 2.3624124117498347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1193088280409668`*^6, 2.444675075288916*^6}, {
       2.1260671719590332`*^6, 2.4250209247110835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.118943116090305*^6, 2.506928802224656*^6}, {
       2.1264328839096944`*^6, 2.4876311977753434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1185943909795773`*^6, 2.569181500823218*^6}, {
       2.126781609020423*^6, 2.5502424991767816`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.118261963760772*^6, 2.6314338188699945`*^6}, {
       2.1271140362392287`*^6, 2.612854181130006*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1179451487149843`*^6, 2.6936863271815404`*^6}, {
       2.1274308512850157`*^6, 2.6754656728184596`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1176432681636624`*^6, 2.7559395263067605`*^6}, {
       2.1277327318363376`*^6, 2.7380764736932395`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.117355656371954*^6, 2.8181938528755084`*^6}, {
       2.128020343628046*^6, 2.8006861471244916`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.117081662662964*^6, 2.880449685568422*^6}, {
       2.1282943373370357`*^6, 2.863294314431578*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1168206538507654`*^6, 2.9427073506946075`*^6}, {
       2.128555346149234*^6, 2.925900649305393*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.11657201608917*^6, 3.0049671273738667`*^6}, {
       2.12880398391083*^6, 2.9885048726261333`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.1163351562228175`*^6, 3.0672292523279423`*^6}, {
       2.129040843777182*^6, 3.0511067476720577`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.116109502717284*^6, 3.1294939242910827`*^6}, {
       2.1292664972827164`*^6, 3.1137060757089173`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.262535068572968*^6, 0.}, {2.232568931427032*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2625039302811516`*^6, 63179.17489116122}, {
       2.2326000697188484`*^6, 61684.82510883878}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2624108745324044`*^6, 126353.18001850315`}, {
       2.2326931254675956`*^6, 123374.81998149684`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2622569690818507`*^6, 189516.94457354196`}, {
       2.232847030918149*^6, 185075.05542645807`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.262043961899836*^6, 252665.59196672094`}, {
       2.233060038100164*^6, 246790.40803327906`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2617742353211353`*^6, 315794.5279335816}, {
       2.233329764678865*^6, 308525.47206641844`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2614507448961455`*^6, 378899.5184494663}, {
       2.233653255103855*^6, 370284.48155053373`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2610769457177236`*^6, 441976.755017462}, {
       2.2340270542822764`*^6, 432071.24498253805`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2606567094377205`*^6, 505022.9056085273}, {
       2.2344472905622795`*^6, 493889.0943914727}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2601942354141464`*^6, 568035.1503036997}, {
       2.234909764585854*^6, 555740.8496963003}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2596939594432465`*^6, 631011.2014566385}, {
       2.2354100405567535`*^6, 617628.7985433614}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.259160463348588*^6, 693949.3089067123}, {
       2.2359435366514125`*^6, 679554.6910932877}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2585983883539285`*^6, 756848.2513848603}, {
       2.2365056116460715`*^6, 741519.7486151396}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2580123547000396`*^6, 819707.315736361}, {
       2.2370916452999604`*^6, 803524.6842636389}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.257406889423932*^6, 882526.2659206716}, {
       2.237697110576068*^6, 865569.7340793282}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.256786363647511*^6, 945305.3039367349}, {
       2.2383176363524883`*^6, 927654.6960632651}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2561549401622596`*^6, 1.0080450248724053`*^6}, {
       2.2389490598377404`*^6, 989778.9751275947}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2555165315801776`*^6, 1.0707463682076142`*^6}, {
       2.2395874684198224`*^6, 1.0519416317923858`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2548747688729586`*^6, 1.1334105673368056`*^6}, {
       2.2402292311270414`*^6, 1.1141414326631946`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.254232979755786*^6, 1.196039099043676*^6}, {
       2.2408710202442138`*^6, 1.1763769009563243`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2535941760952207`*^6, 1.2586336343865963`*^6}, {
       2.2415098239047793`*^6, 1.238646365613404*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.252961049331*^6, 1.3211959921601308`*^6}, {
       2.2421429506689995`*^6, 1.3009480078398692`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2523359727922836`*^6, 1.3837280958067945`*^6}, {
       2.242768027207716*^6, 1.3632799041932058`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.251721009749296*^6, 1.4462319343791339`*^6}, {
       2.243382990250704*^6, 1.4256400656208661`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2511179260587553`*^6, 1.5087095279062719`*^6}, {
       2.2439860739412443`*^6, 1.4880264720937281`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.250528206322633*^6, 1.5711628973078374`*^6}, {
       2.2445757936773663`*^6, 1.5504371026921626`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.249953072571919*^6, 1.6335940388246346`*^6}, {
       2.2451509274280816`*^6, 1.6128699611753651`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2493935045986413`*^6, 1.6960049027994701`*^6}, {
       2.245710495401359*^6, 1.6753230972005296`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.248850261180702*^6, 1.7583973765410536`*^6}, {
       2.246253738819298*^6, 1.7377946234589464`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.248323901567183*^6, 1.8207732709352009`*^6}, {
       2.2467800984328166`*^6, 1.8002827290647991`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.247814806710825*^6, 1.883134310426231*^6}, {
       2.2472891932891756`*^6, 1.8627856895737692`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.247323199845083*^6, 1.9454821259727168`*^6}, {
       2.2477808001549165`*^6, 1.9253018740272832`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.246849166102904*^6, 2.0078182505809388`*^6}, {
       2.2482548338970966`*^6, 1.9878297494190612`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2463926709616724`*^6, 2.0701441170321312`*^6}, {
       2.2487113290383276`*^6, 2.050367882967869*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2459535773733007`*^6, 2.1324610574420667`*^6}, {
       2.2491504226267*^6, 2.1129149425579337`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2455316615003045`*^6, 2.194770304320375*^6}, {
       2.2495723384996955`*^6, 2.1754696956796255`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2451266270289*^6, 2.2570729928295524`*^6}, {
       2.2499773729711*^6, 2.238031007170447*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2447381180695873`*^6, 2.3193701639777464`*^6}, {
       2.2503658819304127`*^6, 2.3005978360222536`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2443657306857677`*^6, 2.381662768513444*^6}, {
       2.250738269314232*^6, 2.3631692314865566`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2440090231128987`*^6, 2.4439516713230135`*^6}, {
       2.2510949768871013`*^6, 2.425744328676986*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2436675247458555`*^6, 2.5062376561627868`*^6}, {
       2.251436475254144*^6, 2.4883223438372132`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2433407439817726`*^6, 2.5685214305855394`*^6}, {
       2.251763256018228*^6, 2.5509025694144606`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2430281750107175`*^6, 2.630803630946598*^6}, {
       2.252075824989283*^6, 2.613484369053402*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2427293036481673`*^6, 2.693084827397201*^6}, {
       2.252374696351833*^6, 2.676067172602799*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2424436123021496`*^6, 2.7553655287923133`*^6}, {
       2.252660387697851*^6, 2.7386504712076867`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2421705841648667`*^6, 2.817646187456899*^6}, {
       2.2529334158351338`*^6, 2.801233812543101*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2419097067141687`*^6, 2.8799272037689383`*^6}, {
       2.2531942932858313`*^6, 2.863816796231062*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2416604746048767`*^6, 2.9422089305294408`*^6}, {
       2.2534435253951233`*^6, 2.9263990694705592`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2414223920240495`*^6, 3.0044916770996028`*^6}, {
       2.2536816079759505`*^6, 2.9889803229003972`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2411949745781342`*^6, 3.066775713293349*^6}, {
       2.2539090254218653`*^6, 3.0515602867066516`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.2409777507737465`*^6, 3.1290612730199983`*^6}, {
       2.2541262492262535`*^6, 3.1141387269800017`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3846389880415997`*^6, 0.}, {2.3601930119584007`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3846139030881627`*^6, 63067.375497074085`}, {
       2.360218096911837*^6, 61796.624502925915`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3845389079810744`*^6, 126130.8038832488}, {
       2.360293092018925*^6, 123597.19611675122`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3844147757269912`*^6, 189186.40591007713`}, {
       2.360417224273009*^6, 185405.5940899229}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3842427740965644`*^6, 252230.43577865438`}, {
       2.360589225903436*^6, 247225.56422134562`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.384024635689197*^6, 315259.342301296}, {
       2.360807364310803*^6, 309060.65769870405`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3837625178109505`*^6, 378269.82372814784`}, {
       2.3610694821890495`*^6, 370914.1762718522}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3834589538106816`*^6, 441258.87466524576`}, {
       2.3613730461893184`*^6, 432789.1253347543}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.383116797801531*^6, 504223.82391624915`}, {
       2.3617152021984686`*^6, 494688.17608375085`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3827391648602816`*^6, 567162.3625249581}, {
       2.362092835139718*^6, 556613.6374750419}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3823293688432304`*^6, 630072.5617483902}, {
       2.362502631156769*^6, 618567.4382516097}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3818908598907054`*^6, 692952.8811211826}, {
       2.3629411401092946`*^6, 680551.1188788175}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3814271635277574`*^6, 755802.16715634}, {
       2.363404836472242*^6, 742565.8328436599}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3809418230261127`*^6, 818619.6435459985}, {
       2.3638901769738877`*^6, 804612.3564540014}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3804383463956933`*^6, 881404.8939670748}, {
       2.3643936536043067`*^6, 866691.1060329253}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3799201590472795`*^6, 944157.8387557626}, {
       2.3649118409527205`*^6, 928802.1612442374}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3793905628341353`*^6, 1.0068787067935948`*^6}, {
       2.3654414371658647`*^6, 990945.2932064051}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3788527018597303`*^6, 1.069568003953329*^6}, {
       2.3659792981402697`*^6, 1.0531199960466707`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3783095351468474`*^6, 1.132226479396184*^6}, {
       2.3665224648531526`*^6, 1.1153255206038158`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3777638160116742`*^6, 1.1948550909061634`*^6}, {
       2.3670681839883253`*^6, 1.1775609090938366`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.377218077781544*^6, 1.2574549703064193`*^6}, {
       2.3676139222184555`*^6, 1.2398250296935807`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3766746253392007`*^6, 1.3200273898404452`*^6}, {
       2.3681573746607993`*^6, 1.3021166101595548`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.376135531868772*^6, 1.382573730229667*^6}, {
       2.368696468131228*^6, 1.364434269770333*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.375602640115199*^6, 1.445095450949068*^6}, {
       2.3692293598848013`*^6, 1.426776549050932*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.375077567444112*^6, 1.5075940631019566`*^6}, {
       2.369754432555888*^6, 1.4891419368980434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3745617139964444`*^6, 1.5700711051296687`*^6}, {
       2.370270286003556*^6, 1.551528894870331*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3740562732644184`*^6, 1.6325281214655747`*^6}, {
       2.3707757267355816`*^6, 1.6139358785344253`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.373562244466241*^6, 1.6949666441370032`*^6}, {
       2.3712697555337586`*^6, 1.6763613558629965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3730804461596184`*^6, 1.7573881772338836`*^6}, {
       2.3717515538403816`*^6, 1.7388038227661161`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.372611530603783*^6, 1.819794184098122*^6}, {
       2.3722204693962163`*^6, 1.8012618159018778`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3721559984516264`*^6, 1.8821860770412728`*^6}, {
       2.3726760015483736`*^6, 1.8637339229587272`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.371714213424286*^6, 1.9445652093677127`*^6}, {
       2.3731177865757146`*^6, 1.9262187906322875`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3712864166876366`*^6, 2.0069328694638223`*^6}, {
       2.3735455833123634`*^6, 1.9887151305361777`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.370872740711751*^6, 2.0692902767081396`*^6}, {
       2.3739592592882495`*^6, 2.0512217232918604`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3704732224495127`*^6, 2.1316385789606743`*^6}, {
       2.374358777550487*^6, 2.1137374210393257`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3700878157186927`*^6, 2.193978851399397*^6}, {
       2.3747441842813073`*^6, 2.1762611486006035`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.369716402712791*^6, 2.2563120964864204`*^6}, {
       2.375115597287209*^6, 2.2387919035135796`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3693588046001624`*^6, 2.3186392448639516`*^6}, {
       2.3754731953998376`*^6, 2.301328755136049*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3690147911987244`*^6, 2.3809611569993766`*^6}, {
       2.3758172088012756`*^6, 2.363870843000623*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.368684089735617*^6, 2.4432786254188027`*^6}, {
       2.376147910264383*^6, 2.4264173745811973`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.368366392718109*^6, 2.50559237738817*^6}, {
       2.376465607281891*^6, 2.4889676226118305`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3680613649545955`*^6, 2.567903077920136*^6}, {
       2.3767706350454045`*^6, 2.551520922079864*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3677686497733393`*^6, 2.6302113330028327`*^6}, {
       2.3770633502266607`*^6, 2.614076666997167*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3674878744923216`*^6, 2.6925176929631024`*^6}, {
       2.3773441255076784`*^6, 2.676634307036898*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.367218655196773*^6, 2.7548226558917556`*^6}, {
       2.3776133448032266`*^6, 2.739193344108244*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.366960600882147*^6, 2.817126671071736*^6}, {
       2.3778713991178526`*^6, 2.8017533289282634`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3667133170199483`*^6, 2.87943014236178*^6}, {
       2.3781186829800513`*^6, 2.8643138576382203`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.366476408602299*^6, 2.941733431498388*^6}, {
       2.378355591397701*^6, 2.9268745685016126`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.366249482718751*^6, 3.0040368612876674`*^6}, {
       2.378582517281249*^6, 2.9894351387123326`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3660321507158848`*^6, 3.066340718666061*^6}, {
       2.3787998492841157`*^6, 3.051995281333939*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.3658240299869063`*^6, 3.128645257615209*^6}, {
       2.379007970013093*^6, 3.114554742384791*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.50714647604198*^6, 0.}, {2.48741352395802*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.507126042467314*^6, 62976.810206699156`}, {
       2.4874339575326857`*^6, 61887.18979330084}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5070649327608454`*^6, 125950.56492807489`}, {
       2.4874950672391546`*^6, 123777.4350719251}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5069637158223973`*^6, 188918.25612172871`}, {
       2.487596284177603*^6, 185673.74387827129`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5068233261375534`*^6, 251876.96919382058`}, {
       2.4877366738624466`*^6, 247579.03080617942`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.506645043812835*^6, 314823.926201686}, {
       2.487914956187165*^6, 309496.0737983141}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.50643046770306*^6, 377756.52502555685`}, {
       2.4881295322969398`*^6, 371427.47497444315`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.506181482631359*^6, 440672.373475602}, {
       2.4883785173686408`*^6, 433375.62652439805`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5059002218847205`*^6, 503569.31753707456`}, {
       2.48865977811528*^6, 495342.68246292544`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.505589026284902*^6, 566445.4632192497}, {
       2.4889709737150986`*^6, 557330.5367807504}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5052504011833346`*^6, 629299.1917459967}, {
       2.4893095988166654`*^6, 619340.8082540032}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.504886972711415*^6, 692129.1680908184}, {
       2.4896730272885854`*^6, 681374.8319091814}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.504501444540857*^6, 754934.3431024528}, {
       2.490058555459143*^6, 743433.6568975472}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5040965562824984`*^6, 817713.9496770239}, {
       2.490463443717502*^6, 805518.050322976}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5036750444882195`*^6, 880467.4936011053}, {
       2.49088495551178*^6, 867628.5063988948}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5032396070326236`*^6, 943194.7398124785}, {
       2.491320392967376*^6, 929765.2601875213}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5027928714518053`*^6, 1.005895694900983*^6}, {
       2.4917671285481947`*^6, 991928.3050990169}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5023373676178497`*^6, 1.0685705867028635`*^6}, {
       2.49222263238215*^6, 1.0541174132971365`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.501875504939705*^6, 1.131219841833161*^6}, {
       2.492684495060295*^6, 1.1163321581668393`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5014095541116274`*^6, 1.1938440619583328`*^6}, {
       2.4931504458883726`*^6, 1.178571938041667*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5009416332849725`*^6, 1.2564439995428126`*^6}, {
       2.4936183667150275`*^6, 1.2408360004571876`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5004736984207314`*^6, 1.3190205337162265`*^6}, {
       2.494086301579269*^6, 1.3031234662837735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.5000075374899134`*^6, 1.3815746468098112`*^6}, {
       2.494552462510086*^6, 1.3654333531901888`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.499544768125867*^6, 1.4441074020077488`*^6}, {
       2.4950152318741325`*^6, 1.4277645979922512`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4990868382947473`*^6, 1.50661992245724*^6}, {
       2.4954731617052522`*^6, 1.4901160775427602`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.498635029534599*^6, 1.569113372084532*^6}, {
       2.4959249704654017`*^6, 1.552486627915468*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.498190462316276*^6, 1.6315889382760033`*^6}, {
       2.496369537683724*^6, 1.6148750617239964`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4977541030969606`*^6, 1.6940478165058887`*^6}, {
       2.49680589690304*^6, 1.6772801834941113`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.497326772665601*^6, 1.7564911969263775`*^6}, {
       2.497233227334399*^6, 1.7397008030736225`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4969091554158363`*^6, 1.8189202528819542`*^6}, {
       2.497650844584164*^6, 1.8021357471180458`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4965018092227755`*^6, 1.881336131267571*^6}, {
       2.498058190777225*^6, 1.864583868732429*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4961051756429304`*^6, 1.9437399446187767`*^6}, {
       2.4984548243570696`*^6, 1.9270440553812233`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.495719590199485*^6, 2.00613276480011*^6}, {
       2.4988404098005146`*^6, 1.9895152351998899`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4953452925564633`*^6, 2.0685156181446204`*^6}, {
       2.4992147074435367`*^6, 2.0519963818553796`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.494982436424004*^6, 2.130889481890958*^6}, {
       2.499577563575996*^6, 2.114486518109042*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4946310990721784`*^6, 2.1932552817637273`*^6}, {
       2.499928900927821*^6, 2.176984718236273*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.494291290362134*^6, 2.255613890546508*^6}, {
       2.5002687096378654`*^6, 2.239490109453492*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4939629612306515`*^6, 2.317966127503956*^6}, {
       2.5005970387693485`*^6, 2.302001872496044*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4936460115875173`*^6, 2.3803127585187615`*^6}, {
       2.5009139884124827`*^6, 2.364519241481239*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.493340297604582*^6, 2.4426544968201034`*^6}, {
       2.5012197023954187`*^6, 2.427041503179897*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.493045638391285*^6, 2.5049920041919374`*^6}, {
       2.501514361608715*^6, 2.489567995808062*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4927618220641483`*^6, 2.567325892561421*^6}, {
       2.5017981779358517`*^6, 2.552098107438579*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4924886112275594`*^6, 2.6296567258796226`*^6}, {
       2.5020713887724406`*^6, 2.614631274120378*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4922257478905744`*^6, 2.6919850222180686`*^6}, {
       2.502334252109426*^6, 2.6771669777819314`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.491972957849702*^6, 2.7543112560153897`*^6}, {
       2.502587042150298*^6, 2.73970474398461*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4917299545711484`*^6, 2.816635860418276*^6}, {
       2.5028300454288516`*^6, 2.802244139581724*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4914964426080263`*^6, 2.8789592296699802`*^6}, {
       2.5030635573919737`*^6, 2.8647847703300193`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.491272120588916*^6, 2.9412817215077425`*^6}, {
       2.5032878794110846`*^6, 2.9273262784922575`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4910566838141023`*^6, 3.003603659537706*^6}, {
       2.503503316185897*^6, 2.9898683404622944`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.4908498264950556`*^6, 3.0659253355622427`*^6}, {
       2.503710173504944*^6, 3.052410664437758*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.490651243671418*^6, 3.128247011840088*^6}, {
       2.5039087563285823`*^6, 3.1149529881599117`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6299825247595585`*^6, 0.}, {2.6143054752404415`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.629965712786836*^6, 62902.66853779735}, {
       2.6143222872131635`*^6, 61961.33146220265}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6299154194571106`*^6, 125802.94215513156`}, {
       2.61437258054289*^6, 123925.05784486842`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6298320697223847`*^6, 188698.45968021694`}, {
       2.6144559302776153`*^6, 185893.54031978306`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.629716362557773*^6, 251586.92651032624`}, {
       2.6145716374422265`*^6, 247869.07348967373`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6295692573869186`*^6, 314466.145617568}, {
       2.6147187426130814`*^6, 309853.854382432}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6293919557437254`*^6, 377334.0459349111}, {
       2.6148960442562746`*^6, 371849.9540650889}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.629185878792913*^6, 440188.70743226097`}, {
       2.6151021212070864`*^6, 433859.29256773903`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6289526414512442`*^6, 503028.38233369455`}, {
       2.615335358548756*^6, 495883.6176663054}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.628694023932997*^6, 565851.512085782}, {
       2.615593976067003*^6, 557924.4879142179}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.628411941585152*^6, 628656.7398537629}, {
       2.6158760584148485`*^6, 619983.2601462371}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.628108413880238*^6, 691442.9184878522}, {
       2.6161795861197617`*^6, 682061.0815121477}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.627785533400851*^6, 754209.1140575724}, {
       2.6165024665991487`*^6, 744158.8859424276}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.627445435584261*^6, 816954.6051905685}, {
       2.616842564415739*^6, 806277.3948094316}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.627090269904754*^6, 879678.8785684687}, {
       2.6171977300952463`*^6, 868417.1214315312}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6267221730624516`*^6, 942381.6210225372}, {
       2.617565826937548*^6, 930578.3789774628}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.626343244627772*^6, 1.0050627087346377`*^6}, {
       2.6179447553722286`*^6, 992761.2912653622}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.625955525467438*^6, 1.0677221940847035`*^6}, {
       2.6183324745325614`*^6, 1.0549658059152968`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6255609791573747`*^6, 1.1303602906962973`*^6}, {
       2.6187270208426253`*^6, 1.1171917093037025`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.625161476475069*^6, 1.1929773572199692`*^6}, {
       2.619126523524931*^6, 1.1794386427800308`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.624758782963165*^6, 1.2555738803637228`*^6}, {
       2.6195292170368345`*^6, 1.2417061196362774`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6243545494697555`*^6, 1.318150457635204*^6}, {
       2.619933450530244*^6, 1.303993542364796*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6239503055006163`*^6, 1.3807077802054263`*^6}, {
       2.620337694499384*^6, 1.3663002197945735`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.623547455164853*^6, 1.4432466162430148`*^6}, {
       2.620740544835147*^6, 1.4286253837569852`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6231472754575433`*^6, 1.5057677950046833`*^6}, {
       2.621140724542457*^6, 1.490968204995317*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.622750916599768*^6, 1.5682721919050124`*^6}, {
       2.6215370834002313`*^6, 1.5533278080949876`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.622359404146236*^6, 1.6307607147290262`*^6}, {
       2.6219285958537636`*^6, 1.6157032852709738`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6219736425714716`*^6, 1.6932342910963653`*^6}, {
       2.622314357428529*^6, 1.6780937089036347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.621594420055239*^6, 1.755693857237261*^6}, {
       2.622693579944761*^6, 1.740498142762739*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.621222414204343*^6, 1.8181403480986876`*^6}, {
       2.623065585795657*^6, 1.8029156519013126`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.620858198469311*^6, 1.8805746887642595`*^6}, {
       2.6234298015306895`*^6, 1.8653453112357405`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.620502249038943*^6, 1.942997787143511*^6}, {
       2.6237857509610574`*^6, 1.9277862128564892`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6201549520218335`*^6, 2.0054105278647514`*^6}, {
       2.624133047978166*^6, 1.9902374721352488`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.619816610750456*^6, 2.0678137672901566`*^6}, {
       2.624471389249544*^6, 2.0526982327098434`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.619487453069342*^6, 2.130208329561424*^6}, {
       2.624800546930658*^6, 2.115167670438576*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.619167638493494*^6, 2.192595003578455*^6}, {
       2.6251203615065063`*^6, 2.1776449964215443`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6188572651459454`*^6, 2.2549745408113697`*^6}, {
       2.625430734854054*^6, 2.2401294591886303`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.618556376404025*^6, 2.3173476538469777`*^6}, {
       2.625731623595975*^6, 2.3026203461530223`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6182649672021805`*^6, 2.379715015573992*^6}, {
       2.6260230327978195`*^6, 2.3651169844260085`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.617982989955161*^6, 2.4420772589161126`*^6}, {
       2.626305010044839*^6, 2.4276187410838874`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.61771036007897*^6, 2.504434977028212*^6}, {
       2.62657763992103*^6, 2.4901250229717884`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6174469610984107`*^6, 2.5667887238776567`*^6}, {
       2.62684103890159*^6, 2.5526352761223433`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.617192649339427*^6, 2.6291390151400794`*^6}, {
       2.6270953506605728`*^6, 2.6151489848599206`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6169472582119624`*^6, 2.6914863293462484`*^6}, {
       2.627340741788038*^6, 2.677665670653752*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.616710602094941*^6, 2.753831109223955*^6}, {
       2.6275773979050596`*^6, 2.7401848907760456`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6164824798394404`*^6, 2.8161737631858136`*^6}, {
       2.62780552016056*^6, 2.8027062368141864`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6162626779093393`*^6, 2.878514666920467*^6}, {
       2.6280253220906607`*^6, 2.8652293330795327`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6160509731809096`*^6, 2.9408541650507953`*^6}, {
       2.628237026819091*^6, 2.927753834949204*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.615847135424158*^6, 3.003192572828355*^6}, {
       2.628440864575842*^6, 2.990279427171645*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6156509294893336`*^6, 3.065530177838317*^6}, {
       2.628637070510667*^6, 3.0528058221616833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.6154621172220805`*^6, 3.12786724169373*^6}, {
       2.628825882777919*^6, 3.1153327583062705`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.753088776218052*^6, 0.}, {2.740927223781948*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.753074817920322*^6, 62841.39053911306}, {
       2.7409411820796775`*^6, 62022.60946088694}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.753033050919655*^6, 125680.88257819579`}, {
       2.7409829490803448`*^6, 124047.11742180421`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7529637969530225`*^6, 188516.60200593236`}, {
       2.7410522030469775`*^6, 186075.3979940676}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7528675858426527`*^6, 251346.7228766641}, {
       2.7411484141573473`*^6, 248109.27712333592`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7527451461028554`*^6, 314169.48998903495`}, {
       2.741270853897145*^6, 310150.510010965}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.752597392210268*^6, 376983.23972876184`}, {
       2.741418607789732*^6, 372200.7602712381}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7524254089330393`*^6, 439786.4187076328}, {
       2.7415905910669607`*^6, 434261.58129236725`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.752230433193535*^6, 502577.599817125}, {
       2.741785566806465*^6, 496334.40018287505`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7520138339960715`*^6, 565355.4954129662}, {
       2.7420021660039285`*^6, 558420.5045870338}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.751777090984364*^6, 628118.9674511402}, {
       2.7422389090156355`*^6, 620521.03254886}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7515217722026426`*^6, 690867.0345008237}, {
       2.7424942277973574`*^6, 682636.9654991762}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.751249511621003*^6, 753598.8756604516}, {
       2.7427664883789965`*^6, 744769.1243395485}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.750961986951973*^6, 816313.8314950939}, {
       2.743054013048027*^6, 806918.1685049062}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.750660898234767*^6, 879011.402193088}, {
       2.7433551017652326`*^6, 869084.5978069119}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.750347947600313*^6, 941691.2432048746}, {
       2.743668052399687*^6, 931268.7567951255}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7500248205579603`*^6, 1.0043531586758592`*^6}, {
       2.7439911794420397`*^6, 993470.8413241408}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7496931690681237`*^6, 1.0669970930174817`*^6}, {
       2.7443228309318763`*^6, 1.0556909069825183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7493545965877683`*^6, 1.1296231209770811`*^6}, {
       2.7446614034122317`*^6, 1.1179288790229186`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7490106452010786`*^6, 1.192231436568929*^6}, {
       2.745005354798922*^6, 1.1801845634310707`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.748662784878612*^6, 1.2548223412178475`*^6}, {
       2.745353215121388*^6, 1.2424576587821525`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.748312404846819*^6, 1.3173962314453842`*^6}, {
       2.7457035951531804`*^6, 1.3047477685546158`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.747960806997385*^6, 1.3799535863990185`*^6}, {
       2.7460551930026156`*^6, 1.3670544136009815`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.747609201223157*^6, 1.4424949554897186`*^6}, {
       2.746406798776843*^6, 1.4293770445102816`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.747258702534589*^6, 1.505020946364677*^6}, {
       2.7467572974654115`*^6, 1.491715053635323*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.746910329787289*^6, 1.5675322134022391`*^6}, {
       2.7471056702127117`*^6, 1.5540677865977606`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7465650058367536`*^6, 1.630029446876649*^6}, {
       2.7474509941632464`*^6, 1.616434553123351*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.746223558929641*^6, 1.6925133629026797`*^6}, {
       2.7477924410703597`*^6, 1.67881463709732*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.745886725140889*^6, 1.7549846942355265`*^6}, {
       2.7481292748591113`*^6, 1.7412073057644737`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7455551516714487`*^6, 1.8174441819702485`*^6}, {
       2.7484608483285513`*^6, 1.8036118180297515`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.745229400831065*^6, 1.8798925681579893`*^6}, {
       2.748786599168935*^6, 1.8660274318420107`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7449099545434364`*^6, 1.9423305893333354`*^6}, {
       2.749106045456563*^6, 1.9284534106666644`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7445972192260153`*^6, 2.0047589709284857`*^6}, {
       2.7494187807739847`*^6, 1.9908890290715145`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.744291530912924*^6, 2.0671784225351824`*^6}, {
       2.7497244690870754`*^6, 2.0533335774648173`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.743993160506108*^6, 2.129589633964315*^6}, {
       2.7500228394938917`*^6, 2.1157863660356854`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7437023190563475`*^6, 2.191993272045341*^6}, {
       2.750313680943652*^6, 2.1782467279546587`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.743419162991661*^6, 2.254389978102802*^6}, {
       2.7505968370083394`*^6, 2.240714021897198*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.743143799225528*^6, 2.3167803660447425`*^6}, {
       2.750872200774472*^6, 2.3031876339552575`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7428762900911034`*^6, 2.3791650209974255`*^6}, {
       2.7511397099088966`*^6, 2.3656669790025745`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.742616658059944*^6, 2.4415444984218925`*^6}, {
       2.7513993419400556`*^6, 2.4281515015781075`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7423648902147375`*^6, 2.5039193236503545`*^6}, {
       2.7516511097852625`*^6, 2.4906406763496455`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7421209424550524`*^6, 2.566289991783725*^6}, {
       2.7518950575449476`*^6, 2.5531340082162754`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.741884743423302*^6, 2.628656967895593*^6}, {
       2.752131256576698*^6, 2.615631032104407*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.741656198144964*^6, 2.691020687492307*^6}, {
       2.7523598018550365`*^6, 2.678131312507693*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.741435191382767*^6, 2.7533815571834194`*^6}, {
       2.7525808086172333`*^6, 2.7406344428165806`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7412215907091387`*^6, 2.8157399555213773`*^6}, {
       2.7527944092908613`*^6, 2.803140044478623*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7410152493047896`*^6, 2.8780962339738715`*^6}, {
       2.7530007506952104`*^6, 2.865647766026129*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.740816008494094*^6, 2.940450717996661*^6}, {
       2.753199991505906*^6, 2.9281572820033394`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7406237000299213`*^6, 3.0028037081788075`*^6}, {
       2.7533922999700787`*^6, 2.990668291821192*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7404381481419904`*^6, 3.065155481436125*^6}, {
       2.7535778518580096`*^6, 3.053180518563875*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.7402591713636797`*^6, 3.127506292232196*^6}, {
       2.7537568286363203`*^6, 3.1156937077678046`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8764192764244005`*^6, 0.}, {2.8673247235755995`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.876407591237123*^6, 62790.30341386469}, {
       2.8673364087628764`*^6, 62073.69658613531}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.876372618330749*^6, 125579.08626658267`}, {
       2.8673713816692512`*^6, 124148.91373341733`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.876314604310852*^6, 188364.84587683724`}, {
       2.867429395689148*^6, 186227.15412316276`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8762339556909227`*^6, 251146.11491231085`}, {
       2.867510044309078*^6, 248309.88508768912`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8761312322874656`*^6, 313921.4780530563}, {
       2.8676127677125344`*^6, 310398.5219469437}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8760071382441763`*^6, 376689.58748410805`}, {
       2.867736861755824*^6, 372494.4125158919}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8758625109413606`*^6, 439449.1768955237}, {
       2.86788148905864*^6, 434598.82310447627`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.875698308099813*^6, 502199.07372182}, {
       2.868045691900187*^6, 496712.9262781799}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8755155934281014`*^6, 564938.2094143215}, {
       2.868228406571898*^6, 558837.7905856787}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8753155211875113`*^6, 627665.6276061225}, {
       2.8684284788124887`*^6, 620974.3723938775}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.875099320059439*^6, 690380.4900969784}, {
       2.868644679940561*^6, 683123.5099030215}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8748682766963327`*^6, 753082.0806513875}, {
       2.868875723303667*^6, 745285.9193486125}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.874623719320507*^6, 815769.8066646754}, {
       2.869120280679493*^6, 807462.1933353245}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8743670017071483`*^6, 878443.198806722}, {
       2.8693769982928517`*^6, 869652.8011932779}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8740994878507312`*^6, 941101.9087993642}, {
       2.8696445121492688`*^6, 931858.0912006357}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8738225375702917`*^6, 1.0037457055203284`*^6}, {
       2.869921462429709*^6, 994078.2944796717}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8735374932611147`*^6, 1.0663744696532618`*^6}, {
       2.8702065067388853`*^6, 1.0563135303467382`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.873245667950702*^6, 1.1289881871200951`*^6}, {
       2.8704983320492986`*^6, 1.1185638128799049`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8729483347676303`*^6, 1.1915869415390734`*^6}, {
       2.8707956652323697`*^6, 1.1808290584609266`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8726467178849857`*^6, 1.2541709059502773`*^6}, {
       2.8710972821150143`*^6, 1.2431090940497224`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8723419849568945`*^6, 1.3167403340414888`*^6}, {
       2.871402015043106*^6, 1.3054036659585114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.872035241028495*^6, 1.379295551092201*^6}, {
       2.871708758971505*^6, 1.3677124489077989`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.871727523867117*^6, 1.4418369448338847`*^6}, {
       2.8720164761328828`*^6, 1.4300350551661153`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8714198006358896`*^6, 1.504364956401674*^6}, {
       2.872324199364111*^6, 1.4923710435983262`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8711129658105066`*^6, 1.5668800715278038`*^6}, {
       2.872631034189494*^6, 1.5547199284721965`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8708078402251787`*^6, 1.6293828121015567`*^6}, {
       2.8729361597748213`*^6, 1.617081187898443*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.870505171124517*^6, 1.6918737281952081`*^6}, {
       2.8732388288754825`*^6, 1.6794542718047916`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8702056330935946`*^6, 1.7543533906312808`*^6}, {
       2.8735383669064054`*^6, 1.7418386093687192`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8699098297380977`*^6, 1.8168223841439947`*^6}, {
       2.8738341702619023`*^6, 1.8042336158560053`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.869618295989562*^6, 1.879281301167531*^6}, {
       2.874125704010438*^6, 1.866638698832469*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.869331500916514*^6, 1.9417307362659166`*^6}, {
       2.874412499083486*^6, 1.9290532637340836`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.869049850930222*^6, 2.0041712812040865`*^6}, {
       2.8746941490697777`*^6, 1.9914767187959133`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8687736932830666`*^6, 2.066603520647016*^6}, {
       2.8749703067169334`*^6, 2.0539084793529843`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.86850331976777*^6, 2.1290280284636165`*^6}, {
       2.8752406802322306`*^6, 2.1163479715363835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8682389705363424`*^6, 2.191445364604235*^6}, {
       2.8755050294636576`*^6, 2.178794635395765*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8679808379682857`*^6, 2.2538560725148213`*^6}, {
       2.8757631620317143`*^6, 2.241247927485179*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8677290705279866`*^6, 2.3162606770469486`*^6}, {
       2.876014929472014*^6, 2.3037073229530514`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8674837765611275`*^6, 2.378659682820601*^6}, {
       2.8762602234388725`*^6, 2.366172317179399*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.867245027989163*^6, 2.4410535729957134`*^6}, {
       2.8764989720108365`*^6, 2.428642427004287*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.867012863869328*^6, 2.5034428084086785`*^6}, {
       2.876731136130672*^6, 2.491117191591321*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.866787293795234*^6, 2.5658278270311165`*^6}, {
       2.8769567062047655`*^6, 2.5535961729688835`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8665683011198146`*^6, 2.6282090437099915`*^6}, {
       2.8771756988801854`*^6, 2.616078956290008*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8663558459882108`*^6, 2.6905868501504594`*^6}, {
       2.877388154011789*^6, 2.6785651498495406`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.866149868173219*^6, 2.7529616151054422`*^6}, {
       2.877594131826781*^6, 2.741054384894558*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.865950289710121*^6, 2.8153336847388004`*^6}, {
       2.877793710289879*^6, 2.8035463152611996`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.865757017331247*^6, 2.8777033831319*^6}, {
       2.8779869826687523`*^6, 2.8660406168681*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.865569944703438*^6, 2.940071012906353*^6}, {
       2.878174055296562*^6, 2.9285369870936465`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8653889544738554`*^6, 3.0024368559386167`*^6}, {
       2.878355045526145*^6, 2.9910351440613833`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8652139201313215`*^6, 3.064801174144929*^6}, {
       2.8785300798686785`*^6, 3.053534825855071*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.8650447076916588`*^6, 3.1271642103177295`*^6}, {
       2.8786992923083417`*^6, 3.116035789682271*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.999937441034509*^6, 0.}, {2.9935345589654907`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.999927584528791*^6, 62747.37396519673}, {
       2.9935444154712097`*^6, 62116.626034803274`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9998980790541875`*^6, 125493.51853561834`}, {
       2.993573920945812*^6, 124234.48146438166`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9998491157696573`*^6, 188237.21759814434`}, {
       2.993622884230343*^6, 186354.78240185566`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9997810100707556`*^6, 250977.28132261735`}, {
       2.9936909899292444`*^6, 248478.71867738265`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.999694196876483*^6, 313712.5586122016}, {
       2.993777803123517*^6, 310607.4413877984}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.999589224208714*^6, 376441.9487511708}, {
       2.993882775791286*^6, 372742.05124882923`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.999466745233093*^6, 439164.4120257546}, {
       2.9940052547669066`*^6, 434883.5879742455}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9993275089662964`*^6, 501878.9791278248}, {
       2.9941444910337036`*^6, 497033.02087217517`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.999172349882447*^6, 564584.7591905812}, {
       2.9942996501175524`*^6, 559191.2408094187}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9990021766704093`*^6, 627280.9463481379}, {
       2.9944698233295907`*^6, 621359.0536518622}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9988179604033623`*^6, 689966.8247550867}, {
       2.9946540395966377`*^6, 683537.1752449133}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9986207223826717`*^6, 752641.7720458311}, {
       2.994851277617328*^6, 745726.2279541689}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.998411521910162*^6, 815305.2612550122}, {
       2.995060478089838*^6, 807926.7387449878}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.998191444227461*^6, 877956.8612581998}, {
       2.9952805557725388`*^6, 870139.1387418003}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9979615888393396`*^6, 940596.2358249975}, {
       2.9955104111606604`*^6, 932363.7641750025}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9977230584112993`*^6, 1.0032231414039839`*^6}, {
       2.9957489415887007`*^6, 994600.8585960161}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9974769484015848`*^6, 1.065837423779959*^6}, {
       2.995995051598415*^6, 1.056850576220041*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9972243375557894`*^6, 1.1284390137586656`*^6}, {
       2.9962476624442106`*^6, 1.1191129862413344`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.996966279359667*^6, 1.1910279220426264`*^6}, {
       2.996505720640333*^6, 1.1813880779573733`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.99670379451394*^6, 1.2536042334644133`*^6}, {
       2.9967682054860606`*^6, 1.2436757665355864`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.996437864464813*^6, 1.316168100741141*^6}, {
       2.997034135535187*^6, 1.3059758992588588`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9961694259964745`*^6, 1.3787197379070164`*^6}, {
       2.9973025740035255`*^6, 1.3682882620929834`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.995899366867598*^6, 1.4412594135702034`*^6}, {
       2.997572633132402*^6, 1.4306125864297964`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9956285224532536`*^6, 1.5037874441269531`*^6}, {
       2.997843477546746*^6, 1.4929485558730469`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9953576733367667`*^6, 1.566304187050739*^6}, {
       2.998114326663234*^6, 1.555295812949261*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9950875437830063`*^6, 1.628810034357815*^6}, {
       2.998384456216994*^6, 1.617653965642185*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.99481880101515*^6, 1.6913054063338889`*^6}, {
       2.99865319898485*^6, 1.6800225936661114`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9945520552109024`*^6, 1.7537907455900735`*^6}, {
       2.998919944789098*^6, 1.7424012544099265`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.994287860131107*^6, 1.816266511500438*^6}, {
       2.9991841398688927`*^6, 1.804789488499562*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.994026714293272*^6, 1.8787331750587027`*^6}, {
       2.9994452857067278`*^6, 1.8671868249412973`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.993769062604299*^6, 1.9411912141781976`*^6}, {
       2.999702937395701*^6, 1.9295927858218022`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9935152983702645`*^6, 2.0036411094472778`*^6}, {
       2.9999567016297355`*^6, 1.992006890552722*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9932657656060127`*^6, 2.0660833403420823`*^6}, {
       3.0002062343939873`*^6, 2.0544286596579177`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.993020761573214*^6, 2.1285183818898224`*^6}, {
       3.0004512384267855`*^6, 2.116857618110178*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9927805394820976`*^6, 2.190946701768672*^6}, {
       3.000691460517902*^6, 2.179293298231328*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.99254531129895*^6, 2.253368757824702*^6}, {
       3.00092668870105*^6, 2.2417352421752983`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9923152506084773`*^6, 2.315784995982038*^6}, {
       3.0011567493915223`*^6, 2.3041830040179626`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9920904954870148`*^6, 2.3781958485194035`*^6}, {
       3.001381504512985*^6, 2.366636151480597*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9918711513492097`*^6, 2.440601732684263*^6}, {
       3.0016008486507903`*^6, 2.4290942673157374`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9916572937370534`*^6, 2.503003049614755*^6}, {
       3.0018147062629466`*^6, 2.491556950385245*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9914489710259405`*^6, 2.5654001835393813`*^6}, {
       3.0020230289740595`*^6, 2.5540238164606183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9912462070277026`*^6, 2.6277935012248107`*^6}, {
       3.002225792972298*^6, 2.6164944987751897`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9910490034753145`*^6, 2.6901833516430533`*^6}, {
       3.002422996524686*^6, 2.678968648356946*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9908573423781553`*^6, 2.752570065830574*^6}, {
       3.0026146576218447`*^6, 2.7414459341694266`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9906711882403637`*^6, 2.8149539569134526`*^6}, {
       3.0028008117596367`*^6, 2.8039260430865474`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9904904901379645`*^6, 2.8773353202745076`*^6}, {
       3.002981509862036*^6, 2.8664086797254924`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9903151836531083`*^6, 2.9397144338401407`*^6}, {
       3.003156816346891*^6, 2.928893566159859*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.990145192665971*^6, 3.002091558466623*^6}, {
       3.003326807334029*^6, 2.9913804415333765`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.989980431006664*^6, 3.0644669384074686`*^6}, {
       3.003491568993336*^6, 3.053869061592531*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{2.9898208039709684`*^6, 3.1268408018454383`*^6}, {
       3.0036511960290316`*^6, 3.1163591981545617`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1236138529786323`*^6, 0.}, {3.1195861470213677`*^6, 0.}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.123605481033477*^6, 62711.03693668258}, {
       3.1195945189665235`*^6, 62152.96306331741}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1235804153377535`*^6, 125421.07124553624`}, {
       3.1196195846622465`*^6, 124306.92875446378`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1235388056115084`*^6, 188129.11028472963`}, {
       3.119661194388492*^6, 186462.88971527034`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.123480899075041*^6, 250834.18119005547`}, {
       3.119719100924959*^6, 248621.8188099445}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.123407037039799*^6, 313535.34028404515`}, {
       3.1197929629602004`*^6, 310784.6597159548}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.123317650254318*^6, 376231.68192659644`}, {
       3.119882349745682*^6, 372952.31807340356`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1232132531183674`*^6, 438922.34664866276`}, {
       3.1199867468816326`*^6, 435125.6533513372}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.12309443690324*^6, 501606.52843262284`}, {
       3.1201055630967594`*^6, 497305.47156737716`}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.122961862135803*^6, 564283.481028562}, {
       3.120238137864197*^6, 559492.518971438}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.122816250317986*^6, 626952.5232237277}, {
       3.120383749682014*^6, 621687.4767762723}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1226583751615575`*^6, 689613.0430116862}, {
       3.1205416248384425`*^6, 683890.9569883138}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.122489053520307*^6, 752264.5006370302}, {
       3.1207109464796935`*^6, 746103.4993629698}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1223091361984857`*^6, 814906.430519776}, {
       3.120890863801514*^6, 808325.569480224}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1221194988059774`*^6, 877538.4420898564}, {
       3.121080501194023*^6, 870557.5579101437}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1219210328179137`*^6, 940160.2195855698}, {
       3.121278967182087*^6, 932799.7804144302}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.121714636980168*^6, 1.0027715208898624`*^6}, {
       3.1214853630198324`*^6, 995052.4791101374}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1215012091831653`*^6, 1.065372175494498*^6}, {
       3.1216987908168347`*^6, 1.057315824505502*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.121281638905759*^6, 1.1279620816943082`*^6}, {
       3.121918361094241*^6, 1.119589918305692*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1210568003093586`*^6, 1.1905412031218042`*^6}, {
       3.1221431996906414`*^6, 1.1818747968781958`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1208275460409205`*^6, 1.2531095647366291`*^6}, {
       3.1223724539590795`*^6, 1.2441704352633709`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.120594701782537*^6, 1.3156672483849397`*^6}, {
       3.1226052982174624`*^6, 1.3064767516150603`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1203590615657936`*^6, 1.3782143880412362`*^6}, {
       3.1228409384342064`*^6, 1.3687936119587638`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1201213838512823`*^6, 1.44075116483989*^6}, {
       3.1230786161487172`*^6, 1.43112083516011*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.119882388358017*^6, 1.5032778019961612`*^6}, {
       3.123317611641983*^6, 1.4934581980038385`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1196427536141477`*^6, 1.5657945597074*^6}, {
       3.123557246385853*^6, 1.5558054402926*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.119403115189502*^6, 1.6283017301148803`*^6}, {
       3.123796884810498*^6, 1.6181622698851197`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.119164064561974*^6, 1.6907996323958181`*^6}, {
       3.124035935438026*^6, 1.6805283676041819`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1189261485636136`*^6, 1.7532886080439892`*^6}, {
       3.124273851436386*^6, 1.7429033919560108`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.118689869348255*^6, 1.8157690163863662`*^6}, {
       3.1245101306517455`*^6, 1.8052869836136338`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1184556848204033`*^6, 1.8782412303726336`*^6}, {
       3.124744315179596*^6, 1.8676787696273664`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.118224009464739*^6, 1.9407056326645426`*^6}, {
       3.124975990535261*^6, 1.9300783673354574`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.117995215516579*^6, 2.003162612043028*^6}, {
       3.125204784483421*^6, 1.9924853879569718`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1177696344158775`*^6, 2.0656125601429099`*^6}, {
       3.125430365584122*^6, 2.0548994398570901`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1175475584904305`*^6, 2.128055868517936*^6}, {
       3.12565244150957*^6, 2.117320131482064*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1173292428177497`*^6, 2.1904929260328817`*^6}, {
       3.12587075718225*^6, 2.1797470739671183`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.117114907219346*^6, 2.2529241165743987`*^6}, {
       3.1260850927806543`*^6, 2.242179883425601*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.116904738345659*^6, 2.3153498170682704`*^6}, {
       3.1262952616543416`*^6, 2.30461818293173*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.116698891814557*^6, 2.377770395787559*^6}, {
       3.1265011081854436`*^6, 2.367061604212441*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1164974943709336`*^6, 2.440186210933837*^6}, {
       3.1267025056290664`*^6, 2.429509789066163*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1163006460394356`*^6, 2.5025976094720704`*^6}, {
       3.1268993539605644`*^6, 2.4919623905279296`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.116108422246647*^6, 2.5650049261987857`*^6}, {
       3.127091577753353*^6, 2.5544190738012143`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1159208758930773`*^6, 2.627408483022733*^6}, {
       3.1272791241069227`*^6, 2.616879516977267*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.115738039358997*^6, 2.6898085884372983`*^6}, {
       3.1274619606410027`*^6, 2.679343411562701*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.115559926431543*^6, 2.7522055371643323`*^6}, {
       3.127640073568457*^6, 2.741810462835668*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.115386534143531*^6, 2.8145996099497653`*^6}, {
       3.1278134658564692`*^6, 2.8042803900502347`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.115217844517077*^6, 2.876991073492311*^6}, {
       3.127982155482923*^6, 2.866752926507689*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1150538262074767`*^6, 2.9393801804876416`*^6}, {
       3.128146173792523*^6, 2.9292278195123584`*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1148944360447857`*^6, 3.0017671697716205`*^6}, {
       3.128305563955214*^6, 2.991704830228379*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.114739620472253*^6, 3.064152266547447*^6}, {
       3.128460379527747*^6, 3.054183733452553*^6}}]}, 
     {Arrowheads[0.015], 
      ArrowBox[{{3.1145893168821875`*^6, 3.12653568268284*^6}, {
       3.1286106831178125`*^6, 3.1166643173171603`*^6}}]}}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-2.3412*^6, 2.3412*^6}, {0, 2.3412*^6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7766622684896665`*^9, 3.7766622975797844`*^9}, 
   3.776662374248908*^9, {3.7766624395926857`*^9, 3.7766624622106953`*^9}, {
   3.7766625092354107`*^9, 3.7766625528969836`*^9}, {3.776662591329404*^9, 
   3.77666260320251*^9}, 3.7766626453927593`*^9, 3.7766627168956633`*^9, {
   3.7766627836259317`*^9, 3.7766628783973002`*^9}, 3.7766629365960217`*^9, {
   3.7766636051543517`*^9, 3.776663716096386*^9}, {3.7766637573413973`*^9, 
   3.776663822107643*^9}, {3.7766638709431796`*^9, 3.7766639030316696`*^9}, 
   3.7766643565124826`*^9, {3.7766701163599005`*^9, 3.7766701846113806`*^9}, 
   3.779601562696712*^9, 3.780332724715861*^9, 3.7803670436370096`*^9, 
   3.7803759831960497`*^9, 3.780389366861765*^9, 3.780571552319208*^9, 
   3.7805738287266226`*^9, 3.781269053675167*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"1141bbdb-22d7-4d36-b510-f5a88bc512de"]
}, Open  ]],

Cell["\<\
Zoomed in vectorfield of the gravity outside Europa on the northern pole. \
Note that the vectors are not pointing straight down but are slightly angled. \
Jupiter is to the right.\
\>", "Text",
 CellChangeTimes->{{3.7812722508276916`*^9, 3.7812722899052067`*^9}, {
  3.7812723299011946`*^9, 
  3.781272333895511*^9}},ExpressionUUID->"d9446298-22ab-496b-ba23-\
6ec95bf6c5af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"JupAtEur", "+", 
      RowBox[{
       RowBox[{"-", "G"}], "*", 
       RowBox[{"MEur", "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "x"}]}], ",", 
     RowBox[{
      RowBox[{"-", "G"}], "*", 
      RowBox[{"MEur", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "0.2"}], "rEur"}], ",", 
     RowBox[{"0.2", "rEur"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"0.9", "rEur"}], ",", 
     RowBox[{"1.2", "rEur"}]}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}], ">", "rEur"}]}], "]"}]}], ",", 
   RowBox[{"VectorPoints", "\[Rule]", " ", "25"}], ",", 
   RowBox[{"VectorScale", "\[Rule]", "0.05"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.2"}], "rEur"}], ",", 
        RowBox[{"0.2", "rEur"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.9", "rEur"}], ",", 
        RowBox[{"1.2", "rEur"}]}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.776664010567581*^9, 3.7766641202659383`*^9}, {
  3.77666434048145*^9, 3.7766643422153597`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"1ab2561c-db48-4c4c-8ef9-54d5c2ee361b"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.025011506086958298`, 1.}}], 
      ArrowBox[{{-318603.74079607625`, 
       1.537068684719454*^6}, {-305716.2592039238, 1.506491315280546*^6}}]}, 
     {Arrowheads[{{0.02444271454253679, 1.}}], 
      ArrowBox[{{-318490.7530924614, 
       1.5562168167113103`*^6}, {-305829.24690753856`, 
       1.5263631832886897`*^6}}]}, 
     {Arrowheads[{{0.023894428849469726`, 1.}}], 
      ArrowBox[{{-318383.0760117394, 
       1.5753773783546786`*^6}, {-305936.9239882606, 
       1.5462226216453211`*^6}}]}, 
     {Arrowheads[{{0.02336571470879863, 1.}}], 
      ArrowBox[{{-318280.40420872293`, 
       1.5945498195813415`*^6}, {-306039.59579127707`, 
       1.5660701804186585`*^6}}]}, 
     {Arrowheads[{{0.022855689922346708`, 1.}}], 
      ArrowBox[{{-318182.4529573501, 
       1.613733619659801*^6}, {-306137.5470426498, 1.5859063803401992`*^6}}]}, 
     {Arrowheads[{{0.022363520984778305`, 1.}}], 
      ArrowBox[{{-318088.95656094817`, 
       1.6329282853919999`*^6}, {-306231.04343905183`, 
       1.6057317146080001`*^6}}]}, 
     {Arrowheads[{{0.02188841992883292, 1.}}], 
      ArrowBox[{{-317999.6668995587, 
       1.652133349433464*^6}, {-306320.3331004413, 1.625546650566536*^6}}]}, 
     {Arrowheads[{{0.02142964140283411, 1.}}], 
      ArrowBox[{{-317914.3521013218, 
       1.671348368727753*^6}, {-306405.6478986782, 1.6453516312722473`*^6}}]}, 
     {Arrowheads[{{0.020986479961454686`, 1.}}], 
      ArrowBox[{{-317832.7953262555, 
       1.6905729230468038`*^6}, {-306487.20467374445`, 
       1.665147076953196*^6}}]}, 
     {Arrowheads[{{0.020558267552426315`, 1.}}], 
      ArrowBox[{{-317754.7936519587, 
       1.7098066136294059`*^6}, {-306565.2063480413, 
       1.6849333863705944`*^6}}]}, 
     {Arrowheads[{{0.02014437118341574, 1.}}], 
      ArrowBox[{{-317680.15705182723`, 
       1.7290490619106297`*^6}, {-306639.84294817277`, 
       1.70471093808937*^6}}]}, 
     {Arrowheads[{{0.019744190754679692`, 1.}}], 
      ArrowBox[{{-317608.7074573169, 
       1.7482999083356054`*^6}, {-306711.292542683, 
       1.7244800916643948`*^6}}]}, 
     {Arrowheads[{{0.01935715704437479, 1.}}], 
      ArrowBox[{{-317540.27789663116`, 
       1.7675588112515297`*^6}, {-306779.72210336884`, 
       1.74424118874847*^6}}]}, 
     {Arrowheads[{{0.018982729834528225`, 1.}}], 
      ArrowBox[{{-317474.71170296206`, 
       1.786825445872276*^6}, {-306845.28829703794`, 1.763994554127724*^6}}]}, 
     {Arrowheads[{{0.018620396166719844`, 1.}}], 
      ArrowBox[{{-317411.86178608885`, 
       1.8060995033103898`*^6}, {-306908.1382139112, 1.78374049668961*^6}}]}, 
     {Arrowheads[{{0.01826966871745184, 1.}}], 
      ArrowBox[{{-317351.5899617362, 
       1.8253806896716703`*^6}, {-306968.4100382639, 
       1.8034793103283297`*^6}}]}, 
     {Arrowheads[{{0.01793008428404022, 1.}}], 
      ArrowBox[{{-317293.76633363613`, 
       1.844668725207891*^6}, {-307026.23366636387`, 
       1.8232112747921092`*^6}}]}, 
     {Arrowheads[{{0.017601202372628313`, 1.}}], 
      ArrowBox[{{-317238.26872371876`, 
       1.8639633435235587`*^6}, {-307081.73127628124`, 
       1.8429366564764415`*^6}}]}, 
     {Arrowheads[{{0.017282603880628283`, 1.}}], 
      ArrowBox[{{-317184.9821462896, 
       1.883264290832916*^6}, {-307135.0178537104, 
       1.8626557091670842`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.025085410988610217`, 1.}}], 
      ArrowBox[{{-292357.09917597927`, 
       1.5372177892597977`*^6}, {-279936.2341573541, 
       1.5063422107402026`*^6}}]}, 
     {Arrowheads[{{0.024510272141711316`, 1.}}], 
      ArrowBox[{{-292251.8587445686, 
       1.5563588464020975`*^6}, {-280041.4745887648, 
       1.5262211535979023`*^6}}]}, 
     {Arrowheads[{{0.02395605122864251, 1.}}], 
      ArrowBox[{{-292151.60342429753`, 
       1.575512744091785*^6}, {-280141.7299090358, 1.5460872559082152`*^6}}]}, 
     {Arrowheads[{{0.023421784752274837`, 1.}}], 
      ArrowBox[{{-292056.04390249314`, 
       1.5946789042156942`*^6}, {-280237.28943084023`, 
       1.5659410957843056`*^6}}]}, 
     {Arrowheads[{{0.022906563653585434`, 1.}}], 
      ArrowBox[{{-291964.9106176893, 
       1.6138567801844063`*^6}, {-280328.42271564406`, 
       1.585783219815594*^6}}]}, 
     {Arrowheads[{{0.02240952969487448, 1.}}], 
      ArrowBox[{{-291877.95221741626`, 
       1.6330458549381034`*^6}, {-280415.38111591706`, 
       1.6056141450618969`*^6}}]}, 
     {Arrowheads[{{0.021929872116702866`, 1.}}], 
      ArrowBox[{{-291794.93415090063`, 
       1.6522456390941918`*^6}, {-280498.39918243274`, 
       1.6254343609058082`*^6}}]}, 
     {Arrowheads[{{0.021466824545452286`, 1.}}], 
      ArrowBox[{{-291715.6373836629, 
       1.6714556692256615`*^6}, {-280577.6959496705, 
       1.6452443307743385`*^6}}]}, 
     {Arrowheads[{{0.021019662130541784`, 1.}}], 
      ArrowBox[{{-291639.8572223651, 
       1.690675506260065*^6}, {-280653.4761109683, 1.665044493739935*^6}}]}, 
     {Arrowheads[{{0.020587698892260024`, 1.}}], 
      ArrowBox[{{-291567.4022394737, 
       1.7099047339898385`*^6}, {-280725.93109385966`, 
       1.6848352660101617`*^6}}]}, 
     {Arrowheads[{{0.02017028526291068, 1.}}], 
      ArrowBox[{{-291498.09328837926`, 
       1.7291429576854538`*^6}, {-280795.2400449541, 
       1.7046170423145464`*^6}}]}, 
     {Arrowheads[{{0.019766805805525617`, 1.}}], 
      ArrowBox[{{-291431.7626005702, 
       1.7483898028035834`*^6}, {-280861.5707327632, 
       1.7243901971964166`*^6}}]}, 
     {Arrowheads[{{0.01937667709581308, 1.}}], 
      ArrowBox[{{-291368.25295731, 
       1.7676449137831072`*^6}, {-280925.08037602337`, 
       1.7441550862168928`*^6}}]}, 
     {Arrowheads[{{0.018999345754282203`, 1.}}], 
      ArrowBox[{{-291307.41692902416`, 
       1.7869079529223682`*^6}, {-280985.9164043092, 
       1.7639120470776316`*^6}}]}, 
     {Arrowheads[{{0.018634286616628987`, 1.}}], 
      ArrowBox[{{-291249.1161762796, 
       1.8061785993316218`*^6}, {-281044.2171570538, 1.783661400668378*^6}}]}, 
     {Arrowheads[{{0.01828100103151985, 1.}}], 
      ArrowBox[{{-291193.2208068425, 
       1.82545654795511*^6}, {-281100.1125264909, 1.80340345204489*^6}}]}, 
     {Arrowheads[{{0.017939015275838414`, 1.}}], 
      ArrowBox[{{-291139.6087838394, 
       1.8447415086576382`*^6}, {-281153.724549494, 
       1.8231384913423618`*^6}}]}, 
     {Arrowheads[{{0.017607879078323344`, 1.}}], 
      ArrowBox[{{-291088.1653805283, 
       1.8640332053709438`*^6}, {-281205.16795280506`, 
       1.8428667946290562`*^6}}]}, 
     {Arrowheads[{{0.017287164243292928`, 1.}}], 
      ArrowBox[{{-291038.78267761826`, 
       1.8833313752955138`*^6}, {-281254.5506557151, 
       1.862588624704486*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.025147018656330174`, 1.}}], 
      ArrowBox[{{-266103.50756507675`, 
       1.5373560572619976`*^6}, {-254163.15910158993`, 
       1.5062039427380022`*^6}}]}, 
     {Arrowheads[{{0.024566071519478042`, 1.}}], 
      ArrowBox[{{-266006.41959104675`, 
       1.5564905040576905`*^6}, {-254260.24707561993`, 
       1.5260894959423095`*^6}}]}, 
     {Arrowheads[{{0.024006425954357237`, 1.}}], 
      ArrowBox[{{-265913.9634740368, 
       1.575638178799399*^6}, {-254352.70319262988`, 1.545961821200601*^6}}]}, 
     {Arrowheads[{{0.023467090988157937`, 1.}}], 
      ArrowBox[{{-265825.86810244556`, 
       1.5947984766519747`*^6}, {-254440.79856422113`, 
       1.5658215233480253`*^6}}]}, 
     {Arrowheads[{{0.022947132308964724`, 1.}}], 
      ArrowBox[{{-265741.8810584365, 
       1.6139708264134424`*^6}, {-254524.78560823016`, 
       1.5856691735865579`*^6}}]}, 
     {Arrowheads[{{0.022445668448118974`, 1.}}], 
      ArrowBox[{{-265661.7671414741, 
       1.6331546883341738`*^6}, {-254604.89952519257`, 
       1.6055053116658262`*^6}}]}, 
     {Arrowheads[{{0.02196186725630852, 1.}}], 
      ArrowBox[{{-265585.3070227181, 
       1.6523495520960612`*^6}, {-254681.35964394858`, 
       1.6253304479039388`*^6}}]}, 
     {Arrowheads[{{0.021494942648111567`, 1.}}], 
      ArrowBox[{{-265512.296017465, 
       1.6715549349387162`*^6}, {-254754.37064920168`, 
       1.6451450650612838`*^6}}]}, 
     {Arrowheads[{{0.02104415159211094, 1.}}], 
      ArrowBox[{{-265442.54296419345`, 
       1.6907703799208642`*^6}, {-254824.12370247327`, 
       1.6649496200791358`*^6}}]}, 
     {Arrowheads[{{0.020608791325843503`, 1.}}], 
      ArrowBox[{{-265375.86919998075`, 
       1.7099954543061308`*^6}, {-254890.7974666859, 
       1.6847445456938692`*^6}}]}, 
     {Arrowheads[{{0.020188196776780777`, 1.}}], 
      ArrowBox[{{-265312.1076231307, 
       1.7292297480633587`*^6}, {-254954.55904353596`, 
       1.704530251936641*^6}}]}, 
     {Arrowheads[{{0.019781738172267752`, 1.}}], 
      ArrowBox[{{-265251.1018348024, 
       1.748472872472442*^6}, {-255015.56483186423`, 
       1.7243071275275578`*^6}}]}, 
     {Arrowheads[{{0.019388818822908712`, 1.}}], 
      ArrowBox[{{-265192.7053522752, 
       1.7677244588274332`*^6}, {-255073.9613143915, 
       1.7440755411725668`*^6}}]}, 
     {Arrowheads[{{0.01900887306529183, 1.}}], 
      ArrowBox[{{-265136.7808872338, 
       1.7869841572293858`*^6}, {-255129.8857794329, 
       1.7638358427706142`*^6}}]}, 
     {Arrowheads[{{0.018641364351213278`, 1.}}], 
      ArrowBox[{{-265083.1996831267, 
       1.8062516354620294`*^6}, {-255183.46698353995`, 
       1.7835883645379706`*^6}}]}, 
     {Arrowheads[{{0.01828578347169982, 1.}}], 
      ArrowBox[{{-265031.8409062445, 
       1.8255265779439502`*^6}, {-255234.82576042216`, 
       1.8033334220560496`*^6}}]}, 
     {Arrowheads[{{0.017941646905166534`, 1.}}], 
      ArrowBox[{{-264982.5910856954, 
       1.8448086847514869`*^6}, {-255284.0755809713, 1.823071315248513*^6}}]}, 
     {Arrowheads[{{0.01760849527997293, 1.}}], 
      ArrowBox[{{-264935.3435979293, 
       1.8640976707070202`*^6}, {-255331.32306873743`, 
       1.8428023292929798`*^6}}]}, 
     {Arrowheads[{{0.017285891942487246`, 1.}}], 
      ArrowBox[{{-264889.9981918843, 
       1.883393264527781*^6}, {-255376.6684747824, 1.862526735472219*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.02460975221885339, 1.}}], 
      ArrowBox[{{-239754.8839058071, 
       1.5566112834696062`*^6}, {-228485.1160941929, 
       1.5259687165303938`*^6}}]}, 
     {Arrowheads[{{0.024045219715627567`, 1.}}], 
      ArrowBox[{{-239670.58198248842`, 
       1.5757532109445652`*^6}, {-228569.41801751158`, 
       1.5458467890554345`*^6}}]}, 
     {Arrowheads[{{0.023501325032542056`, 1.}}], 
      ArrowBox[{{-239590.2814249249, 
       1.5949080973178188`*^6}, {-228649.71857507507`, 
       1.5657119026821814`*^6}}]}, 
     {Arrowheads[{{0.022977110412726855`, 1.}}], 
      ArrowBox[{{-239513.74886638948`, 
       1.61407534825817*^6}, {-228726.25113361052`, 
       1.5855646517418302`*^6}}]}, 
     {Arrowheads[{{0.022471672838204528`, 1.}}], 
      ArrowBox[{{-239440.7669981223, 
       1.633254402713121*^6}, {-228799.23300187767`, 1.605405597286879*^6}}]}, 
     {Arrowheads[{{0.021984160334698282`, 1.}}], 
      ArrowBox[{{-239371.13330167183`, 
       1.6524447307260775`*^6}, {-228868.86669832814`, 
       1.6252352692739225`*^6}}]}, 
     {Arrowheads[{{0.02151376856196562, 1.}}], 
      ArrowBox[{{-239304.65889371609`, 
       1.6716458314164632`*^6}, {-228935.34110628391`, 
       1.6450541685835368`*^6}}]}, 
     {Arrowheads[{{0.021059737664917432`, 1.}}], 
      ArrowBox[{{-239241.167472321, 
       1.6908572311092077`*^6}, {-228998.83252767904`, 
       1.6648627688907923`*^6}}]}, 
     {Arrowheads[{{0.020621349363147835`, 1.}}], 
      ArrowBox[{{-239180.4943547766, 
       1.7100784816013041`*^6}, {-229059.50564522337`, 
       1.6846615183986959`*^6}}]}, 
     {Arrowheads[{{0.020197924258623687`, 1.}}], 
      ArrowBox[{{-239122.4855982006, 
       1.7293091585542446`*^6}, {-229117.5144017994, 
       1.7044508414457552`*^6}}]}, 
     {Arrowheads[{{0.01978881934317599, 1.}}], 
      ArrowBox[{{-239066.99719502416`, 
       1.7485488600021356`*^6}, {-229173.0028049758, 
       1.7242311399978641`*^6}}]}, 
     {Arrowheads[{{0.019393425689152234`, 1.}}], 
      ArrowBox[{{-239013.89433629814`, 
       1.7677972049662087`*^6}, {-229226.1056637019, 1.744002795033791*^6}}]}, 
     {Arrowheads[{{0.019011166308111824`, 1.}}], 
      ArrowBox[{{-238963.05073648522`, 
       1.7870538321672522`*^6}, {-229276.94926351478`, 
       1.763766167832748*^6}}]}, 
     {Arrowheads[{{0.01864149416383392, 1.}}], 
      ArrowBox[{{-238914.34801405176`, 
       1.8063183988282357`*^6}, {-229325.65198594824`, 
       1.783521601171764*^6}}]}, 
     {Arrowheads[{{0.01828389032714281, 1.}}], 
      ArrowBox[{{-238867.67512274784`, 
       1.8255905795600675`*^6}, {-229372.32487725216`, 
       1.8032694204399325`*^6}}]}, 
     {Arrowheads[{{0.017937862261180524`, 1.}}], 
      ArrowBox[{{-238822.92782897735`, 
       1.8448700653240276`*^6}, {-229417.07217102265`, 
       1.8230099346759727`*^6}}]}, 
     {Arrowheads[{{0.01760294222676009, 1.}}], 
      ArrowBox[{{-238780.00823111672`, 
       1.8641565624649785`*^6}, {-229459.99176888328`, 
       1.8427434375350212`*^6}}]}, 
     {Arrowheads[{{0.01727868579834918, 1.}}], 
      ArrowBox[{{-238738.82431704746`, 
       1.8834497918099507`*^6}, {-229501.1756829525, 
       1.8624702081900493`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024640985502874344`, 1.}}], 
      ArrowBox[{{-213497.7385851741, 
       1.5567207113723692`*^6}, {-202715.59474815917`, 
       1.525859288627631*^6}}]}, 
     {Arrowheads[{{0.024072129012039093`, 1.}}], 
      ArrowBox[{{-213421.920345518, 
       1.575857400035358*^6}, {-202791.4129878153, 1.545742599964642*^6}}]}, 
     {Arrowheads[{{0.023524206529206407`, 1.}}], 
      ArrowBox[{{-213349.72128187784`, 
       1.5950073558962822`*^6}, {-202863.61205145548`, 
       1.5656126441037178`*^6}}]}, 
     {Arrowheads[{{0.022996238851688326`, 1.}}], 
      ArrowBox[{{-213280.92888833565`, 
       1.6141699632091527`*^6}, {-202932.40444499764`, 
       1.5854700367908475`*^6}}]}, 
     {Arrowheads[{{0.02248730326586978, 1.}}], 
      ArrowBox[{{-213215.34539641102`, 
       1.633344641213945*^6}, {-202997.98793692232`, 1.605315358786055*^6}}]}, 
     {Arrowheads[{{0.02199652969238576, 1.}}], 
      ArrowBox[{{-213152.78660121653`, 
       1.6525308418007516`*^6}, {-203060.54673211678`, 
       1.6251491581992481`*^6}}]}, 
     {Arrowheads[{{0.021523097132894655`, 1.}}], 
      ArrowBox[{{-213093.080792823, 
       1.6717280473520292`*^6}, {-203120.25254051035`, 
       1.6449719526479705`*^6}}]}, 
     {Arrowheads[{{0.021066230391937165`, 1.}}], 
      ArrowBox[{{-213036.0677823868, 
       1.6909357687477644`*^6}, {-203177.26555094653`, 
       1.6647842312522356`*^6}}]}, 
     {Arrowheads[{{0.020625197049951423`, 1.}}], 
      ArrowBox[{{-212981.59801372868`, 
       1.7101535435197952`*^6}, {-203231.7353196046, 
       1.6845864564802048`*^6}}]}, 
     {Arrowheads[{{0.02019930466581752, 1.}}], 
      ArrowBox[{{-212929.53175205353`, 
       1.7293809341428117`*^6}, {-203283.8015812798, 
       1.7043790658571883`*^6}}]}, 
     {Arrowheads[{{0.019787898189363096`, 1.}}], 
      ArrowBox[{{-212879.7383423857, 
       1.7486175264507006`*^6}, {-203333.5949909476, 
       1.7241624735492994`*^6}}]}, 
     {Arrowheads[{{0.01939035756611289, 1.}}], 
      ArrowBox[{{-212832.095531078, 
       1.7678629281679401`*^6}, {-203381.23780225532`, 
       1.7439370718320599`*^6}}]}, 
     {Arrowheads[{{0.019006095518219076`, 1.}}], 
      ArrowBox[{{-212786.4888444438, 
       1.7871167675466805`*^6}, {-203426.8444888895, 
       1.7637032324533197`*^6}}]}, 
     {Arrowheads[{{0.01863455548699424, 1.}}], 
      ArrowBox[{{-212742.81101917854`, 
       1.8063786921009836`*^6}, {-203470.52231415478`, 
       1.7834613078990162`*^6}}]}, 
     {Arrowheads[{{0.018275209723808035`, 1.}}], 
      ArrowBox[{{-212700.96147978096`, 
       1.8256483674304588`*^6}, {-203512.37185355235`, 
       1.8032116325695415`*^6}}]}, 
     {Arrowheads[{{0.017927557517311236`, 1.}}], 
      ArrowBox[{{-212660.84585867127`, 
       1.8449254761262087`*^6}, {-203552.48747466205`, 
       1.822954523873791*^6}}]}, 
     {Arrowheads[{{0.017591123546028146`, 1.}}], 
      ArrowBox[{{-212622.3755551339, 
       1.8642097167526293`*^6}, {-203590.9577781994, 
       1.8426902832473707`*^6}}]}, 
     {Arrowheads[{{0.01726545634634403, 1.}}], 
      ArrowBox[{{-212585.46732959856`, 
       1.8835008028991544`*^6}, {-203627.8660037348, 
       1.8624191971008456`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.02465947712834757, 1.}}], 
      ArrowBox[{{-187235.50685969187`, 
       1.5568183516063043`*^6}, {-176951.15980697476`, 
       1.5257616483936957`*^6}}]}, 
     {Arrowheads[{{0.024086882669326615`, 1.}}], 
      ArrowBox[{{-187168.47338877778`, 
       1.5759503404112072`*^6}, {-177018.19327788884`, 
       1.5456496595887928`*^6}}]}, 
     {Arrowheads[{{0.023535485433173135`, 1.}}], 
      ArrowBox[{{-187104.65587106213`, 
       1.595095874780458*^6}, {-177082.0107956045, 1.565524125219542*^6}}]}, 
     {Arrowheads[{{0.023004286950064692`, 1.}}], 
      ArrowBox[{{-187043.86434756426`, 
       1.6142543194879685`*^6}, {-177142.80231910237`, 
       1.5853856805120315`*^6}}]}, 
     {Arrowheads[{{0.02249234682574487, 1.}}], 
      ArrowBox[{{-186985.92212424165`, 
       1.6334250758598598`*^6}, {-177200.74454242497`, 
       1.6052349241401402`*^6}}]}, 
     {Arrowheads[{{0.021998778740736257`, 1.}}], 
      ArrowBox[{{-186930.6647071208, 
       1.6526075792968546`*^6}, {-177256.00195954586`, 
       1.6250724207031452`*^6}}]}, 
     {Arrowheads[{{0.021522746765976805`, 1.}}], 
      ArrowBox[{{-186877.93883371225`, 
       1.6718012969889897`*^6}, {-177308.72783295435`, 
       1.6448987030110105`*^6}}]}, 
     {Arrowheads[{{0.021063461966719477`, 1.}}], 
      ArrowBox[{{-186827.60159105633`, 
       1.6910057258059*^6}, {-177359.0650756103, 1.6647142741941*^6}}]}, 
     {Arrowheads[{{0.020620179269317834`, 1.}}], 
      ArrowBox[{{-186779.51961180463`, 
       1.7102203903475455`*^6}, {-177407.14705486197`, 
       1.6845196096524547`*^6}}]}, 
     {Arrowheads[{{0.02019219456799441, 1.}}], 
      ArrowBox[{{-186733.56834067864`, 
       1.7294448411416789`*^6}, {-177453.09832598802`, 
       1.7043151588583211`*^6}}]}, 
     {Arrowheads[{{0.019778842050901354`, 1.}}], 
      ArrowBox[{{-186689.63136446846`, 
       1.7486786529756612`*^6}, {-177497.03530219817`, 
       1.7241013470243388`*^6}}]}, 
     {Arrowheads[{{0.019379491726759943`, 1.}}], 
      ArrowBox[{{-186647.59979946443`, 
       1.7679214233513724`*^6}, {-177539.0668672022, 
       1.7438785766486279`*^6}}]}, 
     {Arrowheads[{{0.018993547135135756`, 1.}}], 
      ArrowBox[{{-186607.37173085648`, 
       1.7871727710530157`*^6}, {-177579.29493581015`, 
       1.7636472289469845`*^6}}]}, 
     {Arrowheads[{{0.018620443224995793`, 1.}}], 
      ArrowBox[{{-186568.8516992071, 
       1.8064323348185485`*^6}, {-177617.81496745956`, 
       1.7834076651814515`*^6}}]}, 
     {Arrowheads[{{0.018259644387617128`, 1.}}], 
      ArrowBox[{{-186531.9502296088, 
       1.825699772106309*^6}, {-177654.71643705782`, 
       1.8031602278936913`*^6}}]}, 
     {Arrowheads[{{0.01791064263119558, 1.}}], 
      ArrowBox[{{-186496.5833995864, 
       1.8449747579491697`*^6}, {-177690.08326708022`, 
       1.8229052420508305`*^6}}]}, 
     {Arrowheads[{{0.017572955885655255`, 1.}}], 
      ArrowBox[{{-186462.67244220225`, 
       1.8642569838892363`*^6}, {-177723.99422446438`, 
       1.842643016110764*^6}}]}, 
     {Arrowheads[{{0.017246126427195172`, 1.}}], 
      ArrowBox[{{-186430.14338117893`, 
       1.8835461569867176`*^6}, {-177756.5232854877, 
       1.8623738430132824`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024664969917210722`, 1.}}], 
      ArrowBox[{{-160968.74556118384`, 
       1.5569038090512548`*^6}, {-151191.2544388161, 1.525676190948745*^6}}]}, 
     {Arrowheads[{{0.024089244167507136`, 1.}}], 
      ArrowBox[{{-160910.7668227743, 
       1.5760316648197072`*^6}, {-151249.23317722563`, 
       1.5455683351802928`*^6}}]}, 
     {Arrowheads[{{0.023534944120645995`, 1.}}], 
      ArrowBox[{{-160855.58180541176`, 
       1.5951733123291577`*^6}, {-151304.4181945882, 
       1.5654466876708425`*^6}}]}, 
     {Arrowheads[{{0.02300105438345683, 1.}}], 
      ArrowBox[{{-160803.0246348171, 
       1.6143280990136384`*^6}, {-151356.97536518282`, 
       1.5853119009863616`*^6}}]}, 
     {Arrowheads[{{0.02248661904416985, 1.}}], 
      ArrowBox[{{-160752.94108912934`, 
       1.6334954102638797`*^6}, {-151407.05891087058`, 
       1.6051645897361203`*^6}}]}, 
     {Arrowheads[{{0.021990737541237138`, 1.}}], 
      ArrowBox[{{-160705.18765714002`, 
       1.6526746668215326`*^6}, {-151454.8123428599, 
       1.6250053331784674`*^6}}]}, 
     {Arrowheads[{{0.021512560861921496`, 1.}}], 
      ArrowBox[{{-160659.63068232682`, 
       1.6718653223786843`*^6}, {-151500.36931767312`, 
       1.6448346776213157`*^6}}]}, 
     {Arrowheads[{{0.021051288041006852`, 1.}}], 
      ArrowBox[{{-160616.14558401125`, 
       1.6910668613644822`*^6}, {-151543.8544159887, 
       1.6646531386355178`*^6}}]}, 
     {Arrowheads[{{0.020606162932934727`, 1.}}], 
      ArrowBox[{{-160574.61614792704`, 
       1.7102787969024675`*^6}, {-151585.38385207288`, 
       1.6844612030975323`*^6}}]}, 
     {Arrowheads[{{0.02017647123330988, 1.}}], 
      ArrowBox[{{-160534.93387933166`, 
       1.7295006689238087`*^6}, {-151625.06612066829`, 
       1.7042593310761913`*^6}}]}, 
     {Arrowheads[{{0.019761537728066672`, 1.}}], 
      ArrowBox[{{-160496.99741253824`, 
       1.7487320424230478`*^6}, {-151663.0025874617, 1.724047957576952*^6}}]}, 
     {Arrowheads[{{0.01936072375068237, 1.}}], 
      ArrowBox[{{-160460.71197140342`, 
       1.767972505844248*^6}, {-151699.28802859655`, 
       1.7438274941557522`*^6}}]}, 
     {Arrowheads[{{0.018973424829703413`, 1.}}], 
      ArrowBox[{{-160425.9888758862, 
       1.7872216695865644`*^6}, {-151734.01112411375`, 
       1.7635983304134354`*^6}}]}, 
     {Arrowheads[{{0.018599068510526406`, 1.}}], 
      ArrowBox[{{-160392.74509030767`, 
       1.8064791646192968`*^6}, {-151767.25490969227`, 
       1.7833608353807032`*^6}}]}, 
     {Arrowheads[{{0.018237112336882338`, 1.}}], 
      ArrowBox[{{-160360.90280939557`, 
       1.8257446411973818`*^6}, {-151799.09719060434`, 
       1.8031153588026182`*^6}}]}, 
     {Arrowheads[{{0.01788704197882128, 1.}}], 
      ArrowBox[{{-160330.38907860193`, 
       1.8450177676691303`*^6}, {-151829.610921398, 
       1.8228622323308694`*^6}}]}, 
     {Arrowheads[{{0.01754836949520626, 1.}}], 
      ArrowBox[{{-160301.13544553964`, 
       1.8642982293687405`*^6}, {-151858.8645544603, 
       1.8426017706312595`*^6}}]}, 
     {Arrowheads[{{0.017220631719820377`, 1.}}], 
      ArrowBox[{{-160273.07763970323`, 
       1.8835857275867956`*^6}, {-151886.9223602967, 
       1.8623342724132042`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024657246087792, 1.}}], 
      ArrowBox[{{-134698.04196692194`, 
       1.5569767332695022`*^6}, {-125435.29136641136`, 
       1.5256032667304978`*^6}}]}, 
     {Arrowheads[{{0.02407901374811011, 1.}}], 
      ArrowBox[{{-134649.35431788574`, 
       1.5761010477249858`*^6}, {-125483.97901544753`, 
       1.5454989522750142`*^6}}]}, 
     {Arrowheads[{{0.02352239929561126, 1.}}], 
      ArrowBox[{{-134603.02140045262`, 
       1.5952393658747356`*^6}, {-125530.31193288066`, 
       1.5653806341252644`*^6}}]}, 
     {Arrowheads[{{0.022986372905567806`, 1.}}], 
      ArrowBox[{{-134558.90279122032`, 
       1.6143910201401256`*^6}, {-125574.43054211295`, 
       1.5852489798598744`*^6}}]}, 
     {Arrowheads[{{0.022469965444454034`, 1.}}], 
      ArrowBox[{{-134516.86798119723`, 
       1.6335553821229006`*^6}, {-125616.46535213606`, 
       1.6051046178770992`*^6}}]}, 
     {Arrowheads[{{0.021972264225678623`, 1.}}], 
      ArrowBox[{{-134476.79556992598`, 
       1.652731859886942*^6}, {-125656.53776340731`, 1.624948140113058*^6}}]}, 
     {Arrowheads[{{0.021492409106749807`, 1.}}], 
      ArrowBox[{{-134438.5725334936, 
       1.6719198954567974`*^6}, {-125694.76079983967`, 
       1.6447801045432023`*^6}}]}, 
     {Arrowheads[{{0.021029588896906516`, 1.}}], 
      ArrowBox[{{-134402.09355890524`, 
       1.6911189625135113`*^6}, {-125731.23977442803`, 
       1.664601037486489*^6}}]}, 
     {Arrowheads[{{0.020583038047368878`, 1.}}], 
      ArrowBox[{{-134367.2604381386, 
       1.7103285642702216`*^6}, {-125766.0728951947, 
       1.6844114357297784`*^6}}]}, 
     {Arrowheads[{{0.020152033599135796`, 1.}}], 
      ArrowBox[{{-134333.98151593484`, 
       1.7295482315117323`*^6}, {-125799.35181739845`, 
       1.7042117684882677`*^6}}]}, 
     {Arrowheads[{{0.01973589236572428, 1.}}], 
      ArrowBox[{{-134302.1711860312, 
       1.7487775207837883`*^6}, {-125831.1621473021, 
       1.7240024792162115`*^6}}]}, 
     {Arrowheads[{{0.01933396833045676, 1.}}], 
      ArrowBox[{{-134271.74943111322`, 
       1.7680160127191797`*^6}, {-125861.58390222008`, 
       1.7437839872808203`*^6}}]}, 
     {Arrowheads[{{0.018945650239859994`, 1.}}], 
      ArrowBox[{{-134242.64140226968`, 
       1.787263310489012*^6}, {-125890.6919310636, 1.763556689510988*^6}}]}, 
     {Arrowheads[{{0.018570359376507594`, 1.}}], 
      ArrowBox[{{-134214.77703418004`, 
       1.8065190383685948`*^6}, {-125918.55629915326`, 
       1.7833209616314054`*^6}}]}, 
     {Arrowheads[{{0.018207547496208586`, 1.}}], 
      ArrowBox[{{-134188.0906926589, 
       1.8257828404083815`*^6}, {-125945.24264067439`, 
       1.8030771595916187`*^6}}]}, 
     {Arrowheads[{{0.017856694915858767`, 1.}}], 
      ArrowBox[{{-134162.52085153275`, 
       1.8450543792012814`*^6}, {-125970.81248180052`, 
       1.8228256207987189`*^6}}]}, 
     {Arrowheads[{{0.01751730873953605, 1.}}], 
      ArrowBox[{{-134138.00979613414`, 
       1.8643333347384604`*^6}, {-125995.32353719915`, 
       1.8425666652615399`*^6}}]}, 
     {Arrowheads[{{0.01718892121156237, 1.}}], 
      ArrowBox[{{-134114.50335097485`, 
       1.883619403346466*^6}, {-126018.82998235844`, 
       1.862300596653534*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024636129310645422`, 1.}}], 
      ArrowBox[{{-108424.01025128347`, 
       1.557036821798983*^6}, {-99682.65641538314, 1.5255431782010167`*^6}}]}, 
     {Arrowheads[{{0.02405603026923788, 1.}}], 
      ArrowBox[{{-108384.81422715883`, 
       1.5761582082953285`*^6}, {-99721.85243950778, 
       1.5454417917046717`*^6}}]}, 
     {Arrowheads[{{0.023497703665383392`, 1.}}], 
      ArrowBox[{{-108347.51964526725`, 
       1.5952937744365416`*^6}, {-99759.14702139937, 
       1.5653262255634584`*^6}}]}, 
     {Arrowheads[{{0.022960107863062074`, 1.}}], 
      ArrowBox[{{-108312.01270656013`, 
       1.6144428401235065`*^6}, {-99794.65396010649, 
       1.5851971598764933`*^6}}]}, 
     {Arrowheads[{{0.022442262917728734`, 1.}}], 
      ArrowBox[{{-108278.18767981516`, 
       1.6336047654633673`*^6}, {-99828.47898685148, 
       1.6050552345366327`*^6}}]}, 
     {Arrowheads[{{0.021943246237809758`, 1.}}], 
      ArrowBox[{{-108245.94624280126`, 
       1.6527789479564633`*^6}, {-99860.72042386535, 1.624901052043537*^6}}]}, 
     {Arrowheads[{{0.021462188597414163`, 1.}}], 
      ArrowBox[{{-108215.1968841614, 
       1.671964819909765*^6}, {-99891.46978250521, 1.644735180090235*^6}}]}, 
     {Arrowheads[{{0.020998270468184373`, 1.}}], 
      ArrowBox[{{-108185.85435979576`, 
       1.6911618460562485`*^6}, {-99920.81230687087, 
       1.6645581539437515`*^6}}]}, 
     {Arrowheads[{{0.020550718641465824`, 1.}}], 
      ArrowBox[{{-108157.8391982269, 
       1.7103695213617175`*^6}, {-99948.82746843972, 
       1.6843704786382825`*^6}}]}, 
     {Arrowheads[{{0.020118803114866236`, 1.}}], 
      ArrowBox[{{-108131.07725004149`, 
       1.729587369002425*^6}, {-99975.58941662514, 1.704172630997575*^6}}]}, 
     {Arrowheads[{{0.01970183421985041, 1.}}], 
      ArrowBox[{{-108105.49927704284`, 
       1.7488149384984924`*^6}, {-100001.16738962378`, 
       1.7239650615015079`*^6}}]}, 
     {Arrowheads[{{0.019299159969309622`, 1.}}], 
      ArrowBox[{{-108081.04057722312`, 
       1.7680518039895792`*^6}, {-100025.62608944353`, 
       1.7437481960104208`*^6}}]}, 
     {Arrowheads[{{0.01891016360608781, 1.}}], 
      ArrowBox[{{-108057.6406420828, 
       1.7872975626405762`*^6}, {-100049.02602458383`, 
       1.7635224373594236`*^6}}]}, 
     {Arrowheads[{{0.018534261335281063`, 1.}}], 
      ArrowBox[{{-108035.24284319492`, 
       1.8065518331662503`*^6}, {-100071.4238234717, 
       1.7832881668337497`*^6}}]}, 
     {Arrowheads[{{0.018170900224755183`, 1.}}], 
      ArrowBox[{{-108013.7941452381, 
       1.8258142544648265`*^6}, {-100092.87252142852`, 
       1.8030457455351732`*^6}}]}, 
     {Arrowheads[{{0.017819556259792157`, 1.}}], 
      ArrowBox[{{-107993.24484301216`, 
       1.845084484351426*^6}, {-100113.42182365445`, 1.822795515648574*^6}}]}, 
     {Arrowheads[{{0.017479732539093455`, 1.}}], 
      ArrowBox[{{-107973.54832020664`, 
       1.8643621983831166`*^6}, {-100133.11834645999`, 
       1.8425378016168836`*^6}}]}, 
     {Arrowheads[{{0.017150957600539026`, 1.}}], 
      ArrowBox[{{-107954.66082792022`, 
       1.8836470887680992`*^6}, {-100152.00583874641`, 
       1.862272911231901*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024601486456850338`, 1.}}], 
      ArrowBox[{{-82147.28758344507, 
       1.557083823042169*^6}, {-73932.71241655489, 1.5254961769578313`*^6}}]}, 
     {Arrowheads[{{0.024020172780087386`, 1.}}], 
      ArrowBox[{{-82117.7459918849, 
       1.576202913021626*^6}, {-73962.25400811505, 1.545397086978374*^6}}]}, 
     {Arrowheads[{{0.023460747360008218`, 1.}}], 
      ArrowBox[{{-82089.64088880445, 
       1.595336321097017*^6}, {-73990.35911119553, 1.565283678902983*^6}}]}, 
     {Arrowheads[{{0.022922159476334875`, 1.}}], 
      ArrowBox[{{-82062.8860618084, 
       1.6144833572805983`*^6}, {-74017.11393819157, 
       1.5851566427194017`*^6}}]}, 
     {Arrowheads[{{0.022403420879681436`, 1.}}], 
      ArrowBox[{{-82037.40143017794, 
       1.6336433726045175`*^6}, {-74042.59856982203, 
       1.6050166273954827`*^6}}]}, 
     {Arrowheads[{{0.02190360137896945, 1.}}], 
      ArrowBox[{{-82013.11254233643, 
       1.6528157562321892`*^6}, {-74066.88745766353, 
       1.6248642437678108`*^6}}]}, 
     {Arrowheads[{{0.021421824787802222`, 1.}}], 
      ArrowBox[{{-81989.95011981396, 1.67199993280397*^6}, {-74090.049880186, 
       1.64470006719603*^6}}]}, 
     {Arrowheads[{{0.020957265196836317`, 1.}}], 
      ArrowBox[{{-81967.84964292843, 
       1.6911953599956837`*^6}, {-74112.15035707153, 
       1.6645246400043163`*^6}}]}, 
     {Arrowheads[{{0.02050914354255584, 1.}}], 
      ArrowBox[{{-81946.75097394087, 
       1.7104015262707355`*^6}, {-74133.24902605909, 
       1.6843384737292645`*^6}}]}, 
     {Arrowheads[{{0.02007672444583912, 1.}}], 
      ArrowBox[{{-81926.59801391662, 
       1.729617948808486*^6}, {-74153.40198608337, 1.704142051191514*^6}}]}, 
     {Arrowheads[{{0.019659313296369073`, 1.}}], 
      ArrowBox[{{-81907.33838993986, 
       1.7488441715932814`*^6}, {-74172.66161006011, 
       1.7239358284067186`*^6}}]}, 
     {Arrowheads[{{0.01925625356129636, 1.}}], 
      ArrowBox[{{-81888.92316969566, 
       1.7680797636500709`*^6}, {-74191.07683030432, 1.743720236349929*^6}}]}, 
     {Arrowheads[{{0.018866924298678072`, 1.}}], 
      ArrowBox[{{-81871.30660075588, 
       1.787324317413914*^6}, {-74208.6933992441, 1.763495682586086*^6}}]}, 
     {Arrowheads[{{0.018490737858098297`, 1.}}], 
      ArrowBox[{{-81854.44587219061, 
       1.8065774472219013`*^6}, {-74225.55412780934, 1.783262552778099*^6}}]}, 
     {Arrowheads[{{0.018127137752551883`, 1.}}], 
      ArrowBox[{{-81838.30089637804, 
       1.8258387879171057`*^6}, {-74241.69910362193, 
       1.8030212120828943`*^6}}]}, 
     {Arrowheads[{{0.017775596687186156`, 1.}}], 
      ArrowBox[{{-81822.83410910847, 
       1.8451079935551642`*^6}, {-74257.1658908915, 
       1.8227720064448358`*^6}}]}, 
     {Arrowheads[{{0.017435614731842138`, 1.}}], 
      ArrowBox[{{-81808.01028627568, 
       1.8643847362049615`*^6}, {-74271.98971372431, 
       1.8425152637950387`*^6}}]}, 
     {Arrowheads[{{0.017106717625542733`, 1.}}], 
      ArrowBox[{{-81793.79637562364, 
       1.8836687048356808`*^6}, {-74286.20362437633, 
       1.8622512951643195`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.02455322901065049, 1.}}], 
      ArrowBox[{{-55868.52991723015, 
       1.5571175387016363`*^6}, {-48184.80341610317, 
       1.5254624612983637`*^6}}]}, 
     {Arrowheads[{{0.023971361790134354`, 1.}}], 
      ArrowBox[{{-55848.76627158031, 
       1.5762349779233008`*^6}, {-48204.567061753005`, 
       1.5453650220766992`*^6}}]}, 
     {Arrowheads[{{0.0234114590736209, 1.}}], 
      ArrowBox[{{-55829.96527914139, 
       1.5953668350020098`*^6}, {-48223.36805419193, 1.56525316499799*^6}}]}, 
     {Arrowheads[{{0.022872463866841428`, 1.}}], 
      ArrowBox[{{-55812.06904990735, 
       1.61451241280494*^6}, {-48241.26428342596, 1.58512758719506*^6}}]}, 
     {Arrowheads[{{0.022353382196040328`, 1.}}], 
      ArrowBox[{{-55795.02382060735, 
       1.6336710558088913`*^6}, {-48258.309512725966`, 
       1.6049889441911087`*^6}}]}, 
     {Arrowheads[{{0.021853278642509702`, 1.}}], 
      ArrowBox[{{-55778.779615619715`, 
       1.6528421471567072`*^6}, {-48274.5537177136, 1.624837852843293*^6}}]}, 
     {Arrowheads[{{0.021371272241652223`, 1.}}], 
      ArrowBox[{{-55763.289939350594`, 
       1.672025105953685*^6}, {-48290.04339398272, 1.644674894046315*^6}}]}, 
     {Arrowheads[{{0.02090653271297077, 1.}}], 
      ArrowBox[{{-55748.51149683103, 
       1.691219384781884*^6}, {-48304.821836502284`, 
       1.6645006152181157`*^6}}]}, 
     {Arrowheads[{{0.020458276990831553`, 1.}}], 
      ArrowBox[{{-55734.40393965416, 
       1.710424467412499*^6}, {-48318.92939367915, 1.6843155325875008`*^6}}]}, 
     {Arrowheads[{{0.020025766028898846`, 1.}}], 
      ArrowBox[{{-55720.92963469673, 
       1.729639866698473*^6}, {-48332.403698636575`, 1.704120133301527*^6}}]}, 
     {Arrowheads[{{0.01960830185385795, 1.}}], 
      ArrowBox[{{-55708.05345335217, 
       1.7488651226313082`*^6}, {-48345.27987998114, 
       1.7239148773686918`*^6}}]}, 
     {Arrowheads[{{0.019205224846461973`, 1.}}], 
      ArrowBox[{{-55695.7425792517, 
       1.768099800547623*^6}, {-48357.59075408161, 1.7437001994523772`*^6}}]}, 
     {Arrowheads[{{0.018815911230085827`, 1.}}], 
      ArrowBox[{{-55683.96633266918, 
       1.7873434894724125`*^6}, {-48369.36700066413, 
       1.7634765105275873`*^6}}]}, 
     {Arrowheads[{{0.018439770748900075`, 1.}}], 
      ArrowBox[{{-55672.69600999901, 
       1.8065958005872413`*^6}, {-48380.6373233343, 
       1.7832441994127587`*^6}}]}, 
     {Arrowheads[{{0.01807624451948904, 1.}}], 
      ArrowBox[{{-55661.90473686719, 
       1.8258563658127172`*^6}, {-48391.42859646612, 
       1.8030036341872828`*^6}}]}, 
     {Arrowheads[{{0.01772480304127401, 1.}}], 
      ArrowBox[{{-55651.56733358696, 
       1.8451248364956127`*^6}, {-48401.76599974636, 
       1.8227551635043873`*^6}}]}, 
     {Arrowheads[{{0.01738494435247959, 1.}}], 
      ArrowBox[{{-55641.66019180422, 
       1.8644008821918967`*^6}, {-48411.673141529085`, 
       1.842499117808103*^6}}]}, 
     {Arrowheads[{{0.017056192319613583`, 1.}}], 
      ArrowBox[{{-55632.161161296885`, 
       1.8836841895377578`*^6}, {-48421.17217203643, 
       1.862235810462242*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024491314122974624`, 1.}}], 
      ArrowBox[{{-29588.407525956507`, 
       1.5571378257203088`*^6}, {-22438.259140710143`, 
       1.5254421742796914`*^6}}]}, 
     {Arrowheads[{{0.02390956021234227, 1.}}], 
      ArrowBox[{{-29578.504845879645`, 
       1.5761018484295616`*^6}, {-22448.161820787005`, 
       1.5451933078204384`*^6}}]}, 
     {Arrowheads[{{0.023349806909584707`, 1.}}], 
      ArrowBox[{{-29569.084998456623`, 
       1.59538519295242*^6}, {-22457.581668210027`, 
       1.5652348070475797`*^6}}]}, 
     {Arrowheads[{{0.02281099381494265, 1.}}], 
      ArrowBox[{{-29560.118913339644`, 
       1.6145298922109657`*^6}, {-22466.547753327006`, 
       1.5851101077890343`*^6}}]}, 
     {Arrowheads[{{0.022292123862639467`, 1.}}], 
      ArrowBox[{{-29551.579595329113`, 
       1.633687708594212*^6}, {-22475.08707133754, 1.604972291405788*^6}}]}, 
     {Arrowheads[{{0.02179225882448099, 1.}}], 
      ArrowBox[{{-29543.441953599675`, 
       1.6528580216061517`*^6}, {-22483.224713066975`, 
       1.6248219783938483`*^6}}]}, 
     {Arrowheads[{{0.021310515181286196`, 1.}}], 
      ArrowBox[{{-29535.682646799825`, 
       1.6720402470072582`*^6}, {-22490.984019866828`, 
       1.6446597529927418`*^6}}]}, 
     {Arrowheads[{{0.02084606032816675, 1.}}], 
      ArrowBox[{{-29528.279942384346`, 
       1.6912338343019572`*^6}, {-22498.3867242823, 
       1.6644861656980426`*^6}}]}, 
     {Arrowheads[{{0.020398109083162568`, 1.}}], 
      ArrowBox[{{-29521.213588725244`, 
       1.710438264426886*^6}, {-22505.45307794141, 1.6843017355731137`*^6}}]}, 
     {Arrowheads[{{0.01996592047184243, 1.}}], 
      ArrowBox[{{-29514.4646987099, 
       1.7296530476218148`*^6}, {-22512.20196795675, 
       1.7041069523781852`*^6}}]}, 
     {Arrowheads[{{0.019548794763227493`, 1.}}], 
      ArrowBox[{{-29508.015643678777`, 
       1.748877721466917*^6}, {-22518.651022987873`, 1.723902278533083*^6}}]}, 
     {Arrowheads[{{0.019146070734844662`, 1.}}], 
      ArrowBox[{{-29501.849956680748`, 
       1.7681118490717064`*^6}, {-22524.8167099859, 
       1.7436881509282934`*^6}}]}, 
     {Arrowheads[{{0.01875712314690001, 1.}}], 
      ArrowBox[{{-29495.95224413532, 
       1.7873550174023886`*^6}, {-22530.71442253133, 
       1.7634649825976111`*^6}}]}, 
     {Arrowheads[{{0.018381360407503985`, 1.}}], 
      ArrowBox[{{-29490.30810508873, 
       1.806606835735673*^6}, {-22536.358561577916`, 1.783233164264327*^6}}]}, 
     {Arrowheads[{{0.01801822241262044, 1.}}], 
      ArrowBox[{{-29484.904057337444`, 
       1.8258669342282347`*^6}, {-22541.762609329202`, 
       1.8029930657717655`*^6}}]}, 
     {Arrowheads[{{0.017667178545964966`, 1.}}], 
      ArrowBox[{{-29479.727469768808`, 
       1.845134962592046*^6}, {-22546.939196897845`, 
       1.8227450374079542`*^6}}]}, 
     {Arrowheads[{{0.01732772582546773, 1.}}], 
      ArrowBox[{{-29474.766500336515`, 
       1.8644105888667193`*^6}, {-22551.90016633013, 1.842489411133281*^6}}]}, 
     {Arrowheads[{{0.016999387184164796`, 1.}}], 
      ArrowBox[{{-29470.010039148387`, 
       1.8836934982808235`*^6}, {-22556.656627518263`, 
       1.8622265017191768`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023834773964440926`, 1.}}], 
      ArrowBox[{{-3307.6003408036167`, 1.5764131319060067`*^6}, {
       3307.6003408036313`, 1.5454917118439935`*^6}}]}, 
     {Arrowheads[{{0.023275798915378433`, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.5953913205606528`*^6}, {
       3307.6003408036318`, 1.5652286794393472`*^6}}]}, 
     {Arrowheads[{{0.022737759235927427`, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.6145357263828737`*^6}, {
       3307.6003408036318`, 1.5851042736171263`*^6}}]}, 
     {Arrowheads[{{0.022219657429192616`, 1.}}], 
      ArrowBox[{{-3307.6003408036177`, 1.633693266685795*^6}, {
       3307.600340803632, 1.6049667333142047`*^6}}]}, 
     {Arrowheads[{{0.02172055490098588, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.6528633197560152`*^6}, {
       3307.6003408036318`, 1.624816680243985*^6}}]}, 
     {Arrowheads[{{0.021239567823687775`, 1.}}], 
      ArrowBox[{{-3307.6003408036163`, 1.6720453002350787`*^6}, {
       3307.600340803631, 1.6446546997649216`*^6}}]}, 
     {Arrowheads[{{0.020775863334817492`, 1.}}], 
      ArrowBox[{{-3307.6003408036167`, 1.6912386565979505`*^6}, {
       3307.6003408036313`, 1.6644813434020493`*^6}}]}, 
     {Arrowheads[{{0.020328656039719138`, 1.}}], 
      ArrowBox[{{-3307.6003408036163`, 1.7104428688331936`*^6}, {
       3307.600340803631, 1.6842971311668062`*^6}}]}, 
     {Arrowheads[{{0.019897204790880387`, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.729657446306617*^6}, {
       3307.6003408036318`, 1.7041025536933828`*^6}}]}, 
     {Arrowheads[{{0.019480809719164643`, 1.}}], 
      ArrowBox[{{-3307.6003408036167`, 1.7488819257920014`*^6}, {
       3307.6003408036313`, 1.7238980742079988`*^6}}]}, 
     {Arrowheads[{{0.019078809494695856`, 1.}}], 
      ArrowBox[{{-3307.6003408036167`, 1.7681158696541288`*^6}, {
       3307.6003408036313`, 1.7436841303458714`*^6}}]}, 
     {Arrowheads[{{0.0186905787973228, 1.}}], 
      ArrowBox[{{-3307.6003408036177`, 1.7873588641708058`*^6}, {
       3307.600340803632, 1.7634611358291942`*^6}}]}, 
     {Arrowheads[{{0.018315525978545313`, 1.}}], 
      ArrowBox[{{-3307.6003408036167`, 1.8066105179818575`*^6}, {
       3307.6003408036313`, 1.7832294820181425`*^6}}]}, 
     {Arrowheads[{{0.017953090898527563`, 1.}}], 
      ArrowBox[{{-3307.6003408036167`, 1.8258704606542308`*^6}, {
       3307.6003408036313`, 1.8029895393457692`*^6}}]}, 
     {Arrowheads[{{0.01760274292338027, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.8451383413533773`*^6}, {
       3307.6003408036318`, 1.8227416586466224`*^6}}]}, 
     {Arrowheads[{{0.017263979069294326`, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.864413827612016*^6}, {
       3307.6003408036318`, 1.8424861723879843`*^6}}]}, 
     {Arrowheads[{{0.01693632228135873, 1.}}], 
      ArrowBox[{{-3307.600340803617, 1.8836966041881992`*^6}, {
       3307.6003408036318`, 1.862223395811801*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024326572627979118`, 1.}}], 
      ArrowBox[{{22973.20684434927, 1.5571378257203088`*^6}, {
       29053.459822317407`, 1.5254421742796914`*^6}}]}, 
     {Arrowheads[{{0.023747052217397566`, 1.}}], 
      ArrowBox[{{22963.30416427241, 1.5761018484295616`*^6}, {
       29063.36250239427, 1.5451933078204384`*^6}}]}, 
     {Arrowheads[{{0.02318948329771725, 1.}}], 
      ArrowBox[{{22953.884316849388`, 1.59538519295242*^6}, {
       29072.782349817287`, 1.5652348070475797`*^6}}]}, 
     {Arrowheads[{{0.022652807365864173`, 1.}}], 
      ArrowBox[{{22944.91823173241, 1.6145298922109657`*^6}, {
       29081.74843493427, 1.5851101077890343`*^6}}]}, 
     {Arrowheads[{{0.022136029159448865`, 1.}}], 
      ArrowBox[{{22936.378913721877`, 1.633687708594212*^6}, {
       29090.2877529448, 1.604972291405788*^6}}]}, 
     {Arrowheads[{{0.02163821216577038, 1.}}], 
      ArrowBox[{{22928.241271992443`, 1.6528580216061517`*^6}, {
       29098.42539467424, 1.6248219783938483`*^6}}]}, 
     {Arrowheads[{{0.02115847449826974, 1.}}], 
      ArrowBox[{{22920.48196519259, 1.6720402470072582`*^6}, {
       29106.18470147409, 1.6446597529927418`*^6}}]}, 
     {Arrowheads[{{0.02069598510648188, 1.}}], 
      ArrowBox[{{22913.079260777115`, 1.6912338343019572`*^6}, {
       29113.58740588956, 1.6644861656980426`*^6}}]}, 
     {Arrowheads[{{0.02024996028902191, 1.}}], 
      ArrowBox[{{22906.01290711801, 1.710438264426886*^6}, {
       29120.653759548666`, 1.6843017355731137`*^6}}]}, 
     {Arrowheads[{{0.019819660482240497`, 1.}}], 
      ArrowBox[{{22899.264017102665`, 1.7296530476218148`*^6}, {
       29127.40264956401, 1.7041069523781852`*^6}}]}, 
     {Arrowheads[{{0.019404387299929764`, 1.}}], 
      ArrowBox[{{22892.814962071545`, 1.748877721466917*^6}, {
       29133.851704595138`, 1.723902278533083*^6}}]}, 
     {Arrowheads[{{0.01900348080190821, 1.}}], 
      ArrowBox[{{22886.649275073516`, 1.7681118490717064`*^6}, {
       29140.017391593166`, 1.7436881509282934`*^6}}]}, 
     {Arrowheads[{{0.018616316971494375`, 1.}}], 
      ArrowBox[{{22880.751562528083`, 1.7873550174023886`*^6}, {
       29145.915104138592`, 1.7634649825976111`*^6}}]}, 
     {Arrowheads[{{0.018242305383818946`, 1.}}], 
      ArrowBox[{{22875.1074234815, 1.806606835735673*^6}, {29151.55924318518, 
       1.783233164264327*^6}}]}, 
     {Arrowheads[{{0.01788088704866369, 1.}}], 
      ArrowBox[{{22869.703375730212`, 1.8258669342282347`*^6}, {
       29156.96329093647, 1.8029930657717655`*^6}}]}, 
     {Arrowheads[{{0.017531532413067628`, 1.}}], 
      ArrowBox[{{22864.526788161573`, 1.845134962592046*^6}, {
       29162.139878505106`, 1.8227450374079542`*^6}}]}, 
     {Arrowheads[{{0.01719373951032948, 1.}}], 
      ArrowBox[{{22859.565818729283`, 1.8644105888667193`*^6}, {
       29167.1008479374, 1.842489411133281*^6}}]}, 
     {Arrowheads[{{0.016867032243282835`, 1.}}], 
      ArrowBox[{{22854.80935754115, 1.8836934982808235`*^6}, {
       29171.857309125528`, 1.8622265017191768`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024223892786985824`, 1.}}], 
      ArrowBox[{{49253.329235622914`, 1.5571175387016363`*^6}, {
       54800.00409771042, 1.525462461298364*^6}}]}, 
     {Arrowheads[{{0.02364648728558055, 1.}}], 
      ArrowBox[{{49233.56558997308, 1.5762349779233008`*^6}, {
       54819.767743360266`, 1.5453650220766992`*^6}}]}, 
     {Arrowheads[{{0.02309094831313686, 1.}}], 
      ArrowBox[{{49214.76459753415, 1.5953668350020098`*^6}, {
       54838.568735799185`, 1.56525316499799*^6}}]}, 
     {Arrowheads[{{0.022556222653151978`, 1.}}], 
      ArrowBox[{{49196.86836830012, 1.61451241280494*^6}, {54856.46496503323, 
       1.58512758719506*^6}}]}, 
     {Arrowheads[{{0.022041319924151474`, 1.}}], 
      ArrowBox[{{49179.82313900012, 1.6336710558088913`*^6}, {
       54873.51019433323, 1.6049889441911087`*^6}}]}, 
     {Arrowheads[{{0.021545308124941022`, 1.}}], 
      ArrowBox[{{49163.57893401248, 1.6528421471567072`*^6}, {
       54889.75439932086, 1.624837852843293*^6}}]}, 
     {Arrowheads[{{0.02106730954363174, 1.}}], 
      ArrowBox[{{49148.08925774336, 1.672025105953685*^6}, {54905.24407558998,
        1.644674894046315*^6}}]}, 
     {Arrowheads[{{0.02060649699689934, 1.}}], 
      ArrowBox[{{49133.3108152238, 1.691219384781884*^6}, {54920.02251810955, 
       1.6645006152181157`*^6}}]}, 
     {Arrowheads[{{0.020162090369380117`, 1.}}], 
      ArrowBox[{{49119.20325804693, 1.710424467412499*^6}, {54934.13007528642,
        1.6843155325875008`*^6}}]}, 
     {Arrowheads[{{0.019733353426152823`, 1.}}], 
      ArrowBox[{{49105.7289530895, 1.729639866698473*^6}, {54947.60438024384, 
       1.704120133301527*^6}}]}, 
     {Arrowheads[{{0.019319590873969606`, 1.}}], 
      ArrowBox[{{49092.85277174494, 1.7488651226313082`*^6}, {
       54960.4805615884, 1.7239148773686918`*^6}}]}, 
     {Arrowheads[{{0.01892014564931401, 1.}}], 
      ArrowBox[{{49080.54189764447, 1.768099800547623*^6}, {54972.79143568887,
        1.7437001994523772`*^6}}]}, 
     {Arrowheads[{{0.018534396413508205`, 1.}}], 
      ArrowBox[{{49068.76565106195, 1.7873434894724125`*^6}, {
       54984.56768227139, 1.7634765105275873`*^6}}]}, 
     {Arrowheads[{{0.01816175523701729, 1.}}], 
      ArrowBox[{{49057.49532839178, 1.8065958005872413`*^6}, {
       54995.83800494156, 1.7832441994127587`*^6}}]}, 
     {Arrowheads[{{0.017801665456807628`, 1.}}], 
      ArrowBox[{{49046.70405525996, 1.8258563658127172`*^6}, {
       55006.629278073386`, 1.8030036341872828`*^6}}]}, 
     {Arrowheads[{{0.017453599692149522`, 1.}}], 
      ArrowBox[{{49036.36665197972, 1.8451248364956127`*^6}, {
       55016.96668135362, 1.8227551635043873`*^6}}]}, 
     {Arrowheads[{{0.017117058005629533`, 1.}}], 
      ArrowBox[{{49026.45951019699, 1.8644008821918967`*^6}, {
       55026.87382313635, 1.842499117808103*^6}}]}, 
     {Arrowheads[{{0.016791566197367547`, 1.}}], 
      ArrowBox[{{49016.96047968965, 1.8836841895377578`*^6}, {
       55036.37285364369, 1.862235810462242*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.024107848421818696`, 1.}}], 
      ArrowBox[{{75532.08690183784, 1.557083823042169*^6}, {80547.91309816216,
        1.5254961769578313`*^6}}]}, 
     {Arrowheads[{{0.023533214158641614`, 1.}}], 
      ArrowBox[{{75502.54531027768, 1.576202913021626*^6}, {80577.45468972233,
        1.545397086978374*^6}}]}, 
     {Arrowheads[{{0.022980321834160433`, 1.}}], 
      ArrowBox[{{75474.44020719721, 1.595336321097017*^6}, {80605.55979280279,
        1.565283678902983*^6}}]}, 
     {Arrowheads[{{0.02244812635595749, 1.}}], 
      ArrowBox[{{75447.68538020118, 1.6144833572805983`*^6}, {
       80632.31461979884, 1.5851566427194017`*^6}}]}, 
     {Arrowheads[{{0.02193564482703855, 1.}}], 
      ArrowBox[{{75422.20074857071, 1.6336433726045175`*^6}, {
       80657.7992514293, 1.6050166273954827`*^6}}]}, 
     {Arrowheads[{{0.021441952149097245`, 1.}}], 
      ArrowBox[{{75397.9118607292, 1.6528157562321892`*^6}, {
       80682.08813927081, 1.6248642437678108`*^6}}]}, 
     {Arrowheads[{{0.02096617698362753, 1.}}], 
      ArrowBox[{{75374.74943820674, 1.67199993280397*^6}, {80705.25056179328, 
       1.64470006719603*^6}}]}, 
     {Arrowheads[{{0.02050749803801285, 1.}}], 
      ArrowBox[{{75352.6489613212, 1.6911953599956837`*^6}, {
       80727.35103867881, 1.6645246400043163`*^6}}]}, 
     {Arrowheads[{{0.0200651406470799, 1.}}], 
      ArrowBox[{{75331.55029233365, 1.7104015262707355`*^6}, {
       80748.44970766637, 1.6843384737292645`*^6}}]}, 
     {Arrowheads[{{0.01963837362358147, 1.}}], 
      ArrowBox[{{75311.39733230938, 1.729617948808486*^6}, {80768.60266769062,
        1.704142051191514*^6}}]}, 
     {Arrowheads[{{0.019226506353728107`, 1.}}], 
      ArrowBox[{{75292.13770833262, 1.7488441715932814`*^6}, {
       80787.86229166738, 1.7239358284067183`*^6}}]}, 
     {Arrowheads[{{0.01882888611623879, 1.}}], 
      ArrowBox[{{75273.72248808842, 1.7680797636500709`*^6}, {
       80806.27751191158, 1.743720236349929*^6}}]}, 
     {Arrowheads[{{0.018444895605493616`, 1.}}], 
      ArrowBox[{{75256.10591914864, 1.787324317413914*^6}, {80823.89408085136,
        1.763495682586086*^6}}]}, 
     {Arrowheads[{{0.018073950641241253`, 1.}}], 
      ArrowBox[{{75239.24519058339, 1.8065774472219013`*^6}, {
       80840.75480941663, 1.783262552778099*^6}}]}, 
     {Arrowheads[{{0.017715498048995568`, 1.}}], 
      ArrowBox[{{75223.10021477082, 1.8258387879171057`*^6}, {
       80856.8997852292, 1.8030212120828943`*^6}}]}, 
     {Arrowheads[{{0.0173690136967565, 1.}}], 
      ArrowBox[{{75207.63342750123, 1.8451079935551642`*^6}, {
       80872.36657249877, 1.8227720064448358`*^6}}]}, 
     {Arrowheads[{{0.017034000675037707`, 1.}}], 
      ArrowBox[{{75192.80960466844, 1.8643847362049615`*^6}, {
       80887.19039533156, 1.8425152637950387`*^6}}]}, 
     {Arrowheads[{{0.016709987608384914`, 1.}}], 
      ArrowBox[{{75178.5956940164, 1.8836687048356808`*^6}, {80901.4043059836,
        1.8622512951643195`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023978627307935912`, 1.}}], 
      ArrowBox[{{101808.80956967625`, 1.557036821798983*^6}, {
       106297.85709699041`, 1.5255431782010167`*^6}}]}, 
     {Arrowheads[{{0.023407409680692638`, 1.}}], 
      ArrowBox[{{101769.6135455516, 1.5761582082953285`*^6}, {
       106337.05312111507`, 1.5454417917046717`*^6}}]}, 
     {Arrowheads[{{0.022857770596066845`, 1.}}], 
      ArrowBox[{{101732.31896366001`, 1.5952937744365416`*^6}, {
       106374.34770300663`, 1.5653262255634584`*^6}}]}, 
     {Arrowheads[{{0.022328675850068955`, 1.}}], 
      ArrowBox[{{101696.8120249529, 1.6144428401235065`*^6}, {
       106409.85464171377`, 1.5851971598764933`*^6}}]}, 
     {Arrowheads[{{0.021819152567983044`, 1.}}], 
      ArrowBox[{{101662.98699820793`, 1.6336047654633673`*^6}, {
       106443.67966845873`, 1.6050552345366327`*^6}}]}, 
     {Arrowheads[{{0.021328284886579136`, 1.}}], 
      ArrowBox[{{101630.74556119404`, 1.6527789479564633`*^6}, {
       106475.92110547262`, 1.624901052043537*^6}}]}, 
     {Arrowheads[{{0.02085520998609689, 1.}}], 
      ArrowBox[{{101599.99620255418`, 1.671964819909765*^6}, {
       106506.67046411248`, 1.644735180090235*^6}}]}, 
     {Arrowheads[{{0.020399114440042904`, 1.}}], 
      ArrowBox[{{101570.65367818854`, 1.6911618460562485`*^6}, {
       106536.01298847813`, 1.6645581539437515`*^6}}]}, 
     {Arrowheads[{{0.01995923085408696, 1.}}], 
      ArrowBox[{{101542.63851661967`, 1.7103695213617175`*^6}, {
       106564.028150047, 1.6843704786382825`*^6}}]}, 
     {Arrowheads[{{0.019534834768224825`, 1.}}], 
      ArrowBox[{{101515.87656843425`, 1.729587369002425*^6}, {
       106590.79009823239`, 1.704172630997575*^6}}]}, 
     {Arrowheads[{{0.019125241798941567`, 1.}}], 
      ArrowBox[{{101490.29859543561`, 1.7488149384984924`*^6}, {
       106616.36807123105`, 1.7239650615015079`*^6}}]}, 
     {Arrowheads[{{0.01872980500039523, 1.}}], 
      ArrowBox[{{101465.83989561588`, 1.7680518039895792`*^6}, {
       106640.82677105078`, 1.7437481960104208`*^6}}]}, 
     {Arrowheads[{{0.018347912425676367`, 1.}}], 
      ArrowBox[{{101442.43996047556`, 1.7872975626405762`*^6}, {
       106664.22670619108`, 1.7635224373594236`*^6}}]}, 
     {Arrowheads[{{0.01797898487102766, 1.}}], 
      ArrowBox[{{101420.0421615877, 1.8065518331662503`*^6}, {
       106686.62450507897`, 1.7832881668337497`*^6}}]}, 
     {Arrowheads[{{0.01762247378752974, 1.}}], 
      ArrowBox[{{101398.59346363087`, 1.8258142544648265`*^6}, {
       106708.07320303578`, 1.8030457455351732`*^6}}]}, 
     {Arrowheads[{{0.017277859346220757`, 1.}}], 
      ArrowBox[{{101378.04416140493`, 1.845084484351426*^6}, {
       106728.62250526174`, 1.822795515648574*^6}}]}, 
     {Arrowheads[{{0.016944648643929354`, 1.}}], 
      ArrowBox[{{101358.3476385994, 1.8643621983831166`*^6}, {
       106748.31902806724`, 1.8425378016168836`*^6}}]}, 
     {Arrowheads[{{0.01662237403826757, 1.}}], 
      ArrowBox[{{101339.460146313, 1.8836470887680992`*^6}, {
       106767.20652035368`, 1.862272911231901*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023836461065776998`, 1.}}], 
      ArrowBox[{{128082.8412853147, 1.5569767332695022`*^6}, {
       132050.49204801864`, 1.5256032667304978`*^6}}]}, 
     {Arrowheads[{{0.023269291387781686`, 1.}}], 
      ArrowBox[{{128034.15363627851`, 1.5761010477249858`*^6}, {
       132099.17969705482`, 1.5454989522750142`*^6}}]}, 
     {Arrowheads[{{0.022723499134081497`, 1.}}], 
      ArrowBox[{{127987.82071884538`, 1.5952393658747356`*^6}, {
       132145.51261448793`, 1.5653806341252644`*^6}}]}, 
     {Arrowheads[{{0.02219806365593683, 1.}}], 
      ArrowBox[{{127943.70210961309`, 1.6143910201401256`*^6}, {
       132189.6312237202, 1.5852489798598744`*^6}}]}, 
     {Arrowheads[{{0.021692024551116847`, 1.}}], 
      ArrowBox[{{127901.66729959, 1.6335553821229006`*^6}, {132231.6660337433,
        1.6051046178770992`*^6}}]}, 
     {Arrowheads[{{0.021204477444869207`, 1.}}], 
      ArrowBox[{{127861.59488831874`, 1.652731859886942*^6}, {
       132271.73844501458`, 1.624948140113058*^6}}]}, 
     {Arrowheads[{{0.0207345701105795, 1.}}], 
      ArrowBox[{{127823.37185188638`, 1.6719198954567974`*^6}, {
       132309.96148144692`, 1.6447801045432023`*^6}}]}, 
     {Arrowheads[{{0.02028149889929329, 1.}}], 
      ArrowBox[{{127786.89287729801`, 1.6911189625135113`*^6}, {
       132346.44045603529`, 1.664601037486489*^6}}]}, 
     {Arrowheads[{{0.019844505450381335`, 1.}}], 
      ArrowBox[{{127752.05975653137`, 1.7103285642702216`*^6}, {
       132381.27357680193`, 1.6844114357297784`*^6}}]}, 
     {Arrowheads[{{0.019422873658391893`, 1.}}], 
      ArrowBox[{{127718.7808343276, 1.7295482315117323`*^6}, {
       132414.55249900572`, 1.7042117684882677`*^6}}]}, 
     {Arrowheads[{{0.019015926873590622`, 1.}}], 
      ArrowBox[{{127686.97050442395`, 1.7487775207837883`*^6}, {
       132446.36282890936`, 1.7240024792162115`*^6}}]}, 
     {Arrowheads[{{0.018623025315891256`, 1.}}], 
      ArrowBox[{{127656.54874950598`, 1.7680160127191797`*^6}, {
       132476.78458382734`, 1.7437839872808203`*^6}}]}, 
     {Arrowheads[{{0.01824356368382913, 1.}}], 
      ArrowBox[{{127627.44072066245`, 1.787263310489012*^6}, {
       132505.89261267087`, 1.763556689510988*^6}}]}, 
     {Arrowheads[{{0.017876968941990718`, 1.}}], 
      ArrowBox[{{127599.5763525728, 1.8065190383685948`*^6}, {
       132533.75698076052`, 1.7833209616314054`*^6}}]}, 
     {Arrowheads[{{0.01752269827187594, 1.}}], 
      ArrowBox[{{127572.89001105167`, 1.8257828404083815`*^6}, {
       132560.44332228164`, 1.8030771595916187`*^6}}]}, 
     {Arrowheads[{{0.017180237172578224`, 1.}}], 
      ArrowBox[{{127547.32016992553`, 1.8450543792012814`*^6}, {
       132586.0131634078, 1.8228256207987189`*^6}}]}, 
     {Arrowheads[{{0.016849097698925872`, 1.}}], 
      ArrowBox[{{127522.80911452691`, 1.8643333347384604`*^6}, {
       132610.5242188064, 1.8425666652615399`*^6}}]}, 
     {Arrowheads[{{0.016528816825865187`, 1.}}], 
      ArrowBox[{{127499.30266936761`, 1.883619403346466*^6}, {
       132634.0306639657, 1.862300596653534*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.02368162352803632, 1.}}], 
      ArrowBox[{{154353.54487957663`, 1.5569038090512548`*^6}, {
       157806.4551204234, 1.525676190948745*^6}}]}, 
     {Arrowheads[{{0.02311911601985838, 1.}}], 
      ArrowBox[{{154295.5661411671, 1.5760316648197072`*^6}, {
       157864.43385883293`, 1.5455683351802928`*^6}}]}, 
     {Arrowheads[{{0.022577748425384233`, 1.}}], 
      ArrowBox[{{154240.38112380455`, 1.5951733123291577`*^6}, {
       157919.61887619548`, 1.5654466876708425`*^6}}]}, 
     {Arrowheads[{{0.022056516197734126`, 1.}}], 
      ArrowBox[{{154187.82395320988`, 1.6143280990136384`*^6}, {
       157972.17604679012`, 1.5853119009863616`*^6}}]}, 
     {Arrowheads[{{0.021554473749394135`, 1.}}], 
      ArrowBox[{{154137.74040752213`, 1.6334954102638797`*^6}, {
       158022.25959247787`, 1.6051645897361203`*^6}}]}, 
     {Arrowheads[{{0.02107073035038154, 1.}}], 
      ArrowBox[{{154089.9869755328, 1.6526746668215326`*^6}, {
       158070.0130244672, 1.6250053331784674`*^6}}]}, 
     {Arrowheads[{{0.020604446354172197`, 1.}}], 
      ArrowBox[{{154044.4300007196, 1.6718653223786843`*^6}, {
       158115.56999928041`, 1.6448346776213157`*^6}}]}, 
     {Arrowheads[{{0.02015482972190267, 1.}}], 
      ArrowBox[{{154000.94490240404`, 1.6910668613644822`*^6}, {
       158159.055097596, 1.6646531386355178`*^6}}]}, 
     {Arrowheads[{{0.019721132818296547`, 1.}}], 
      ArrowBox[{{153959.41546631983`, 1.7102787969024675`*^6}, {
       158200.58453368017`, 1.6844612030975323`*^6}}]}, 
     {Arrowheads[{{0.019302649455390498`, 1.}}], 
      ArrowBox[{{153919.73319772445`, 1.7295006689238087`*^6}, {
       158240.26680227555`, 1.7042593310761913`*^6}}]}, 
     {Arrowheads[{{0.018898712162472586`, 1.}}], 
      ArrowBox[{{153881.79673093103`, 1.7487320424230478`*^6}, {
       158278.203269069, 1.724047957576952*^6}}]}, 
     {Arrowheads[{{0.018508689662729772`, 1.}}], 
      ArrowBox[{{153845.51128979618`, 1.767972505844248*^6}, {
       158314.48871020382`, 1.7438274941557522`*^6}}]}, 
     {Arrowheads[{{0.01813198453897198, 1.}}], 
      ArrowBox[{{153810.78819427898`, 1.7872216695865644`*^6}, {
       158349.21180572105`, 1.7635983304134354`*^6}}]}, 
     {Arrowheads[{{0.017768031072467525`, 1.}}], 
      ArrowBox[{{153777.54440870046`, 1.8064791646192968`*^6}, {
       158382.45559129957`, 1.7833608353807032`*^6}}]}, 
     {Arrowheads[{{0.01741629324042376, 1.}}], 
      ArrowBox[{{153745.70212778836`, 1.8257446411973818`*^6}, {
       158414.29787221164`, 1.803115358802618*^6}}]}, 
     {Arrowheads[{{0.017076262858987296`, 1.}}], 
      ArrowBox[{{153715.18839699472`, 1.8450177676691303`*^6}, {
       158444.8116030053, 1.8228622323308694`*^6}}]}, 
     {Arrowheads[{{0.016747457859848, 1.}}], 
      ArrowBox[{{153685.93476393243`, 1.8642982293687405`*^6}, {
       158474.0652360676, 1.8426017706312595`*^6}}]}, 
     {Arrowheads[{{0.01642942068961112, 1.}}], 
      ArrowBox[{{153657.87695809602`, 1.8835857275867956`*^6}, {
       158502.12304190398`, 1.8623342724132042`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023514428771207477`, 1.}}], 
      ArrowBox[{{180620.30617808466`, 1.5568183516063043`*^6}, {
       183566.36048858202`, 1.5257616483936957`*^6}}]}, 
     {Arrowheads[{{0.022957177728215792`, 1.}}], 
      ArrowBox[{{180553.27270717054`, 1.5759503404112072`*^6}, {
       183633.3939594961, 1.5456496595887928`*^6}}]}, 
     {Arrowheads[{{0.02242079425459454, 1.}}], 
      ArrowBox[{{180489.4551894549, 1.595095874780458*^6}, {
       183697.21147721176`, 1.565524125219542*^6}}]}, 
     {Arrowheads[{{0.021904292311036758`, 1.}}], 
      ArrowBox[{{180428.66366595705`, 1.6142543194879687`*^6}, {
       183758.00300070966`, 1.5853856805120315`*^6}}]}, 
     {Arrowheads[{{0.021406743340391384`, 1.}}], 
      ArrowBox[{{180370.72144263444`, 1.6334250758598598`*^6}, {
       183815.94522403224`, 1.6052349241401402`*^6}}]}, 
     {Arrowheads[{{0.020927272299852855`, 1.}}], 
      ArrowBox[{{180315.46402551356`, 1.6526075792968546`*^6}, {
       183871.2026411531, 1.6250724207031452`*^6}}]}, 
     {Arrowheads[{{0.020465054007345187`, 1.}}], 
      ArrowBox[{{180262.73815210504`, 1.6718012969889897`*^6}, {
       183923.92851456164`, 1.6448987030110105`*^6}}]}, 
     {Arrowheads[{{0.020019309774120125`, 1.}}], 
      ArrowBox[{{180212.40090944912`, 1.6910057258059*^6}, {183974.2657572176,
        1.6647142741941*^6}}]}, 
     {Arrowheads[{{0.019589304298347293`, 1.}}], 
      ArrowBox[{{180164.31893019742`, 1.7102203903475455`*^6}, {
       184022.34773646927`, 1.6845196096524547`*^6}}]}, 
     {Arrowheads[{{0.019174342796939813`, 1.}}], 
      ArrowBox[{{180118.3676590714, 1.7294448411416789`*^6}, {
       184068.29900759525`, 1.7043151588583211`*^6}}]}, 
     {Arrowheads[{{0.018773768355057636`, 1.}}], 
      ArrowBox[{{180074.43068286125`, 1.7486786529756612`*^6}, {
       184112.23598380544`, 1.7241013470243388`*^6}}]}, 
     {Arrowheads[{{0.018386959474697123`, 1.}}], 
      ArrowBox[{{180032.39911785722`, 1.7679214233513724`*^6}, {
       184154.26754880947`, 1.7438785766486279`*^6}}]}, 
     {Arrowheads[{{0.018013327805535623`, 1.}}], 
      ArrowBox[{{179992.17104924927`, 1.7871727710530157`*^6}, {
       184194.49561741741`, 1.7636472289469843`*^6}}]}, 
     {Arrowheads[{{0.017652316042778726`, 1.}}], 
      ArrowBox[{{179953.65101759986`, 1.8064323348185485`*^6}, {
       184233.01564906683`, 1.7834076651814515`*^6}}]}, 
     {Arrowheads[{{0.017303395978177753`, 1.}}], 
      ArrowBox[{{179916.74954800156`, 1.825699772106309*^6}, {
       184269.9171186651, 1.8031602278936913`*^6}}]}, 
     {Arrowheads[{{0.01696606669164641, 1.}}], 
      ArrowBox[{{179881.3827179792, 1.8449747579491697`*^6}, {
       184305.28394868752`, 1.8229052420508305`*^6}}]}, 
     {Arrowheads[{{0.01663985287206337, 1.}}], 
      ArrowBox[{{179847.47176059504`, 1.8642569838892363`*^6}, {
       184339.19490607167`, 1.842643016110764*^6}}]}, 
     {Arrowheads[{{0.01632430325686673, 1.}}], 
      ArrowBox[{{179814.94269957172`, 1.8835461569867176`*^6}, {
       184371.723967095, 1.8623738430132824`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.02333522883992675, 1.}}], 
      ArrowBox[{{206882.5379035669, 1.5567207113723692`*^6}, {
       209330.79542976647`, 1.525859288627631*^6}}]}, 
     {Arrowheads[{{0.02278380600371549, 1.}}], 
      ArrowBox[{{206806.7196639108, 1.575857400035358*^6}, {209406.6136694226,
        1.545742599964642*^6}}]}, 
     {Arrowheads[{{0.022252945325210247`, 1.}}], 
      ArrowBox[{{206734.5206002706, 1.5950073558962822`*^6}, {
       209478.81273306278`, 1.5656126441037178`*^6}}]}, 
     {Arrowheads[{{0.02174168151913444, 1.}}], 
      ArrowBox[{{206665.72820672844`, 1.6141699632091527`*^6}, {
       209547.60512660493`, 1.5854700367908475`*^6}}]}, 
     {Arrowheads[{{0.021249105131177268`, 1.}}], 
      ArrowBox[{{206600.14471480378`, 1.633344641213945*^6}, {
       209613.18861852956`, 1.605315358786055*^6}}]}, 
     {Arrowheads[{{0.020774358719250204`, 1.}}], 
      ArrowBox[{{206537.58591960932`, 1.6525308418007516`*^6}, {
       209675.74741372408`, 1.6251491581992481`*^6}}]}, 
     {Arrowheads[{{0.020316633333940775`, 1.}}], 
      ArrowBox[{{206477.88011121575`, 1.6717280473520292`*^6}, {
       209735.4532221176, 1.6449719526479705`*^6}}]}, 
     {Arrowheads[{{0.01987516527183721, 1.}}], 
      ArrowBox[{{206420.86710077958`, 1.6909357687477644`*^6}, {
       209792.4662325538, 1.6647842312522356`*^6}}]}, 
     {Arrowheads[{{0.019449233077963375`, 1.}}], 
      ArrowBox[{{206366.39733212147`, 1.7101535435197952`*^6}, {
       209846.9360012119, 1.6845864564802048`*^6}}]}, 
     {Arrowheads[{{0.01903815477585184, 1.}}], 
      ArrowBox[{{206314.3310704463, 1.7293809341428117`*^6}, {
       209899.00226288705`, 1.7043790658571883`*^6}}]}, 
     {Arrowheads[{{0.018641285305828443`, 1.}}], 
      ArrowBox[{{206264.53766077847`, 1.7486175264507006`*^6}, {
       209948.79567255487`, 1.7241624735492994`*^6}}]}, 
     {Arrowheads[{{0.01825801415392154, 1.}}], 
      ArrowBox[{{206216.8948494708, 1.7678629281679401`*^6}, {
       209996.4384838626, 1.7439370718320599`*^6}}]}, 
     {Arrowheads[{{0.017887763155452173`, 1.}}], 
      ArrowBox[{{206171.2881628366, 1.7871167675466805`*^6}, {
       210042.0451704968, 1.7637032324533197`*^6}}]}, 
     {Arrowheads[{{0.017529984458837158`, 1.}}], 
      ArrowBox[{{206127.6103375713, 1.8063786921009836`*^6}, {
       210085.72299576204`, 1.7834613078990162`*^6}}]}, 
     {Arrowheads[{{0.017184158636466988`, 1.}}], 
      ArrowBox[{{206085.76079817372`, 1.8256483674304588`*^6}, {
       210127.57253515962`, 1.8032116325695415`*^6}}]}, 
     {Arrowheads[{{0.0168497929307158, 1.}}], 
      ArrowBox[{{206045.64517706406`, 1.8449254761262087`*^6}, {
       210167.68815626932`, 1.822954523873791*^6}}]}, 
     {Arrowheads[{{0.01652641962420957, 1.}}], 
      ArrowBox[{{206007.1748735267, 1.8642097167526293`*^6}, {
       210206.15845980667`, 1.8426902832473707`*^6}}]}, 
     {Arrowheads[{{0.016213594524459037`, 1.}}], 
      ArrowBox[{{205970.26664799132`, 1.8835008028991544`*^6}, {
       210243.06668534206`, 1.8624191971008456`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.02314441119682625, 1.}}], 
      ArrowBox[{{233139.68322419986`, 1.5566112834696062`*^6}, {
       235100.31677580017`, 1.5259687165303938`*^6}}]}, 
     {Arrowheads[{{0.02259936335482848, 1.}}], 
      ArrowBox[{{233055.3813008812, 1.5757532109445652`*^6}, {
       235184.61869911887`, 1.5458467890554345`*^6}}]}, 
     {Arrowheads[{{0.022074541142814867`, 1.}}], 
      ArrowBox[{{232975.0807433177, 1.5949080973178188`*^6}, {
       235264.91925668236`, 1.5657119026821814`*^6}}]}, 
     {Arrowheads[{{0.021569002100943667`, 1.}}], 
      ArrowBox[{{232898.54818478227`, 1.61407534825817*^6}, {
       235341.45181521782`, 1.5855646517418302`*^6}}]}, 
     {Arrowheads[{{0.021081857792731275`, 1.}}], 
      ArrowBox[{{232825.5663165151, 1.633254402713121*^6}, {
       235414.43368348497`, 1.605405597286879*^6}}]}, 
     {Arrowheads[{{0.02061227014847878, 1.}}], 
      ArrowBox[{{232755.93262006462`, 1.6524447307260775`*^6}, {
       235484.06737993544`, 1.6252352692739225`*^6}}]}, 
     {Arrowheads[{{0.020159448091701053`, 1.}}], 
      ArrowBox[{{232689.45821210888`, 1.6716458314164632`*^6}, {
       235550.54178789118`, 1.6450541685835368`*^6}}]}, 
     {Arrowheads[{{0.019722644424008128`, 1.}}], 
      ArrowBox[{{232625.96679071375`, 1.6908572311092077`*^6}, {
       235614.03320928628`, 1.6648627688907923`*^6}}]}, 
     {Arrowheads[{{0.01930115294623873, 1.}}], 
      ArrowBox[{{232565.2936731694, 1.7100784816013041`*^6}, {
       235674.70632683067`, 1.6846615183986959`*^6}}]}, 
     {Arrowheads[{{0.018894305795754938`, 1.}}], 
      ArrowBox[{{232507.2849165934, 1.7293091585542446`*^6}, {
       235732.71508340666`, 1.7044508414457552`*^6}}]}, 
     {Arrowheads[{{0.018501470981687033`, 1.}}], 
      ArrowBox[{{232451.79651341695`, 1.7485488600021356`*^6}, {
       235788.2034865831, 1.7242311399978641`*^6}}]}, 
     {Arrowheads[{{0.018122050101623616`, 1.}}], 
      ArrowBox[{{232398.6936546909, 1.7677972049662087`*^6}, {
       235841.30634530913`, 1.744002795033791*^6}}]}, 
     {Arrowheads[{{0.017755476224753035`, 1.}}], 
      ArrowBox[{{232347.850054878, 1.7870538321672522`*^6}, {
       235892.14994512207`, 1.763766167832748*^6}}]}, 
     {Arrowheads[{{0.0174012119278408, 1.}}], 
      ArrowBox[{{232299.14733244455`, 1.8063183988282357`*^6}, {
       235940.8526675555, 1.783521601171764*^6}}]}, 
     {Arrowheads[{{0.017058747471653403`, 1.}}], 
      ArrowBox[{{232252.4744411406, 1.8255905795600675`*^6}, {
       235987.52555885946`, 1.8032694204399325`*^6}}]}, 
     {Arrowheads[{{0.016727599106556395`, 1.}}], 
      ArrowBox[{{232207.72714737014`, 1.8448700653240276`*^6}, {
       236032.27285262995`, 1.8230099346759727`*^6}}]}, 
     {Arrowheads[{{0.016407307497009565`, 1.}}], 
      ArrowBox[{{232164.80754950948`, 1.8641565624649785`*^6}, {
       236075.19245049055`, 1.8427434375350212`*^6}}]}, 
     {Arrowheads[{{0.016097436255592568`, 1.}}], 
      ArrowBox[{{232123.62363544025`, 1.8834497918099507`*^6}, {
       236116.3763645598, 1.8624702081900493`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023501382801336006`, 1.}}], 
      ArrowBox[{{259488.30688346952`, 1.5373560572619976`*^6}, {
       260778.3597831972, 1.5062039427380022`*^6}}]}, 
     {Arrowheads[{{0.02294239593404086, 1.}}], 
      ArrowBox[{{259391.21890943954`, 1.5564905040576905`*^6}, {
       260875.4477572272, 1.5260894959423095`*^6}}]}, 
     {Arrowheads[{{0.022404242767598784`, 1.}}], 
      ArrowBox[{{259298.7627924296, 1.575638178799399*^6}, {
       260967.90387423718`, 1.545961821200601*^6}}]}, 
     {Arrowheads[{{0.021885949698607052`, 1.}}], 
      ArrowBox[{{259210.66742083835`, 1.5947984766519747`*^6}, {
       261055.9992458284, 1.5658215233480253`*^6}}]}, 
     {Arrowheads[{{0.02138659897596582, 1.}}], 
      ArrowBox[{{259126.68037682932`, 1.6139708264134424`*^6}, {
       261139.98628983743`, 1.5856691735865579`*^6}}]}, 
     {Arrowheads[{{0.020905324926610215`, 1.}}], 
      ArrowBox[{{259046.5664598669, 1.6331546883341738`*^6}, {
       261220.10020679983`, 1.6055053116658262`*^6}}]}, 
     {Arrowheads[{{0.020441310472165516`, 1.}}], 
      ArrowBox[{{258970.1063411109, 1.6523495520960612`*^6}, {
       261296.56032555585`, 1.6253304479039388`*^6}}]}, 
     {Arrowheads[{{0.019993783911460127`, 1.}}], 
      ArrowBox[{{258897.0953358578, 1.6715549349387162`*^6}, {
       261369.57133080895`, 1.6451450650612838`*^6}}]}, 
     {Arrowheads[{{0.019562015946203354`, 1.}}], 
      ArrowBox[{{258827.3422825862, 1.6907703799208642`*^6}, {
       261439.32438408054`, 1.6649496200791358`*^6}}]}, 
     {Arrowheads[{{0.019145316929268203`, 1.}}], 
      ArrowBox[{{258760.66851837354`, 1.7099954543061308`*^6}, {
       261505.9981482932, 1.6847445456938692`*^6}}]}, 
     {Arrowheads[{{0.018743034316937475`, 1.}}], 
      ArrowBox[{{258696.9069415235, 1.7292297480633587`*^6}, {
       261569.75972514323`, 1.704530251936641*^6}}]}, 
     {Arrowheads[{{0.01835455030818879, 1.}}], 
      ArrowBox[{{258635.90115319524`, 1.748472872472442*^6}, {
       261630.7655134715, 1.7243071275275578`*^6}}]}, 
     {Arrowheads[{{0.017979279655645178`, 1.}}], 
      ArrowBox[{{258577.504670668, 1.7677244588274332`*^6}, {
       261689.16199599876`, 1.7440755411725668`*^6}}]}, 
     {Arrowheads[{{0.017616667634209594`, 1.}}], 
      ArrowBox[{{258521.58020562658`, 1.7869841572293858`*^6}, {
       261745.08646104016`, 1.7638358427706142`*^6}}]}, 
     {Arrowheads[{{0.01726618815466144, 1.}}], 
      ArrowBox[{{258467.99900151952`, 1.8062516354620294`*^6}, {
       261798.66766514722`, 1.7835883645379706`*^6}}]}, 
     {Arrowheads[{{0.01692734201062186, 1.}}], 
      ArrowBox[{{258416.64022463732`, 1.8255265779439502`*^6}, {
       261850.02644202943`, 1.8033334220560496`*^6}}]}, 
     {Arrowheads[{{0.016599655248324872`, 1.}}], 
      ArrowBox[{{258367.3904040882, 1.8448086847514869`*^6}, {
       261899.27626257855`, 1.823071315248513*^6}}]}, 
     {Arrowheads[{{0.0162826776495498, 1.}}], 
      ArrowBox[{{258320.14291632205`, 1.8640976707070202`*^6}, {
       261946.5237503447, 1.8428023292929798`*^6}}]}, 
     {Arrowheads[{{0.015975981318909996`, 1.}}], 
      ArrowBox[{{258274.79751027707`, 1.883393264527781*^6}, {
       261991.86915638967`, 1.8625267354722193`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023280813337208935`, 1.}}], 
      ArrowBox[{{285741.898494372, 1.5372177892597977`*^6}, {
       286551.4348389614, 1.5063422107402026`*^6}}]}, 
     {Arrowheads[{{0.022729632785118168`, 1.}}], 
      ArrowBox[{{285636.65806296136`, 1.5563588464020975`*^6}, {
       286656.675270372, 1.5262211535979023`*^6}}]}, 
     {Arrowheads[{{0.022198864981989724`, 1.}}], 
      ArrowBox[{{285536.4027426903, 1.575512744091785*^6}, {286756.9305906431,
        1.5460872559082152`*^6}}]}, 
     {Arrowheads[{{0.02168756498394631, 1.}}], 
      ArrowBox[{{285440.8432208859, 1.5946789042156942`*^6}, {
       286852.4901124475, 1.5659410957843056`*^6}}]}, 
     {Arrowheads[{{0.021194841433660256`, 1.}}], 
      ArrowBox[{{285349.7099360821, 1.6138567801844063`*^6}, {
       286943.6233972513, 1.585783219815594*^6}}]}, 
     {Arrowheads[{{0.020719852988299068`, 1.}}], 
      ArrowBox[{{285262.751535809, 1.6330458549381034`*^6}, {
       287030.58179752436`, 1.6056141450618969`*^6}}]}, 
     {Arrowheads[{{0.020261805018369373`, 1.}}], 
      ArrowBox[{{285179.7334692934, 1.6522456390941918`*^6}, {
       287113.59986404004`, 1.6254343609058082`*^6}}]}, 
     {Arrowheads[{{0.01981994655456388, 1.}}], 
      ArrowBox[{{285100.4367020556, 1.6714556692256615`*^6}, {
       287192.8966312777, 1.6452443307743385`*^6}}]}, 
     {Arrowheads[{{0.019393567461832836`, 1.}}], 
      ArrowBox[{{285024.65654075786`, 1.690675506260065*^6}, {
       287268.6767925755, 1.665044493739935*^6}}]}, 
     {Arrowheads[{{0.018981995821811665`, 1.}}], 
      ArrowBox[{{284952.2015578665, 1.7099047339898385`*^6}, {
       287341.1317754669, 1.6848352660101617`*^6}}]}, 
     {Arrowheads[{{0.018584595506462232`, 1.}}], 
      ArrowBox[{{284882.892606772, 1.7291429576854538`*^6}, {
       287410.44072656136`, 1.7046170423145464`*^6}}]}, 
     {Arrowheads[{{0.018200763927329895`, 1.}}], 
      ArrowBox[{{284816.5619189629, 1.7483898028035834`*^6}, {
       287476.7714143704, 1.7243901971964166`*^6}}]}, 
     {Arrowheads[{{0.017829929946219986`, 1.}}], 
      ArrowBox[{{284753.05227570276`, 1.7676449137831072`*^6}, {
       287540.2810576306, 1.7441550862168928`*^6}}]}, 
     {Arrowheads[{{0.017471551934361586`, 1.}}], 
      ArrowBox[{{284692.2162474169, 1.7869079529223682`*^6}, {
       287601.11708591646`, 1.7639120470776316`*^6}}]}, 
     {Arrowheads[{{0.01712511596826021, 1.}}], 
      ArrowBox[{{284633.9154946724, 1.8061785993316218`*^6}, {
       287659.41783866106`, 1.783661400668378*^6}}]}, 
     {Arrowheads[{{0.01679013415148437, 1.}}], 
      ArrowBox[{{284578.02012523526`, 1.82545654795511*^6}, {
       287715.3132080982, 1.80340345204489*^6}}]}, 
     {Arrowheads[{{0.016466143052551365`, 1.}}], 
      ArrowBox[{{284524.40810223215`, 1.8447415086576382`*^6}, {
       287768.9252311012, 1.8231384913423618`*^6}}]}, 
     {Arrowheads[{{0.016152702249933548`, 1.}}], 
      ArrowBox[{{284472.9646989211, 1.8640332053709438`*^6}, {
       287820.36863441236`, 1.8428667946290562`*^6}}]}, 
     {Arrowheads[{{0.01584939297596677, 1.}}], 
      ArrowBox[{{284423.581996011, 1.8833313752955138`*^6}, {
       287869.75133732235`, 1.862588624704486*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[{{0.023049486138808126`, 1.}}], 
      ArrowBox[{{311988.540114469, 1.537068684719454*^6}, {
       312331.45988553105`, 1.506491315280546*^6}}]}, 
     {Arrowheads[{{0.02250659797782829, 1.}}], 
      ArrowBox[{{311875.55241085414`, 1.5562168167113103`*^6}, {
       312444.4475891458, 1.5263631832886897`*^6}}]}, 
     {Arrowheads[{{0.021983675620685, 1.}}], 
      ArrowBox[{{311767.87533013214`, 1.5753773783546786`*^6}, {
       312552.1246698679, 1.5462226216453211`*^6}}]}, 
     {Arrowheads[{{0.02147980436808774, 1.}}], 
      ArrowBox[{{311665.2035271157, 1.5945498195813415`*^6}, {
       312654.7964728843, 1.5660701804186585`*^6}}]}, 
     {Arrowheads[{{0.02099412073596376, 1.}}], 
      ArrowBox[{{311567.2522757429, 1.613733619659801*^6}, {
       312752.74772425706`, 1.5859063803401992`*^6}}]}, 
     {Arrowheads[{{0.020525809092941674`, 1.}}], 
      ArrowBox[{{311473.7558793409, 1.6329282853919999`*^6}, {
       312846.2441206591, 1.6057317146080001`*^6}}]}, 
     {Arrowheads[{{0.020074098548223576`, 1.}}], 
      ArrowBox[{{311384.46621795144`, 1.652133349433464*^6}, {
       312935.53378204856`, 1.625546650566536*^6}}]}, 
     {Arrowheads[{{0.019638260069139563`, 1.}}], 
      ArrowBox[{{311299.15141971456`, 1.671348368727753*^6}, {
       313020.84858028544`, 1.6453516312722473`*^6}}]}, 
     {Arrowheads[{{0.019217603809544577`, 1.}}], 
      ArrowBox[{{311217.59464464826`, 1.6905729230468038`*^6}, {
       313102.40535535174`, 1.665147076953196*^6}}]}, 
     {Arrowheads[{{0.01881147663191256, 1.}}], 
      ArrowBox[{{311139.59297035146`, 1.7098066136294059`*^6}, {
       313180.40702964854`, 1.6849333863705944`*^6}}]}, 
     {Arrowheads[{{0.0184192598075034, 1.}}], 
      ArrowBox[{{311064.95637022, 1.7290490619106297`*^6}, {
       313255.04362978006`, 1.70471093808937*^6}}]}, 
     {Arrowheads[{{0.01804036688035818, 1.}}], 
      ArrowBox[{{310993.5067757097, 1.7482999083356054`*^6}, {
       313326.4932242903, 1.7244800916643948`*^6}}]}, 
     {Arrowheads[{{0.01767424168213132, 1.}}], 
      ArrowBox[{{310925.0772150239, 1.7675588112515297`*^6}, {
       313394.92278497614`, 1.74424118874847*^6}}]}, 
     {Arrowheads[{{0.01732035648588846, 1.}}], 
      ArrowBox[{{310859.5110213548, 1.786825445872276*^6}, {313460.4889786452,
        1.763994554127724*^6}}]}, 
     {Arrowheads[{{0.016978210288035266`, 1.}}], 
      ArrowBox[{{310796.66110448155`, 1.8060995033103898`*^6}, {
       313523.3388955184, 1.78374049668961*^6}}]}, 
     {Arrowheads[{{0.016647327208459208`, 1.}}], 
      ArrowBox[{{310736.38928012893`, 1.8253806896716703`*^6}, {
       313583.6107198711, 1.8034793103283297`*^6}}]}, 
     {Arrowheads[{{0.0163272549998173, 1.}}], 
      ArrowBox[{{310678.5656520289, 1.844668725207891*^6}, {313641.4343479711,
        1.8232112747921092`*^6}}]}, 
     {Arrowheads[{{0.016017563657661698`, 1.}}], 
      ArrowBox[{{310623.0680421115, 1.8639633435235587`*^6}, {
       313696.93195788853`, 1.8429366564764415`*^6}}]}, 
     {Arrowheads[{{0.015717844123794216`, 1.}}], 
      ArrowBox[{{310569.78146468237`, 1.883264290832916*^6}, {
       313750.21853531763`, 1.8626557091670842`*^6}}]}}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-312160., 312160.}, {1.40472*^6, 1.87296*^6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7766640529270725`*^9, 3.7766641207344494`*^9}, 
   3.776664351666164*^9, 3.779601563288063*^9, 3.780332725252966*^9, 
   3.7803670442723227`*^9, 3.7803759840866566`*^9, 3.7803893672896876`*^9, 
   3.780571552731105*^9, 3.780573829070377*^9, 3.7812690540830297`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"23232154-ad2b-429d-9d1f-085905c54942"]
}, Open  ]],

Cell["\<\
Vector field all around Europa. Note the tilt in the vectors and that the \
Jovian (right) side vectors are shorter than the Anti-Jovian.\
\>", "Text",
 CellChangeTimes->{{3.7812722974071274`*^9, 
  3.7812723460839353`*^9}},ExpressionUUID->"a0071a78-2c80-4093-94e2-\
8f873681d733"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"JupAtEur", "+", 
      RowBox[{
       RowBox[{"-", "G"}], "*", 
       RowBox[{"MEur", "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "x"}]}], ",", 
     RowBox[{
      RowBox[{"-", "G"}], "*", 
      RowBox[{"MEur", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"3", "/", "2"}], ")"}]}]}], "*", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "rEur"}], ",", 
     RowBox[{"2", "rEur"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "rEur"}], ",", 
     RowBox[{"2", "rEur"}]}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}], ",", 
      RowBox[{
       RowBox[{"1.04", "rEur"}], ">", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}], ">", 
       RowBox[{"0.96", "rEur"}]}]}], "]"}]}], ",", 
   RowBox[{"VectorPoints", "\[Rule]", " ", "51"}], ",", 
   RowBox[{"VectorScale", "\[Rule]", "5"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.2"}], "rEur"}], ",", 
        RowBox[{"1.2", "rEur"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.2"}], "rEur"}], ",", 
        RowBox[{"1.2", "rEur"}]}], "}"}]}], "}"}]}], ",", 
   RowBox[{"VectorStyle", "\[Rule]", 
    RowBox[{"Arrowheads", "[", "0.02", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.776664165731595*^9, 3.7766642517465916`*^9}, {
  3.7766643439179516`*^9, 3.7766643656619215`*^9}, {3.7766644164489517`*^9, 
  3.776664498486965*^9}, {3.776664658033914*^9, 3.7766646740420303`*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"7998b808-f190-41c4-ac76-c9775db01441"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6489468440193257`*^6, -673510.3270881006}, \
{-1.3477891559806743`*^6, -573178.6729118995}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.659246967250562*^6, -543022.0360808925}, \
{-1.337489032749438*^6, -455889.96391910745`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6683182681661835`*^6, -409534.3522895748}, \
{-1.3284177318338163`*^6, -339649.6477104252}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6754606666445124`*^6, -274213.3012727714}, \
{-1.3212753333554873`*^6, -225242.69872722862`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6800435006618202`*^6, -137488.5534711613}, \
{-1.3166924993381798`*^6, -112239.44652883869`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6816243063864356`*^6, -975.5}, {-1.3151116936135644`*^6, \
-975.5}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6800435006618202`*^6, 
       137488.5534711613}, {-1.3166924993381798`*^6, 112239.44652883869`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6754606666445124`*^6, 
       274213.3012727714}, {-1.3212753333554873`*^6, 225242.69872722862`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6683182681661835`*^6, 
       409534.3522895748}, {-1.3284177318338163`*^6, 339649.6477104252}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.659246967250562*^6, 
       543022.0360808925}, {-1.337489032749438*^6, 455889.96391910745`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.6489468440193257`*^6, 
       673510.3270881006}, {-1.3477891559806743`*^6, 573178.6729118995}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5130773048465496`*^6, -943661.3746246052}, \
{-1.2339306951534504`*^6, -804434.6253753948}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5269417576758764`*^6, -816415.0356370865}, \
{-1.2200662423241236`*^6, -681952.9643629135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5411306455661547`*^6, -686795.3575264865}, \
{-1.2058773544338455`*^6, -561844.6424735135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5548946328700993`*^6, -554441.3723135327}, \
{-1.1921133671299007`*^6, -444470.62768646725`}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5548946328700993`*^6, 
       554441.3723135327}, {-1.1921133671299007`*^6, 444470.62768646725`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5411306455661547`*^6, 
       686795.3575264865}, {-1.2058773544338455`*^6, 561844.6424735135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5269417576758764`*^6, 
       816415.0356370865}, {-1.2200662423241236`*^6, 681952.9643629135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.5130773048465496`*^6, 
       943661.3746246052}, {-1.2339306951534504`*^6, 804434.6253753948}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.3693420307856337`*^6, -1.2052450545999745`*^6}, \
{-1.1279379692143663`*^6, -1.0423069454000256`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.3837756474122782`*^6, -1.0828758307235152`*^6}, \
{-1.1135043525877218`*^6, -914948.1692764849}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.400016954005165*^6, -958885.2664980965}, \
{-1.0972630459948347`*^6, -789210.7335019035}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.4178032141898274`*^6, -832573.4131091657}, \
{-1.0794767858101726`*^6, -665794.5868908342}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.4178032141898274`*^6, 
       832573.4131091657}, {-1.0794767858101726`*^6, 665794.5868908342}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.400016954005165*^6, 
       958885.2664980965}, {-1.0972630459948347`*^6, 789210.7335019035}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.3837756474122782`*^6, 
       1.0828758307235152`*^6}, {-1.1135043525877218`*^6, 
       914948.1692764849}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.3693420307856337`*^6, 
       1.2052450545999745`*^6}, {-1.1279379692143663`*^6, 
       1.0423069454000256`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.2354259136078588`*^6, -1.3391611717777494`*^6}, \
{-1.0121260863921413`*^6, -1.1581188282222506`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.2501708028963627`*^6, -1.2199899438884784`*^6}, \
{-997381.1971036373, -1.0275620561115217`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.267577840248336*^6, -1.0999084277692905`*^6}, \
{-979974.1597516638, -897915.5722307095}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.2877998121558467`*^6, -978148.0746706374}, \
{-959752.1878441534, -769947.9253293626}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.2877998121558467`*^6, 
       978148.0746706374}, {-959752.1878441534, 769947.9253293626}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.267577840248336*^6, 
       1.0999084277692905`*^6}, {-979974.1597516638, 897915.5722307095}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.2501708028963627`*^6, 
       1.2199899438884784`*^6}, {-997381.1971036373, 
       1.0275620561115217`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.2354259136078588`*^6, 
       1.3391611717777494`*^6}, {-1.0121260863921413`*^6, 
       1.1581188282222506`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.0991738805700974`*^6, -1.4698654046480427`*^6}, \
{-898650.1194299026, -1.2771425953519573`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.1130566897313995`*^6, -1.353594788404394*^6}, \
{-884767.3102686005, -1.143685211595606*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.1300892867771748`*^6, -1.2373969812404518`*^6}, \
{-867734.7132228251, -1.0101550187595481`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.1508636317417398`*^6, -1.1206827727338555`*^6}, \
{-846960.3682582602, -877141.2272661446}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.1508636317417398`*^6, 
       1.1206827727338555`*^6}, {-846960.3682582602, 877141.2272661446}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.1300892867771748`*^6, 
       1.2373969812404518`*^6}, {-867734.7132228251, 
       1.0101550187595481`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.1130566897313995`*^6, 
       1.353594788404394*^6}, {-884767.3102686005, 1.143685211595606*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.0991738805700974`*^6, 
       1.4698654046480427`*^6}, {-898650.1194299026, 
       1.2771425953519573`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-973842.2336324896, -1.4828964458386654`*^6}, \
{-774253.7663675105, -1.2641115541613349`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-989066.1255059808, -1.3698360949972807`*^6}, \
{-759029.8744940191, -1.1274439050027193`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.0083289336785218`*^6, -1.2576189531479622`*^6}, \
{-739767.0663214782, -989933.0468520377}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-1.0083289336785218`*^6, 
       1.2576189531479622`*^6}, {-739767.0663214782, 989933.0468520377}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-989066.1255059808, 
       1.3698360949972807`*^6}, {-759029.8744940191, 
       1.1274439050027193`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-973842.2336324896, 
       1.4828964458386654`*^6}, {-774253.7663675105, 
       1.2641115541613349`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-834130.7959718256, -1.6078998739278824`*^6}, \
{-664237.2040281744, -1.3888361260721176`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-846595.8946449709, -1.4967608986679919`*^6}, \
{-651772.1053550291, -1.2502471013320081`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-862754.2721170501, -1.387622355181943*^6}, \
{-635613.7278829499, -1.109657644818057*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-862754.2721170501, 
       1.387622355181943*^6}, {-635613.7278829499, 1.109657644818057*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-846595.8946449709, 
       1.4967608986679919`*^6}, {-651772.1053550291, 
       1.2502471013320081`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-834130.7959718256, 
       1.6078998739278824`*^6}, {-664237.2040281744, 
       1.3888361260721176`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-704666.6860959849, -1.6177904850114414`*^6}, \
{-543973.3139040151, -1.3769945149885586`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-716976.2165343708, -1.5109497865582702`*^6}, \
{-531663.7834656291, -1.2360582134417298`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-733363.8082359597, -1.4063658984561507`*^6}, \
{-515276.19176404027`, -1.090914101543849*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-733363.8082359597, 
       1.4063658984561507`*^6}, {-515276.19176404027`, 
       1.090914101543849*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-716976.2165343708, 
       1.5109497865582702`*^6}, {-531663.7834656291, 
       1.2360582134417298`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-704666.6860959849, 
       1.6177904850114414`*^6}, {-543973.3139040151, 
       1.3769945149885586`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-564677.3697889908, -1.737113660038596*^6}, \
{-434234.6302110091, -1.5093503399614037`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-573202.895088777, -1.6290661082426778`*^6}, \
{-425709.10491122305`, -1.3676698917573222`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-584622.231321417, -1.524713773862215*^6}, \
{-414289.768678583, -1.222294226137785*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-584622.231321417, 1.524713773862215*^6}, {-414289.768678583,
        1.222294226137785*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-573202.895088777, 
       1.6290661082426778`*^6}, {-425709.10491122305`, 
       1.3676698917573222`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-564677.3697889908, 
       1.737113660038596*^6}, {-434234.6302110091, 
       1.5093503399614037`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-432618.6321554884, -1.743897016972951*^6}, \
{-316565.36784451164`, -1.502566983027049*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-439715.21129745914`, -1.6381374091582992`*^6}, \
{-309468.78870254086`, -1.3585985908417008`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-449387.1767238718, -1.5370898316252872`*^6}, \
{-299796.8232761282, -1.2099181683747126`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-449387.1767238718, 
       1.5370898316252872`*^6}, {-299796.8232761282, 
       1.2099181683747126`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-439715.21129745914`, 
       1.6381374091582992`*^6}, {-309468.78870254086`, 
       1.3585985908417008`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-432618.6321554884, 
       1.743897016972951*^6}, {-316565.36784451164`, 
       1.502566983027049*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-299283.28615804884`, -1.7491657764760691`*^6}, \
{-200172.71384195116`, -1.4972982235239306`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-304394.1602806557, -1.6452798076366282`*^6}, \
{-195061.83971934428`, -1.3514561923633718`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-311454.0386991145, -1.5470024883017659`*^6}, \
{-188001.96130088548`, -1.2000055116982341`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-311454.0386991145, 
       1.5470024883017659`*^6}, {-188001.96130088548`, 
       1.2000055116982341`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-304394.1602806557, 
       1.6452798076366282`*^6}, {-195061.83971934428`, 
       1.3514561923633718`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-299283.28615804884`, 
       1.7491657764760691`*^6}, {-200172.71384195116`, 
       1.4972982235239306`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-164989.6268113994, -1.7525139814456953`*^6}, \
{-84738.37318860061, -1.4939500185543045`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-167669.41247904568`, -1.649862641653936*^6}, \
{-82058.58752095433, -1.346873358346064*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-171402.78667514795`, -1.5534412043398996`*^6}, \
{-78325.21332485205, -1.1935667956601004`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{-171402.78667514795`, 
       1.5534412043398996`*^6}, {-78325.21332485205, 
       1.1935667956601004`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-167669.41247904568`, 
       1.649862641653936*^6}, {-82058.58752095433, 1.346873358346064*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{-164989.6268113994, 
       1.7525139814456953`*^6}, {-84738.37318860061, 
       1.4939500185543045`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{104627.90879563068`, -1.7525139814456953`*^6}, {
       145100.09120436932`, -1.4939500185543047`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{107307.69446327697`, -1.649862641653936*^6}, {
       142420.30553672303`, -1.346873358346064*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{111041.06865937923`, -1.5534412043398996`*^6}, {
       138686.93134062077`, -1.1935667956601004`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{111041.06865937923`, 1.5534412043398996`*^6}, {
       138686.93134062077`, 1.1935667956601004`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{107307.69446327697`, 1.649862641653936*^6}, {
       142420.30553672303`, 1.346873358346064*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{104627.90879563068`, 1.7525139814456953`*^6}, {
       145100.09120436932`, 1.4939500185543047`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{238921.56814228013`, -1.7491657764760691`*^6}, {
       260534.43185771987`, -1.4972982235239309`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{244032.442264887, -1.6452798076366282`*^6}, {
       255423.557735113, -1.3514561923633718`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{251092.3206833458, -1.5470024883017659`*^6}, {
       248363.67931665422`, -1.2000055116982341`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{251092.3206833458, 1.5470024883017659`*^6}, {
       248363.67931665422`, 1.2000055116982341`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{244032.442264887, 1.6452798076366282`*^6}, {255423.557735113,
        1.3514561923633718`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{238921.56814228013`, 1.7491657764760691`*^6}, {
       260534.43185771987`, 1.4972982235239309`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{372256.9141397197, -1.743897016972951*^6}, {
       376927.08586028026`, -1.502566983027049*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{379353.49328169046`, -1.6381374091582992`*^6}, {
       369830.50671830954`, -1.3585985908417008`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{389025.4587081031, -1.5370898316252872`*^6}, {
       360158.54129189695`, -1.2099181683747126`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{389025.4587081031, 1.5370898316252872`*^6}, {
       360158.54129189695`, 1.2099181683747126`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{379353.49328169046`, 1.6381374091582992`*^6}, {
       369830.50671830954`, 1.3585985908417008`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{372256.9141397197, 1.743897016972951*^6}, {
       376927.08586028026`, 1.502566983027049*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{504315.65177322214`, -1.737113660038596*^6}, {
       494596.34822677786`, -1.5093503399614037`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{512841.1770730082, -1.6290661082426778`*^6}, {
       486070.82292699174`, -1.3676698917573222`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{524260.51330564835`, -1.524713773862215*^6}, {
       474651.48669435165`, -1.222294226137785*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{524260.51330564835`, 1.524713773862215*^6}, {
       474651.48669435165`, 1.222294226137785*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{512841.1770730082, 1.6290661082426778`*^6}, {
       486070.82292699174`, 1.3676698917573222`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{504315.65177322214`, 1.737113660038596*^6}, {
       494596.34822677786`, 1.5093503399614037`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{644304.9680802162, -1.6177904850114414`*^6}, {
       604335.0319197838, -1.3769945149885586`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{656614.4985186021, -1.5109497865582702`*^6}, {
       592025.5014813978, -1.2360582134417298`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{673002.090220191, -1.4063658984561507`*^6}, {
       575637.909779809, -1.0909141015438493`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{673002.090220191, 1.4063658984561507`*^6}, {575637.909779809,
        1.0909141015438493`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{656614.4985186021, 1.5109497865582702`*^6}, {
       592025.5014813978, 1.2360582134417298`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{644304.9680802162, 1.6177904850114414`*^6}, {
       604335.0319197838, 1.3769945149885586`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{773769.0779560569, -1.6078998739278824`*^6}, {
       724598.9220439432, -1.3888361260721176`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{786234.1766292022, -1.4967608986679919`*^6}, {
       712133.8233707979, -1.250247101332008*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{802392.5541012815, -1.387622355181943*^6}, {
       695975.4458987185, -1.109657644818057*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{802392.5541012815, 1.387622355181943*^6}, {695975.4458987185,
        1.109657644818057*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{786234.1766292022, 1.4967608986679919`*^6}, {
       712133.8233707979, 1.250247101332008*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{773769.0779560569, 1.6078998739278824`*^6}, {
       724598.9220439432, 1.3888361260721176`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{913480.5156167209, -1.4828964458386654`*^6}, {
       834615.4843832792, -1.2641115541613349`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{928704.4074902121, -1.3698360949972807`*^6}, {
       819391.5925097878, -1.1274439050027193`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{947967.215662753, -1.2576189531479622`*^6}, {
       800128.784337247, -989933.0468520377}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{947967.215662753, 1.2576189531479622`*^6}, {800128.784337247,
        989933.0468520377}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{928704.4074902121, 1.3698360949972807`*^6}, {
       819391.5925097878, 1.1274439050027193`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{913480.5156167209, 1.4828964458386654`*^6}, {
       834615.4843832792, 1.2641115541613349`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.0388121625543286`*^6, -1.4698654046480427`*^6}, {
       959011.8374456714, -1.277142595351957*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.0526949717156307`*^6, -1.353594788404394*^6}, {
       945129.0282843693, -1.143685211595606*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.0697275687614062`*^6, -1.2373969812404518`*^6}, {
       928096.4312385938, -1.0101550187595481`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.090501913725971*^6, -1.1206827727338553`*^6}, {
       907322.086274029, -877141.2272661446}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.090501913725971*^6, 1.1206827727338553`*^6}, {
       907322.086274029, 877141.2272661446}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.0697275687614062`*^6, 1.2373969812404518`*^6}, {
       928096.4312385938, 1.0101550187595481`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.0526949717156307`*^6, 1.353594788404394*^6}, {
       945129.0282843693, 1.143685211595606*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.0388121625543286`*^6, 1.4698654046480427`*^6}, {
       959011.8374456714, 1.277142595351957*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.17506419559209*^6, -1.3391611717777494`*^6}, {
       1.07248780440791*^6, -1.1581188282222506`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.189809084880594*^6, -1.2199899438884784`*^6}, {
       1.057742915119406*^6, -1.0275620561115217`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.2072161222325675`*^6, -1.0999084277692905`*^6}, {
       1.0403358777674326`*^6, -897915.5722307095}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.227438094140078*^6, -978148.0746706374}, {
       1.0201139058599221`*^6, -769947.9253293626}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.227438094140078*^6, 978148.0746706374}, {
       1.0201139058599221`*^6, 769947.9253293626}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.2072161222325675`*^6, 1.0999084277692905`*^6}, {
       1.0403358777674326`*^6, 897915.5722307095}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.189809084880594*^6, 1.2199899438884784`*^6}, {
       1.057742915119406*^6, 1.0275620561115217`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.17506419559209*^6, 1.3391611717777494`*^6}, {
       1.07248780440791*^6, 1.1581188282222506`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.308980312769865*^6, -1.2052450545999745`*^6}, {
       1.1882996872301348`*^6, -1.0423069454000256`*^6}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.3234139293965097`*^6, -1.082875830723515*^6}, {
       1.1738660706034903`*^6, -914948.1692764849}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.3396552359893965`*^6, -958885.2664980965}, {
       1.1576247640106035`*^6, -789210.7335019035}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.3574414961740586`*^6, -832573.4131091657}, {
       1.1398385038259414`*^6, -665794.5868908342}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.3574414961740586`*^6, 832573.4131091657}, {
       1.1398385038259414`*^6, 665794.5868908342}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.3396552359893965`*^6, 958885.2664980965}, {
       1.1576247640106035`*^6, 789210.7335019035}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.3234139293965097`*^6, 1.082875830723515*^6}, {
       1.1738660706034903`*^6, 914948.1692764849}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.308980312769865*^6, 1.2052450545999745`*^6}, {
       1.1882996872301348`*^6, 1.0423069454000256`*^6}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.4527155868307808`*^6, -943661.3746246052}, {
       1.294292413169219*^6, -804434.6253753948}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.4665800396601076`*^6, -816415.0356370865}, {
       1.2804279603398924`*^6, -681952.9643629135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.480768927550386*^6, -686795.3575264865}, {
       1.266239072449614*^6, -561844.6424735135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.4945329148543307`*^6, -554441.3723135327}, {
       1.2524750851456695`*^6, -444470.6276864673}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.4945329148543307`*^6, 554441.3723135327}, {
       1.2524750851456695`*^6, 444470.6276864673}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.480768927550386*^6, 686795.3575264865}, {
       1.266239072449614*^6, 561844.6424735135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.4665800396601076`*^6, 816415.0356370865}, {
       1.2804279603398924`*^6, 681952.9643629135}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.4527155868307808`*^6, 943661.3746246052}, {
       1.294292413169219*^6, 804434.6253753948}}]}}, 
    {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
     {Arrowheads[0.02], 
      ArrowBox[{{1.588585126003557*^6, -673510.3270881006}, {
       1.4081508739964429`*^6, -573178.6729118995}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.5988852492347935`*^6, -543022.0360808925}, {
       1.3978507507652068`*^6, -455889.96391910745`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.607956550150415*^6, -409534.3522895748}, {
       1.388779449849585*^6, -339649.6477104252}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.6150989486287439`*^6, -274213.3012727714}, {
       1.3816370513712564`*^6, -225242.69872722862`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.6196817826460514`*^6, -137488.5534711613}, {
       1.3770542173539484`*^6, -112239.44652883869`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.6212625883706668`*^6, -975.5}, {
       1.375473411629333*^6, -975.5}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.6196817826460514`*^6, 137488.5534711613}, {
       1.3770542173539484`*^6, 112239.44652883869`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.6150989486287439`*^6, 274213.3012727714}, {
       1.3816370513712564`*^6, 225242.69872722862`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.607956550150415*^6, 409534.3522895748}, {
       1.388779449849585*^6, 339649.6477104252}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.5988852492347935`*^6, 543022.0360808925}, {
       1.3978507507652068`*^6, 455889.96391910745`}}]}, 
     {Arrowheads[0.02], 
      ArrowBox[{{1.588585126003557*^6, 673510.3270881006}, {
       1.4081508739964429`*^6, 573178.6729118995}}]}}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-1.87296*^6, 1.87296*^6}, {-1.87296*^6, 1.87296*^6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.776664175650981*^9, 3.7766642521994457`*^9}, {
   3.776664345948724*^9, 3.7766643663178797`*^9}, 3.7766644180109277`*^9, {
   3.7766644497419767`*^9, 3.7766644988619113`*^9}, {3.7766646649650817`*^9, 
   3.7766646745417643`*^9}, 3.779601563563711*^9, 3.780332725469355*^9, 
   3.780367044578473*^9, 3.780375984286621*^9, 3.780389367546322*^9, 
   3.7805715529114213`*^9, 3.7805738292525034`*^9, 3.7812690542715206`*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"49f9c008-172d-498d-8769-300857600cfb"]
}, Open  ]],

Cell["\<\
Relative difference between the Anti-Jovian and Jovian gravity.\
\>", "Text",
 CellChangeTimes->{{3.7812723579312687`*^9, 
  3.7812723880676775`*^9}},ExpressionUUID->"f9b7678e-3504-4ebd-bb22-\
a3a8f476b09b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RelGrav", "=", 
  FractionBox[
   RowBox[{"EurAtEur", "+", "JupAtEur"}], 
   RowBox[{"EurAtEur", "-", "JupAtEur"}]]}]], "Input",
 CellChangeTimes->{{3.776664732648097*^9, 3.776664754808392*^9}, {
  3.77666485237523*^9, 3.7766648550011983`*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"fbf4d63a-ce66-4aa8-8667-0840240ad5da"],

Cell[BoxData["1.5443216469065488`"], "Output",
 CellChangeTimes->{3.776664755155223*^9, 3.7766648557022305`*^9, 
  3.7796015636056004`*^9, 3.7803327255212154`*^9, 3.7803670446283703`*^9, 
  3.780375984368318*^9, 3.7803893675810976`*^9, 3.7805715529711657`*^9, 
  3.7805738293005075`*^9, 3.7812690543323584`*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"ca33e8fd-0b6d-4d05-a731-509eff2616d9"]
}, Open  ]],

Cell["\<\
Angle of the force of gravity with respect to the surface at the northern pole.
The plot indicates the actual angle under which one would experience Jupiter\
\[CloseCurlyQuote]s gravity.\
\>", "Text",
 CellChangeTimes->{{3.781272421264904*^9, 3.7812724336158404`*^9}, {
  3.7812725277431297`*^9, 3.781272536321186*^9}, {3.781272614953908*^9, 
  3.781272650011157*^9}, {3.781272695771787*^9, 
  3.781272713768657*^9}},ExpressionUUID->"f6234b57-52c0-49af-879b-\
9489e628d99a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"AngleAtPoles", "=", 
  RowBox[{
   RowBox[{"180", "/", "\[Pi]"}], "*", 
   RowBox[{"ArcTan", "[", 
    RowBox[{"JupAtEur", "/", "EurAtEur"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{"REur", "-", 
       RowBox[{"rEur", "*", 
        RowBox[{"Cos", "[", "theta", "]"}]}]}], 
      RowBox[{"rEur", "*", 
       RowBox[{"Sin", "[", "theta", "]"}]}]], "]"}], "-", "theta"}], ",", 
   RowBox[{"{", 
    RowBox[{"theta", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.776664860637641*^9, 3.7766648795317307`*^9}, {
  3.7766649419467907`*^9, 3.776664945024375*^9}, {3.781272397298994*^9, 
  3.7812723975832*^9}, {3.7812724877181606`*^9, 3.7812725030302134`*^9}, {
  3.781272606339944*^9, 3.781272606511484*^9}, {3.781272689896497*^9, 
  3.781272690606598*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"e28c71ec-7d80-4065-8310-1cb6690a6769"],

Cell[BoxData["12.075590718245166`"], "Output",
 CellChangeTimes->{
  3.776664880156397*^9, 3.776664945633418*^9, 3.779601563627543*^9, 
   3.7803327255581264`*^9, 3.780367044648286*^9, 3.7803759843871355`*^9, 
   3.7803893676033*^9, 3.780571553000657*^9, 3.7805738293261695`*^9, 
   3.7812690543672323`*^9, 3.781272399473147*^9, {3.781272488338502*^9, 
   3.7812725033214483`*^9}, 3.781272607079996*^9, 3.7812726912189703`*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"7da6bb1b-7c41-4dd8-b141-dae6ff5f708e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVlGs0lHkcgIfReEe1ZzgaSWRI7VJHne3mDPv711aKVqiE7Boj5dK6b5to
7UqjIo1xOYQYGbSVOHZMafK3i11TKsdl1IjkUhS5Du9rXLY+POf58Hx/OPww
9wBtGo32w2e+mI71nvdvj/huhq7zvYZDgdVwLdcs/TDodiRkMswomKuwPflK
5At6T7WG9NdQMGgYSFaLwqD0Ie3a1wYUqPYn/iMRxcP1O4zOY9oUdPiKNuaL
rsP1bUdCKvpIcD9jrMoWFYAycCIz4BYJaZM+VVmi+9Cu56F5sZ4EbqOT3p6o
OgiLZjV7GcxC+HkXv6rwJpjQSBmrDGbg5wcBqdqWLZDquXfkJVsN7UMHmaX8
dqhPVFkfZUzDVdsZWrXXS8hQXLbTJqYgwqYps07yGoTissig6QmY8w8p7w7t
BfolybLXg+PAf+zhKjzVB6TD4TSdtjHwn2ivq7s8AFZFUpbi/iikbJGFlQje
gaFjoFJd8RG062Q7E88PQcbWdA5XPgz61s7P32R/AOeZwc2Lee/hQMGeW+Oi
ETBLcvH9pmgQjMaa98fLPoEiOvuJMq4fbvxXo0UPGgfzesY2sd9bsDfdvWR+
cgJ2sZuHijt6wKaXNXAhehLMb6V0GKWr4F6ZQaA0cgpW2F+t8shRQlzPj202
gmk49Kiwr9ypFSLsdznfzFBDU8NqeZJ5M8wV7OV/FM7Ag19Mdjs4NEBL+A3e
r0WzgIpTzpzlycDO0WKxW0wCujkeOSzJB8U+uzKUR8HvtpOvPGMKsaQyx67v
zhyY/32yeO2Oh3iV5abgn25rIDtRanRU0IBbtYgEY/k81MlV/VtMnmEpEVXS
oliAu4tr217Ut+JNq1jB/MZFkOdd4XlWKvFY6ozht8olKPOQZkqmVNgyKck2
LJiGVlAbv3Ia7cF93l2qPe9pyCmttsUv6C0+MNhGSUO1kPdBn+TfBP34XGRA
IHtUC5UsrEw/FD+IXapzndhntZFFkdX8uaL3+NN8cBx9RhuNeN5b4y0exuLO
P/4KjaKjUFH1Xeusj3gu0IEXo6Ej97tNhJd0FJsupJ2IOK+DzLaTvbsrxvA7
x+QnhM4yZBRN29zwYRzXb2gGs+Rl6EL0nX955AQOJkp0OEwG2iaLCO2emsSy
wvUO9WkM5JlwXHhFZxo/59o3uuvrItfY4z5GdDUmg3OP8FJ10awiSi6eV+Mm
14JjK9kEOj3BqfVZPov5dvalpRkEcgxDtRpdEgeNPlO/ziKQwM/nsf8KEoeL
ffca5BCopz1E/pRF4njmxbdx+QS6zTxVk2tM4rxXChP3EgJd3PlMyrUhsTLm
uHBeRiAOI/3PWBcSO9VExrh1EchH4ntNk0Fit1CdJkE3gWIZLsn+OST2tMhi
y98QqBjtuPI0n8Snrz6s2jBAILRcnZhbQuJEb9onzQiBapK2xnEfkLh27hq/
ZJFAXGFrUGwXiRvL11V20ZiI73b2dP8bEjfzK5dYdCbyWm0U4DxA4q4n7Xmx
ukxEJbjyTEZJTN4w6XRlMVGBV5nHo0USL7ncsxIYfO6ddkct6RRm0CH6kSET
FU4q3JJ1KWwYwtffYMxE7KZ3h06wKGyybtr3hAkTXRqKcqo3pLBF26VyoSkT
JYTTDtgYU9g6yWihcR0T9YpS9qWbUngr97azhsNEwQmrv/wL/w+ljWla
       "]]},
     Annotation[#, "Charting`Private`Tag$21268#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->
   NCache[{{0, Pi}, {-1.5707962628295271`, 1.5707962625313008`}}, {{
     0, 3.141592653589793}, {-1.5707962628295271`, 1.5707962625313008`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.776664880156397*^9, 3.776664945633418*^9, 3.779601563627543*^9, 
   3.7803327255581264`*^9, 3.780367044648286*^9, 3.7803759843871355`*^9, 
   3.7803893676033*^9, 3.780571553000657*^9, 3.7805738293261695`*^9, 
   3.7812690543672323`*^9, 3.781272399473147*^9, {3.781272488338502*^9, 
   3.7812725033214483`*^9}, 3.781272607079996*^9, 3.7812726912907763`*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"037a6b8c-3b60-455f-ac8a-7cfb13337208"]
}, Open  ]],

Cell["\<\
gEy is the vertical component of Europa\[CloseCurlyQuote]s gravity.
rJprime is the distance to the centre of Jupiter as function of \[Theta], \
where \[Theta] is the angle on Europa. \[Theta]=0 is the Jovian pole, \
\[Theta]=\[Pi] is the Anti-Jovian pole.
gJ0 is the magnitude of Jupiter\[CloseCurlyQuote]s gravity, gJy the component \
perpendicular to the surface, and gJx the component parallel.\
\>", "Text",
 CellChangeTimes->{{3.7812727325843487`*^9, 
  3.7812728586452303`*^9}},ExpressionUUID->"60049ab4-9ada-431e-a3c1-\
937507ae6211"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"gEy", "=", 
  RowBox[{
   RowBox[{"-", "G"}], "*", 
   RowBox[{"MEur", "/", 
    RowBox[{"rEur", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"rJprime", "=", 
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"REur", "^", "2"}], "-", 
    RowBox[{"2", "rEur", "*", "REur", "*", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
    RowBox[{"rEur", "^", "2"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"theta2", "=", 
  RowBox[{
   RowBox[{"ArcTan", "[", 
    FractionBox[
     RowBox[{"REur", "-", 
      RowBox[{"rEur", "*", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], 
     RowBox[{"rEur", "*", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]], "]"}], "-", 
   "\[Theta]"}]}], "\[IndentingNewLine]", 
 RowBox[{"gJ0", "=", 
  RowBox[{"G", "*", 
   RowBox[{"MJup", "/", 
    RowBox[{"rJprime", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"gJy", "=", 
  RowBox[{"gJ0", "*", 
   RowBox[{"Sin", "[", "theta2", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"gJx", "=", 
  RowBox[{"gJ0", "*", 
   RowBox[{"Cos", "[", "theta2", "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.7774521476172132`*^9, 3.777452275846592*^9}, {
   3.7774523066548615`*^9, 3.777452399887699*^9}, {3.7774524938417387`*^9, 
   3.7774525031758347`*^9}, {3.777452541710064*^9, 3.7774525421857977`*^9}, {
   3.777452616715746*^9, 3.7774526602806406`*^9}, {3.7774527140787973`*^9, 
   3.777452726545989*^9}, 3.777452772606356*^9},
 CellLabel->"In[59]:=",ExpressionUUID->"072db138-d4b1-432b-8542-5e9bdcbfa5ac"],

Cell[BoxData[
 RowBox[{"-", "1.3147087261694181`"}]], "Output",
 CellChangeTimes->{3.777452727992066*^9, 3.777452773690012*^9, 
  3.778734855822818*^9, 3.778746555517232*^9, 3.77960156374953*^9, 
  3.780332725701733*^9, 3.780367044771953*^9, 3.7803759844704185`*^9, 
  3.7803893677319813`*^9, 3.7805715531314793`*^9, 3.780573829433403*^9, 
  3.781269054481963*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"b47acaec-deb7-4d91-a850-aed3affa2dac"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"450377646096640000", "-", 
   RowBox[{"2094905760000000", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]], "Output",
 CellChangeTimes->{3.777452727992066*^9, 3.777452773690012*^9, 
  3.778734855822818*^9, 3.778746555517232*^9, 3.77960156374953*^9, 
  3.780332725701733*^9, 3.780367044771953*^9, 3.7803759844704185`*^9, 
  3.7803893677319813`*^9, 3.7805715531314793`*^9, 3.780573829433403*^9, 
  3.7812690544859495`*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"ba5aa13e-783f-4a56-afe0-9d318bee44cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[Theta]"}], "+", 
  RowBox[{"ArcTan", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"671100000", "-", 
       RowBox[{"1560800", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
     RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "1560800"], "]"}]}]], "Output",
 CellChangeTimes->{3.777452727992066*^9, 3.777452773690012*^9, 
  3.778734855822818*^9, 3.778746555517232*^9, 3.77960156374953*^9, 
  3.780332725701733*^9, 3.780367044771953*^9, 3.7803759844704185`*^9, 
  3.7803893677319813`*^9, 3.7805715531314793`*^9, 3.780573829433403*^9, 
  3.781269054494891*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"7d43a927-ea08-4eae-80ce-f7cfdadd8931"],

Cell[BoxData[
 FractionBox["1.2667403839999998`*^17", 
  RowBox[{"450377646096640000", "-", 
   RowBox[{"2094905760000000", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]], "Output",
 CellChangeTimes->{3.777452727992066*^9, 3.777452773690012*^9, 
  3.778734855822818*^9, 3.778746555517232*^9, 3.77960156374953*^9, 
  3.780332725701733*^9, 3.780367044771953*^9, 3.7803759844704185`*^9, 
  3.7803893677319813`*^9, 3.7805715531314793`*^9, 3.780573829433403*^9, 
  3.78126905450985*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"60eb08c0-19c8-4b82-beb5-2b824f8a9be7"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"1.2667403839999998`*^17", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Theta]", "-", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"671100000", "-", 
           RowBox[{"1560800", " ", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "1560800"], "]"}]}], 
     "]"}]}], 
   RowBox[{"450377646096640000", "-", 
    RowBox[{"2094905760000000", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]}]], "Output",
 CellChangeTimes->{3.777452727992066*^9, 3.777452773690012*^9, 
  3.778734855822818*^9, 3.778746555517232*^9, 3.77960156374953*^9, 
  3.780332725701733*^9, 3.780367044771953*^9, 3.7803759844704185`*^9, 
  3.7803893677319813`*^9, 3.7805715531314793`*^9, 3.780573829433403*^9, 
  3.7812690545148373`*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"eb421c0e-6274-4026-836f-d4fb35d9eed7"],

Cell[BoxData[
 FractionBox[
  RowBox[{"1.2667403839999998`*^17", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "-", 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"671100000", "-", 
          RowBox[{"1560800", " ", 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
        RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "1560800"], "]"}]}], "]"}]}], 
  RowBox[{"450377646096640000", "-", 
   RowBox[{"2094905760000000", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]]], "Output",
 CellChangeTimes->{3.777452727992066*^9, 3.777452773690012*^9, 
  3.778734855822818*^9, 3.778746555517232*^9, 3.77960156374953*^9, 
  3.780332725701733*^9, 3.780367044771953*^9, 3.7803759844704185`*^9, 
  3.7803893677319813`*^9, 3.7805715531314793`*^9, 3.780573829433403*^9, 
  3.7812690545258083`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"f6fe80ca-567a-4f26-a129-276d8d164ce6"]
}, Open  ]],

Cell["\<\
This plot shows the parallel and perpendicular components of the total \
gravity on Europa as function of \[Theta].\
\>", "Text",
 CellChangeTimes->{{3.781272864209352*^9, 
  3.7812728940037456`*^9}},ExpressionUUID->"55eb7ba4-32dc-40d5-837f-\
bd7c90f3fd36"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gJx", ",", 
     RowBox[{"gEy", "+", "gJy"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Net Surface Gravity on Europa\>\""}], 
   ",", 
   RowBox[{"PlotLabels", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"gx", ",", "gy"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Scaled", "[", "2", "]"}], ",", "Above"}], "}"}]}], "]"}]}], 
   ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Theta](rad)\>\"", ",", "\"\<gravity(G)\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7774527452601795`*^9, 3.7774527931708417`*^9}, {
  3.7774528254849844`*^9, 3.7774528869199405`*^9}, {3.7774529186901507`*^9, 
  3.777452941944827*^9}, {3.777452997076569*^9, 3.7774530403060074`*^9}, {
  3.777453124560337*^9, 3.777453137679487*^9}, {3.7774531686685467`*^9, 
  3.7774531717967157`*^9}, {3.7774536248558245`*^9, 3.777453688944643*^9}, {
  3.7774537615650563`*^9, 3.77745380797816*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"ed7767cb-afc2-42c8-99b5-69dd81cd402c"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nc8VX8YB3ArrvohI35WGWmoJKRhPCdpkk2/MopCiayiQbILySgZGWVX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       "]]},
     Annotation[#, "Charting`Private`Tag$2256#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1Hk01c8bB3DrvZ9b+CLpG9lVQkjWL5pRSlGWJBWyVBJlSwhRyVIiLglZ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       "]]},
     Annotation[#, "Charting`Private`Tag$2256#2"]& ]}, {{}, {{{}, 
      InsetBox["gx", {3.141592589475655, 0.02151560575925268}, 
       ImageScaled[{1, 0}]]}, {{}, 
      InsetBox["gy", {3.141592589475658, -1.5937795504675565}, 
       ImageScaled[{1, 0}]]}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Theta](rad)\"", TraditionalForm], 
    FormBox["\"gravity(G)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Net Surface Gravity on Europa\"", TraditionalForm],
  PlotRange->
   NCache[{{0, Pi}, {-1.594668334504146, 0.28126788477367004`}}, {{
     0, 3.141592653589793}, {-1.594668334504146, 0.28126788477367004`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.12322631936001499`]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.777452794076194*^9, 3.777452868880734*^9, {3.7774529151235995`*^9, 
   3.7774529437423267`*^9}, {3.7774530112771797`*^9, 3.7774530408525457`*^9}, 
   3.777453141062304*^9, 3.7774531730016994`*^9, 3.7774536903196077`*^9, {
   3.777453790550395*^9, 3.777453808594516*^9}, 3.7796015642628827`*^9, 
   3.7803327260897703`*^9, 3.7803670453718643`*^9, 3.780375984899356*^9, 
   3.7803893683332233`*^9, 3.780571553750696*^9, 3.780573829666011*^9, 
   3.7812690548619375`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"de7841c2-9aba-4354-9415-c2078feb1c92"]
}, Open  ]],

Cell["\<\
This plot shows the angle in radians of the gravity with respect to the \
Europan surface.\
\>", "Text",
 CellChangeTimes->{{3.7812729037984824`*^9, 
  3.7812729251374493`*^9}},ExpressionUUID->"ed6caa2f-6776-4a89-99d3-\
6d7a40ce4993"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"ArcTan", "[", 
    FractionBox[
     RowBox[{"-", "gJx"}], 
     RowBox[{"gJy", "+", "gEy"}]], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Angle of net gravity w.r.t. Europan surface\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Theta](rad)\>\"", ",", "\"\<angle(rad)\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.777452402624518*^9, 3.777452427398838*^9}, {
  3.7774532815751657`*^9, 3.7774533699737086`*^9}, {3.7774535566176233`*^9, 
  3.7774535997980595`*^9}, {3.7774539101469646`*^9, 3.777454026068276*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"88b835c3-1c57-403b-b368-4fc903fa1b1b"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nlcTN0fB/BpoQnRnjYtFE/6ESVF+YyEhNKmItLQomijEimRIkllS0oK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       "]]},
     Annotation[#, "Charting`Private`Tag$2553#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Theta](rad)\"", TraditionalForm], 
    FormBox["\"angle(rad)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Angle of net gravity w.r.t. Europan surface\"", TraditionalForm],
  PlotRange->
   NCache[{{0, Pi}, {0., 0.21582404107904388`}}, {{0, 3.141592653589793}, {0.,
      0.21582404107904388`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.777453998915943*^9, 3.777454028017065*^9}, 
   3.7796015644643917`*^9, 3.7803327263832474`*^9, 3.780367045510494*^9, 
   3.7803759849955716`*^9, 3.780389368488599*^9, 3.7805715540785866`*^9, 
   3.780573829798831*^9, 3.781269055054412*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"ad141207-0aae-470d-858f-d91787cabab5"]
}, Open  ]],

Cell["Calculated masses of the crust, sea and core of Europa.", "Text",
 CellChangeTimes->{{3.78127293455028*^9, 
  3.7812729450721087`*^9}},ExpressionUUID->"c435ab49-f6e7-453d-988b-\
0a2afeda74f7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"mcrust", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], "*", "\[Pi]", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"rEur", "^", "3"}], "-", 
      RowBox[{"rc", "^", "3"}]}], ")"}], "*", "934"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"msea", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"4", "/", "3"}], "*", "\[Pi]", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"rc", "^", "3"}], "-", 
      RowBox[{"r0", "^", "3"}]}], ")"}], "*", "1000"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"mcore", "=", 
  RowBox[{"MEur", "-", "mcrust", "-", "msea"}]}]}], "Input",
 CellChangeTimes->{{3.7787343200795393`*^9, 3.778734392530732*^9}, {
  3.778734586902973*^9, 3.7787346030128946`*^9}, {3.7787349056475887`*^9, 
  3.77873490976458*^9}, {3.77874658027931*^9, 3.778746596319073*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"5c21ea93-39de-46e4-aaca-95ce00ae83d3"],

Cell[BoxData["3.0666656585394756`*^20"], "Output",
 CellChangeTimes->{{3.778734388494527*^9, 3.7787343928179655`*^9}, {
   3.7787345930285606`*^9, 3.77873461116905*^9}, 3.7787349114959373`*^9, {
   3.778746560552369*^9, 3.778746596859874*^9}, 3.779601564488305*^9, 
   3.7803327264276385`*^9, 3.7803670455483923`*^9, 3.7803759850155964`*^9, 
   3.780389368518265*^9, 3.780571554115591*^9, 3.7805738298357363`*^9, 
   3.781269055093295*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"7cffa8af-077c-4691-ac20-ec1010a8756c"],

Cell[BoxData["4.1044908019150645`*^21"], "Output",
 CellChangeTimes->{{3.778734388494527*^9, 3.7787343928179655`*^9}, {
   3.7787345930285606`*^9, 3.77873461116905*^9}, 3.7787349114959373`*^9, {
   3.778746560552369*^9, 3.778746596859874*^9}, 3.779601564488305*^9, 
   3.7803327264276385`*^9, 3.7803670455483923`*^9, 3.7803759850155964`*^9, 
   3.780389368518265*^9, 3.780571554115591*^9, 3.7805738298357363`*^9, 
   3.7812690550983152`*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"f9f26bcc-382c-422c-9694-675a0a945f1a"],

Cell[BoxData["4.357684263223099`*^22"], "Output",
 CellChangeTimes->{{3.778734388494527*^9, 3.7787343928179655`*^9}, {
   3.7787345930285606`*^9, 3.77873461116905*^9}, 3.7787349114959373`*^9, {
   3.778746560552369*^9, 3.778746596859874*^9}, 3.779601564488305*^9, 
   3.7803327264276385`*^9, 3.7803670455483923`*^9, 3.7803759850155964`*^9, 
   3.780389368518265*^9, 3.780571554115591*^9, 3.7805738298357363`*^9, 
   3.7812690551013074`*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"74e1f395-55a8-44a0-80e8-53f1b535f204"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of gravity and pressure", "Section",
 CellChangeTimes->{{3.7812734005570536`*^9, 
  3.781273410493509*^9}},ExpressionUUID->"620891fb-8db6-4337-9a8c-\
103c21ff3f89"],

Cell["\<\
Gravity at the seafloor and bottom of the crust, respectively\
\>", "Text",
 CellChangeTimes->{{3.781272952227971*^9, 
  3.781272968958231*^9}},ExpressionUUID->"5d1faba4-076c-4bba-ac0d-\
d8c6c78446b5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g0", "=", 
  RowBox[{"mcore", "*", 
   RowBox[{"G", "/", 
    RowBox[{"r0", "^", "2"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"gc", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"mcore", "+", "msea"}], ")"}], "*", 
   RowBox[{"G", "/", 
    RowBox[{"rc", "^", "2"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.778734486769717*^9, 3.778734488336528*^9}, {
  3.7787347427631707`*^9, 3.778734748823958*^9}, {3.7787349509923186`*^9, 
  3.778734964756509*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"04939220-d3a7-45dc-ac36-99c1bb769d41"],

Cell[BoxData["1.4838537442597968`"], "Output",
 CellChangeTimes->{3.778734749530054*^9, 3.77873496543966*^9, 
  3.7787465663588514`*^9, 3.7787465992307234`*^9, 3.7796015645156126`*^9, 
  3.780332726474512*^9, 3.780367045582303*^9, 3.7803759850788283`*^9, 
  3.7803893685423603`*^9, 3.7805715541569757`*^9, 3.780573829965559*^9, 
  3.781269055131227*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"8c401f83-214e-48ce-8ae8-082ffb80b046"],

Cell[BoxData["1.3245745425438726`"], "Output",
 CellChangeTimes->{3.778734749530054*^9, 3.77873496543966*^9, 
  3.7787465663588514`*^9, 3.7787465992307234`*^9, 3.7796015645156126`*^9, 
  3.780332726474512*^9, 3.780367045582303*^9, 3.7803759850788283`*^9, 
  3.7803893685423603`*^9, 3.7805715541569757`*^9, 3.780573829965559*^9, 
  3.7812690551352167`*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"a1db8b47-0d73-47a4-81fd-ccd8d8f36cb2"]
}, Open  ]],

Cell["\<\
Gravitational acceleration in Europa as function of distance from the core.\
\>", "Text",
 CellChangeTimes->{{3.781272981676239*^9, 
  3.7812730544675627`*^9}},ExpressionUUID->"1efa6937-b1a4-465d-9670-\
66b3c297f934"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"grsub", "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"mcore", "+", 
             RowBox[{
              RowBox[{"4", "/", "3"}], "\[Pi]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"r", "^", "3"}], "-", 
                RowBox[{"r0", "^", "3"}]}], ")"}], "*", "1000"}]}], ")"}], 
           "*", 
           RowBox[{"G", "/", 
            RowBox[{"r", "^", "2"}]}]}], "-", "gJ0"}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", " ", "0"}]}], ",", 
        RowBox[{"r0", "\[LessEqual]", " ", "r", "\[LessEqual]", " ", "rc"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"mcore", "+", "msea", "+", 
             RowBox[{
              RowBox[{"4", "/", "3"}], "\[Pi]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"r", "^", "3"}], "-", 
                RowBox[{"rc", "^", "3"}]}], ")"}], "*", "1000"}]}], ")"}], 
           "*", 
           RowBox[{"G", "/", 
            RowBox[{"r", "^", "2"}]}]}], "-", "gJ0"}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", " ", "0"}]}], ",", 
        RowBox[{"rc", "<", "r", "\[LessEqual]", " ", "rEur"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"r", "<", "r0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"r", "<", " ", "rEur"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"grsub", ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "r0", ",", "rEur"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"granti", "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"mcore", "+", 
             RowBox[{
              RowBox[{"4", "/", "3"}], "\[Pi]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"r", "^", "3"}], "-", 
                RowBox[{"r0", "^", "3"}]}], ")"}], "*", "1000"}]}], ")"}], 
           "*", 
           RowBox[{"G", "/", 
            RowBox[{"r", "^", "2"}]}]}], "+", "gJ0"}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", " ", "0"}]}], ",", 
        RowBox[{"r0", "\[LessEqual]", " ", "r", "\[LessEqual]", " ", "rc"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"mcore", "+", "msea", "+", 
             RowBox[{
              RowBox[{"4", "/", "3"}], "\[Pi]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"r", "^", "3"}], "-", 
                RowBox[{"rc", "^", "3"}]}], ")"}], "*", "1000"}]}], ")"}], 
           "*", 
           RowBox[{"G", "/", 
            RowBox[{"r", "^", "2"}]}]}], "+", "gJ0"}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", " ", "0"}]}], ",", 
        RowBox[{"rc", "<", "r", "\[LessEqual]", " ", "rEur"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"r", "<", "r0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"r", "<", " ", "rEur"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"granti", ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "r0", ",", "rEur"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.778735181762209*^9, 3.778735184739214*^9}, {
  3.7787352630598*^9, 3.778735263496606*^9}, {3.7787353005126114`*^9, 
  3.7787354219987583`*^9}, {3.778736214619115*^9, 3.778736245427758*^9}, {
  3.7787362870793858`*^9, 3.7787363112676964`*^9}, {3.7787430335783377`*^9, 
  3.7787430370491047`*^9}, {3.7787441353332973`*^9, 3.7787441386519504`*^9}, {
  3.7787442145981627`*^9, 3.778744229751834*^9}, {3.7796015759902525`*^9, 
  3.7796015768776765`*^9}, {3.780367491005402*^9, 3.7803675057349386`*^9}, {
  3.7803675421185513`*^9, 3.780367543015131*^9}, {3.780367595292061*^9, 
  3.7803677584900455`*^9}, {3.780367791241578*^9, 3.780367803009241*^9}, {
  3.780368082056069*^9, 3.7803681064235888`*^9}, {3.780368473427268*^9, 
  3.780368486030403*^9}, {3.7803687542363663`*^9, 3.780368808812623*^9}, {
  3.781273038924157*^9, 3.781273047709667*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"b6f6c647-2ec4-42a7-b829-47b78b7246f0"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAqRDXAMBcNUF4/C/JbjjzP+5a+1Hx
XDVBowGFiiw48z80pR+jIl01QZTmCE7qN/M/wDloRYVdNUE//5zbZTfzP9Zi
+YlKXjVBaDf0EF028z8CtRsT1V81QakkTeRLNPM/WllgJepiNUEFLxwtKzDz
Pwqi6UkUaTVBL9zLQvAn8z/idlYQcnY1QePjmKk1FvM/PO1rFe2CNUGmq2g3
zAXzP77lD24pjzVBJaBO/Nb18j+3IQ5Eb5w1QQSRkv6s5PI/Mv+0WNKoNUGe
B5gdy9TyPyQgtuo+tjVBRQSEf7rD8j8+w0XQbMM1QRq0fE8fs/I/2gd+9LfP
NUEruCpAw6PyP+2PEJYM3TVB5PcpmD+T8j+BuUt2fuk1QdlYLXP2g/I/PmUV
qrH1NUG/KJR/GXXyP3JUOVvuAjZBekPtvhtl8j8n5QVLSA82QQHsSCdQVvI/
U7ksuKscNkEx6cBaaUbyP6gP4njQKTZBInNF5+828j9+B0B4EjY2QTWnak6g
KPI/y0L49F1DNkFs/E8lPBnyP5kfWbDGTzZB5ZmRkv0K8j/ePxTpOF02QZi/
l86v+/E/TOJddWxqNkE01xcHy+zxPzsmUEC9djZBL6hd3QPf8T+hrZyIF4Q2
QTkEdeMz0PE/idaRD4+QNkEquPVufcLxP5mBFerHnDZBPF0fxSe18T8gcPNB
Cqo2QYT6613PpvE/KQB62Gm2NkF4NcAQiZnxP6nTWuzSwzZB6ucWBkWL8T9R
KcpT/dA2QcjKn9RiffE/eyDi+UTdNkFnxK5ai3DxPxxbVB2W6jZBXTX1FLxi
8T8+N29/BPc2QYwVrrvzVfE/iZUYNTQDN0Hd2nOkhUnxP0s3HGhtEDdB+bzQ
aiU88T+OesjZwxw3QQ+vajzFL/E/SAHPyCMqN0EZdYSUdyLxP4QpfvagNjdB
F9LQUSYW8T/o07t330I3QUVrpdQrCvE/w8FTdidQN0H1BOZQSf3wPyBRlLOM
XDdBrL3lk1zx8D/0Iy9u+2k3QbVSdEyM5PA/8HhYfCt3N0HiRoTCE9jwP25v
Ksl4gzdBnSuVZ4rM8D9jqVaTz5A3QdXn4tgiwPA/2YQrnEOdN0EGB0sWp7Tw
P8wpeLl8pjdBTyrSPjWs8D90K40S
        "]], LineBox[CompressedData["
1:eJwVx1koA3AcwPGFB02Ua9GkJJqV3P7Rtr8/Ec0DcoU9MCuWuYpJeyLnFjYj
KZNjUrMWClm8EKHNsWy1hUTI+U/KVfh5+PbtE1bVUCBxYzAYwdD/E+09WVdz
iIz4BekdBooHOnNPVlcQifLXVLZNUByxs3Tvv4VIoG9baJmG4n2dB1sI5jI1
Rg64Xl4s7ADPxLQI3tUUr3G+DBTcuDEq0YJzlURm2UaEHZC5Zx2iuDnv6KV7
B5Hz6LSbjEGKN51Pb597iNyk8lpjVBSLl3FE3D4i2YZywY+SYk+VuqgGbExO
97SA8/lJK3ZwX0X1lBR8PamQLx8gYmN93+n7KWZKvL7qLIiYnWJLSB/FJr6I
OwseJE+LD70UF7JMZS6wzcwbWwdP7BaYc6yI3M5HS0vBsdxxReQhIvaxonBt
D8Wnbo8LIvCx1ZslBre7+GdasFmrZMaDt1WXfPcjRAwDjo/DboprJQn1qWDn
lP5VB/YRdOmawEL3lGcZeInlsM6Dh6fVDzxwyQvn9wKc3WC69wL/ARFtyUo=

        "]]},
      Annotation[#, 
       "Charting`Private`Tag$24797#1"]& ], {}}, {{}, {}, {}}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 1.032726208438321},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1560800}, {1.032726208438321, 1.2012775286564459`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7812730481923456`*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"bd152e72-59af-437c-a764-dc1cfd4daade"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAqRDXAMBcNUEEyIINTEP8P+5a+1Hx
XDVBL83XzglD/D80pR+jIl01QSCyW5LHQvw/wDloRYVdNUHLyu8fQ0L8P9Zi
+YlKXjVB9AJHVTpB/D8CtRsT1V81QTXwnygpP/w/WllgJepiNUGR+m5xCDv8
Pwqi6UkUaTVBu6ceh80y/D/idlYQcnY1QW+v6+0SIfw/PO1rFe2CNUEyd7t7
qRD8P77lD24pjzVBsWuhQLQA/D+3IQ5Eb5w1QZBc5UKK7/s/Mv+0WNKoNUEq
0+phqN/7PyQgtuo+tjVB0c/Ww5fO+z8+w0XQbMM1QaZ/z5P8vfs/2gd+9LfP
NUG3g32EoK77P+2PEJYM3TVBcMN83Bye+z+BuUt2fuk1QWUkgLfTjvs/PmUV
qrH1NUFL9ObD9n/7P3JUOVvuAjZBBg9AA/lv+z8n5QVLSA82QY23m2stYfs/
U7ksuKscNkG9tBOfRlH7P6gP4njQKTZBrj6YK81B+z9+B0B4EjY2QcFyvZJ9
M/s/y0L49F1DNkH4x6JpGST7P5kfWbDGTzZBcWXk1toV+z/ePxTpOF02QSSL
6hKNBvs/TOJddWxqNkHAompLqPf6PzsmUEC9djZBu3OwIeHp+j+hrZyIF4Q2
QcXPxycR2/o/idaRD4+QNkG2g0izWs36P5mBFerHnDZByChyCQXA+j8gcPNB
Cqo2QRDGPqKssfo/KQB62Gm2NkEEARNVZqT6P6nTWuzSwzZBdrNpSiKW+j9R
KcpT/dA2QVSW8hhAiPo/eyDi+UTdNkHzjwGfaHv6PxxbVB2W6jZB6QBIWZlt
+j8+N29/BPc2QRjhAADRYPo/iZUYNTQDN0FppsboYlT6P0s3HGhtEDdBhYgj
rwJH+j+OesjZwxw3QZt6vYCiOvo/SAHPyCMqN0GlQNfYVC36P4QpfvagNjdB
o50jlgMh+j/o07t330I3QdE2+BgJFfo/w8FTdidQN0GB0DiVJgj6PyBRlLOM
XDdBOIk42Dn8+T/0Iy9u+2k3QUEex5Bp7/k/8HhYfCt3N0FuEtcG8eL5P25v
Ksl4gzdBKffnq2fX+T9jqVaTz5A3QWGzNR0Ay/k/2YQrnEOdN0GS0p1ahL/5
P8wpeLl8pjdB2/UkgxK3+T+g949p
        "]], LineBox[CompressedData["
1:eJwVx2kow2EcwPE1R3ImUXihvaC10txP1N/jeWNpI+So1aIxV0xDlPZCk6O2
3KzmSjnmLsefKG8sx2SkoYwJ82IilOQZxc+Lb98+PHltroLL4XBCof8nXHSk
P0wjwrNXOddYirtaJWcbLCLrdsdUvpHiyL2Vp6BdRCauzXI0SrF5zD1cDGbP
He8eYGVTgVgDFn7va6wjFG/yXfNv4J9O56wKLNGSmmMTIjO3er+FYYrrsk9f
2/cQqaJ9Ap6B4p2rlw96iEidZ/eWr57iklUcGWtGxNq4pLENUeyl682vACdz
ByVz4Bwmkb0AB/M3HkVgx7i6afUIkaL7zOjWQYq9FT6u6mNERNNsoKuf4mVG
JpgEh/ulfR6A80KWpTZwUUf3tR48up+7nWFBpL6hZSkRHCMwqKNOEJGXGstV
fRSfc58XZGCZoViaBm62MTcDYFGxPSsAbNLdMW6niCCpgFnspbhSEa9MAZfV
fCWpwf6pbWMq8KVFGycGr4RcWozgCKVDGAYufOX/3oKtKVyhs4fiP/pxzCQ=

        "]]},
      Annotation[#, 
       "Charting`Private`Tag$24841#1"]& ], {}}, {{}, {}, {}}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 1.5978786312368145`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1560800}, {1.5978786312368145`, 1.7664299514549393`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.781273048260178*^9},
 CellLabel->
  "Out[146]=",ExpressionUUID->"dbad26ee-e9fa-438e-9ad4-a275d6a3a22b"]
}, Open  ]],

Cell["Density as function of depth in Europa.", "Text",
 CellChangeTimes->{{3.7812730632610545`*^9, 
  3.78127307270481*^9}},ExpressionUUID->"031829c0-60a0-408c-aef5-\
58f2a05b41b8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rho0", "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1000", ",", 
        RowBox[{"r0", "\[LessEqual]", " ", "r", "\[LessEqual]", " ", "rc"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"934", ",", 
        RowBox[{"rc", "<", "r", "\[LessEqual]", " ", "rEur"}]}], "}"}]}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"rho0", ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "r0", ",", "rEur"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.778735583191701*^9, 3.7787356358229265`*^9}, {
   3.778736263358802*^9, 3.7787362677291293`*^9}, 3.7787363143783393`*^9, {
   3.779601603909593*^9, 3.779601639580223*^9}, {3.7803675815442195`*^9, 
   3.7803675863153563`*^9}, {3.7803677662355394`*^9, 3.780367778806939*^9}, {
   3.780367817670162*^9, 3.780367819844539*^9}, {3.7803680263291736`*^9, 
   3.780368065428623*^9}, {3.7803681213078127`*^9, 3.780368125478157*^9}, {
   3.780368488448464*^9, 3.780368492651499*^9}, {3.780368538856307*^9, 
   3.7803685396011057`*^9}, {3.780368782440383*^9, 3.7803687836559887`*^9}, {
   3.780368814489102*^9, 3.780368814703537*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"5b5acca3-a1c3-442b-a9a0-9f9740f9fe63"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"rprime", ">", "0"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{"rprime", ",", "Reals"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7787438709624414`*^9, 3.7787438931339445`*^9}},
 CellLabel->
  "In[158]:=",ExpressionUUID->"7c536099-2408-4e7e-99bd-56967249d524"],

Cell["\<\
gr picks a side for the calculation (granti or grsub).
p then uses the barometric formula to calculate the hydrostatic pressure as \
function of depth in atmospheres.\
\>", "Text",
 CellChangeTimes->{{3.781273083767211*^9, 3.7812731340906353`*^9}, {
  3.7812732991771736`*^9, 
  3.7812733054174747`*^9}},ExpressionUUID->"9a97cf0e-61a3-4832-bb1c-\
780b6e99a5be"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gr", "=", "granti"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"rho0", "*", "gr", "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "/", "rprime"}], ")"}], "^", "2"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "rprime", ",", "rEur"}], "}"}]}], "]"}], "/", 
    "101300"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p0", "=", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"r0", "^", "2"}]}], "*", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"rho0", "*", "gr", "*", 
        RowBox[{"r", "^", "2"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "r0", ",", "rEur"}], "}"}]}], "]"}], "/", 
     "101300"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pc", "=", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"rc", "^", "2"}]}], "*", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"rho0", "*", "gr", "*", 
        RowBox[{"r", "^", "2"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "rc", ",", "rEur"}], "}"}]}], "]"}], "/", 
     "101300"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", 
    RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.77873565536569*^9, 3.778735680858493*^9}, 
   3.778742958029606*^9, {3.7787438571231337`*^9, 3.7787438609912558`*^9}, {
   3.77874390025723*^9, 3.778743922405126*^9}, {3.7787440608156977`*^9, 
   3.7787440671578894`*^9}, {3.7787441740414324`*^9, 3.778744195455573*^9}, {
   3.778744237128352*^9, 3.778744345282296*^9}, {3.778744383633453*^9, 
   3.7787444403394556`*^9}, {3.7787445410692024`*^9, 
   3.7787445416826077`*^9}, {3.778744673793969*^9, 3.7787446743993816`*^9}, {
   3.7787486159067154`*^9, 3.778748616480914*^9}, {3.7796016416524787`*^9, 
   3.7796016458890085`*^9}, 3.7796087197989006`*^9, {3.779610947524977*^9, 
   3.7796109508322554`*^9}, {3.7803339124848237`*^9, 3.780333917508275*^9}, {
   3.7803678882760153`*^9, 3.7803679027439423`*^9}, {3.780367987207032*^9, 
   3.780368019532776*^9}, {3.781273150184632*^9, 3.781273156072853*^9}, 
   3.781273284710881*^9},
 CellLabel->
  "In[164]:=",ExpressionUUID->"b0dd1d5a-3d85-4824-97dd-af14346f9d29"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0Hs0lAkYBnA0laVmqnFtraLrupSmvu9ro3rfdhFtURPHVlSaoRlNcYgc
k8uGzCrLjFzGZYYxM5TQOZKRbGe3MpXIYctErSYpam3Uruy27Ld/POc5vz/e
857zOIWf2MM3MzEx2Unn/+4p15vcPEBgxTrje4ajFjR9k6ZjtH2u5l2e46CF
U4tWzXIIJXCR29o488VacMjMmH2Kdskszup5NlrgibZZeIQRmNHl52rF1MIH
z1a28iCBXxYEla2c1oCVoX5lajiBdx6J3YOeaSCYXfgtHCVQcYn9oq9cA2uT
R6A5jsDdQewXz601MKxuqTuQSuAuhkvnrwVq+DjRpL6TTeACWWsd63M1HCIp
79VFBO6RP6+puVAFGpIMa1IR2NSdbfhoXwVfu+uWeDUQ2LewVHY/XwWefpHC
s60EmibEO75ZpIKFzvlrZtoJ/HDERfKDvBI2j39TcryXwNk3CdFju0rwPR2X
ZjFI4NAylj5LWQG1a7reRb0h8IbigX2gawUcfXTZ/PYkgclTN1vf1irBzNNS
7j+LxHm9qSGtlBImLrztaWeRKFe6rmDEKmCzzVSBhQOJcwMzE/Xicojgpvck
riLx9PJ0QW5RGbzMlDUPrifxjxUyP2llKWxLcLKN20riWv8WL35bCfwZut5x
ZgeJFw/VTDTo5cAQRtcFhJD4+IBzoKmhGMY5bs0dR0hcIAz/8dbfRbBhIkqI
0STaxb+b8rcsgqDjLgXGJBIfGiUDbPdC6GZZ7fA7S6JT/a2M1L0FoNKmVWtl
9L/AdTaTwgvA/SRK4ShIbNtfWx4izYfvfJ9NN14iURor2T5dLYPr1xLn/nuN
xMN1bQLubSn8MySTxPxCYrG+UeI1kQd55pzGp10kxmjDuuuYeTB7ZFdIfD+J
InETP8szF3rHCjJ6h0k0NFmZRffnwNRo+H6X9yRyCp908Jach0+qyxdrp+k9
q/1TMs9kQzBXXLnSksKeex7dNe0SyPnpLvuBDYW67KQtVa5Z4LR7G/MrZwrV
B413J4szwcKw5UrpGgobJpNf3nudDt1ftDxw20Th4mHFK0PwGRgL0UkbfShs
Z9ouf6hOg0jdi0FTLoUnroWiYDoF2h6dq04Ko3BclL/35JgYokZ1dr8LKXQP
uN/jXZEIf7XwzbLjKTwq3KlvyY2HgQavk2NpFHbVe97tlMWCXVlhrl8OhZwP
DE7evmjg+MSs6C6m0LE4rfmKTgjlYX1KhpxCxWuDiKkQgkXCVoeNtN2PndNH
pQvBqJ3PVtAeChgWrQ4QgvSziyaiEgo3hOoSaoYEMN5h7DcvozCN5fX9PZYA
Grh7paCkkPemzTsrIhIcjl2fH0dbGjBaPLUjErLSnSVa2rbxldKodZFw6Oq7
FGYFfX9CEbP7UwSwbM+LBmg/f2X3crk0Ao4/ub39lIrCzNiY0tEbfHgy4Xbr
Eu05IgEZoeKDj2X+1t9ozzw9G2fM4oOjVzjpU0XvWeb4dIDLh86y6WVWagqr
RkwOGkZ4sKmJr/ClbTWeaL+viweazo7FSbSZEcMJ/Y08SJ6RLzTSFtunLh1M
4cGordl5aw2F3kVK4RE+D4I9BOZ+tK3nloS88ufBz9sfnhHTDpwjGI3y4IH7
YWqmnjaxkbF03JoH/wFhdCuc
       "]]},
     Annotation[#, "Charting`Private`Tag$233372#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1550000}, {0., 2959.0096731839735`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7787356815965185`*^9, 3.778736273047865*^9, 3.778736317695484*^9, 
   3.7787429587893515`*^9, 3.778743040828639*^9, 3.77874386268029*^9, {
   3.778743896723104*^9, 3.778743924946876*^9}, 3.778744070098489*^9, 
   3.778744155413555*^9, {3.778744187226867*^9, 3.778744198593531*^9}, {
   3.778744281618084*^9, 3.778744346493347*^9}, {3.7787443923381376`*^9, 
   3.778744434795265*^9}, {3.7787445241574187`*^9, 3.778744544528578*^9}, 
   3.7787446774259653`*^9, 3.7787466108636866`*^9, 3.7787486194295425`*^9, 
   3.7796015670499735`*^9, 3.7796016579934635`*^9, 3.7796087215171075`*^9, 
   3.779610952496702*^9, 3.7803327287353587`*^9, {3.780333912999452*^9, 
   3.7803339194402485`*^9}, 3.7803670478444567`*^9, 3.780367828126199*^9, 
   3.780367905013027*^9, {3.7803680339568195`*^9, 3.7803680702509117`*^9}, 
   3.780368129482044*^9, {3.780368525472674*^9, 3.780368544272746*^9}, 
   3.7803688202196474`*^9, 3.7803759873543386`*^9, 3.780389370668455*^9, 
   3.780571556348678*^9, 3.7805738315086718`*^9, 3.7812690571155076`*^9, {
   3.781273208341077*^9, 3.781273208605372*^9}, {3.781273280420323*^9, 
   3.781273287806571*^9}},
 CellLabel->
  "Out[168]=",ExpressionUUID->"433d4fec-1805-4c60-b8c8-7f01d0bea84e"]
}, Open  ]],

Cell["Pressure at seafloor and top of the ocean in GPa.", "Text",
 CellChangeTimes->{{3.7812731829050975`*^9, 
  3.7812731932444468`*^9}},ExpressionUUID->"40cd50d9-d978-4a26-b693-\
d29706cd3832"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"p0", "*", "101300", "*", 
  RowBox[{"10", "^", 
   RowBox[{"-", "9"}]}], "*", "GPa"}], "\[IndentingNewLine]", 
 RowBox[{"pc", "*", "101300", "*", 
  RowBox[{"10", "^", 
   RowBox[{"-", "9"}]}], "*", "GPa"}]}], "Input",
 CellChangeTimes->{{3.778744657040239*^9, 3.778744667135917*^9}, 
   3.7787466157892017`*^9, {3.7787486313246136`*^9, 3.778748636960618*^9}, {
   3.7796035114784575`*^9, 3.7796035148386016`*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"fbd740d1-0f33-4cda-aaae-6008d43d70b9"],

Cell[BoxData[
 RowBox[{"0.299747686611825`", " ", "GPa"}]], "Output",
 CellChangeTimes->{{3.778744667519943*^9, 3.778744683915815*^9}, 
   3.7787466161281967`*^9, {3.778748621258828*^9, 3.7787486374044685`*^9}, 
   3.7796015675163527`*^9, 3.779603515515791*^9, 3.7803327299354486`*^9, 
   3.780367049195021*^9, 3.7803759883613176`*^9, 3.780389371662458*^9, 
   3.7805715573796415`*^9, 3.7805738324680567`*^9, 3.7812690581286435`*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"e135f168-5258-4d27-962b-919596f0f46d"],

Cell[BoxData[
 RowBox[{"0.016277454826526958`", " ", "GPa"}]], "Output",
 CellChangeTimes->{{3.778744667519943*^9, 3.778744683915815*^9}, 
   3.7787466161281967`*^9, {3.778748621258828*^9, 3.7787486374044685`*^9}, 
   3.7796015675163527`*^9, 3.779603515515791*^9, 3.7803327299354486`*^9, 
   3.780367049195021*^9, 3.7803759883613176`*^9, 3.780389371662458*^9, 
   3.7805715573796415`*^9, 3.7805738324680567`*^9, 3.7812690581326265`*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"e20bb5a4-056d-4143-9fbd-6c29bb52b015"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Density", "Section",
 CellChangeTimes->{{3.7812734220615454`*^9, 
  3.7812734228754025`*^9}},ExpressionUUID->"544ba0d5-6e9d-4dad-bde5-\
3e028f55dcea"],

Cell["\<\
Density as function of depth, taking the compressibility of water into \
account.\
\>", "Text",
 CellChangeTimes->{{3.781273196782985*^9, 
  3.781273211549497*^9}},ExpressionUUID->"782ad1c4-4df8-4e93-8189-\
c67ac7852813"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rhow", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"rhor", "=", 
  RowBox[{"rhow", "/", 
   RowBox[{"(", 
    RowBox[{"0.99523", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "3.20629"}], "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "5"}]}], "*", "pr"}], "]"}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"rhor", "/.", 
    RowBox[{"pr", "\[Rule]", " ", "p"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.779601707881651*^9, 3.7796017243604503`*^9}, {
  3.779604658864149*^9, 3.7796047865999527`*^9}, {3.7796048298481812`*^9, 
  3.7796048733072376`*^9}, {3.7796054873409615`*^9, 3.7796055531288476`*^9}, {
  3.7796056459878893`*^9, 3.7796057446343784`*^9}, {3.7796076693481555`*^9, 
  3.779607669550474*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"78477ed8-c163-4936-8b2a-4aaf06ef625c"],

Cell[BoxData[
 RowBox[{"1004.7928619515087`", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"0.0000320629`", " ", "pr"}]]}]], "Output",
 CellChangeTimes->{{3.7796047306916075`*^9, 3.779604760150479*^9}, {
   3.779604838795245*^9, 3.7796048737879353`*^9}, {3.779605530942904*^9, 
   3.779605553519244*^9}, {3.779605705301566*^9, 3.779605745906721*^9}, 
   3.779607670046131*^9, 3.780332729981325*^9, 3.780367049225938*^9, 
   3.780375988396515*^9, 3.780389371690531*^9, 3.780571557428796*^9, 
   3.7805738325230784`*^9, 3.7812690581655083`*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"3b32e023-e79d-44c8-97e6-ea34703f83ad"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0HswlXkYB/DjNp3I9eSSpKHoMpFR7/smNs+DPTlRTZ0NzeZUbBK5bUJz
SrRLSXl/r+tGLnU6tBSarEvaVRuLliSmVJTsZiu7kraL7Sz72z+eeebzz/e5
2IXEbN2jLRKJNtL6v/eVdIhu7GBQbZVWtMxbgPKBD1rj1D3eFgf1qJPMlujY
BDPoWjK0+ZmXADbpaXpJ1JILRrPPUH8V5aXvomDQ3/9jhpj6b/frkrKdDB64
N9j2Bwgw92GNY0oIgya6qQ4V6wQIkBT4QziDZtFjKcvWCrAy+SU0xjN4VOPr
dsRFgFH1teodKQxaLc2Zn7FEgI+T9epfMhnUKptzot9WgF0s9/nS7xjUZP1Y
lGhO92VZRb2KQYs4jyvdcwTwdmpa6FHL4MIUs4JkHQHcZXsjjl9n8CHGx8T8
Q8DUPtd5pp3BnMUZnNEkgc/e+BRF9zNo2NKcbPCSwPoj8an6wwyyz1ys64YJ
XHLumYgcY/D7BFlswQCB8PuXxW0fGLz5fnvLYA8BbXeDwg06LH5S3GzpaCcw
mfdnX7sxiycvBhbMa6H5FlP5+jYsSstCs9T1BMLk3/YdWsKiuYV/eV81gefp
OY3Dq1gsendifF85Aa9EO8t4TxZLrF9Pl5YQeBe8ynbGj0UTH/v3kE9ANyK2
enMQi7V2hkrrLAJvXFc0doWymNmVmMSnE1g9GRmBsSxad3Qe/zqZwLbo5fkj
ShbVigUD4wkEeo3n+smOsxhaHSAtjSGgqki9WJHDYrpmsPXGXgJyTdRR11I6
33SUJO4isH39k+m6Khb1lDufnwsi0NxwaNa/DTQvdVudaAuBT7/nZMTdYvHB
oqqxCRkBQexaN9TD4pE4Iz7Qi4Dey01BCY/pf946FW50J9A/np/WP8piYGf7
gvjVBKZehXy5/C2L61SNHRInAhrV5cpL0yzWz17p6+lIIEB++LyjAYed+/JW
jtoSyGrplHRbcJgnz9WztCJgt8XLyM2ew6oZh/AEUwL6D9ddOevM4cSa/Nty
fXrvgmvdK9ZyuP/Y1YYGHQLjQU3ZdVIOdTL9CDfFw96m34a15Bwuunn1QPAY
Dz/dP3VRqeDQd79jc8YTHiJfNVn9FcEh0Xnh33yXh/fX9mhnJnDYLh7ofX2L
h8Faj4PjqXS/ZgWrbODBqriAyLI4tLs3rTKp5MFVGufQe4bDQHbe0PliHkoU
A2W6hRzK5iwmkdT6iZ42a6iVT0d9VlOPVBhKSqnDl+VebTvLQ/bsSlFUEYei
6ZPqF0U8vOkaeSwu5tDN+8Fj50IeauVfZEMZhy+kgcL1fB5s9jcbxlMvNXZT
plGf+NY+o4Lagbkbtol61w8TR43OcVghtfUezuPB2PJ01CD1ryxnoksd/ajN
N0lF/zNrg8Yvh4dHkytaq6hbhxO1zKmlBrmeT6m33t4ufpLNg61HCCu9wGHy
Ibf5sdR3iqcXzVVzyGiFbcsVeFhbv6d0PfUOM9fwYOryO13WSuruU1cOO1In
zxSajlCHRdyubCQ8vLLUPm1ezuGUKrQ1lTrAZZ9YRl3/tubpBuqffe9+c5i6
16dGI6F22s3N1FBnHts9f4jn4T8O1CTo
       "]]},
     Annotation[#, "Charting`Private`Tag$7353#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 1009.9829623811687`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1550000}, {1009.9829623811687`, 1104.790632323865}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7796047306916075`*^9, 3.779604760150479*^9}, {
   3.779604838795245*^9, 3.7796048737879353`*^9}, {3.779605530942904*^9, 
   3.779605553519244*^9}, {3.779605705301566*^9, 3.779605745906721*^9}, 
   3.779607670046131*^9, 3.780332729981325*^9, 3.780367049225938*^9, 
   3.780375988396515*^9, 3.780389371690531*^9, 3.780571557428796*^9, 
   3.7805738325230784`*^9, 3.781269058228376*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"f9eebc49-09b3-4509-84d6-2e9860d4715d"]
}, Open  ]],

Cell["\<\
Change in water density per unit length as function of depth.\
\>", "Text",
 CellChangeTimes->{{3.78127324412938*^9, 
  3.781273271884182*^9}},ExpressionUUID->"63b5cc77-72fe-4153-be3e-\
0252af3cef17"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dpdr", "=", 
   RowBox[{"D", "[", 
    RowBox[{"p", ",", "rprime"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", "dpdr"}], ",", 
   RowBox[{"{", 
    RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.779608672646337*^9, 3.779608706494974*^9}, {
   3.779608743213956*^9, 3.779608775365102*^9}, 3.7796088234371004`*^9},
 CellLabel->"In[89]:=",ExpressionUUID->"e1806262-93dc-4d63-b606-e5f7713c8ee9"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0ntUjHkYB/AUZ8ZUnBSlotuqztDlTPv+XoSnp12NImtFtTapLNkyxRYm
k2hLdFp5531nXrYUNpVbF07SzbZrN9dBaEtktVEhRsUu1qX97R/P+Z7PH9/v
X49LXPLSNaYmJiah9P7P28WXTH6JYjCpXDEQ7CNC2Z3Xo4zU56ykZg3eIqgn
eJg5rmTQ1yHAWU7tmLNzjJoaJnckyLxE+EYVKPONZlDqVhBwVS7CK/8m60Or
GMzZDsZQdxFsOqvcd8QxGCLELImYIkK49b5FAesY9HFpdd1qLoJPxpOAulQG
WzzFNEmvHvpKGyqjdjDolRKl3vqrHt4M15ZeyGPw1dm994eL9RBD2Pme+xkM
rbS53JmmhzJComtLGMxKGXNyb4QePvOqd5pTzeBS+1bVeYUe/IPjE3Y1Mbgq
ecUf78fpwcpV5z1ykUGb+CWGF891MHfo88KkNtpXF6ZuuKID5bbUTFk3gw/P
tLsXH9PBSe8bg4kDDF7qf5TclKuDde0V0pbXDNp3ey1Xx+vA1N+8IMSMoKaq
v9Sg1MGw/tnti+MJCnaep65Oo/uT3ooyR4IV7J2Uc6N1sDYs+3aaB0Gd03fo
1ydAb45Q1+1H0C2n3nd1iwCBW1xsU4Egs97slEW5AH+v9Js6spDuLY26kp4j
wOiEDZVfRBLcmF8a17ZWgCHFjDrDaoJ+gbd8+GABPh1OTMANBEtWNM2aJhdg
eZJc7NEQ7I+TZdtYCnBzvM3C4F0EJa5vYjoGeSgpzzxaLhDcFBsTse0WD2Hv
VdsVBwlWLzPUqmp5+Er558eaEwTn3h8oXLSfh8azaZIPZwlq7777YKLh4d0j
IXfjbwTVXfvcjKt40EoVNfdvEDwS7za3I5CHMU8WR26+R7CJOy0Z9OChzSju
bOsjeHyh3MNgycPbp3Ffy18SlLE1L6uHtPC+pOL4yY8ExW5X+ZkOLYSHpf/k
bs7idM3YXEOjFvKbL1tfm0Sdklrx72EtuHwZOG6WK4urQzvyHu7Wgqxz3qkD
3iw61eHpAZUWbk5puDZjNotuyr8c3i3TgjGynq8JYvG1BX/Fb7YW4usfdo8K
Y9GOcX7u6ayFn9t/OKqJZjGq5MWbiVItJD6tt3uewKJ0Pmsx08jBPw1rTPM2
s9iyFj8Jaeegq3rOJmMmdeuxR9JmDuyK9nHB+SwmJ4bckpRxoAjaOO3mjyyq
ey+Ij/M5KI6+c2h0AYsFpeHXMqllW8BxJnV9Z5/Egbqn3NL6IPX+Pklu6B4O
+LHHTVSFLD7Zq2w8ncfBkKHnnrSIRXsr/YNtuzmoDlvGBxxiMeu6p7vt9xw4
rm+0TKW2Wp/UVZ3Jwe5s19xy6tiLlWIIdcyZwe3jDrPoMMrJNmMHB+Nt96i6
qNNz6pS9GRwk3W1ZoC5hMc/iaHyNhoO7wzN+P0FdpMheuZg6yFwHD6gH5kVG
PN7KwdQ5cSToCEv/pT/ckfp60Uc3m1IW8zMO7MxWczC7ds1BJbVzt6JwKnXZ
dYO9hnrCueaaui0cZIwUWPVQd/o1vXy2mYOntqZ7JpaxaJ0yffIu6nDfb6XB
1GlqLtCF+vyC1qx06vOTBpIbN3HgFcuOVFFXOfsfXk79H7CDJAg=
       "]]},
     Annotation[#, "Charting`Private`Tag$7448#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 0.016072595563657085`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1550000}, {0.016072595563657085`, 
    0.021664767246569232`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7796086759868426`*^9, 3.7796087070967913`*^9}, {
   3.779608746515505*^9, 3.7796087758304186`*^9}, 3.7796088237634*^9, 
   3.7803327301851454`*^9, 3.7803670493935995`*^9, 3.780375988608121*^9, 
   3.780389371855412*^9, 3.7805715576645813`*^9, 3.7805738326647587`*^9, 
   3.7812690583550344`*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"82340e7c-211c-4a80-be15-8dc0dbbf6c4f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating the balloon sizes", "Section",
 CellChangeTimes->{{3.781273443564045*^9, 
  3.781273449142128*^9}},ExpressionUUID->"61f361cb-02f6-4997-b8fe-\
b9c56e893a1c"],

Cell["\<\
Example calculation to find the volume of the balloons as function of pressure.
Vbalp is the volume of the balloons as function of pressure.
The last outcome of the calculation is the volume the balloons should have at \
3000 atmospheres of pressure.\
\>", "Text",
 CellChangeTimes->{{3.781273339602092*^9, 3.7812733611045885`*^9}, {
  3.781273464605774*^9, 
  3.7812735554697876`*^9}},ExpressionUUID->"ead1bcde-4f2e-4dde-aa3d-\
7d0c131553ad"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mcom", "=", "800"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vsub", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Vbal", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      FractionBox["mcom", 
       RowBox[{"Vsub", "+", "Vp"}]], "\[Equal]", 
      RowBox[{"1004.79", "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"3.20629", "*", 
         RowBox[{"10", "^", 
          RowBox[{"-", "5"}]}], "*", "pr"}], "]"}]}]}], ",", "Vp"}], "]"}], 
   "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Vbalp", "=", 
  RowBox[{"Vp", "/.", "Vbal"}]}], "\[IndentingNewLine]", 
 RowBox[{"Vbalp", "/.", 
  RowBox[{"pr", "\[Rule]", " ", "3000"}]}]}], "Input",
 CellChangeTimes->{{3.779609848419223*^9, 3.7796099704016104`*^9}, {
  3.7796100555161667`*^9, 3.7796100643350787`*^9}, {3.779610203120221*^9, 
  3.7796102115929685`*^9}, {3.779611008966564*^9, 3.779611052641984*^9}, {
  3.779611121352433*^9, 3.7796111687131696`*^9}, {3.779611299183672*^9, 
  3.7796113236445026`*^9}, {3.77961158097013*^9, 3.779611623657359*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"97721cdb-ef55-46b1-ad44-174b1f0255cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Vp", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "0.5`"}], "+", 
    RowBox[{"0.7961862677773465`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "0.0000320629`"}], " ", "pr"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.77960991615965*^9, 3.7796099389864254`*^9}, 
   3.7796099720019464`*^9, {3.77961005748042*^9, 3.779610064716091*^9}, {
   3.779610208734541*^9, 3.7796102119098434`*^9}, 3.779611054545154*^9, {
   3.7796111222415795`*^9, 3.7796111360260735`*^9}, 3.779611170110137*^9, 
   3.7796113520116873`*^9, {3.7796115844436674`*^9, 3.779611623938379*^9}, 
   3.7803327302300262`*^9, 3.780367049430501*^9, 3.7803759886487403`*^9, 
   3.780389371901944*^9, 3.7805715577294507`*^9, 3.780573832716523*^9, 
   3.781269058391901*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"d6997b62-7771-41bc-884a-6f094a567f60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.5`"}], "+", 
  RowBox[{"0.7961862677773465`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0000320629`"}], " ", "pr"}]]}]}]], "Output",
 CellChangeTimes->{{3.77960991615965*^9, 3.7796099389864254`*^9}, 
   3.7796099720019464`*^9, {3.77961005748042*^9, 3.779610064716091*^9}, {
   3.779610208734541*^9, 3.7796102119098434`*^9}, 3.779611054545154*^9, {
   3.7796111222415795`*^9, 3.7796111360260735`*^9}, 3.779611170110137*^9, 
   3.7796113520116873`*^9, {3.7796115844436674`*^9, 3.779611623938379*^9}, 
   3.7803327302300262`*^9, 3.780367049430501*^9, 3.7803759886487403`*^9, 
   3.780389371901944*^9, 3.7805715577294507`*^9, 3.780573832716523*^9, 
   3.781269058403869*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"9464bfc6-5b90-45ba-84eb-95242065587f"],

Cell[BoxData["0.2231700992900082`"], "Output",
 CellChangeTimes->{{3.77960991615965*^9, 3.7796099389864254`*^9}, 
   3.7796099720019464`*^9, {3.77961005748042*^9, 3.779610064716091*^9}, {
   3.779610208734541*^9, 3.7796102119098434`*^9}, 3.779611054545154*^9, {
   3.7796111222415795`*^9, 3.7796111360260735`*^9}, 3.779611170110137*^9, 
   3.7796113520116873`*^9, {3.7796115844436674`*^9, 3.779611623938379*^9}, 
   3.7803327302300262`*^9, 3.780367049430501*^9, 3.7803759886487403`*^9, 
   3.780389371901944*^9, 3.7805715577294507`*^9, 3.780573832716523*^9, 
   3.781269058406888*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"6bb2d641-cc55-4620-b68a-5fb446f3d891"]
}, Open  ]],

Cell["\<\
These plots show the volume and density of the balloon as function of \
pressure and depth.\
\>", "Text",
 CellChangeTimes->{{3.781273569727461*^9, 
  3.781273597945998*^9}},ExpressionUUID->"9f92af0d-bff5-406b-8cb6-\
24e09d885bf1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{"Vbalp", ",", 
   RowBox[{"{", 
    RowBox[{"pr", ",", "0", ",", "3000"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"rhocom", "=", 
  FractionBox["50", "Vbalp"]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"rhocom", ",", 
   RowBox[{"{", 
    RowBox[{"pr", ",", "1", ",", "3000"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["mcom", 
         RowBox[{"Vsub", "+", "Vbalp"}]]}], "+", "rhor"}], ")"}], "*", 
     "mcom"}], "/.", 
    RowBox[{"pr", "\[Rule]", " ", "p"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7796111870320635`*^9, 3.7796113454263573`*^9}, {
   3.779611383339086*^9, 3.779611386465937*^9}, {3.7796114382637615`*^9, 
   3.7796114881528215`*^9}, {3.7796115280880957`*^9, 3.779611542955577*^9}, 
   3.779611651438773*^9, {3.7796118327634435`*^9, 3.779611833794169*^9}, {
   3.7796118775076303`*^9, 3.779611877627278*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"091a69c4-6a8b-434c-b9ff-dd9e0e403db5"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVzns01AkUB3DaTsmwRquaxK5HhTStU6Is3Su9VETjUTm7KaSOV1OLQqVs
ym55P8Y0pDEzP1qGbEiIRMRvxm9+TbYcjR7O5pVXHkltO/vHPd/zOeee+72m
RyP2B83T0NBwU8//aVNVX3NXhwnT6fedqidpsD5j5/YP9z1YFr6u8VLbNi3A
UML9Al1WrXYTH2ioMf6kkcjVxbFM2Xq22nMB2ycjucb4uKZ1Q+E4DUYLh96H
cdnYPxdxMGWEhtLn9YMnuE7o75m44Xg/DZHOFgPBXDeUtpw1M+qh4dXB7WnB
0l9wsDaFH/eQBjc7522l7cdQlKS5r7SIhpesjZ9qWeHISxIcPpZKw70u90vi
eaexvUCqNI6iIXhmlcqxMgr589+LhD/TwOLaBxpUx+Cg+cY1li40HM05fcVO
ch6Pf2S/sLOiQWt3MSotLyLlrT2lp6/un6zcz16dgJsE/TeHpxUwpG3gIdW8
jEX+uzalqxSwNXqhQPk0EQ81XJyrf6wAQybrC192FVVT9/XHShSwyiDGNUn8
Ox7q7nfuz1TAnW2zt5eJr6Fo6pX2QIwCkjp0/fbcSMZ1Ufy2k0cU0K7aHPvU
PhXDu6iGWlcFMMNjOYqNaehzPtlosY0CRiuCTN+apWP56TiHNSwF6CWrZpvN
M7B78JKGx78UeBsIz87+kInfX/zu8lwfBbYe3446M7JwsR97JEhGgZfZoohD
2tn4WU+v7dVfFOjeLulL/JiNdUVLmcsFFAz38DUXvMnBeN1OK+VvFOhIlll5
9/KQl5YSLAyhoGWl0457HblY1NznYe1FQcPm8bChDj7OX+Ka/cSBgt7ZUUdu
6w1c6ht2asiUAl5EjiajQoCBWzStW7QpSI+VUb+W56FX3JPpsLedsMqpJGsi
Lx8NjBO4D+52gqr4meajxJuY+uKBH/NKJ4R27ai741yAJDXWlOPdCVXroyf+
qC5ArSz93ESLTjDpHmG7299CnczknWVTcvDtcQjkS29h6EBRkmOrHExt146k
mAuRSWSPt+XKgfF34LkwoRDjGX3Rmcfl0KTkLnzGKkRlqZDd4CCHXOPH2Stz
C5G5c7kve5EcvqlrOGu8TIQm0YYWgucycKi87ltwTYSWI6+LA/+UQdqs0IGh
I8aTF4amI2NkUMm7xtJIEOOB8ClL1V4ZhF5fsTt/Roxal7uDnE1k4CIbj18Z
JcH5vBD+xCgJ74IFFbbDEsx09zsx1USCqudOr8uIBEteut5bq7bSs1WHMybB
tQWDWoEPSWj6aeIYd1KCjeVby+gGEvL1dq2QfpZgXO5eZnkdCT7VHxIsdAkM
5TSbh1SR0LJgj7fhOgI96qxS3xSTUBfrf8nKhsC9eb5LDNWuGIss27SeQC9H
e4FnEQkF3QWLfO0IHBYzyholJMRJp+sztqjvNWoN5BeSYOsjXK27j8DJlx5S
vzwSrDuqOUaeBH5+x3PPEJBghrJ4a456PzJ9rP0GCcw1H7tdfQnsZ/A3O/BJ
GP7ilpJ4mMDyxk+9rBwS3p4KqMs6QmDcBfl1j2wSut+dGRAFEOgv4jhdzSKh
TVHo8iiYwB79U7dmMkho2FFzkj5BoBGH4fOj2lW18rzXIQRSQ946wekklNj0
tY+FEXjguWdzfhoJheLZma8R6v8Mvp7rSiXhP2OGam4=
       "]]},
     Annotation[#, "Charting`Private`Tag$7492#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.22317010070961618`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3000}, {0.22317010070961618`, 0.29618626621440514`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7796112042359624`*^9, 3.7796112764172153`*^9}, {
   3.779611345953953*^9, 3.7796113539988575`*^9}, 3.779611386840968*^9, {
   3.77961147106723*^9, 3.7796114893929605`*^9}, {3.779611533162731*^9, 
   3.779611543391306*^9}, 3.779611651763934*^9, 3.779611834166193*^9, 
   3.7796118781666484`*^9, 3.7803327303207827`*^9, 3.7803670495202723`*^9, 
   3.7803759888095975`*^9, 3.780389371988076*^9, 3.7805715578551455`*^9, 
   3.7805738328155575`*^9, 3.781269058480692*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"ea79196d-3e7c-4771-b791-4f5b2660d437"],

Cell[BoxData[
 FractionBox["50", 
  RowBox[{
   RowBox[{"-", "0.5`"}], "+", 
   RowBox[{"0.7961862677773465`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0000320629`"}], " ", "pr"}]]}]}]]], "Output",
 CellChangeTimes->{{3.7796112042359624`*^9, 3.7796112764172153`*^9}, {
   3.779611345953953*^9, 3.7796113539988575`*^9}, 3.779611386840968*^9, {
   3.77961147106723*^9, 3.7796114893929605`*^9}, {3.779611533162731*^9, 
   3.779611543391306*^9}, 3.779611651763934*^9, 3.779611834166193*^9, 
   3.7796118781666484`*^9, 3.7803327303207827`*^9, 3.7803670495202723`*^9, 
   3.7803759888095975`*^9, 3.780389371988076*^9, 3.7805715578551455`*^9, 
   3.7805738328155575`*^9, 3.7812690584866796`*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"89fde538-78c8-4885-ac7c-f7810bd25256"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVkGlQUwcUhVlcaEUoiEBdoLIopYUUkYixhSNSqmhcU0HFotL3sjyWEiBs
40JFyUSGQi0RsUCIJG9EQCBK0CriUkEWFygIg7YgLohgWBOKGWj6486Zb86Z
O/eeFYdjdhEmRkZGbMP8r3dEoR4wGvHvSw+/lbSEQCyrRFylnvE/HlxLvjbw
J7O62Bz1PEhUlVacpQTC+4rJNLU1lC5pQsYyAhlt2oPJ6s/QGa8If72cAFMa
cGMwmoFHhPMAZwWBJouoa6+j/VAw6KVa40bAZotJ7cv3bBj7ZK2f9SFQQzB2
P3j3A3Keu9XZcwh4RjeH/zFAYk1XdrXwJ0P+gzrNnRmNa0ta3FMyCSzrb/Kd
ZxWHRHZGjeslAmxbs4db74qQ+tH5rrmNBAoGvmlquZeCpk1BHnlvDPudd+jz
VEchSWSyeueRYO7pIg4w0nBf7OS3w4XEisE5xqe/PIFG/wqnk4Ekekq6BP3z
T2KKYd7Yc5jE9Jl8TV/3KaTaZl7vOU7iYlvXqiPtYmTubz6uKiaxyrfOc+Ml
CQIXCPVF9Ya7hx3fKkoz8W6naDbuBQllZ0xdhSwLlb5W6dOmXMTHeXvFsrIx
ElXVmeHMRZjzcNhe3xw8aNcdswriooyc1uxx/RXBm7OdzpNc3Hvy5zOnlWfw
auCU5WoJFxYhZk83OP2GsvqXqSnlXNTHFPqKFuYi4krB/CsPuWBVjo0nmUsR
37g53Gqci6Xp+bY501LU5nllhS7mgSG8FqTvPwuxoLQ8YC0PH4ulj3368vDt
9R1HuGE8sL0abqe3nkOc/eRN8hgPoSY15vLWfFTf3FKqUvCQO7yUsH5wHg1D
wt6KZh5YkR0uearf8TDA2iZewwNtzfYbqiqAXDPHR2bLR+pW+1vfFxWio4QO
ylrPx8+yfWxrcRE0e5dLlhzkwy2rPH9bgAx1mQ4Jq8R83M0NueNQK8OyG8nr
XpXzEVDVa9u5thhlwq0zvk/5SJAucrS/XAxh4lVTnxk+bpuZVJi6yDHh7RPZ
6iLAaNYjfqdcDtnFsGa77QJ0/B3U7f3pBTzX/Wg3JRKgIKAgIencBXTzQ34p
lgtw1PtyHmlXgqFKmXSyVYBF7wUx/2SWoKGn922zVoDTN+bG+ZsrcHa4KFLi
TEHNCXZ3P6GAAy+q7Dabgj45mFenU2DXQGF4diIFV9Xn7etESiTtHRgnFRRM
aqpH/YeU+HowrqX4MYWjfzWPbnuvhI0o8mnEEwrTYy9HD4woIevmvHNtozDK
sBtLnVDC/pzOo7SdQu/F1DG1XomNi6UOqk4KdQWB44yFNHiW9eX3n1FIOdk5
4ehJQ3JwkXhigIL2gmbC8ysaC5uY1eq3FIR3zCa/WU2DrDzwKmWQAn+WNbmf
afAja0njIQqhyUWTZ/1oOA5Xd1hoKDCjeFrL7TTyrgYRX0xSqD6dpnXYSaNy
5ZCjxsCepflaj900GvSF/dVaw79vWrRbQmhYchinWFMUbA556TLCaQTamvsG
f6CQfSxYJz1EI9bWc72FnsKCwgidIoKGW8Lh79oMbNKTq7vLpWHVMid134yh
n38rdG18GhzTeLnDrKEfu0ZdH0Vjk91U2wsDi5h9upEoGll0jjltFIlRzrRu
NobG8O4N2ynjSPwH07VRiA==
       "]]},
     Annotation[#, "Charting`Private`Tag$7536#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 168.82723969131533`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1, 3000}, {168.82723969131533`, 224.04434931525557`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7796112042359624`*^9, 3.7796112764172153`*^9}, {
   3.779611345953953*^9, 3.7796113539988575`*^9}, 3.779611386840968*^9, {
   3.77961147106723*^9, 3.7796114893929605`*^9}, {3.779611533162731*^9, 
   3.779611543391306*^9}, 3.779611651763934*^9, 3.779611834166193*^9, 
   3.7796118781666484`*^9, 3.7803327303207827`*^9, 3.7803670495202723`*^9, 
   3.7803759888095975`*^9, 3.780389371988076*^9, 3.7805715578551455`*^9, 
   3.7805738328155575`*^9, 3.7812690585494804`*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"c07a9e91-881d-4712-807e-026b54b640fb"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwd0X001XccB/Dr+71J5NlS6M7DCRPWUag8fUgXs7U1y7kmZpq6roeuc0w6
KteUh4UVYmP3uhIakco8XIpTqXaOhxymVKubrBYboYUz7t3344/f+Z3Xeb8/
n/s592cVffjzGMLhcD5hD76HZPc43ftdfTmc2x802HCh5uG8xhQa6PJ3zKlG
dtQiAvPiQQGzRdapVakr1kvnMn+T4Ke9JZK5WzkRbs2Ftx6dxvKvMOdr6lhx
wWT0sq0kmllSHyzicSHUuPRjEGI/c63TBi58eOI1tCVjf7PBuC4XXlYrGvdL
sL9rOolyYWG2pfrOabwnZzpokUKUm/tu+x/R+3IipijUuLlFtlRhX7zgO05h
l1P7+55NaKMrMaMUPIIOibI7cf857nA/BUPrYmf1XZxX+ev2UPCa8S9PHEb/
vuF7BYWA48kZ2kq8b+R+fxOFS84Db+Im0TvWCmopCEcatHrmcb/lhL2UAvHQ
KfuIurH9+b6dRRRmz/09dFefGayKy3LZ/nWLJdoWzBKZ8no6hYMhJ4eO2mH/
YIgshcKfWUVtyq3M3YG/9MVT8DtiZZrsg/1aYesBCv9GbOWpg7Ef6joXRoEr
Ejd+KsB+3ZL4MwozLo5tvQfQA5suBFDYNhsn8hXj71fqOXlT2JfoUDKWhrnl
LaErhUF9k+CgbMztdj93pFBVm3Gxtgj3L3Cv2VAIWUpId6lAx751MacQFvBU
1VyP9zhQfSMKHa1HVy+34nxasP0aCv+NF+Um3cLccPskh8JZLZfmPwZwfuS8
7gKBVa/3CFIeY64MfzBNYHiq5NTwS5wXVo6+IrA4ER3uMIf3LRV7PyOwVNVQ
d0mFfVUd/wGB0JBj52113Fm/Q7+5n0BB12/GfeuYOcZRN+8QsNrrp7fDGnMN
tWYXAe1R7ys/OzNL+HPXWggMblT0Oe7EPOPpciOBKUF7YTMf57ukV2sIHGp/
odQIYZaL9WQyAjdG8i6mRWJfUWBdSiBuon39PyJmy3sDJj8QeKeIIadTmJV5
PFk2gSdNnt9OZWAuMvtSQmC9tPRMUAHubyjPSiXgwk/aNPgTOreIn0RAFvlQ
zi3DvmCvLbP2ER+L7WiwMtBkHqvVNa5AR7We6RETKFxTx0kox/yd1J95pnfs
sZYU7035y+8wgaaQLwpBjnmYFyQQsIjv0E1GyzeaWzLnnLTOrUV3Ty2q4wlE
/fomXa8S709TdDHrm+YnPEFDZoAPc+KjnsDUKsyFZ73jCDyadbxdj44yT+cx
83WKfZ6hYTBBJSLA84x241/AfNueG8z9UpWNSTX+/8/NvJl3tsRUBKDleQY8
5pr+XrO0lXzzalUsgRPqMsOxFafMX2eeMCX579WsfN8ZKXPollitILTy6uRx
5puB9zOP1ax831cRzE5fu6svo+XKF17M/wMeLMxo
       "]]},
     Annotation[#, "Charting`Private`Tag$7580#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 2.301387577335845},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1550000}, {2.301387577335845, 2.517420126241632}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7796112042359624`*^9, 3.7796112764172153`*^9}, {
   3.779611345953953*^9, 3.7796113539988575`*^9}, 3.779611386840968*^9, {
   3.77961147106723*^9, 3.7796114893929605`*^9}, {3.779611533162731*^9, 
   3.779611543391306*^9}, 3.779611651763934*^9, 3.779611834166193*^9, 
   3.7796118781666484`*^9, 3.7803327303207827`*^9, 3.7803670495202723`*^9, 
   3.7803759888095975`*^9, 3.780389371988076*^9, 3.7805715578551455`*^9, 
   3.7805738328155575`*^9, 3.781269058611354*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"267ece82-a0c7-4bfa-8b3b-85b2176b78e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhocom", "/.", 
  RowBox[{"pr", "\[Rule]", " ", "1"}]}]], "Input",
 CellChangeTimes->{{3.7796118832777977`*^9, 3.7796118868350115`*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"a74b1deb-7d1b-48f6-9102-880b5c3939d4"],

Cell[BoxData["168.82723880068195`"], "Output",
 CellChangeTimes->{3.7796118872628665`*^9, 3.7803327305128117`*^9, 
  3.780367049721236*^9, 3.780375989018029*^9, 3.78038937215405*^9, 
  3.7805715580031805`*^9, 3.7805738329987907`*^9, 3.781269058644256*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"2ed5d397-c4d1-4350-bdfd-0339ea6ab7a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    FractionBox["800", 
     RowBox[{"0.5", "+", "Vp"}]], "\[Equal]", 
    RowBox[{"1004.79", "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"3.20629", "*", 
       RowBox[{"10", "^", 
        RowBox[{"-", "5"}]}], "*", "pr"}], "]"}]}]}], ",", "Vp"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.779610114407216*^9, 3.779610174618609*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"6809f8f0-df4a-427e-8bb2-6902c33cdb8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"Vp", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "0.5`"}], "+", 
     RowBox[{"0.7961862677773465`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0000320629`"}], " ", "pr"}]]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.779610175275838*^9, 3.7803327305477176`*^9, 
  3.7803670497471657`*^9, 3.7803759890474167`*^9, 3.7803893721792994`*^9, 
  3.780571558032056*^9, 3.7805738330232735`*^9, 3.781269058680185*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"8568f48c-42f3-4fd7-a9d0-846caaecc037"]
}, Open  ]],

Cell["Plot of the volume as function of pressure.", "Text",
 CellChangeTimes->{{3.781273707194847*^9, 
  3.7812737125345664`*^9}},ExpressionUUID->"88d9e4f4-077d-47b9-9f6c-\
bb47fae3d90e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhox", "=", 
  RowBox[{
   RowBox[{"800", "/", "Vp"}], "/.", 
   RowBox[{"Vp", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "0.5`"}], "+", 
     RowBox[{"0.7961862677773465`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0000320629`"}], " ", "pr"}]]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.7796107051629443`*^9, 3.7796107169575777`*^9}, {
  3.779610754288102*^9, 3.7796107606711874`*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"da178b20-31e4-433a-85fb-ef29cd44c6e8"],

Cell[BoxData[
 FractionBox["800", 
  RowBox[{
   RowBox[{"-", "0.5`"}], "+", 
   RowBox[{"0.7961862677773465`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0000320629`"}], " ", "pr"}]]}]}]]], "Output",
 CellChangeTimes->{
  3.779610719952726*^9, {3.77961075563766*^9, 3.779610761016387*^9}, 
   3.7803327305866117`*^9, 3.780367049779093*^9, 3.7803759890850773`*^9, 
   3.780389372208273*^9, 3.780571558071395*^9, 3.780573833065275*^9, 
   3.7812690587130747`*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"ba829ba0-8b33-4e93-bcd6-cd739beeda0e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"rhox", ",", 
   RowBox[{"{", 
    RowBox[{"pr", ",", "0", ",", "3000"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7796107257722483`*^9, 3.7796107355123396`*^9}, {
  3.7796108476908674`*^9, 3.7796108498621855`*^9}, {3.7803671224474297`*^9, 
  3.7803671371961775`*^9}, {3.7812736937957106`*^9, 3.781273694980549*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"bb3b9f4f-586b-470b-8bca-5a4536e98f4e"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVz30wlAkAx/HdalKtvdwN2lPKa5Rjulqv5fzkpWS21IapbtoLkSltT8Uq
153rRdxJVPISYXef59ndB529Wy/jpZtUyp6GvDVOW0kkopywSW7vj9/85vPn
1zpCvOvgPBaLJTDs/19XWV/zp7GJz8wrTjrbgoRToptggHjr4yFq9RAbzM+K
tKCIWR/HIf5Qr8E1lh9ZKQQX0y91u6uXk5iJDJiIJyzhcag2XGxJYoXR8Ns4
whlewQ0cnRWJsif1b2IJb6jN17g0OJCI93UYiiEEMBWmRae5kni+JyArpnw/
pgebjsiFJARuvv5lzdFYvLLs8ZyYxFOe68da3lGMHNpXtyidRHXX9rPkvBNw
EZi90KhIxEzZ6zZpEmBe0JCa00SCR7hHmVadhvOWyHSnQRIROScuulE/Ia4j
OSh+IYVF25TocPwF83VtrwdsKTyf0OxyXn0OeUrVNUt/CsNLTEPK2RcQnDkw
HB9BYbPEqKCjPQVjZk6ZkmQKFia82fyWVGib1G47SyjYm54OSiN/xROn2iSf
vyhU+OtVy8h0UINtiWZ9FNK03H3BNzIQxXo+XTifRrPOM6ndPRP7h4+7ONvS
MDmaJGxzzUJiYNhodQCNMfVB65c2VxAnCMrwj6axNEOnv2t7FQ1JmvKnaTRC
TaWn9Kuuof0oP8SxjAY/5IsxX042st2NJiMf0dhts1i8d8l1pPJQ0jhOg6sq
7U+Zvo469hMjrpkCI7357IV9OSjVskV6NwWMqWVrQp/lInsuQGb1vQL37LwD
q7V5+DrtnpfNzwrc9nwfN6zNR2Kytp4gFXimH9tENN2AVZE8XaxVIFecw+ao
CyBKXeXpPqbAlaSW1pO/F+JgdYN5tLkS9t6l2eOFN9Go974btlEJnbKT3ZhS
BKq7SPZKpMSRrsC6Ct9ifBlx4fiHi0pUrpeM/1ZVjIceNVOaMiWsekadt7uX
wPhC5wPjbiXCe72i8stLID8cW8n5rIQ1/5vRy7ZS/LHkkBFtpwKnO+pMnFQK
pee3RRPbVbjTQRh18mQI9ds8252gQp7l/et2eTLkE4J/zktVmF93+5TlMjkc
vB8E97ao4KW5FF6cLod83pBOM6lCll7qxTEmMRK2YEZiy0CTm85jnSNxOTdP
qRYwOHJp+babUyTCGu3+Pi9h4NfyPtkugUJL2aiLiGQwGFOg5o9QiMpIUBS2
MtD1VjzzG6VQ+flRo6iNQcfOJmPhOwrWzbzX1o8Z3Nk4Hk1MUFjafzaYamdw
c+nW5eWfKMT63zlzq4tBWNW/5xy4NLoGEjIbexncWxgcauFCw9VqwYnx1wzq
kn44u2YdjQiH6jLNEAP1u/hbHutpPNxAvE98w6C4p3hxuBsN386Jq3PDDH4s
n6y/+h1t6BAGcMcY8MOkq7k7aKzO1u9Z+4GBk7ZKuGInjY5NW+1HDbZBS7KT
kAbRQeorJhmYrJ3uCQqnYRaSWe85zWBkVnA5RUSjs3+DOmiGwcvjkXXZB2hs
kXDucz8x6BlMHJJH0pBMTPa1GfygTebXGEPjpLOxx97PDG4H1hx7HEuDcXQ/
tnKOQWXto8IXh2kcuJRY0Wdw6br+5ndxhr6Z1hmKVQoZqZ+aE9OQfeW74zC7
FP8B/nRdPg==
       "]]},
     Annotation[#, "Charting`Private`Tag$235428#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 2701.003021594833},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3000}, {2701.003021594833, 3584.7095890364885`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.779610735912051*^9, 3.7796107624894276`*^9}, 
   3.7796108503047686`*^9, 3.7803327306689005`*^9, 3.7803670498658485`*^9, {
   3.7803671235168915`*^9, 3.7803671376959515`*^9}, 3.780375989190485*^9, 
   3.7803893722951803`*^9, 3.7805715581726284`*^9, 3.78057383314852*^9, 
   3.781269058784891*^9, 3.7812736957444887`*^9},
 CellLabel->
  "Out[170]=",ExpressionUUID->"1c6799bd-110d-42db-beda-79a1df65b385"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rhox", "/.", 
  RowBox[{"pr", "\[Rule]", " ", "3000"}]}]], "Input",
 CellChangeTimes->{{3.7803671522249684`*^9, 3.7803671815918074`*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"95e20719-5d53-425c-82e3-99ba7d9782ee"],

Cell[BoxData["3584.709611839195`"], "Output",
 CellChangeTimes->{{3.780367168766221*^9, 3.780367182094842*^9}, 
   3.7803759892131743`*^9, 3.7803893723125305`*^9, 3.780571558202506*^9, 
   3.7805738331835327`*^9, 3.7812690588217707`*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"dcbca48b-05d2-4241-acd8-f289961c9c41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"800", "/", "1100"}], "-", "0.5"}]], "Input",
 CellChangeTimes->{{3.779610353278698*^9, 3.7796103590705366`*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"3aca5fca-941a-46a0-bee3-e1703c9d223b"],

Cell[BoxData["0.2272727272727273`"], "Output",
 CellChangeTimes->{3.7796103594338613`*^9, 3.7803327307137995`*^9, 
  3.780367049902748*^9, 3.780375989234126*^9, 3.780389372329376*^9, 
  3.780571558229817*^9, 3.780573833206457*^9, 3.781269058853305*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"2928650a-22fc-4dfb-9ab1-048ab4a25431"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"rhor", "\[Equal]", "1004.79"}], ",", "pr"}], "]"}]], "Input",
 CellChangeTimes->{{3.779610433722946*^9, 3.7796105286737695`*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"8c54fdde-989c-4b9a-af4e-cd126ca3a661"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,107,2,29942431949888263582,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.779610443528578*^9, 3.7796105289682503`*^9}, 
   3.7803327307895775`*^9, 3.780367050011459*^9, 3.7803759893921585`*^9, 
   3.7803893723676147`*^9, 3.780571558396507*^9, 3.7805738332687645`*^9, 
   3.7812690589230843`*^9},
 CellLabel->
  "During evaluation of \
In[107]:=",ExpressionUUID->"8c4e1aad-e94b-48c0-8da6-bb6f185a68a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"pr", "\[Rule]", 
    RowBox[{"-", "0.08883488569236965`"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.7796104435315933`*^9, 3.779610529003157*^9}, 
   3.7803327308314652`*^9, 3.7803670501470957`*^9, 3.7803759894365864`*^9, 
   3.7803893724204383`*^9, 3.7805715584837284`*^9, 3.7805738333248777`*^9, 
   3.781269058991911*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"7870bfd7-6ed2-4f48-8001-6456bcc457d5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Actually calculating the balloon sizes", "Section",
 CellChangeTimes->{{3.781273750100109*^9, 
  3.7812737590860977`*^9}},ExpressionUUID->"a9ebe4d5-923a-4d4c-9594-\
d38d6414875f"],

Cell["\<\
The above used some incorrect assumptions to calculate the sizes of the \
balloons. In this case, we will look at the actual sizes of the submarine and \
use actually existing materials.\
\>", "Text",
 CellChangeTimes->{{3.7812737618347297`*^9, 
  3.7812738062200603`*^9}},ExpressionUUID->"8c88e398-5610-4edf-8db3-\
3e6e7c250f23"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", ">", "0"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{"m", ",", "Reals"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.78036896090981*^9, 3.780368977661995*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"81b67756-2872-45ba-8756-9ce29d9e8f1d"],

Cell["\<\
Density of pentane and butane as function of pressure.
buoy2 is the buoyant force on the submarine as function of the mass of a \
pentane balloon.\
\>", "Text",
 CellChangeTimes->{{3.7812738178838434`*^9, 3.7812738267710767`*^9}, {
  3.7812738766606655`*^9, 3.781273921323224*^9}, {3.781274312402405*^9, 
  3.7812743203232536`*^9}},ExpressionUUID->"e530beb9-a5f4-4ab2-b20b-\
f75c442f1b23"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rhopent", "=", 
   RowBox[{"626", 
    RowBox[{"Exp", "[", 
     RowBox[{"1.13944", "*", 
      RowBox[{"10", "^", 
       RowBox[{"-", "5"}]}], " ", "pr"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rhobut", "=", 
   RowBox[{"602", 
    RowBox[{"Exp", "[", 
     RowBox[{"4.81", "*", 
      RowBox[{"10", "^", 
       RowBox[{"-", "5"}]}], "pr"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"buoy2", "=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0.141", "+", 
         RowBox[{"m", "/", "rhopent"}]}], ")"}], "*", "rhor"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pr", "\[Rule]", " ", "p"}], ",", 
        RowBox[{"r", "\[Rule]", " ", "rprime"}], ",", 
        RowBox[{"m", "\[Rule]", " ", "20"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7805736599647446`*^9, 3.780573666981641*^9}, 
   3.780589928470397*^9, 3.7812738540391893`*^9, {3.7812738985740933`*^9, 
   3.7812739072030177`*^9}},ExpressionUUID->"c52f4fca-e979-446e-bacb-\
d38e95d650b7"],

Cell["Plot of the pressure just as a reminder.", "Text",
 CellChangeTimes->{{3.7812743428380146`*^9, 
  3.7812743493256645`*^9}},ExpressionUUID->"ac353873-f12a-4857-8ed1-\
cc0c608ddada"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"p", ",", 
    RowBox[{"{", 
     RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7805737865297956`*^9, 3.7805738045597496`*^9}, 
   3.781273946565725*^9},
 CellLabel->
  "In[186]:=",ExpressionUUID->"c8c2e9e4-3ec7-4dbe-806e-41a4a9681ec9"],

Cell["\<\
Plot the densities of butane and pentane in the same diagram.
The used density is set as the density of pentane.
Then rhosol is defined as the density of the combination of submarine and \
balloons.
msol is the mass for which the density of the combination is equal to water \
at a given pressure. Bear in mind that of course only one mass can be chosen \
for the balloons. The graph for msol thus indicates for every particular \
pressure what balloon mass would be required to make the submarine float there.
buoy \
\>", "Text",
 CellChangeTimes->{{3.7812743875255113`*^9, 
  3.781274583133418*^9}},ExpressionUUID->"6db50a6b-ef1d-48cc-8fb7-\
00b6f3fee1ec"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rhobut", ",", "rhopent"}], "}"}], "/.", 
    RowBox[{"pr", "\[Rule]", " ", "p"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rhouse", "=", "rhopent"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rhosol", "=", 
   FractionBox[
    RowBox[{"202.2", "+", "m"}], 
    RowBox[{"0.141", "+", 
     RowBox[{"m", "/", "rhouse"}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"msol", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"rhor", "\[Equal]", "rhosol"}], ",", "m"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"msol", "=", 
   RowBox[{"m", "/.", "msol"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"msol", ",", 
   RowBox[{"{", 
    RowBox[{"pr", ",", "100", ",", "3000"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7803332584046607`*^9, 3.7803332835482426`*^9}, {
   3.7803333513917713`*^9, 3.780333413505953*^9}, 3.780333460616339*^9, {
   3.780333548388839*^9, 3.780333575312039*^9}, {3.7803336497711196`*^9, 
   3.780333662146448*^9}, {3.780333703451039*^9, 3.7803337127816744`*^9}, {
   3.7803337850103226`*^9, 3.780333793736312*^9}, {3.7803338600185432`*^9, 
   3.78033387881152*^9}, {3.780333925127759*^9, 3.7803339487025547`*^9}, {
   3.7803340094058094`*^9, 3.780334168441369*^9}, {3.7803342806194725`*^9, 
   3.7803343891825237`*^9}, {3.780334467615224*^9, 3.780334505959896*^9}, {
   3.7803345413403864`*^9, 3.780334545681074*^9}, {3.780334630657425*^9, 
   3.780334669677825*^9}, 3.7803347403229275`*^9, {3.780334889019437*^9, 
   3.780334906543359*^9}, {3.780334937156683*^9, 3.78033496391179*^9}, {
   3.780335031268358*^9, 3.780335127896183*^9}, {3.7803351689317236`*^9, 
   3.7803351858495216`*^9}, {3.780335217104848*^9, 3.78033522010573*^9}, {
   3.7803352783683777`*^9, 3.7803353640385013`*^9}, {3.78033539894293*^9, 
   3.7803355077751684`*^9}, {3.780335610784582*^9, 3.7803356174841843`*^9}, {
   3.7803356600282397`*^9, 3.780335720623316*^9}, {3.7803672322679048`*^9, 
   3.7803673556590605`*^9}, 3.7803681896396017`*^9, {3.78036822115895*^9, 
   3.7803682929014874`*^9}, {3.780368338699543*^9, 3.7803683426137767`*^9}, 
   3.7803684099601507`*^9, {3.7803692215995073`*^9, 3.780369408057871*^9}, {
   3.7803694468784757`*^9, 3.7803694489362764`*^9}, {3.78036950647972*^9, 
   3.7803695091610084`*^9}, {3.78036956540149*^9, 3.780369612273717*^9}, {
   3.7803696890229516`*^9, 3.7803697442934036`*^9}, {3.7803697754269586`*^9, 
   3.7803701240854793`*^9}, {3.7803702930198746`*^9, 
   3.7803703269180393`*^9}, {3.780376045666112*^9, 3.780376102333461*^9}, {
   3.7803893847044554`*^9, 3.780389398856239*^9}, {3.780571641879738*^9, 
   3.7805716719690013`*^9}, 3.7805717047357473`*^9, {3.7805732710295753`*^9, 
   3.780573294085881*^9}, {3.78057357704705*^9, 3.7805736473450737`*^9}, {
   3.7805737191380663`*^9, 3.780573736876799*^9}, 3.780574259762161*^9, {
   3.7805743717714214`*^9, 3.78057443956013*^9}, {3.7805744803133464`*^9, 
   3.780574500961029*^9}, 3.7805745661306486`*^9, {3.7805828388289766`*^9, 
   3.780582857243335*^9}, {3.7805830585763855`*^9, 3.78058305902942*^9}, {
   3.7805830901333904`*^9, 3.7805831063928595`*^9}, {3.7805855635133686`*^9, 
   3.780585637442216*^9}, {3.780586373241428*^9, 3.7805864204237394`*^9}, {
   3.7805884103295174`*^9, 3.7805884314624853`*^9}, {3.780588465976494*^9, 
   3.780588493089673*^9}, {3.7805887474332047`*^9, 3.7805887506824274`*^9}, {
   3.780589314962757*^9, 3.780589318791464*^9}, {3.7805902350693016`*^9, 
   3.7805902386428413`*^9}, 3.7812738602316284`*^9, {3.7812743583106384`*^9, 
   3.7812743598076377`*^9}, 3.7812745912467203`*^9},
 CellLabel->
  "In[201]:=",ExpressionUUID->"78fd872c-a231-41c5-994d-c01fca417298"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVzn04lXccBvCDWnYaKhLbWS0VXaY0PM9TEd+vyaFaq5ReFmFEdFTbSYpS
5/c8mqEXGk2EjpyKsDlxqPXq9HaRiZqKyMpQuTgpL4n9+uO+7utz3f/c04O2
rQrRF4lE39F87PqTt0VXNzLYYxxYn1siQH5jv1439cOBlcV+1NGTbAwkfgxK
X99PtqSWxAtjo6mNwvhVR4sFCJa5i+f5M3hQmzu0v0iAPudLpjmbGFz8tUob
UCiA2aNi6/1BDDZEvVhsdUYAX9P0ZRDGoFn0vv8KswWw39cJGjmDHQN//Rqd
LED76cqijfsZFGcYrlXGCjCgKzt9M5HBup73Nd5bBQhgucWzjzOYY51yUbOB
/mVZ/zIlg6UF66tjlgjw7ZyKaS4lDCoDlzcZLRDA2Ts0/OAlBkOcBhZKZgsw
0erY3NFbDA4aWeh+thBgUa/HicgGBjVhE7hT4wSQ7pUfELcy+KftoNRsgIfC
ubU9ES8ZlGwyTerv4CHs4XlDbT+D149l7NE08qDvPD5jiQGLVw1aQkvv8KD7
7VX9LRMWtXlHWo5W8LDIfDBNLGGxZlnZnLazPGz24et327AoTydPg07w8CI+
VdPqyOKF7NzOmkQe3HdNnyJ3YzEiXbU5eC8Pb/0cp44uZTH9Q0JVl4yHMeHb
i75fx6LHmJDIZn8eeh3sNNU/srjzqVTQreDBSRcRjttZvNLs3P4BeVgTaZvW
FsPi5bW6CTZOPNSZmC31PsjiyNBXbqXWPChVB86oUlns9Gi85mzBg8+wLM4h
m8XgYe6fR2Ie1kufjqgLWEySGbvuHiZwsXz3uA/lLJYFWrrHdhN4/zw1YccN
FltlvreSnhE4auigbq5l8WzTg/C8egJjO5evi3pC93mpW7Q3CTR0pwkN7Sx6
Tesqx0oCg11BP9i+YTFTfT7zbiGBYeX5c4UjLN7lW+LW5BDw9Yk9ZT2ew86W
qXt7UwgcunLHtMacw8by9sOJ8QSmr3Q3XmDF4bNrrzpi9xAQP3L9I3Muhzak
L56XEaj7srLGbiGHjuYjXiSQQPe6ihS1J4fN+n2pmasJhFb826rnw+G5+Y5q
Iy8Clx8mnYnx5zDPUjxzmwuBiK4Ki9fhHOZnqyf32BN4VxminxjFoSypv95v
JoGmEped3Qc4HP3JOkBiScAiK/2I9yEO35Q+nzb6GQEHzx2z6n7ncMOkG1tv
6xE46d+YMyaDw53iF0lp1OJdbpL51GvlV4qCqdtURqbZ1FrM6hdRp3x6TiQ7
waGt+1DWAhGB3uq2J4ZZHCY0zFpUMKKAEp/VKZDD4fYwZdXh9wqQbL1oJKfe
sVL1hT/1L7xVgoq6rS5AbkcdcKEnzjiXQzvXPts7QwowmZIsa6L29coo1KeO
fKz1ilZyGC6t1YsaUMBjnV1VAbW9gZXcg9pz/DG3lo/7y9kdk6inugSxnnkc
lrevelDcr4B7WSMzzE5z6GQyuarznQIWloVkS6lnXvjEQ0Odf6/68xjq4/cL
tPHU+0YzJrZRqy0n3JtB3TVFP3lyPoffmNeu1r1VgO+8LYbe1M322HyV+rrX
3ySW2mbF5tDD1HMCudFi6rgA1zd+1P8D7eY65w==
       "]], LineBox[CompressedData["
1:eJwV0X9UzXcYB/ArWimUbj+3ysrPY9Va9v18XYnnuem3GW4zk9oVFrcfYldE
Sj5fNUOzotZPJbdav7PErYYT7eZEOERklhrSKnVFmn7ssz+e85zXOc95zvs5
j13wjrVbdUQi0Res/u93c5pEVzZyKEqvK6l1FaCgbXhSP3PF4sdZJcx7TeZP
tg7ksF29PSmL2TrhsO5e5sOrmnfFMm8Jlxo4B3E4TVoEUuYh13px7rcc+m1o
HLi+RADThxXzDgZzWJQTduahRIB14rSVsI1D34pdvv/yAnwa+xIuKjk8ujms
fmCRAM9VteUbD3Jo5tH7u4uzAO+0Nao/jnLoOFpsmeQggJzwHgt+4bBqiBTn
LWB5CQmqyecwfFezzsQcAdwd1bOWVnLY0/DJBTM7AVx9QhSJ9Rymuae89bAR
YKb9SacJDYcR4QrJJSsB3AZXZEbc49Dg+2bnQTMBvA4o4w06OBzW3e0eaiJA
qdOtgdB/OKwzOWY8NkOAbffL9BuHOdQ36m3zNRRAx9Uww3cywT632x890RNA
e6r3rsaI4KvZn4U4TWH7zUdSDawJzjWRZKWKBPhOJtyNnk9Qs2JOhXSMwrOE
lIsdiwjuszivVzZCQbrHzkK5nGDYWrFiw1sKbwIX2U74Eaz6sdpEo6UwRRFZ
/uV6gtLA1mu+rygMujhcvLGZYMWR1GGjXgqfa0MVGEkws/R9zqluCl9FLEzt
3E9ww+qnowHPKNwxMvXzSST4k1xzi++kkF8YX1SYQlDrbktan1CQjYbHuZwm
GJef9KKqncI3Xk/Gq0sIyq0qLde0Uai7EK03doHg049TXuq2Unj/d8qRnVcJ
9g4qs9/dofCzvkv1n7cIXjW/8qK8hYLuy1Xro9oJJgdqA840U7jXn3r43nOC
83Rjx35tojDSExyw8DXBqPEet6hGCqP5ZcWl4wTL4swDYhsorJPFnJlnyOMb
+esBv8sUki5fF9805zHdqu6cfz0FuzXSGRJ7HrvTO15HqikYPFxWleXEo9gq
ulhWw+61qb3psITHAz15qyJ/o9C/Xp1c7cmj3jPFYv9KCiHqro5JMh63u3k3
+ZVRuHT/WNH+IB63jExMjSmmENqjtuxTsPnGZYnKQgpva7fqHI3isWDQ2FR1
lsLjyqW7++N51NhLdLrzKFhmp53wSeIxvmuT2VAOBRfPnXPvpPP49aBKzGdR
yAlqy52SwePQNL2uhcwGe5ZbL2a2Cak7Z8vcWThdfJp5pMlG9gFz8tRiUXgm
j4kdTWmtmezfNzrb9bN5DF153lnJXCnzT4ZcHuXHWnKrMihYh9VNVzKPlZ7Y
p2L+QbA/Usg8nqnyT2eWnx+Im5HHo+MDzdR4ZiOL4+GPmRPkfXtWM0c8avTe
m8/yV6k3v0qn8EjrcK2EeZ9ZobSL2dPw5PK/mHWNX9g9YLZdGkw8z/L4vDbo
6SXmluzx2aYqHoMSHLYkMS+p2Xrai3m3W7nHIeaClhsf7mf23nFofhRz7ETG
zE5mCWffG8jcY6Fz3KyAx+CGvpY1zOuct+v7MMvrDc95MDd436YxzLWzYk5J
mB038RMVzEPdy6Idmf8D1q8yBw==
       "]]},
     Annotation[#, "Charting`Private`Tag$244612#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 606.6708741067122},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1550000}, {606.6708741067122, 694.0790164549526}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.780335364459405*^9, 3.7803355082967715`*^9, {3.7803356646383905`*^9, 
   3.7803357212815638`*^9}, 3.780367050329609*^9, 3.7803673564549627`*^9, 
   3.780368159984233*^9, 3.780368190098734*^9, 3.780368257231707*^9, 
   3.7803682953826904`*^9, 3.7803683434609413`*^9, 3.780368410478732*^9, 
   3.7803689806488905`*^9, 3.7803692231876707`*^9, 3.7803693503819904`*^9, 
   3.7803693979138536`*^9, 3.7803694281184826`*^9, 3.780369458430664*^9, 
   3.7803695105970078`*^9, {3.7803695671262007`*^9, 3.780369582583626*^9}, 
   3.780369612662369*^9, 3.780369745908924*^9, 3.780369779380512*^9, 
   3.7803699111551566`*^9, {3.7803700688434057`*^9, 3.7803700919740744`*^9}, 
   3.7803701248215103`*^9, {3.780370308171627*^9, 3.7803703362465353`*^9}, 
   3.7803759920354495`*^9, 3.7803760619246097`*^9, 3.780376103332557*^9, {
   3.7803893753182964`*^9, 3.7803893998110113`*^9}, 3.780571561149152*^9, {
   3.7805716550308075`*^9, 3.7805716725001354`*^9}, 3.7805717051122007`*^9, {
   3.7805732792142115`*^9, 3.7805732949480176`*^9}, {3.780573596730399*^9, 
   3.780573617797409*^9}, {3.780573691389752*^9, 3.780573738581783*^9}, 
   3.780573836774128*^9, 3.7805742608879347`*^9, 3.7805743847217803`*^9, {
   3.7805744169184384`*^9, 3.78057444043978*^9}, {3.7805744837315145`*^9, 
   3.7805745019563036`*^9}, 3.780574566707808*^9, 3.7805828172391157`*^9, 
   3.7805828578056946`*^9, 3.7805830603087425`*^9, 3.7805831144971037`*^9, {
   3.7805855941160774`*^9, 3.780585638306929*^9}, {3.78058637972812*^9, 
   3.7805863887946167`*^9}, 3.780586420788748*^9, {3.7805884109360847`*^9, 
   3.780588432041913*^9}, 3.780588466710519*^9, {3.780588499696474*^9, 
   3.7805885065795126`*^9}, 3.7805887511955957`*^9, 3.7805893192755404`*^9, 
   3.780590361188439*^9, 3.7812690617008076`*^9, 3.7812743634010563`*^9, 
   3.781274599287221*^9},
 CellLabel->
  "Out[201]=",ExpressionUUID->"284048ea-8091-4124-9534-de5c8599d6bb"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVzX081AcAx/HDvdJlrzquB6VOcTNRqahRWV9celXMzz0fKZNDzUPMTBil
hHIejlOeiqP7oU7Ww8qlpMvDi1KtRa1OvXJFdjWT6iat3f74vj6v91/fJWFx
HIkphULxN+7/bp1ab6BQxOAFuaadaxIhNKV702t3Me6XD155rxIhycArfhQv
xnFzi8/rjFZMxKw4NyTGnMmXBZrTIkzqT4bv6grCpYD6x7/Xi9CgNbvXkb8d
Q44eNgaFCIeevuB1zAwFjTXg4XVMhOfXVcuPVO2Cjs36S5shQuaUqH4b73vo
zlT1C/1FGD1ka2bNjofQPy9RwhRhQt2YONGbiJWTxXz5mBBxKk1PdHUyzrXN
Udu2CaGZniJLck1DQc6MQy5FQrDpO23zafvB4aderd0pRL/r7bmCsQNY63ZR
usFFiAcWM7oifj2I3x4+TPIzFeKLG9LdHYos9KwoU926J0Dzsmc3o2OzMTLL
TtlaJwD1bLoXbVUuTFqys24kC1A0K7z57fyjsCq3orG3CHCEZf3Q4XkeMov3
vvpqkQCt8xjj5N18xDPfthe+5iPAUjV3VnAhCvStass2Pt6PXSqM9SxC2IMY
1XAxH+qNL83erZahKZuv8ZfwcWEk9b6tdTEKu70mTNbx0UNZUxlPL4Gntv7b
AAs+LrNK3nlS5XB2jzNv0vKgVQSdbhqWY3Jp7Cv/8zwwC9lBvoOl0F4L0BRl
8SAfkEsybx7DBavgJfRgHnROUhMP5XFoGG4y2SoeiNdk6dyKMpRV/BigofIw
TnPKOZ5Rjgrn6TF2j7lolt9J8PqpAo0h+QL3Ji58l9u8Cd9TiZoFyjBeJhcM
276OZf5VqBB/bJSJuZjKqCu18TmBdJn6TdFyLmzWP9c0OZ5EQ89RVxWVC5rJ
EAap1RBLve1vPOGAURlRaUivBnN9Z2/NLxy46xY5vBirRnvnNroslwP9UMQy
SXQNTkhq6PwdHFwpHAq99LQGbpF7au3WcpDkc17bSSiwTx/jp5vJQZtq9sDu
XgVkijS7TF0g7Dsa/h30rAUZZbrf9mog5pTcVQy31OLPjKm+alkg3kZtLVC5
1iFmdCnTencg9KMfGjadqkPYGe3wQe9AJLK+9opffAoHkTPxxDoQ8ywap8UV
n0Lrgad3WOMElB/iZjtRlXCpPMIR3iKgqeg6kZyuRO6jPNP9tQQ+6jnCsjEl
StoFttKfCXSX9f9dOq5Ex8bEabo0AiW+QXklE0o4OSvH1hm9ovq79gKDEnmj
vn0jKQRCuXudD1NI9Cfsa2InE7jZIv2cQCfxSSc1/ZRAIO9wN+m3kkTIjj5D
XBQBkauf99bVJOT527y7Igl8+ezOk81uJGrX/JHPNPqax4CljzuJi7nOq25L
CIzpX6R6gATjQkW50y4CfK4Z4UCQqI6sorwMIWBHyR6155A4O+6Q6mn0mzMz
spbwSPSmXDeUbCeQM81KvVBE4pm9/SefYALqlsUsRiiJyE11TgoRgcMRddfo
YSQesE5f/UdIgMtwFM8MJ9HDbucGGq2PdsmnRZGgjyzIpQgIXJ5/3tF8D4nN
G3Y4ivgEsjrXaqjRxr+E5p6zPAKcH9QhprEkFiZa7jU3mrn4G8PnOBIqxwPW
O7kE/gNoNDNK
       "]]},
     Annotation[#, "Charting`Private`Tag$244657#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{100, 65.30267918217824},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{100, 3000}, {65.30267918217824, 98.72964386954237}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.780335364459405*^9, 3.7803355082967715`*^9, {3.7803356646383905`*^9, 
   3.7803357212815638`*^9}, 3.780367050329609*^9, 3.7803673564549627`*^9, 
   3.780368159984233*^9, 3.780368190098734*^9, 3.780368257231707*^9, 
   3.7803682953826904`*^9, 3.7803683434609413`*^9, 3.780368410478732*^9, 
   3.7803689806488905`*^9, 3.7803692231876707`*^9, 3.7803693503819904`*^9, 
   3.7803693979138536`*^9, 3.7803694281184826`*^9, 3.780369458430664*^9, 
   3.7803695105970078`*^9, {3.7803695671262007`*^9, 3.780369582583626*^9}, 
   3.780369612662369*^9, 3.780369745908924*^9, 3.780369779380512*^9, 
   3.7803699111551566`*^9, {3.7803700688434057`*^9, 3.7803700919740744`*^9}, 
   3.7803701248215103`*^9, {3.780370308171627*^9, 3.7803703362465353`*^9}, 
   3.7803759920354495`*^9, 3.7803760619246097`*^9, 3.780376103332557*^9, {
   3.7803893753182964`*^9, 3.7803893998110113`*^9}, 3.780571561149152*^9, {
   3.7805716550308075`*^9, 3.7805716725001354`*^9}, 3.7805717051122007`*^9, {
   3.7805732792142115`*^9, 3.7805732949480176`*^9}, {3.780573596730399*^9, 
   3.780573617797409*^9}, {3.780573691389752*^9, 3.780573738581783*^9}, 
   3.780573836774128*^9, 3.7805742608879347`*^9, 3.7805743847217803`*^9, {
   3.7805744169184384`*^9, 3.78057444043978*^9}, {3.7805744837315145`*^9, 
   3.7805745019563036`*^9}, 3.780574566707808*^9, 3.7805828172391157`*^9, 
   3.7805828578056946`*^9, 3.7805830603087425`*^9, 3.7805831144971037`*^9, {
   3.7805855941160774`*^9, 3.780585638306929*^9}, {3.78058637972812*^9, 
   3.7805863887946167`*^9}, 3.780586420788748*^9, {3.7805884109360847`*^9, 
   3.780588432041913*^9}, 3.780588466710519*^9, {3.780588499696474*^9, 
   3.7805885065795126`*^9}, 3.7805887511955957`*^9, 3.7805893192755404`*^9, 
   3.780590361188439*^9, 3.7812690617008076`*^9, 3.7812743634010563`*^9, 
   3.7812745993490863`*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"aa0e2570-06af-42c5-8d37-411026fdd2ab"]
}, Open  ]],

Cell["\<\
buoy is the buoyant force on the submarine as function of depth.
mopt is the mass which enables the submarine to float at the seafloor.
The plot indicates the buoyant force on the submarine as function of depth \
for different balloon masses. The lower lines indicate lighter balloons.\
\>", "Text",
 CellChangeTimes->{{3.7812746117558956`*^9, 
  3.781274711683648*^9}},ExpressionUUID->"052b822e-914d-4e8b-917e-\
d93d4696fe2f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"buoy", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"202.3", "+", "m"}], ")"}]}], "*", "gr"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0.141", "+", 
         RowBox[{"m", "/", "rhouse"}]}], ")"}], "*", "rhor", "*", "gr"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"pr", "\[Rule]", " ", "p"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"buoy", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"PiecewiseExpand", "[", 
     RowBox[{"buoy", "/.", 
      RowBox[{"r", "\[Rule]", " ", "rprime"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"buoy", "/.", 
  RowBox[{"rprime", "\[Rule]", " ", "r0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mopt", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"buoy", "\[Equal]", "0"}], "/.", 
      RowBox[{"rprime", "\[Rule]", " ", "r0"}]}], ",", "m"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"mopt", "=", 
  RowBox[{"m", "/.", "mopt"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"buoy", "/.", 
    RowBox[{"m", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"20", ",", "40", ",", "60", ",", "80", ",", "100", ",", "120"}],
       "}"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"rprime", ",", "r0", ",", "rc"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.781274593572534*^9, 3.781274595248052*^9}},
 CellLabel->
  "In[207]:=",ExpressionUUID->"94fc0de4-64d7-498d-b37a-2b3e898fac34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.6927111505633509`"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "397.2311880681915`"}], "-", 
    RowBox[{"4.351181101470102`", " ", "m"}], "+", 
    RowBox[{"2.5500238508106663`", " ", 
     RowBox[{"(", 
      RowBox[{"202.3`", "\[VeryThinSpace]", "+", "m"}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.7812743715442657`*^9, 3.781274607917142*^9},
 CellLabel->
  "Out[208]=",ExpressionUUID->"5819bbc5-8385-4122-b5a5-f2f47d139cec"],

Cell[BoxData[
 RowBox[{"{", "65.86800619844303`", "}"}]], "Output",
 CellChangeTimes->{3.7812743715442657`*^9, 3.781274607922168*^9},
 CellLabel->
  "Out[210]=",ExpressionUUID->"a5485153-b1b7-4baf-9e08-5a2e5520e6ee"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVz3001XccB/DbjZOoJLpsu2lXutecaqLf97cofFQe6nLv/f3KOB4Wkodi
7CDtWmXdSinqSk1CskspZSZPlX201OqkZtQkSpLKlrBFD7r23R+f8z6vc97n
fc5HEv41FykUCAS+9P7PtsLfBBjMQFCLt92qAjmWdoxNGqRekpy2QVEox9RZ
ssniEAaeDVhqA4vkKN69yzCVutp9X1NcsRw3xHkYO4QyEJCXmpirk+O/LpfM
T3zFQP+fQaLeCjla3D8v3RHOwPdBrDqhUY7+5kfl7tEMJD+5/zzskRw/3/bC
vS6JAV3OSqGJ1Bf7dQ3ngncw8BhqrUVRvvhmpEZ3LZOBa+9GGb3OF9cTdpXd
DwxwWuam9wtfLCUktKaEgTGPjWZE5ocrFtbPXVbJwOzL386JiPFDF5+o2D2X
GFg3HjM/7rQfmtkcXjRxnYG2BHlaQJ8fLh9emR/fzkDtHyHRwfMU6PVdUrpx
D917VdUZFqLAs4vuDG36iwF15eSbmlwFRt+rMGoeY8C7rqkjv1WBQheTY6sn
E3A/uu/TFAMljuT+3XbdlMCN2lGvqTZKXC56e8RYTAB582lnXJW4kde0bZUR
EOvXZxgEKvHp7py6HicC3oXbHrPJSvTYIrFMciOgjJ/T7ZCtxNchTtYTawi0
NmxueV2uRIPYhHOKAAKfXKqTdDYrcdhxQd2tCAIq1+0Txx8qccnIplhIIEAC
VFbit0pcF29/pFdNoLerPnO3mQpbTS3W+OwhMBicNs3+MxWWlKWfKssh8KDK
xlbtoUJ+PG67YxGBq17Bd1sCVRjo9VBffYbA8sCR903fqPBi7dYpH2oJ5DZa
6Qf3qfB9X87exF8JPO1KX+hUrMJDRo7V3XcIZJ98bGFSr0LDF34BKQ8IHFrB
rzS8o8L2wSO72vsJLDE0yvTrU+HbgfAg+38IdPfGXLZ+r8Lxkorys3oCL5dm
a2xncujPp52UmrBw23ZpYamUw6xfbpi3iFh4/vpldrQLhxKVx4ylNizootze
aRQcGt93/en4IhZMvdY+M4vksHVOQ8sCZxaGom58P5TK4WBAvbbak4Vxu/wO
JovDqPonPZN4FlLOZiXcPclh4739p9ShLDj4X57ScYHDTQP1Vi9j6Z6zC5Cb
HI42RAozU1iQvOmPEHRz2FW5LHkwnQXubkgxecWhVcHRgz5ZtJ+XZ98o5NHR
M3F+ax4Lrk26uU0WPBaGdpwwOMbChYNdIrPZPBpvcRN/QS3NnWkcRt1bNt28
iDohIrFPIOJRO7VcEJfPQruNdYy7JY/Dt3ofGBXQ/3duqGr8iMdKfq3W/QQL
P4eXetZZ8yjefHF6ErVCPKtxylweMzQ2e8uonRnN4i+p118Y2j6jmIWeU2nT
RqlNLQ/EdVFLD13TOkl4jO9s9k4tYUEk0fdUzOOxc2TB1TPUODZs9YHa0+Sw
2yPq8oYhudyWR+tl4cTzRxYyZDNPD1DfLtDPs9CxcO7Aw8UyKY/ONZFFXtRu
NYtXp1CX3r71sZo60lQb2ky9beKYWS+1LFmtjpDxOGApPDC7lIWyWYaaKmp/
hxgjH+pwYUHGJDser3j/vjON+sr+FXuV1AvD2Inz1Obv3uwqov4Pu7k0/Q==

       "]], LineBox[CompressedData["
1:eJwVzns41XccB3CUJ+OpEyKzs0IXrXVo9Pv+Ks6cj8O5/oiUaa5TUkRqrpNr
IROZinXkFh2VTuSREO1TwjyPLqKWyxanKVkZttJF7Lc/3s/7ef3zft7mgfu3
BmlpaGi4sPm/e4p/1UAfCjZJGuI2rBCg8vG05jjrmJlqVepKAcYaWM7j+lIQ
yZHcv79KgNz0NO1Y1syY7/C+NQLcFeaou96PgvAzAtsKngD/tWs2LPWnwHxC
nc/ZKMAlfdWrkwMpkHQWB/UxAvQ0LGAEeyggzR0Bm6IFaJ34QtAQScHMgStm
2vcE+Oxc02WfZAqqMqzdus0A307Vn2vPokAR+MPwh/2AAYR2XvMzu89tedR0
G1BJiF99OQWytYMD7QaOKOQ1LrevoWDnkN1B/m5HtJMGh2Q0U5DroKzVv+aI
+hYnreY6KHBrkbknaAqRP+lUGN5LwTH9fJOV7kIUJ0Sm6A5R4J+2Je6oQoiX
rO5NhP5FgSZPwSkYFuKeRyqdtmkKDn4xWVjHc0ItOz2FbB4B8Q4e/eB7J5w6
9bKng0OglVf6Zf8NJ+Qbv8vX5RI43XrWJ2uBM+72ONITZ0mgrSfTPEHmjCPp
JxqGbAl0tsAF6zxndIwxXxrpQEDPMP6NsNcZX/vaLpuTE9h68rDttKkI54dE
XN7iRUDfM4gf7y/CSZt1DV07CThHpCnPFItww1RoCEQQODqVkEfUItwevjZf
HU/gYYgq85iZGLs5S+TSDAKnAvTqJ3zEWF6Zcr7yBIEPbYd/vFAkRo+ZsCSb
EgL+D6ofevSJcYf4j9m6KgKGSe9NqE8leP1a3IKP1wjwe8vSVnwjwQ9/nsg8
0EpgeDRrO50rwZ90bOp+v0fgSlaHR8AdCWq/cPWKHiAw+3RvWKe2FHvH89N6
nxHwtFdZRdlL8d1YoPfafwhot87kGcdIcaZcdfHSLAHGJUe1WiVFT49DZ1fr
0SBIELsZPJdizi+dhneMaVAvd4lI48rQ3N1x0SYLGrY2J/t5uslQt+/rK2es
aGhKNS0YyZBh9+dNd9ZtpkFvfDDd8roMx70a8+pENHS/lWZzpmQY3Ph0SNOD
hqp6o2+3WcrxxqNj5+P9aHgyGvQqykuOoWONJq9CaPjYNk/DIluOb5qCtLKi
aWgPe52ILXIcrLGPGk+hwYgzavr8pRxNigpypTk0JM+l7k9czqCN6MCq7tM0
CDcGa1q5Mljs97h0voIGaUv69o+sdWMcuBtZ8/++WdK1hUF15ULDEtbvdHOM
Q90ZzPvkokZYIQ0j08ezK7cxONmlHtApoiHzq+6yZd4M1nhsyxOU0lDY8z5Y
ew+D3H3XF0ayrhgZTO5hffSIRWYl6yrjieNlexkMuDqRtKiMhgUpl3L5oQxy
lmaHDbKuMcvlRoUzGN7fJoktZ//VFvipIxnsn1p3u4r1kYqB/uooBkV6Jx2e
sJ7x9nZJiGZwmX0gEVXQkHRrsZFJLIN3i2ZXLDlHQ5HmbmuXeAY31weViFkb
1Sp8TQ8xqLzbZRrP2iZ6cepz1olzCn01a5cnN1UpiQyOLdXKNlLSsOu32TrX
JAY91+/VkbI2yEyq/SyZwVuS+4cPsW4vclKOsuZ9R89Vs756wzX3agqD/wEe
/zol
       "]], LineBox[CompressedData["
1:eJwVzns81Xccx3F02YlScRZr5xCKLpLw+/0cjs75fJWcodvReZByOaNCrHKm
i9RRVEZWh5zowjo4dghJIlafaqZtUmKhLE1bpTaL2qyHk7Nff7wf78fzv5ed
/It1MSZGRkZB7D5857nbRriRArNPloXaSPhY1jNqPMS6lM+7Ur2ej7stnCbw
NlFQW3QjSSznI+9wxqTdrG+ey54SmcLH6ARi6hpOgZ1+ebn6Ah/fejdbFkdQ
YOG7punFTBvk9lY7KuUU7GxYqrR4aIMyS3WgeCsFldIHcl+PObhk/6C4QUGB
Cvbo9f12+Kz0atVGJQXXqKLJbnEO+N9IfekPWRTULxh1f/Z8LkbSzIr5pyjQ
qS2OXVI6YhlNh9drKFD4+ReEv3NC38WNtsIaCn4yf/tpRPYC9JZsiTvSTIHM
7CtDj8UinGmf52JopcDDaW7B0b3O6DO8/HRiFwUiEDhUjy3GlamKNNMnFEji
ayKaw5dgpcvd1/GvKJgqjdKtC3PFrQ8ucFpGKQhiEwstl6KJt1nhZxNocORk
bdj+3VIcOflnZ+t0Gt53l+b4Jrmhz6x3+aY8GvZe9yFpDu64WZreuceJhiaZ
JnqgxR3/OJzb8MSdhtepU237kzyQ7LKzUohoGFQlxwRyKfxnk7uNIYCGGZvD
Tk1CCifGba9aHULD0JbaxPTNNA67OTe0fU5DS6v1mXEDjR4j8XGwnQZFbO2L
2BIG1ycuzB9IoeEy0z5qJfTEjuncAMkRGjLMhWWz73qiRptWrs2lQR2YXtC4
TYBSfcIBtyIa4heuMrYeF2DoysfjdRU0hKjnKNoKvLDpyp6P3l+hAWVzbe67
euPY77mZO26x/UvmF89o9sYTHLe6X+/ScLREPRa8VoiTBleFJD+iISttQ8mM
R0LsGsrP6HpGQ0VfXk5hpA++eykPW/iGhhJlgKz/bx/Uay7oKsdp0AbpNRzF
MpRJ9513NGOgLkpwu8pYhDnXf7S8M4sBg3ZfWlK6CO3WEnOBPQNrvj14+7yx
GE17l10848JA0K7sCO0KMXbwr95x9mLAe6oTJzFdjEMhjao6PwZ0RZtiL7WK
cUvj0yfGUgZiuOad7zmA1x5kl6eEMxAxb+3P3isA4182Wv8Vx8Cw1YnU7gzA
f6/GmGQlMyB6xaOVNwD7aoRfDqUxcCKJ+yZyDND6rPq4JIeBwbb7mUoBQTe/
HfM6ChgwGzp4q3cnwXPhPcUTCxmYHxqc2pNE0HSXiOfJ2qVOvqhbQXBAO82y
iLXFakF0VzJB1RSdUcJpBux1T/3b9xIcbht4xDnLgG9Y7+PrBwnWSINV4mIG
7v1WTgpVBHnbmqYpWGtUJzPUuQSPpttnaln33exuzssjGHn59QHzbxgIrong
fJ1PcLrVsYQ+1ra2uZaHCgkmPmzx361hYIe9+9jW8wQfjjh/X8E6NbTzUIyG
oJ9Znqif9WXyi5G8hKCNUE77lTDwljLu2VBGsP3suAO3lIHO5+ZjATqCXvUx
RStZXxztcPSvIFjW3jY7hfXxO3q/5ZUE9xsKZw6wDuzKjhZWEXxpZXLs4zIG
Dme+ifKsJihzjeVIWMdNa5F61BC86X/v0D7Wk+1NvFwvElwcxRiqWUsyK7jO
tQT/B809M6o=
       "]], LineBox[CompressedData["
1:eJwVyXs0lHkcx/Fxq2kmhEFphtwvEb/R8zyF1u8rjXTbwjqc1axVYrWUs7qI
DKcp67ScItoUk1wmKmwrhiy/JXR1r021NTulNpVldrvYLPv0x+e8z+t8bGN2
hcTqcjicjew+daj0OodEUaArH+geKUO46v57nXHWwrEBmUcpwvtNnfWEWymY
2lS3I6sYYeGRwwb7WfMOv/3FtQDh7YkBPC8pBZoWaX66HOF/fFvNzn5FQXOb
qN8tDmHBSJ1TZgwF0OhwtNod4XCzkxtwPAXVDs1ST5UX9sx4iVUpFHwIHMqx
SvfEzytbaqMyKbh/Web9R60H/qBtrOw+SoEL81FkP7EUR9PMGpcfKdCDPiw3
ccNVNC1tLKfgpFDtJ41wwas9mm386ilw3j73OJPphH2D4xKyWyloeyG/daLR
AZvYnVg220PBb1Ua02cL7PGqycDTScMUyDtHF4s32uKggylZPDXrjJb1IZE2
+OKyvomdryiY7ut2tRcLcfy9S9yu9xSklsne9PYvxLq+/OJ1ejTMyzEdNfrZ
HGsLXw/1GNOgqR180RBlildZTBXxhDRoYXNVGTbCO0LlQ6nONGwZiOu9EMzF
o0cKVGpvGlZOh5ZzR3VwwD5byxR/Glz1jy3Rzrz3f7vV23p2PQ2SAv7NHa3P
/fUTdtd+HkHDXWHQ8i6Hi+2TYnfV7W002Knvbj8Y8Wf7cu3OBNjN+lFed4Lk
Q/sXSW5FmjQaDHrnaxpVOmTAWLA+OJuGcDVPT2E3l5Qrs84rC2iIjudOcCbn
k9DpRJlYQcMcoo2ydTIhkUGPZxou0ODU4TXSoi8gV5tS5/7XRINIILiWcseC
fHxWkJPcScN3KzRhN6WLyHGuuOH3PhoaujM/q7QREoOXmyL2PqQh/rW8aWWN
NRkeLzo8/JwGl6xSWeGxJWRqLOZLt79pSH3nY2j/1JZMl1+quThDg4WOaiR7
sT0JD00/58Rn4OPxnifJCQ4kr/2G2R0LBpKXtAWqFI7EdkuA0Uo7BqIjTW+2
3nIivJHPfjqzjIHzdVOKCkMXMiBquePuw8Bw9TXHQdqVjEc05zdIGOBbdZlv
3eNG4pqfqnVCGdh8fZFXSc1S0nbvh/NpUgbSsycr5lx3JzvHmhe+SWDARJn6
2vtfD/KuJVb36F4G5pebXJkVeJJH9X57xrPYvz6r6IqZF1lYcvJYcB4DecvX
rDVQehGxJNlx4BQDaUGr+HxPREql98/qFzOgM7Z6XRxChLfPX7iCdZh2TlKn
NyIapaGZgrWb041taSsQyZ9Xw0k8zcBlVRJ3DBCZvK15yC1hwIjXyXSEIVIf
GpaPzzJgo77kIz2AiPDbq4YprCWyM4KmdES+l9vlKD/5ccaQsQyR6CsTMqMy
BuzaHTm/HkLE2DI38RFrK193c7tcRJIedK3dX86AtWOJ5xMFIg+07tcusNYT
FUXS5xCR8E/4P2HdGlIan1uBiLVfDC2pYGAw5CnlW41Ib8mMvaCSAeczu3IL
LyPi0xirCGJdd8BU/aoBkare21ZprEXrBi0DmhDJmC020bAuzK+jx68iMmap
m2texcDqff2iwDZEwr2+4QazjrU3HztFEOlY238onXXeBtnpvzoQ8fiama1j
3aNcIF7Thcj/i4Egdg==
       "]], LineBox[CompressedData["
1:eJwV0Hs0lHkcx/GZMTUuW45MyRLRMiWh4fk9uT7fL2bcuivHCrU2q8h0OZLZ
csu1UymX2EKUXEoXnRDD2dok2SiWLFGJpRMlZGvbmrHP/vE5n/P6920Ssndz
KI/D4axj9/93nX/IuRtI4XcenzOV3hIo6/3EnWDdHFkTPewpgZgFIjXDIAon
j4oOtkolYJiaMieGtZq+6M4ZVwnsjHTVtAmmcFtAWJq1gwRmHBt1i7dTaNiS
9jpshQSEfTfME0IoDHhn0T8ukICfbt5a2EVhTr2MhmZ3sI57A3VRFL6aFiR/
Q9xhtFRxPTCBwtGyMAPlTTf4Z7q29MFxCsdDvxhoid1gB6Ely3+h8JD0qtr7
ClcoIyS4toTCP4zv3U+1cAW3VfXGTlUUNtQknLItQXD0CgtPa6Sw5uOlUs5S
BB3THKvZFgrtgxTWwnIA5yn3fFk3hQvEv/UkmwF4xEYlag5S2BFVs1UQyMBV
qyeTEeMUvlC4MzujXGBXzzX15k8UzszhUrwjzsBz1DrnrUbw7lph+6dcJ5g+
87arRZugv/Up3vkLjuC86HOupiFB047Oysu3HOAn3+QuuYigmY+z/7peexhJ
za4btCXIxL7yMHm3BlwPmehFMQSTs9MvWwjXwN9BtkazPgStjL/y21bSwA/f
d32DP8HTS+Mub/cmMCW2rGv7kWDT7kfN0T9TYDcdEY77CBpkDJ4qyLeDrTKL
3KHDBO34PsxYuy10agt9vNIIpvjJRw7MtYWS8sSK8myCvuKjQXIbMfh+jYwX
FxHc/Hv3ZkHEavje44WqupLgNpIu2JtnAw235QLlbYKKs3Yx1jnW8OWv7GP7
mwjuEcnG/fStIFNdXP38CcHUo9fr+EmWMOfNev/ofrbHIpvM11oroXsiN6V7
lGB/7dslmsUr4PNYyDaLDwRXCk2yYvSXw9eSa1euqtheZ9NzuDfNwc/3yEVz
LRqLioY75FZmkHGnVbd9EY1S7Vh5dOsyMNnkOt/elMa46ZGTOntNQbPP5WaB
FY3DsS4uW74shc4linZLBxoHFGZXRJ7GMOFfn1UtpbEjp/eD+S5DCKsfHuT6
0uicqNErL9SHX3tOVBwOplFjXtODJg09iBirX/wunMY804sObyVC+KgI5R2P
prGlvXiAV6cDA1VOBycSaQylLVtrfp4PiwvzTntl0Kie0re4WqQBYul+s86z
NN4KC0ged+LD+eDeYv45Ghum5q7WFfFB8xBjuIb1WqPGp446fBgqn6dbxDrh
BE9wekQNsjSucCLzaaxcuEHgnqEGU21D/eqFNM7ohu5/9pIHVb5bsqCYxmqD
qvi7SVww3NMwL4q1nGRqC2RcSE82PVbOutE748x6fy7sqJmMn3+Bxsc6RUmD
llzQ1jsZOcDaA2Sj2j0ckD1r9owpodH+6fb6guUceDZteb+S9caHXSXTCzgg
1cphXrJuUz6fm/3vLGPkFEKkl2j03NnoNlMyyzwuVC0TltIYf/DNrfaPKsah
NrTIg3X+hfd/pj9SMWWP2749zDr8wMYRSbGKiZs9pzPEuo9UNDR7qZgxPd7J
hWU0TkpDktONVIyfzW51L9abGCW17oOSuefZkXSEdWBVQIfuQyWz6gd69gZr
lTjQd6BAyfwHjTQOUg==
       "]], LineBox[CompressedData["
1:eJwVzXtUzHkYBvAkpIvul2NbKWTXScvk+/2Nru/b/aaGISMVTSKlTEdpbG0X
ComWlCTJiskWadtWV4xWWtv9NGzXbbRElkppk2ztb/94z3M+53nOeU2EB7eE
KCooKGxi7//svPKbgtSfoOGQ0/ITgzyQdE3NG2HtNCHVFzzngVh79XyjAILr
78R98bWcB0bHUxeIWZdV/ujT1M+DPREOKusCCeaUtAk1u3nwwbpO5+ougoe2
J1nmt/FAt/uOWZKQYMODIPHDOh746uR4QSjBgyLprg05PPgmYRiqogkyp1o4
aS48GLpRU+qfRNA0aHQYP/rAx/G7Nx6nEzSYjRWph/rAbso4f3WRYGndyqn4
Fm+QUBp4t5DgKa7Xp0k7b3BcW21sU0YwNvOB1Q7JJrB23xd2oo7gnp9DDf21
N4GWaZbFXCPBWs06v9E0L7B975QXKSPoMHHS7N6UJ7h+F52sIic4udJOrV/k
Cbcs2sbC/2YtV+0xHvGA0Ge3lRumCLZrbd7+OsgDFK1VL3nMp5g1EzWWLXeH
8ey3nY0aFKO6s0IW+bqDrf70BRUjiu+aDpwraHODvfyUziOrKX5q8c0r57vB
y+Pnq+SWFHfa3rrX3uoKDrEmBtH2FAU6KYaWW11hMsBy2Zwnxedjnft72l1A
KUxU6iOgKOY09YRudoH3HPOq5mCKjg8Da7t6nWHDeHgYiij2KekNtQU4w7bI
NRcG4ygu7gi/HTPsBB0aup7uJyhmKxU/vSx2gsKi5JtF5yl2Vx09kDbnCPzP
EYmcAooBpocSmr53hB2uf85WlLB771LhQkNHqK08sujfSorQdnnr40IHmHlx
Pi3qV4qP/PjSFK4DnFPmVPS3UdTwW60U24CwYNhbcLiX7W+enLPaiSAbuZAq
G6LYMtMfueYDwPQb4c41ExQrXHeppaYCfC68XXxrlmKzV7lUaAzgy4+/ZqbK
4PHQRml5sD1kPHii06LPYKJxX96WXDsw2eywZKMpg07Go+OjMltQ6bb76bIF
g5XbrDPMFG2h48uaFnMrBiM4k6/i7W1gRFCdWeHC4MU/WpXqI61hX/Vf8nl8
Bvuua6WoXreC+89O34wLZFDg0UNevt4I4W+qDd+FMSh7cUZHc/lG+KcmRDH9
MPuf2+2WvJcLfWU2MSPJDOreb1YOLmfAMD/nrHsGg7XZcd7jYxQ4LlGrOnIZ
3Pec/9bZjsKVwK6rSpcYFElS9c2tKajE2htxWX+ejgnW5lIYLFLXKWAd/SQt
ZGA9hczFxQoReQxyEhxU4lZReN882Kucz6Cqj5GsSo1CGX9rJlxlUO1Vrp93
LwGjA7Xq0axrmpO6uF0ETqaYphWxnhQNilc8JbD7l7HEJT8wWHJM3WS6lYCG
wZmIPtbY1LhEUk8gsqfBTVzIeulkwMJiAj3j5o9KWCtqpCtOSAi4qGbZD7CO
0f72yUAhgWU2QupyncHUAb/71fkEWvNnV+jeYLD+97eOB88RsLobUuDKeipS
c8Y/g4CktXlpHGsQxMs80gkkzF3SGmQtyl05YpZK4I2B4hk9CYNBUn8LvaME
fNftV3Zn7dMkOzs/kUC9W/uxeNYp107pjccRWBvEzN1hrWURXycXE/gP4d8e
mA==
       "]]},
     Annotation[#, "Charting`Private`Tag$249055#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1400000, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{1400000, 1550000}, {-76.63473653139253, 67.53949743965529}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7812743715442657`*^9, 3.7812746079810066`*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"4d0a2df9-f0d8-4200-a689-686aae48ce82"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{766, 772},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
Magnification:>1.1 Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 161, 3, 73, "Section",ExpressionUUID->"76f44a64-3640-4015-853c-253782a1e72b"],
Cell[744, 27, 847, 17, 267, "Text",ExpressionUUID->"8ace106f-1d12-470d-8a18-390a34dc8036"],
Cell[1594, 46, 129, 3, 32, "Input",ExpressionUUID->"55847610-67ca-4f38-aeb1-a844655f3306"],
Cell[1726, 51, 318, 8, 90, "Text",ExpressionUUID->"d99e1840-adba-448c-843c-48952433b680"],
Cell[2047, 61, 172, 4, 32, "Input",ExpressionUUID->"d1d0f014-0b03-4cf0-b945-7788706b1f9f"],
Cell[2222, 67, 501, 9, 90, "Text",ExpressionUUID->"10dcd794-0ded-4b17-98b6-28c3bd4c2b45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2760, 81, 170, 3, 73, "Section",ExpressionUUID->"2c949d39-4642-4878-b2d5-425a5476d010"],
Cell[2933, 86, 360, 8, 65, "Text",ExpressionUUID->"7aa7650f-8547-41cc-b663-6c05ba659465"],
Cell[3296, 96, 1928, 52, 341, "Input",ExpressionUUID->"9b62f570-9d32-43d0-bb28-041fb8721c0e"],
Cell[5227, 150, 276, 7, 65, "Text",ExpressionUUID->"52ffb717-368c-4b9d-a782-f77549e168ac"],
Cell[CellGroupData[{
Cell[5528, 161, 1255, 30, 143, "Input",ExpressionUUID->"eed5f51d-b24e-4bcb-adb5-f363a6ffff8f"],
Cell[6786, 193, 702, 10, 36, "Output",ExpressionUUID->"f0b793c1-aad1-4a59-aecf-b85321ad2e3c"],
Cell[7491, 205, 705, 10, 36, "Output",ExpressionUUID->"c9bfaff2-affa-4aff-87c9-60b852aa79a3"],
Cell[8199, 217, 706, 10, 36, "Output",ExpressionUUID->"b30ab26f-94d8-47d2-8ad0-ea5b223a7330"],
Cell[8908, 229, 707, 10, 36, "Output",ExpressionUUID->"20a8bd31-123e-4d01-ab27-148237066307"],
Cell[9618, 241, 705, 10, 36, "Output",ExpressionUUID->"1fb743bc-97af-4f3e-83cc-ffa4df6b4d77"],
Cell[10326, 253, 708, 10, 36, "Output",ExpressionUUID->"4e10d356-43cf-4924-9244-388a899b8bb2"]
}, Open  ]],
Cell[11049, 266, 178, 3, 39, "Text",ExpressionUUID->"1b02befe-9f27-4d7b-9b86-fd7d7ba37a76"],
Cell[CellGroupData[{
Cell[11252, 273, 311, 5, 55, "Input",ExpressionUUID->"9d88ee5c-dd9f-41fc-b63c-1319bff39f23"],
Cell[11566, 280, 401, 5, 36, "Output",ExpressionUUID->"606b3597-d7c7-40b4-bf8c-c24951597b83"],
Cell[11970, 287, 402, 5, 36, "Output",ExpressionUUID->"68b4fa3c-ddb8-4620-9874-bfdb481071fd"]
}, Open  ]],
Cell[12387, 295, 190, 3, 39, "Text",ExpressionUUID->"cad05219-547c-4eb4-a8a0-097140813e89"],
Cell[CellGroupData[{
Cell[12602, 302, 433, 10, 55, "Input",ExpressionUUID->"b28fa99f-f261-4998-bd96-ae7ada529644"],
Cell[13038, 314, 409, 5, 36, "Output",ExpressionUUID->"1dfb6d0b-55af-4d9f-824c-c5c2eb4baef4"],
Cell[13450, 321, 410, 5, 36, "Output",ExpressionUUID->"ed11f457-2745-446f-8b7e-85f6c8611822"]
}, Open  ]],
Cell[13875, 329, 331, 6, 39, "Text",ExpressionUUID->"3ea15f92-97af-40f3-be55-67f7aa441b32"],
Cell[CellGroupData[{
Cell[14231, 339, 2359, 58, 99, "Input",ExpressionUUID->"86e507a9-b397-4fb3-a36c-5ca6a54dbca0"],
Cell[16593, 399, 58811, 1110, 375, "Output",ExpressionUUID->"eccae03c-40c2-4347-a14d-62a070c6418a"]
}, Open  ]],
Cell[75419, 1512, 270, 6, 39, "Text",ExpressionUUID->"fcbfd747-7689-4e2e-9b44-0c0cbfa1814c"],
Cell[CellGroupData[{
Cell[75714, 1522, 2596, 68, 121, "Input",ExpressionUUID->"22d74ead-4ab9-42ce-a378-44a9035d88e7"],
Cell[78313, 1592, 323681, 7134, 389, "Output",ExpressionUUID->"1141bbdb-22d7-4d36-b510-f5a88bc512de"]
}, Open  ]],
Cell[402009, 8729, 385, 8, 65, "Text",ExpressionUUID->"d9446298-22ab-496b-ba23-6ec95bf6c5af"],
Cell[CellGroupData[{
Cell[402419, 8741, 2012, 61, 121, "Input",ExpressionUUID->"1ab2561c-db48-4c4c-8ef9-54d5c2ee361b"],
Cell[404434, 8804, 80744, 1579, 376, "Output",ExpressionUUID->"23232154-ad2b-429d-9d1f-085905c54942"]
}, Open  ]],
Cell[485193, 10386, 291, 6, 65, "Text",ExpressionUUID->"a0071a78-2c80-4093-94e2-8f873681d733"],
Cell[CellGroupData[{
Cell[485509, 10396, 2307, 68, 143, "Input",ExpressionUUID->"7998b808-f190-41c4-ac76-c9775db01441"],
Cell[487819, 10466, 28372, 599, 383, "Output",ExpressionUUID->"49f9c008-172d-498d-8769-300857600cfb"]
}, Open  ]],
Cell[516206, 11068, 217, 5, 39, "Text",ExpressionUUID->"f9b7678e-3504-4ebd-bb22-a3a8f476b09b"],
Cell[CellGroupData[{
Cell[516448, 11077, 347, 7, 59, "Input",ExpressionUUID->"fbf4d63a-ce66-4aa8-8667-0840240ad5da"],
Cell[516798, 11086, 390, 5, 36, "Output",ExpressionUUID->"ca33e8fd-0b6d-4d05-a731-509eff2616d9"]
}, Open  ]],
Cell[517203, 11094, 484, 9, 65, "Text",ExpressionUUID->"f6234b57-52c0-49af-879b-9489e628d99a"],
Cell[CellGroupData[{
Cell[517712, 11107, 990, 24, 84, "Input",ExpressionUUID->"e28c71ec-7d80-4065-8310-1cb6690a6769"],
Cell[518705, 11133, 510, 8, 36, "Output",ExpressionUUID->"7da6bb1b-7c41-4dd8-b141-dae6ff5f708e"],
Cell[519218, 11143, 3666, 78, 255, "Output",ExpressionUUID->"037a6b8c-3b60-455f-ac8a-7cfb13337208"]
}, Open  ]],
Cell[522899, 11224, 551, 10, 141, "Text",ExpressionUUID->"60049ab4-9ada-431e-a3c1-937507ae6211"],
Cell[CellGroupData[{
Cell[523475, 11238, 1516, 38, 175, "Input",ExpressionUUID->"072db138-d4b1-432b-8542-5e9bdcbfa5ac"],
Cell[524994, 11278, 443, 7, 36, "Output",ExpressionUUID->"b47acaec-deb7-4d91-a850-aed3affa2dac"],
Cell[525440, 11287, 539, 10, 41, "Output",ExpressionUUID->"ba5aa13e-783f-4a56-afe0-9d318bee44cc"],
Cell[525982, 11299, 719, 16, 54, "Output",ExpressionUUID->"7d43a927-ea08-4eae-80ce-f7cfdadd8931"],
Cell[526704, 11317, 567, 10, 60, "Output",ExpressionUUID->"60eb08c0-19c8-4b82-beb5-2b824f8a9be7"],
Cell[527274, 11329, 982, 23, 66, "Output",ExpressionUUID->"eb421c0e-6274-4026-836f-d4fb35d9eed7"],
Cell[528259, 11354, 944, 21, 66, "Output",ExpressionUUID->"f6fe80ca-567a-4f26-a129-276d8d164ce6"]
}, Open  ]],
Cell[529218, 11378, 267, 6, 65, "Text",ExpressionUUID->"55eb7ba4-32dc-40d5-837f-bd7c90f3fd36"],
Cell[CellGroupData[{
Cell[529510, 11388, 1228, 29, 77, "Input",ExpressionUUID->"ed7767cb-afc2-42c8-99b5-69dd81cd402c"],
Cell[530741, 11419, 12884, 232, 266, "Output",ExpressionUUID->"de7841c2-9aba-4354-9415-c2078feb1c92"]
}, Open  ]],
Cell[543640, 11654, 244, 6, 39, "Text",ExpressionUUID->"ed6caa2f-6776-4a89-99d3-6d7a40ce4993"],
Cell[CellGroupData[{
Cell[543909, 11664, 805, 19, 118, "Input",ExpressionUUID->"88b835c3-1c57-403b-b368-4fc903fa1b1b"],
Cell[544717, 11685, 7400, 140, 272, "Output",ExpressionUUID->"ad141207-0aae-470d-858f-d91787cabab5"]
}, Open  ]],
Cell[552132, 11828, 198, 3, 39, "Text",ExpressionUUID->"c435ab49-f6e7-453d-988b-0a2afeda74f7"],
Cell[CellGroupData[{
Cell[552355, 11835, 931, 24, 77, "Input",ExpressionUUID->"5c21ea93-39de-46e4-aaca-95ce00ae83d3"],
Cell[553289, 11861, 518, 7, 38, "Output",ExpressionUUID->"7cffa8af-077c-4691-ac20-ec1010a8756c"],
Cell[553810, 11870, 520, 7, 38, "Output",ExpressionUUID->"f9f26bcc-382c-422c-9694-675a0a945f1a"],
Cell[554333, 11879, 519, 7, 38, "Output",ExpressionUUID->"74e1f395-55a8-44a0-80e8-53f1b535f204"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[554901, 11892, 182, 3, 73, "Section",ExpressionUUID->"620891fb-8db6-4337-9a8c-103c21ff3f89"],
Cell[555086, 11897, 211, 5, 39, "Text",ExpressionUUID->"5d1faba4-076c-4bba-ac0d-d8c6c78446b5"],
Cell[CellGroupData[{
Cell[555322, 11906, 556, 14, 55, "Input",ExpressionUUID->"04939220-d3a7-45dc-ac36-99c1bb769d41"],
Cell[555881, 11922, 432, 6, 36, "Output",ExpressionUUID->"8c401f83-214e-48ce-8ae8-082ffb80b046"],
Cell[556316, 11930, 434, 6, 36, "Output",ExpressionUUID->"a1db8b47-0d73-47a4-81fd-ccd8d8f36cb2"]
}, Open  ]],
Cell[556765, 11939, 227, 5, 39, "Text",ExpressionUUID->"1efa6937-b1a4-465d-9670-66b3c297f934"],
Cell[CellGroupData[{
Cell[557017, 11948, 4572, 121, 231, "Input",ExpressionUUID->"b6f6c647-2ec4-42a7-b829-47b78b7246f0"],
Cell[561592, 12071, 3377, 75, 262, "Output",ExpressionUUID->"bd152e72-59af-437c-a764-dc1cfd4daade"],
Cell[564972, 12148, 3379, 75, 262, "Output",ExpressionUUID->"dbad26ee-e9fa-438e-9ad4-a275d6a3a22b"]
}, Open  ]],
Cell[568366, 12226, 182, 3, 39, "Text",ExpressionUUID->"031829c0-60a0-408c-aef5-58f2a05b41b8"],
Cell[568551, 12231, 1314, 28, 55, "Input",ExpressionUUID->"5b5acca3-a1c3-442b-a9a0-9f9740f9fe63"],
Cell[569868, 12261, 384, 10, 32, "Input",ExpressionUUID->"7c536099-2408-4e7e-99bd-56967249d524"],
Cell[570255, 12273, 371, 8, 90, "Text",ExpressionUUID->"9a97cf0e-61a3-4832-bb1c-780b6e99a5be"],
Cell[CellGroupData[{
Cell[570651, 12285, 2357, 59, 121, "Input",ExpressionUUID->"b0dd1d5a-3d85-4824-97dd-af14346f9d29"],
Cell[573011, 12346, 4316, 87, 260, "Output",ExpressionUUID->"433d4fec-1805-4c60-b8c8-7f01d0bea84e"]
}, Open  ]],
Cell[577342, 12436, 195, 3, 39, "Text",ExpressionUUID->"40cd50d9-d978-4a26-b693-d29706cd3832"],
Cell[CellGroupData[{
Cell[577562, 12443, 518, 10, 55, "Input",ExpressionUUID->"fbd740d1-0f33-4cda-aaae-6008d43d70b9"],
Cell[578083, 12455, 512, 7, 36, "Output",ExpressionUUID->"e135f168-5258-4d27-962b-919596f0f46d"],
Cell[578598, 12464, 515, 7, 36, "Output",ExpressionUUID->"e20bb5a4-056d-4143-9fbd-6c29bb52b015"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[579162, 12477, 156, 3, 73, "Section",ExpressionUUID->"544ba0d5-6e9d-4dad-bde5-3e028f55dcea"],
Cell[579321, 12482, 231, 6, 39, "Text",ExpressionUUID->"782ad1c4-4df8-4e93-8189-c67ac7852813"],
Cell[CellGroupData[{
Cell[579577, 12492, 979, 24, 77, "Input",ExpressionUUID->"78477ed8-c163-4936-8b2a-4aaf06ef625c"],
Cell[580559, 12518, 630, 10, 38, "Output",ExpressionUUID->"3b32e023-e79d-44c8-97e6-ea34703f83ad"],
Cell[581192, 12530, 3544, 74, 260, "Output",ExpressionUUID->"f9eebc49-09b3-4509-84d6-2e9860d4715d"]
}, Open  ]],
Cell[584751, 12607, 210, 5, 39, "Text",ExpressionUUID->"63b5cc77-72fe-4153-be3e-0252af3cef17"],
Cell[CellGroupData[{
Cell[584986, 12616, 519, 12, 55, "Input",ExpressionUUID->"e1806262-93dc-4d63-b606-e5f7713c8ee9"],
Cell[585508, 12630, 3489, 74, 258, "Output",ExpressionUUID->"82340e7c-211c-4a80-be15-8dc0dbbf6c4f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[589046, 12710, 174, 3, 73, "Section",ExpressionUUID->"61f361cb-02f6-4997-b8fe-b9c56e893a1c"],
Cell[589223, 12715, 453, 9, 115, "Text",ExpressionUUID->"ead1bcde-4f2e-4dde-aa3d-7d0c131553ad"],
Cell[CellGroupData[{
Cell[589701, 12728, 1198, 28, 148, "Input",ExpressionUUID->"97721cdb-ef55-46b1-ad44-174b1f0255cb"],
Cell[590902, 12758, 891, 17, 42, "Output",ExpressionUUID->"d6997b62-7771-41bc-884a-6f094a567f60"],
Cell[591796, 12777, 827, 15, 38, "Output",ExpressionUUID->"9464bfc6-5b90-45ba-84eb-95242065587f"],
Cell[592626, 12794, 663, 9, 36, "Output",ExpressionUUID->"6bb2d641-cc55-4620-b68a-5fb446f3d891"]
}, Open  ]],
Cell[593304, 12806, 241, 6, 39, "Text",ExpressionUUID->"9f92af0d-bff5-406b-8cb6-24e09d885bf1"],
Cell[CellGroupData[{
Cell[593570, 12816, 1201, 31, 158, "Input",ExpressionUUID->"091a69c4-6a8b-434c-b9ff-dd9e0e403db5"],
Cell[594774, 12849, 3690, 76, 263, "Output",ExpressionUUID->"ea79196d-3e7c-4771-b791-4f5b2660d437"],
Cell[598467, 12927, 807, 15, 56, "Output",ExpressionUUID->"89fde538-78c8-4885-ac7c-f7810bd25256"],
Cell[599277, 12944, 3669, 76, 259, "Output",ExpressionUUID->"c07a9e91-881d-4712-807e-026b54b640fb"],
Cell[602949, 13022, 3448, 72, 262, "Output",ExpressionUUID->"267ece82-a0c7-4bfa-8b3b-85b2176b78e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[606434, 13099, 243, 5, 32, "Input",ExpressionUUID->"a74b1deb-7d1b-48f6-9102-880b5c3939d4"],
Cell[606680, 13106, 338, 5, 36, "Output",ExpressionUUID->"2ed5d397-c4d1-4350-bdfd-0339ea6ab7a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[607055, 13116, 480, 14, 59, "Input",ExpressionUUID->"6809f8f0-df4a-427e-8bb2-6902c33cdb8b"],
Cell[607538, 13132, 602, 15, 42, "Output",ExpressionUUID->"8568f48c-42f3-4fd7-a9d0-846caaecc037"]
}, Open  ]],
Cell[608155, 13150, 187, 3, 39, "Text",ExpressionUUID->"88d9e4f4-077d-47b9-9f6c-bb47fae3d90e"],
Cell[CellGroupData[{
Cell[608367, 13157, 538, 14, 34, "Input",ExpressionUUID->"da178b20-31e4-433a-85fb-ef29cd44c6e8"],
Cell[608908, 13173, 583, 14, 56, "Output",ExpressionUUID->"ba829ba0-8b33-4e93-bcd6-cd739beeda0e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[609528, 13192, 453, 9, 32, "Input",ExpressionUUID->"bb3b9f4f-586b-470b-8bca-5a4536e98f4e"],
Cell[609984, 13203, 3511, 75, 255, "Output",ExpressionUUID->"1c6799bd-110d-42db-beda-79a1df65b385"]
}, Open  ]],
Cell[CellGroupData[{
Cell[613532, 13283, 244, 5, 32, "Input",ExpressionUUID->"95e20719-5d53-425c-82e3-99ba7d9782ee"],
Cell[613779, 13290, 320, 5, 36, "Output",ExpressionUUID->"dcbca48b-05d2-4241-acd8-f289961c9c41"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614136, 13300, 230, 5, 32, "Input",ExpressionUUID->"3aca5fca-941a-46a0-bee3-e1703c9d223b"],
Cell[614369, 13307, 335, 5, 36, "Output",ExpressionUUID->"2928650a-22fc-4dfb-9ab1-048ab4a25431"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614741, 13317, 273, 6, 32, "Input",ExpressionUUID->"8c54fdde-989c-4b9a-af4e-cd126ca3a661"],
Cell[615017, 13325, 648, 14, 43, "Message",ExpressionUUID->"8c4e1aad-e94b-48c0-8da6-bb6f185a68a8"],
Cell[615668, 13341, 472, 10, 36, "Output",ExpressionUUID->"7870bfd7-6ed2-4f48-8001-6456bcc457d5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[616189, 13357, 185, 3, 73, "Section",ExpressionUUID->"a9ebe4d5-923a-4d4c-9594-d38d6414875f"],
Cell[616377, 13362, 340, 7, 65, "Text",ExpressionUUID->"8c88e398-5610-4edf-8db3-3e6e7c250f23"],
Cell[616720, 13371, 369, 10, 32, "Input",ExpressionUUID->"81b67756-2872-45ba-8756-9ce29d9e8f1d"],
Cell[617092, 13383, 399, 8, 65, "Text",ExpressionUUID->"e530beb9-a5f4-4ab2-b20b-f75c442f1b23"],
Cell[617494, 13393, 1219, 36, 99, "Input",ExpressionUUID->"c52f4fca-e979-446e-bacb-d38e95d650b7"],
Cell[618716, 13431, 186, 3, 39, "Text",ExpressionUUID->"ac353873-f12a-4857-8ed1-cc0c608ddada"],
Cell[618905, 13436, 346, 9, 32, "Input",ExpressionUUID->"c8c2e9e4-3ec7-4dbe-806e-41a4a9681ec9"],
Cell[619254, 13447, 668, 13, 217, "Text",ExpressionUUID->"6db50a6b-ef1d-48cc-8fb7-00b6f3fee1ec"],
Cell[CellGroupData[{
Cell[619947, 13464, 3906, 72, 193, "Input",ExpressionUUID->"78fd872c-a231-41c5-994d-c01fca417298"],
Cell[623856, 13538, 6643, 123, 262, "Output",ExpressionUUID->"284048ea-8091-4124-9534-de5c8599d6bb"],
Cell[630502, 13663, 5013, 96, 262, "Output",ExpressionUUID->"aa0e2570-06af-42c5-8d37-411026fdd2ab"]
}, Open  ]],
Cell[635530, 13762, 437, 8, 115, "Text",ExpressionUUID->"052b822e-914d-4e8b-917e-d93d4696fe2f"],
Cell[CellGroupData[{
Cell[635992, 13774, 1554, 45, 143, "Input",ExpressionUUID->"94fc0de4-64d7-498d-b37a-2b3e898fac34"],
Cell[637549, 13821, 496, 13, 36, "Output",ExpressionUUID->"5819bbc5-8385-4122-b5a5-f2f47d139cec"],
Cell[638048, 13836, 216, 4, 36, "Output",ExpressionUUID->"a5485153-b1b7-4baf-9e08-5a2e5520e6ee"],
Cell[638267, 13842, 11717, 216, 255, "Output",ExpressionUUID->"4d0a2df9-f0d8-4200-a689-686aae48ce82"]
}, Open  ]]
}, Open  ]]
}
]
*)

